#
# spec file for package texlive-filesystem
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

%define texlive_version  2023
%define texlive_previous 2022
%define texlive_release  20230311
%define texlive_noarch   208
%define texlive_source   texlive-20230311-source
%define biber_version    2.19

%define __perl_requires		%{nil}
%define __os_install_post	/usr/lib/rpm/brp-compress \\\
  %(ls /usr/lib/rpm/brp-suse.d/* 2> /dev/null | grep -vE 'symlink|desktop') %{nil}

%bcond_with     zypper_posttrans

Name:           texlive-filesystem
Version:        %{texlive_version}.%{texlive_noarch}
Release:        60.1
Summary:        Basic file system of TeX Live
License:        Apache-2.0 AND Artistic-1.0 AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND LPPL-1.3c AND LPPL-1.0 AND MIT AND BSD-3-Clause AND SUSE-TeX AND SUSE-Public-Domain
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
%if 0%{?suse_version} <= 1550
Requires:       cron
%else
Requires:       rpm_macro(_unitdir)
%endif
Requires:       python3
Requires(pre):  user(mktex)
Requires(pre):  group(mktex)
Requires(pre):  /usr/bin/stat
%if 0%{?suse_version} > 1550
Requires(pre):  rpm_macro(service_add_pre)
%endif
Requires(post): %fillup_prereq
Requires(post): permissions
Requires(post): /usr/bin/mktemp
Requires(post): /usr/bin/mv
Requires(post): /usr/bin/setpriv
%if 0%{?suse_version} > 1550
Requires(pre):  rpm_macro(service_add_post)
%endif
Requires(postun):coreutils
Requires(postun):ed
Requires(postun):findutils
Requires(postun):grep
Requires(postun):sed
%if 0%{?suse_version} > 1550
Requires(pre):  rpm_macro(service_del_postun)
%endif
Requires(pre):  /usr/bin/perl
Requires(pre):  /usr/bin/clear
Requires(pre):  /usr/bin/dialog
Requires(pre):  coreutils
Requires(pre):  ed
Requires(pre):  findutils
Requires(pre):  grep
Requires(pre):  sed
%if 0%{?suse_version} > 1550
Requires(preun):rpm_macro(service_del_preun)
%endif
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Requires(verify):permissions
Obsoletes:      tetex <= %{texlive_previous}
BuildRequires:  cron
BuildRequires:  ed
BuildRequires:  fontconfig
#BuildConflicts: texinfo
Source10:       rc.config.texlive
Source11:       update.texlive
Source12:       texlive.cron
Source13:       texlive.sh
Source14:       texlive.csh
Source15:       fc-texlive.conf
Source16:       fc-t1-texlive.conf
Source17:       fc-truetype-texlive.conf
Source18:       texlive.timer
Source19:       texlive.service
Source20:       texlive-initial.service
Source30:       texlive-filesystem-rpmlintrc
Source31:       dot.dvipsrc
Source42:       zypplugin.in
# Download at ftp://ftp.tug.org/texlive/tlpretest/archive/
# from 20230311
Source1000:     scheme-basic.tar.xz
Source1001:     scheme-bookpub.tar.xz
Source1002:     scheme-context.tar.xz
Source1003:     scheme-full.tar.xz
Source1004:     scheme-gust.tar.xz
Source1005:     scheme-infraonly.tar.xz
Source1006:     scheme-medium.tar.xz
Source1007:     scheme-minimal.tar.xz
Source1008:     scheme-small.tar.xz
Source1009:     scheme-tetex.tar.xz
Source1010:     collection-basic.tar.xz
Source1011:     collection-bibtexextra.tar.xz
Source1012:     collection-binextra.tar.xz
Source1013:     collection-context.tar.xz
Source1014:     collection-fontsextra.tar.xz
Source1015:     collection-fontsrecommended.tar.xz
Source1016:     collection-fontutils.tar.xz
Source1017:     collection-formatsextra.tar.xz
Source1018:     collection-games.tar.xz
Source1019:     collection-humanities.tar.xz
Source1020:     collection-langarabic.tar.xz
Source1021:     collection-langchinese.tar.xz
Source1022:     collection-langcjk.tar.xz
Source1023:     collection-langcyrillic.tar.xz
Source1024:     collection-langczechslovak.tar.xz
Source1025:     collection-langenglish.tar.xz
Source1026:     collection-langeuropean.tar.xz
Source1027:     collection-langfrench.tar.xz
Source1028:     collection-langgerman.tar.xz
Source1029:     collection-langgreek.tar.xz
Source1030:     collection-langitalian.tar.xz
Source1031:     collection-langjapanese.tar.xz
Source1032:     collection-langkorean.tar.xz
Source1033:     collection-langother.tar.xz
Source1034:     collection-langpolish.tar.xz
Source1035:     collection-langportuguese.tar.xz
Source1036:     collection-langspanish.tar.xz
Source1037:     collection-latex.tar.xz
Source1038:     collection-latexextra.tar.xz
Source1039:     collection-latexrecommended.tar.xz
Source1040:     collection-luatex.tar.xz
Source1041:     collection-mathscience.tar.xz
Source1042:     collection-metapost.tar.xz
Source1043:     collection-music.tar.xz
Source1044:     collection-pictures.tar.xz
Source1045:     collection-plaingeneric.tar.xz
Source1046:     collection-pstricks.tar.xz
Source1047:     collection-publishers.tar.xz
Source1048:     collection-xetex.tar.xz
BuildArch:      noarch
Prefix:         %{_bindir}
# skip-check-libtool-deps

%global _varlib		%{_localstatedir}/lib

%define _texmfdistdir	%{_datadir}/texmf
%if 0%{texlive_version} >= 2013
%define _texmfmaindir	%{_texmfdistdir}
%define _texmfdirs	%{_texmfdistdir}
%else
%define _texmfmaindir	%{_libexecdir}/texmf
%define _texmfdirs	\{%{_texmfdistdir},%{_texmfmaindir}\}
%endif

%define _texmfconfdir	%{_sysconfdir}/texmf
%define _texmfvardir	%{_varlib}/texmf
%define _texmfcache	%{_localstatedir}/cache/texmf
%define _fontcache	%{_texmfcache}/fonts
#
%define _x11bin		%{_prefix}/bin
%define _x11lib		%{_libdir}
%define _x11data	%{_datadir}/X11
%define _x11inc		%{_includedir}
%define _appdefdir	%{_x11data}/app-defaults
#
%define texgrp          mktex
%define texusr          mktex

#define texgid          505
#define texuid          505
#
%description
The basic file system layout for TeX Live installation.

%package -n texlive-scheme-basic
Version:        %{texlive_version}.%{texlive_noarch}.svn54191
Release:        60.1
License:        LPPL-1.0
Summary:        Basic scheme (plain and latex)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
BuildArch:      noarch

%description -n texlive-scheme-basic
This is the basic TeX Live scheme: it is a small set of files
sufficient to typeset plain TeX or LaTeX documents in
PostScript or PDF, using the Computer Modern fonts. This scheme
corresponds to collection-basic and collection-latex.

%package -n texlive-scheme-bookpub
Version:        %{texlive_version}.%{texlive_noarch}.svn63547
Release:        60.1
License:        LPPL-1.0
Summary:        Book publishing scheme (core LaTeX and add-ons)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-barcodes >= %{texlive_version}
#!BuildIgnore: texlive-barcodes
Requires:       texlive-biber >= %{texlive_version}
#!BuildIgnore: texlive-biber
Requires:       texlive-biblatex >= %{texlive_version}
#!BuildIgnore: texlive-biblatex
Requires:       texlive-bookcover >= %{texlive_version}
#!BuildIgnore: texlive-bookcover
Requires:       texlive-caption >= %{texlive_version}
#!BuildIgnore: texlive-caption
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-enumitem >= %{texlive_version}
#!BuildIgnore: texlive-enumitem
Requires:       texlive-fontspec >= %{texlive_version}
#!BuildIgnore: texlive-fontspec
Requires:       texlive-latexmk >= %{texlive_version}
#!BuildIgnore: texlive-latexmk
Requires:       texlive-lipsum >= %{texlive_version}
#!BuildIgnore: texlive-lipsum
Requires:       texlive-listings >= %{texlive_version}
#!BuildIgnore: texlive-listings
Requires:       texlive-markdown >= %{texlive_version}
#!BuildIgnore: texlive-markdown
Requires:       texlive-memoir >= %{texlive_version}
#!BuildIgnore: texlive-memoir
Requires:       texlive-microtype >= %{texlive_version}
#!BuildIgnore: texlive-microtype
Requires:       texlive-minted >= %{texlive_version}
#!BuildIgnore: texlive-minted
Requires:       texlive-novel >= %{texlive_version}
#!BuildIgnore: texlive-novel
Requires:       texlive-octavo >= %{texlive_version}
#!BuildIgnore: texlive-octavo
Requires:       texlive-pdfpages >= %{texlive_version}
#!BuildIgnore: texlive-pdfpages
Requires:       texlive-pgf >= %{texlive_version}
#!BuildIgnore: texlive-pgf
Requires:       texlive-qrcode >= %{texlive_version}
#!BuildIgnore: texlive-qrcode
Requires:       texlive-shapes >= %{texlive_version}
#!BuildIgnore: texlive-shapes
Requires:       texlive-titlesec >= %{texlive_version}
#!BuildIgnore: texlive-titlesec
Requires:       texlive-tocloft >= %{texlive_version}
#!BuildIgnore: texlive-tocloft
Requires:       texlive-tufte-latex >= %{texlive_version}
#!BuildIgnore: texlive-tufte-latex
Requires:       texlive-willowtreebook >= %{texlive_version}
#!BuildIgnore: texlive-willowtreebook
BuildArch:      noarch

%description -n texlive-scheme-bookpub
This is a book publishing scheme, containing core (Lua)LaTeX
and selected additional packages likely to be useful for
non-technical book publication. It does not contain additional
fonts (different books need different fonts, and the packages
are large), nor does it contain additional mathematical or
other technical packages.

%package -n texlive-scheme-context
Version:        %{texlive_version}.%{texlive_noarch}.svn59636
Release:        60.1
License:        LPPL-1.0
Summary:        ConTeXt scheme
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-antt >= %{texlive_version}
#!BuildIgnore: texlive-antt
Requires:       texlive-asana-math >= %{texlive_version}
#!BuildIgnore: texlive-asana-math
Requires:       texlive-ccicons >= %{texlive_version}
#!BuildIgnore: texlive-ccicons
Requires:       texlive-collection-context >= %{texlive_version}
#!BuildIgnore: texlive-collection-context
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-dejavu >= %{texlive_version}
#!BuildIgnore: texlive-dejavu
Requires:       texlive-eulervm >= %{texlive_version}
#!BuildIgnore: texlive-eulervm
Requires:       texlive-gentium-tug >= %{texlive_version}
#!BuildIgnore: texlive-gentium-tug
Requires:       texlive-iwona >= %{texlive_version}
#!BuildIgnore: texlive-iwona
Requires:       texlive-kurier >= %{texlive_version}
#!BuildIgnore: texlive-kurier
Requires:       texlive-ly1 >= %{texlive_version}
#!BuildIgnore: texlive-ly1
Requires:       texlive-manfnt-font >= %{texlive_version}
#!BuildIgnore: texlive-manfnt-font
Requires:       texlive-marvosym >= %{texlive_version}
#!BuildIgnore: texlive-marvosym
Requires:       texlive-mflogo-font >= %{texlive_version}
#!BuildIgnore: texlive-mflogo-font
Requires:       texlive-poltawski >= %{texlive_version}
#!BuildIgnore: texlive-poltawski
Requires:       texlive-pxfonts >= %{texlive_version}
#!BuildIgnore: texlive-pxfonts
Requires:       texlive-tex-gyre >= %{texlive_version}
#!BuildIgnore: texlive-tex-gyre
Requires:       texlive-tex-gyre-math >= %{texlive_version}
#!BuildIgnore: texlive-tex-gyre-math
Requires:       texlive-txfonts >= %{texlive_version}
#!BuildIgnore: texlive-txfonts
Requires:       texlive-wasy >= %{texlive_version}
#!BuildIgnore: texlive-wasy
Requires:       texlive-xits >= %{texlive_version}
#!BuildIgnore: texlive-xits
Provides:       tex(context)
BuildArch:      noarch

%description -n texlive-scheme-context
This is the TeX Live scheme for installing ConTeXt.

%package -n texlive-scheme-full
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Full scheme (everything)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-bibtexextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-bibtexextra
Requires:       texlive-collection-binextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-binextra
Requires:       texlive-collection-context >= %{texlive_version}
#!BuildIgnore: texlive-collection-context
Requires:       texlive-collection-fontsextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsextra
Requires:       texlive-collection-fontsrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsrecommended
Requires:       texlive-collection-fontutils >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontutils
Requires:       texlive-collection-formatsextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-formatsextra
Requires:       texlive-collection-games >= %{texlive_version}
#!BuildIgnore: texlive-collection-games
Requires:       texlive-collection-humanities >= %{texlive_version}
#!BuildIgnore: texlive-collection-humanities
Requires:       texlive-collection-langarabic >= %{texlive_version}
#!BuildIgnore: texlive-collection-langarabic
Requires:       texlive-collection-langchinese >= %{texlive_version}
#!BuildIgnore: texlive-collection-langchinese
Requires:       texlive-collection-langcjk >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcjk
Requires:       texlive-collection-langcyrillic >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcyrillic
Requires:       texlive-collection-langczechslovak >= %{texlive_version}
#!BuildIgnore: texlive-collection-langczechslovak
Requires:       texlive-collection-langenglish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langenglish
Requires:       texlive-collection-langeuropean >= %{texlive_version}
#!BuildIgnore: texlive-collection-langeuropean
Requires:       texlive-collection-langfrench >= %{texlive_version}
#!BuildIgnore: texlive-collection-langfrench
Requires:       texlive-collection-langgerman >= %{texlive_version}
#!BuildIgnore: texlive-collection-langgerman
Requires:       texlive-collection-langgreek >= %{texlive_version}
#!BuildIgnore: texlive-collection-langgreek
Requires:       texlive-collection-langitalian >= %{texlive_version}
#!BuildIgnore: texlive-collection-langitalian
Requires:       texlive-collection-langjapanese >= %{texlive_version}
#!BuildIgnore: texlive-collection-langjapanese
Requires:       texlive-collection-langkorean >= %{texlive_version}
#!BuildIgnore: texlive-collection-langkorean
Requires:       texlive-collection-langother >= %{texlive_version}
#!BuildIgnore: texlive-collection-langother
Requires:       texlive-collection-langpolish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langpolish
Requires:       texlive-collection-langportuguese >= %{texlive_version}
#!BuildIgnore: texlive-collection-langportuguese
Requires:       texlive-collection-langspanish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langspanish
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collection-latexextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexextra
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-luatex >= %{texlive_version}
#!BuildIgnore: texlive-collection-luatex
Requires:       texlive-collection-mathscience >= %{texlive_version}
#!BuildIgnore: texlive-collection-mathscience
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-collection-music >= %{texlive_version}
#!BuildIgnore: texlive-collection-music
Requires:       texlive-collection-pictures >= %{texlive_version}
#!BuildIgnore: texlive-collection-pictures
Requires:       texlive-collection-plaingeneric >= %{texlive_version}
#!BuildIgnore: texlive-collection-plaingeneric
Requires:       texlive-collection-pstricks >= %{texlive_version}
#!BuildIgnore: texlive-collection-pstricks
Requires:       texlive-collection-publishers >= %{texlive_version}
#!BuildIgnore: texlive-collection-publishers
Requires:       texlive-collection-xetex >= %{texlive_version}
#!BuildIgnore: texlive-collection-xetex
BuildArch:      noarch

%description -n texlive-scheme-full
This is the full TeX Live scheme: it installs everything
available.

%package -n texlive-scheme-gust
Version:        %{texlive_version}.%{texlive_noarch}.svn59755
Release:        60.1
License:        LPPL-1.0
Summary:        GUST TeX Live scheme
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-amslatex-primer >= %{texlive_version}
#!BuildIgnore: texlive-amslatex-primer
Requires:       texlive-amstex >= %{texlive_version}
#!BuildIgnore: texlive-amstex
Requires:       texlive-antt >= %{texlive_version}
#!BuildIgnore: texlive-antt
Requires:       texlive-bibtex8 >= %{texlive_version}
#!BuildIgnore: texlive-bibtex8
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-context >= %{texlive_version}
#!BuildIgnore: texlive-collection-context
Requires:       texlive-collection-fontsrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsrecommended
Requires:       texlive-collection-fontutils >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontutils
Requires:       texlive-collection-langpolish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langpolish
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-collection-plaingeneric >= %{texlive_version}
#!BuildIgnore: texlive-collection-plaingeneric
Requires:       texlive-collection-xetex >= %{texlive_version}
#!BuildIgnore: texlive-collection-xetex
Requires:       texlive-comment >= %{texlive_version}
#!BuildIgnore: texlive-comment
Requires:       texlive-comprehensive >= %{texlive_version}
#!BuildIgnore: texlive-comprehensive
Requires:       texlive-concrete >= %{texlive_version}
#!BuildIgnore: texlive-concrete
Requires:       texlive-cyklop >= %{texlive_version}
#!BuildIgnore: texlive-cyklop
Requires:       texlive-dvidvi >= %{texlive_version}
#!BuildIgnore: texlive-dvidvi
Requires:       texlive-dviljk >= %{texlive_version}
#!BuildIgnore: texlive-dviljk
Requires:       texlive-fontinstallationguide >= %{texlive_version}
#!BuildIgnore: texlive-fontinstallationguide
Requires:       texlive-gustprog >= %{texlive_version}
#!BuildIgnore: texlive-gustprog
Requires:       texlive-impatient >= %{texlive_version}
#!BuildIgnore: texlive-impatient
Requires:       texlive-iwona >= %{texlive_version}
#!BuildIgnore: texlive-iwona
Requires:       texlive-metafont-beginners >= %{texlive_version}
#!BuildIgnore: texlive-metafont-beginners
Requires:       texlive-metapost-examples >= %{texlive_version}
#!BuildIgnore: texlive-metapost-examples
Requires:       texlive-poltawski >= %{texlive_version}
#!BuildIgnore: texlive-poltawski
Requires:       texlive-seetexk >= %{texlive_version}
#!BuildIgnore: texlive-seetexk
Requires:       texlive-seminar >= %{texlive_version}
#!BuildIgnore: texlive-seminar
Requires:       texlive-tds >= %{texlive_version}
#!BuildIgnore: texlive-tds
Requires:       texlive-tex4ht >= %{texlive_version}
#!BuildIgnore: texlive-tex4ht
Requires:       texlive-texdoc >= %{texlive_version}
#!BuildIgnore: texlive-texdoc
BuildArch:      noarch

%description -n texlive-scheme-gust
This is the GUST TeX Live scheme: it is a set of files
sufficient to typeset Polish plain TeX, LaTeX and ConTeXt
documents in PostScript or PDF.

%package -n texlive-scheme-infraonly
Version:        %{texlive_version}.%{texlive_noarch}.svn54191
Release:        60.1
License:        LPPL-1.0
Summary:        Infrastructure-only scheme (no TeX at all)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-hyphen-base >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-base
Requires:       texlive-kpathsea >= %{texlive_version}
#!BuildIgnore: texlive-kpathsea
Requires:       texlive-scripts >= %{texlive_version}
#!BuildIgnore: texlive-scripts
Requires:       texlive-texlive.infra >= %{texlive_version}
#!BuildIgnore: texlive-texlive.infra
BuildArch:      noarch

%description -n texlive-scheme-infraonly
This is the TeX Live scheme for infrastructure only, with no
TeX engines at all. It is useful for automated testing, where
the actual programs and packages to be tested are installed
separately afterwards, with tlmgr install.

%package -n texlive-scheme-medium
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Medium scheme (small + more packages and languages)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-binextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-binextra
Requires:       texlive-collection-context >= %{texlive_version}
#!BuildIgnore: texlive-collection-context
Requires:       texlive-collection-fontsrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsrecommended
Requires:       texlive-collection-fontutils >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontutils
Requires:       texlive-collection-langczechslovak >= %{texlive_version}
#!BuildIgnore: texlive-collection-langczechslovak
Requires:       texlive-collection-langenglish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langenglish
Requires:       texlive-collection-langeuropean >= %{texlive_version}
#!BuildIgnore: texlive-collection-langeuropean
Requires:       texlive-collection-langfrench >= %{texlive_version}
#!BuildIgnore: texlive-collection-langfrench
Requires:       texlive-collection-langgerman >= %{texlive_version}
#!BuildIgnore: texlive-collection-langgerman
Requires:       texlive-collection-langitalian >= %{texlive_version}
#!BuildIgnore: texlive-collection-langitalian
Requires:       texlive-collection-langpolish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langpolish
Requires:       texlive-collection-langportuguese >= %{texlive_version}
#!BuildIgnore: texlive-collection-langportuguese
Requires:       texlive-collection-langspanish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langspanish
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-luatex >= %{texlive_version}
#!BuildIgnore: texlive-collection-luatex
Requires:       texlive-collection-mathscience >= %{texlive_version}
#!BuildIgnore: texlive-collection-mathscience
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-collection-plaingeneric >= %{texlive_version}
#!BuildIgnore: texlive-collection-plaingeneric
Requires:       texlive-collection-xetex >= %{texlive_version}
#!BuildIgnore: texlive-collection-xetex
BuildArch:      noarch

%description -n texlive-scheme-medium
This is the medium TeX Live collection: it contains plain TeX,
LaTeX, many recommended packages, and support for most European
languages.

%package -n texlive-scheme-minimal
Version:        %{texlive_version}.%{texlive_noarch}.svn54191
Release:        60.1
License:        LPPL-1.0
Summary:        Minimal scheme (plain only)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
BuildArch:      noarch

%description -n texlive-scheme-minimal
This is the minimal TeX Live scheme, with support for only
plain TeX. (No LaTeX macros.) LuaTeX is included because Lua
scripts are used in TeX Live infrastructure. This scheme
corresponds exactly to collection-basic.

%package -n texlive-scheme-small
Version:        %{texlive_version}.%{texlive_noarch}.svn54191
Release:        60.1
License:        LPPL-1.0
Summary:        Small scheme (basic + xetex, metapost, a few languages)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-basque >= %{texlive_version}
#!BuildIgnore: texlive-babel-basque
Requires:       texlive-babel-czech >= %{texlive_version}
#!BuildIgnore: texlive-babel-czech
Requires:       texlive-babel-danish >= %{texlive_version}
#!BuildIgnore: texlive-babel-danish
Requires:       texlive-babel-dutch >= %{texlive_version}
#!BuildIgnore: texlive-babel-dutch
Requires:       texlive-babel-english >= %{texlive_version}
#!BuildIgnore: texlive-babel-english
Requires:       texlive-babel-finnish >= %{texlive_version}
#!BuildIgnore: texlive-babel-finnish
Requires:       texlive-babel-french >= %{texlive_version}
#!BuildIgnore: texlive-babel-french
Requires:       texlive-babel-german >= %{texlive_version}
#!BuildIgnore: texlive-babel-german
Requires:       texlive-babel-hungarian >= %{texlive_version}
#!BuildIgnore: texlive-babel-hungarian
Requires:       texlive-babel-italian >= %{texlive_version}
#!BuildIgnore: texlive-babel-italian
Requires:       texlive-babel-norsk >= %{texlive_version}
#!BuildIgnore: texlive-babel-norsk
Requires:       texlive-babel-polish >= %{texlive_version}
#!BuildIgnore: texlive-babel-polish
Requires:       texlive-babel-portuges >= %{texlive_version}
#!BuildIgnore: texlive-babel-portuges
Requires:       texlive-babel-spanish >= %{texlive_version}
#!BuildIgnore: texlive-babel-spanish
Requires:       texlive-babel-swedish >= %{texlive_version}
#!BuildIgnore: texlive-babel-swedish
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-collection-xetex >= %{texlive_version}
#!BuildIgnore: texlive-collection-xetex
Requires:       texlive-ec >= %{texlive_version}
#!BuildIgnore: texlive-ec
Requires:       texlive-eurosym >= %{texlive_version}
#!BuildIgnore: texlive-eurosym
Requires:       texlive-hyphen-basque >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-basque
Requires:       texlive-hyphen-czech >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-czech
Requires:       texlive-hyphen-danish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-danish
Requires:       texlive-hyphen-dutch >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-dutch
Requires:       texlive-hyphen-english >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-english
Requires:       texlive-hyphen-finnish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-finnish
Requires:       texlive-hyphen-french >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-french
Requires:       texlive-hyphen-german >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-german
Requires:       texlive-hyphen-hungarian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-hungarian
Requires:       texlive-hyphen-italian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-italian
Requires:       texlive-hyphen-norwegian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-norwegian
Requires:       texlive-hyphen-polish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-polish
Requires:       texlive-hyphen-portuguese >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-portuguese
Requires:       texlive-hyphen-spanish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-spanish
Requires:       texlive-hyphen-swedish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-swedish
Requires:       texlive-lm >= %{texlive_version}
#!BuildIgnore: texlive-lm
Requires:       texlive-lualibs >= %{texlive_version}
#!BuildIgnore: texlive-lualibs
Requires:       texlive-luaotfload >= %{texlive_version}
#!BuildIgnore: texlive-luaotfload
Requires:       texlive-luatexbase >= %{texlive_version}
#!BuildIgnore: texlive-luatexbase
Requires:       texlive-revtex >= %{texlive_version}
#!BuildIgnore: texlive-revtex
Requires:       texlive-synctex >= %{texlive_version}
#!BuildIgnore: texlive-synctex
Requires:       texlive-times >= %{texlive_version}
#!BuildIgnore: texlive-times
Requires:       texlive-tipa >= %{texlive_version}
#!BuildIgnore: texlive-tipa
Requires:       texlive-ulem >= %{texlive_version}
#!BuildIgnore: texlive-ulem
Requires:       texlive-upquote >= %{texlive_version}
#!BuildIgnore: texlive-upquote
Requires:       texlive-zapfding >= %{texlive_version}
#!BuildIgnore: texlive-zapfding
BuildArch:      noarch

%description -n texlive-scheme-small
This is a small TeX Live scheme, corresponding to MacTeX's
BasicTeX variant. It adds XeTeX, MetaPost, various
hyphenations, and some recommended packages to scheme-basic.

%package -n texlive-scheme-tetex
Version:        %{texlive_version}.%{texlive_noarch}.svn59715
Release:        60.1
License:        LPPL-1.0
Summary:        TeTeX scheme (more than medium, but nowhere near full)
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-acronym >= %{texlive_version}
#!BuildIgnore: texlive-acronym
Requires:       texlive-amslatex-primer >= %{texlive_version}
#!BuildIgnore: texlive-amslatex-primer
Requires:       texlive-bbm >= %{texlive_version}
#!BuildIgnore: texlive-bbm
Requires:       texlive-bbm-macros >= %{texlive_version}
#!BuildIgnore: texlive-bbm-macros
Requires:       texlive-bbold >= %{texlive_version}
#!BuildIgnore: texlive-bbold
Requires:       texlive-bibtex8 >= %{texlive_version}
#!BuildIgnore: texlive-bibtex8
Requires:       texlive-cmbright >= %{texlive_version}
#!BuildIgnore: texlive-cmbright
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-context >= %{texlive_version}
#!BuildIgnore: texlive-collection-context
Requires:       texlive-collection-fontsrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsrecommended
Requires:       texlive-collection-fontutils >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontutils
Requires:       texlive-collection-formatsextra >= %{texlive_version}
#!BuildIgnore: texlive-collection-formatsextra
Requires:       texlive-collection-langcjk >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcjk
Requires:       texlive-collection-langcyrillic >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcyrillic
Requires:       texlive-collection-langczechslovak >= %{texlive_version}
#!BuildIgnore: texlive-collection-langczechslovak
Requires:       texlive-collection-langenglish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langenglish
Requires:       texlive-collection-langeuropean >= %{texlive_version}
#!BuildIgnore: texlive-collection-langeuropean
Requires:       texlive-collection-langfrench >= %{texlive_version}
#!BuildIgnore: texlive-collection-langfrench
Requires:       texlive-collection-langgerman >= %{texlive_version}
#!BuildIgnore: texlive-collection-langgerman
Requires:       texlive-collection-langgreek >= %{texlive_version}
#!BuildIgnore: texlive-collection-langgreek
Requires:       texlive-collection-langitalian >= %{texlive_version}
#!BuildIgnore: texlive-collection-langitalian
Requires:       texlive-collection-langother >= %{texlive_version}
#!BuildIgnore: texlive-collection-langother
Requires:       texlive-collection-langpolish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langpolish
Requires:       texlive-collection-langportuguese >= %{texlive_version}
#!BuildIgnore: texlive-collection-langportuguese
Requires:       texlive-collection-langspanish >= %{texlive_version}
#!BuildIgnore: texlive-collection-langspanish
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-mathscience >= %{texlive_version}
#!BuildIgnore: texlive-collection-mathscience
Requires:       texlive-collection-metapost >= %{texlive_version}
#!BuildIgnore: texlive-collection-metapost
Requires:       texlive-collection-pictures >= %{texlive_version}
#!BuildIgnore: texlive-collection-pictures
Requires:       texlive-collection-plaingeneric >= %{texlive_version}
#!BuildIgnore: texlive-collection-plaingeneric
Requires:       texlive-collection-pstricks >= %{texlive_version}
#!BuildIgnore: texlive-collection-pstricks
Requires:       texlive-ctie >= %{texlive_version}
#!BuildIgnore: texlive-ctie
Requires:       texlive-cweb >= %{texlive_version}
#!BuildIgnore: texlive-cweb
Requires:       texlive-detex >= %{texlive_version}
#!BuildIgnore: texlive-detex
Requires:       texlive-dtl >= %{texlive_version}
#!BuildIgnore: texlive-dtl
Requires:       texlive-dvicopy >= %{texlive_version}
#!BuildIgnore: texlive-dvicopy
Requires:       texlive-dvidvi >= %{texlive_version}
#!BuildIgnore: texlive-dvidvi
Requires:       texlive-dviljk >= %{texlive_version}
#!BuildIgnore: texlive-dviljk
Requires:       texlive-eplain >= %{texlive_version}
#!BuildIgnore: texlive-eplain
Requires:       texlive-eulervm >= %{texlive_version}
#!BuildIgnore: texlive-eulervm
Requires:       texlive-gentle >= %{texlive_version}
#!BuildIgnore: texlive-gentle
Requires:       texlive-lshort-english >= %{texlive_version}
#!BuildIgnore: texlive-lshort-english
Requires:       texlive-mltex >= %{texlive_version}
#!BuildIgnore: texlive-mltex
Requires:       texlive-multirow >= %{texlive_version}
#!BuildIgnore: texlive-multirow
Requires:       texlive-nomencl >= %{texlive_version}
#!BuildIgnore: texlive-nomencl
Requires:       texlive-patgen >= %{texlive_version}
#!BuildIgnore: texlive-patgen
Requires:       texlive-pst-pdf >= %{texlive_version}
#!BuildIgnore: texlive-pst-pdf
Requires:       texlive-rsfs >= %{texlive_version}
#!BuildIgnore: texlive-rsfs
Requires:       texlive-seetexk >= %{texlive_version}
#!BuildIgnore: texlive-seetexk
Requires:       texlive-siunits >= %{texlive_version}
#!BuildIgnore: texlive-siunits
Requires:       texlive-subfigure >= %{texlive_version}
#!BuildIgnore: texlive-subfigure
Requires:       texlive-supertabular >= %{texlive_version}
#!BuildIgnore: texlive-supertabular
Requires:       texlive-tamethebeast >= %{texlive_version}
#!BuildIgnore: texlive-tamethebeast
Requires:       texlive-tds >= %{texlive_version}
#!BuildIgnore: texlive-tds
Requires:       texlive-tex-refs >= %{texlive_version}
#!BuildIgnore: texlive-tex-refs
Requires:       texlive-tie >= %{texlive_version}
#!BuildIgnore: texlive-tie
Requires:       texlive-web >= %{texlive_version}
#!BuildIgnore: texlive-web
Requires:       texlive-xpdfopen >= %{texlive_version}
#!BuildIgnore: texlive-xpdfopen
Provides:       tex(tetex)
BuildArch:      noarch

%description -n texlive-scheme-tetex
TeX Live scheme nearly equivalent to the teTeX distribution
that was maintained by Thomas Esser.

%package -n texlive-collection-basic
Version:        %{texlive_version}.%{texlive_noarch}.svn59159
Release:        60.1
License:        LPPL-1.0
Summary:        Essential programs and files
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive <= %{texlive_previous}
Requires:       texlive-amsfonts >= %{texlive_version}
#!BuildIgnore: texlive-amsfonts
Requires:       texlive-bibtex >= %{texlive_version}
#!BuildIgnore: texlive-bibtex
Requires:       texlive-cm >= %{texlive_version}
#!BuildIgnore: texlive-cm
Requires:       texlive-colorprofiles >= %{texlive_version}
#!BuildIgnore: texlive-colorprofiles
Requires:       texlive-dvipdfmx >= %{texlive_version}
#!BuildIgnore: texlive-dvipdfmx
Requires:       texlive-dvips >= %{texlive_version}
#!BuildIgnore: texlive-dvips
Requires:       texlive-ec >= %{texlive_version}
#!BuildIgnore: texlive-ec
Requires:       texlive-enctex >= %{texlive_version}
#!BuildIgnore: texlive-enctex
Requires:       texlive-etex >= %{texlive_version}
#!BuildIgnore: texlive-etex
Requires:       texlive-etex-pkg >= %{texlive_version}
#!BuildIgnore: texlive-etex-pkg
Requires:       texlive-glyphlist >= %{texlive_version}
#!BuildIgnore: texlive-glyphlist
Requires:       texlive-graphics-def >= %{texlive_version}
#!BuildIgnore: texlive-graphics-def
Requires:       texlive-hyph-utf8 >= %{texlive_version}
#!BuildIgnore: texlive-hyph-utf8
Requires:       texlive-hyphen-base >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-base
Requires:       texlive-hyphenex >= %{texlive_version}
#!BuildIgnore: texlive-hyphenex
Requires:       texlive-ifplatform >= %{texlive_version}
#!BuildIgnore: texlive-ifplatform
Requires:       texlive-iftex >= %{texlive_version}
#!BuildIgnore: texlive-iftex
Requires:       texlive-knuth-lib >= %{texlive_version}
#!BuildIgnore: texlive-knuth-lib
Requires:       texlive-knuth-local >= %{texlive_version}
#!BuildIgnore: texlive-knuth-local
Requires:       texlive-kpathsea >= %{texlive_version}
#!BuildIgnore: texlive-kpathsea
Requires:       texlive-lua-alt-getopt >= %{texlive_version}
#!BuildIgnore: texlive-lua-alt-getopt
Requires:       texlive-luahbtex >= %{texlive_version}
#!BuildIgnore: texlive-luahbtex
Requires:       texlive-luatex >= %{texlive_version}
#!BuildIgnore: texlive-luatex
Requires:       texlive-makeindex >= %{texlive_version}
#!BuildIgnore: texlive-makeindex
Requires:       texlive-metafont >= %{texlive_version}
#!BuildIgnore: texlive-metafont
Requires:       texlive-mflogo >= %{texlive_version}
#!BuildIgnore: texlive-mflogo
Requires:       texlive-mfware >= %{texlive_version}
#!BuildIgnore: texlive-mfware
Requires:       texlive-modes >= %{texlive_version}
#!BuildIgnore: texlive-modes
Requires:       texlive-pdftex >= %{texlive_version}
#!BuildIgnore: texlive-pdftex
Requires:       texlive-plain >= %{texlive_version}
#!BuildIgnore: texlive-plain
Requires:       texlive-tex >= %{texlive_version}
#!BuildIgnore: texlive-tex
Requires:       texlive-tex-ini-files >= %{texlive_version}
#!BuildIgnore: texlive-tex-ini-files
Requires:       texlive-texlive-common >= %{texlive_version}
#!BuildIgnore: texlive-texlive-common
Requires:       texlive-texlive-en >= %{texlive_version}
#!BuildIgnore: texlive-texlive-en
Requires:       texlive-scripts >= %{texlive_version}
#!BuildIgnore: texlive-scripts
Requires:       texlive-texlive.infra >= %{texlive_version}
#!BuildIgnore: texlive-texlive.infra
Requires:       texlive-unicode-data >= %{texlive_version}
#!BuildIgnore: texlive-unicode-data
Requires:       texlive-xdvi >= %{texlive_version}
#!BuildIgnore: texlive-xdvi
Provides:       tex(basic)
Provides:       tex(tex)
BuildArch:      noarch

%description -n texlive-collection-basic
These files are regarded as basic for any TeX system, covering
plain TeX macros, Computer Modern fonts, and configuration for
common drivers; no LaTeX.

%package -n texlive-collection-bibtexextra
Version:        %{texlive_version}.%{texlive_noarch}.svn65257
Release:        60.1
License:        LPPL-1.0
Summary:        BibTeX additional styles
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-aaai-named >= %{texlive_version}
#!BuildIgnore: texlive-aaai-named
Requires:       texlive-aichej >= %{texlive_version}
#!BuildIgnore: texlive-aichej
Requires:       texlive-ajl >= %{texlive_version}
#!BuildIgnore: texlive-ajl
Requires:       texlive-amsrefs >= %{texlive_version}
#!BuildIgnore: texlive-amsrefs
Requires:       texlive-annotate >= %{texlive_version}
#!BuildIgnore: texlive-annotate
Requires:       texlive-apacite >= %{texlive_version}
#!BuildIgnore: texlive-apacite
Requires:       texlive-apalike-ejor >= %{texlive_version}
#!BuildIgnore: texlive-apalike-ejor
Requires:       texlive-apalike2 >= %{texlive_version}
#!BuildIgnore: texlive-apalike2
Requires:       texlive-archaeologie >= %{texlive_version}
#!BuildIgnore: texlive-archaeologie
Requires:       texlive-authordate >= %{texlive_version}
#!BuildIgnore: texlive-authordate
Requires:       texlive-beebe >= %{texlive_version}
#!BuildIgnore: texlive-beebe
Requires:       texlive-besjournals >= %{texlive_version}
#!BuildIgnore: texlive-besjournals
Requires:       texlive-bestpapers >= %{texlive_version}
#!BuildIgnore: texlive-bestpapers
Requires:       texlive-bib2gls >= %{texlive_version}
#!BuildIgnore: texlive-bib2gls
Requires:       texlive-bibarts >= %{texlive_version}
#!BuildIgnore: texlive-bibarts
Requires:       texlive-bibcop >= %{texlive_version}
#!BuildIgnore: texlive-bibcop
Requires:       texlive-biber >= %{texlive_version}
#!BuildIgnore: texlive-biber
Requires:       texlive-biber-ms >= %{texlive_version}
#!BuildIgnore: texlive-biber-ms
Requires:       texlive-bibexport >= %{texlive_version}
#!BuildIgnore: texlive-bibexport
Requires:       texlive-bibhtml >= %{texlive_version}
#!BuildIgnore: texlive-bibhtml
Requires:       texlive-biblatex >= %{texlive_version}
#!BuildIgnore: texlive-biblatex
Requires:       texlive-biblatex-abnt >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-abnt
Requires:       texlive-biblatex-ajc2020unofficial >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-ajc2020unofficial
Requires:       texlive-biblatex-anonymous >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-anonymous
Requires:       texlive-biblatex-apa >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-apa
Requires:       texlive-biblatex-apa6 >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-apa6
Requires:       texlive-biblatex-archaeology >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-archaeology
Requires:       texlive-biblatex-arthistory-bonn >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-arthistory-bonn
Requires:       texlive-biblatex-bath >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-bath
Requires:       texlive-biblatex-bookinarticle >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-bookinarticle
Requires:       texlive-biblatex-bookinother >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-bookinother
Requires:       texlive-biblatex-bwl >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-bwl
Requires:       texlive-biblatex-caspervector >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-caspervector
Requires:       texlive-biblatex-chem >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-chem
Requires:       texlive-biblatex-chicago >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-chicago
Requires:       texlive-biblatex-claves >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-claves
Requires:       texlive-biblatex-cv >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-cv
Requires:       texlive-biblatex-dw >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-dw
Requires:       texlive-biblatex-enc >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-enc
Requires:       texlive-biblatex-ext >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-ext
Requires:       texlive-biblatex-fiwi >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-fiwi
Requires:       texlive-biblatex-gb7714-2015 >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-gb7714-2015
Requires:       texlive-biblatex-german-legal >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-german-legal
Requires:       texlive-biblatex-gost >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-gost
Requires:       texlive-biblatex-historian >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-historian
Requires:       texlive-biblatex-ieee >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-ieee
Requires:       texlive-biblatex-ijsra >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-ijsra
Requires:       texlive-biblatex-iso690 >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-iso690
Requires:       texlive-biblatex-jura2 >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-jura2
Requires:       texlive-biblatex-juradiss >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-juradiss
Requires:       texlive-biblatex-license >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-license
Requires:       texlive-biblatex-lncs >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-lncs
Requires:       texlive-biblatex-lni >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-lni
Requires:       texlive-biblatex-luh-ipw >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-luh-ipw
Requires:       texlive-biblatex-manuscripts-philology >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-manuscripts-philology
Requires:       texlive-biblatex-mla >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-mla
Requires:       texlive-biblatex-morenames >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-morenames
Requires:       texlive-biblatex-ms >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-ms
Requires:       texlive-biblatex-multiple-dm >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-multiple-dm
Requires:       texlive-biblatex-musuos >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-musuos
Requires:       texlive-biblatex-nature >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-nature
Requires:       texlive-biblatex-nejm >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-nejm
Requires:       texlive-biblatex-nottsclassic >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-nottsclassic
Requires:       texlive-biblatex-opcit-booktitle >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-opcit-booktitle
Requires:       texlive-biblatex-oxref >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-oxref
Requires:       texlive-biblatex-philosophy >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-philosophy
Requires:       texlive-biblatex-phys >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-phys
Requires:       texlive-biblatex-publist >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-publist
Requires:       texlive-biblatex-readbbl >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-readbbl
Requires:       texlive-biblatex-realauthor >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-realauthor
Requires:       texlive-biblatex-sbl >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-sbl
Requires:       texlive-biblatex-science >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-science
Requires:       texlive-biblatex-shortfields >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-shortfields
Requires:       texlive-biblatex-socialscienceshuberlin >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-socialscienceshuberlin
Requires:       texlive-biblatex-software >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-software
Requires:       texlive-biblatex-source-division >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-source-division
Requires:       texlive-biblatex-spbasic >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-spbasic
Requires:       texlive-biblatex-subseries >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-subseries
Requires:       texlive-biblatex-swiss-legal >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-swiss-legal
Requires:       texlive-biblatex-trad >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-trad
Requires:       texlive-biblatex-true-citepages-omit >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-true-citepages-omit
Requires:       texlive-biblatex-unified >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-unified
Requires:       texlive-biblatex-vancouver >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-vancouver
Requires:       texlive-biblatex2bibitem >= %{texlive_version}
#!BuildIgnore: texlive-biblatex2bibitem
Requires:       texlive-biblist >= %{texlive_version}
#!BuildIgnore: texlive-biblist
Requires:       texlive-bibtexperllibs >= %{texlive_version}
#!BuildIgnore: texlive-bibtexperllibs
Requires:       texlive-bibtopic >= %{texlive_version}
#!BuildIgnore: texlive-bibtopic
Requires:       texlive-bibtopicprefix >= %{texlive_version}
#!BuildIgnore: texlive-bibtopicprefix
Requires:       texlive-bibunits >= %{texlive_version}
#!BuildIgnore: texlive-bibunits
Requires:       texlive-biolett-bst >= %{texlive_version}
#!BuildIgnore: texlive-biolett-bst
Requires:       texlive-bookdb >= %{texlive_version}
#!BuildIgnore: texlive-bookdb
Requires:       texlive-breakcites >= %{texlive_version}
#!BuildIgnore: texlive-breakcites
Requires:       texlive-cell >= %{texlive_version}
#!BuildIgnore: texlive-cell
Requires:       texlive-chbibref >= %{texlive_version}
#!BuildIgnore: texlive-chbibref
Requires:       texlive-chembst >= %{texlive_version}
#!BuildIgnore: texlive-chembst
Requires:       texlive-chicago >= %{texlive_version}
#!BuildIgnore: texlive-chicago
Requires:       texlive-chicago-annote >= %{texlive_version}
#!BuildIgnore: texlive-chicago-annote
Requires:       texlive-chicagoa >= %{texlive_version}
#!BuildIgnore: texlive-chicagoa
Requires:       texlive-chscite >= %{texlive_version}
#!BuildIgnore: texlive-chscite
Requires:       texlive-citation-style-language >= %{texlive_version}
#!BuildIgnore: texlive-citation-style-language
Requires:       texlive-citeall >= %{texlive_version}
#!BuildIgnore: texlive-citeall
Requires:       texlive-citeref >= %{texlive_version}
#!BuildIgnore: texlive-citeref
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-collref >= %{texlive_version}
#!BuildIgnore: texlive-collref
Requires:       texlive-compactbib >= %{texlive_version}
#!BuildIgnore: texlive-compactbib
Requires:       texlive-crossrefware >= %{texlive_version}
#!BuildIgnore: texlive-crossrefware
Requires:       texlive-custom-bib >= %{texlive_version}
#!BuildIgnore: texlive-custom-bib
Requires:       texlive-din1505 >= %{texlive_version}
#!BuildIgnore: texlive-din1505
Requires:       texlive-dk-bib >= %{texlive_version}
#!BuildIgnore: texlive-dk-bib
Requires:       texlive-doipubmed >= %{texlive_version}
#!BuildIgnore: texlive-doipubmed
Requires:       texlive-ecobiblatex >= %{texlive_version}
#!BuildIgnore: texlive-ecobiblatex
Requires:       texlive-econ-bst >= %{texlive_version}
#!BuildIgnore: texlive-econ-bst
Requires:       texlive-economic >= %{texlive_version}
#!BuildIgnore: texlive-economic
Requires:       texlive-fbs >= %{texlive_version}
#!BuildIgnore: texlive-fbs
Requires:       texlive-figbib >= %{texlive_version}
#!BuildIgnore: texlive-figbib
Requires:       texlive-footbib >= %{texlive_version}
#!BuildIgnore: texlive-footbib
Requires:       texlive-francais-bst >= %{texlive_version}
#!BuildIgnore: texlive-francais-bst
Requires:       texlive-gbt7714 >= %{texlive_version}
#!BuildIgnore: texlive-gbt7714
Requires:       texlive-geschichtsfrkl >= %{texlive_version}
#!BuildIgnore: texlive-geschichtsfrkl
Requires:       texlive-harvard >= %{texlive_version}
#!BuildIgnore: texlive-harvard
Requires:       texlive-harvmac >= %{texlive_version}
#!BuildIgnore: texlive-harvmac
Requires:       texlive-hep-bibliography >= %{texlive_version}
#!BuildIgnore: texlive-hep-bibliography
Requires:       texlive-historische-zeitschrift >= %{texlive_version}
#!BuildIgnore: texlive-historische-zeitschrift
Requires:       texlive-icite >= %{texlive_version}
#!BuildIgnore: texlive-icite
Requires:       texlive-ietfbibs >= %{texlive_version}
#!BuildIgnore: texlive-ietfbibs
Requires:       texlive-ijqc >= %{texlive_version}
#!BuildIgnore: texlive-ijqc
Requires:       texlive-inlinebib >= %{texlive_version}
#!BuildIgnore: texlive-inlinebib
Requires:       texlive-iopart-num >= %{texlive_version}
#!BuildIgnore: texlive-iopart-num
Requires:       texlive-is-bst >= %{texlive_version}
#!BuildIgnore: texlive-is-bst
Requires:       texlive-jbact >= %{texlive_version}
#!BuildIgnore: texlive-jbact
Requires:       texlive-jmb >= %{texlive_version}
#!BuildIgnore: texlive-jmb
Requires:       texlive-jneurosci >= %{texlive_version}
#!BuildIgnore: texlive-jneurosci
Requires:       texlive-jurabib >= %{texlive_version}
#!BuildIgnore: texlive-jurabib
Requires:       texlive-ksfh_nat >= %{texlive_version}
#!BuildIgnore: texlive-ksfh_nat
Requires:       texlive-listbib >= %{texlive_version}
#!BuildIgnore: texlive-listbib
Requires:       texlive-logreq >= %{texlive_version}
#!BuildIgnore: texlive-logreq
Requires:       texlive-ltb2bib >= %{texlive_version}
#!BuildIgnore: texlive-ltb2bib
Requires:       texlive-luabibentry >= %{texlive_version}
#!BuildIgnore: texlive-luabibentry
Requires:       texlive-margbib >= %{texlive_version}
#!BuildIgnore: texlive-margbib
Requires:       texlive-multibib >= %{texlive_version}
#!BuildIgnore: texlive-multibib
Requires:       texlive-multibibliography >= %{texlive_version}
#!BuildIgnore: texlive-multibibliography
Requires:       texlive-munich >= %{texlive_version}
#!BuildIgnore: texlive-munich
Requires:       texlive-nar >= %{texlive_version}
#!BuildIgnore: texlive-nar
Requires:       texlive-newcastle-bst >= %{texlive_version}
#!BuildIgnore: texlive-newcastle-bst
Requires:       texlive-nmbib >= %{texlive_version}
#!BuildIgnore: texlive-nmbib
Requires:       texlive-notes2bib >= %{texlive_version}
#!BuildIgnore: texlive-notes2bib
Requires:       texlive-notex-bst >= %{texlive_version}
#!BuildIgnore: texlive-notex-bst
Requires:       texlive-oscola >= %{texlive_version}
#!BuildIgnore: texlive-oscola
Requires:       texlive-perception >= %{texlive_version}
#!BuildIgnore: texlive-perception
Requires:       texlive-plainyr >= %{texlive_version}
#!BuildIgnore: texlive-plainyr
Requires:       texlive-pnas2009 >= %{texlive_version}
#!BuildIgnore: texlive-pnas2009
Requires:       texlive-rsc >= %{texlive_version}
#!BuildIgnore: texlive-rsc
Requires:       texlive-showtags >= %{texlive_version}
#!BuildIgnore: texlive-showtags
Requires:       texlive-sort-by-letters >= %{texlive_version}
#!BuildIgnore: texlive-sort-by-letters
Requires:       texlive-splitbib >= %{texlive_version}
#!BuildIgnore: texlive-splitbib
Requires:       texlive-turabian-formatting >= %{texlive_version}
#!BuildIgnore: texlive-turabian-formatting
Requires:       texlive-uni-wtal-ger >= %{texlive_version}
#!BuildIgnore: texlive-uni-wtal-ger
Requires:       texlive-uni-wtal-lin >= %{texlive_version}
#!BuildIgnore: texlive-uni-wtal-lin
Requires:       texlive-urlbst >= %{texlive_version}
#!BuildIgnore: texlive-urlbst
Requires:       texlive-usebib >= %{texlive_version}
#!BuildIgnore: texlive-usebib
Requires:       texlive-vak >= %{texlive_version}
#!BuildIgnore: texlive-vak
Requires:       texlive-windycity >= %{texlive_version}
#!BuildIgnore: texlive-windycity
Requires:       texlive-xcite >= %{texlive_version}
#!BuildIgnore: texlive-xcite
Requires:       texlive-zootaxa-bst >= %{texlive_version}
#!BuildIgnore: texlive-zootaxa-bst
BuildArch:      noarch

%description -n texlive-collection-bibtexextra
Additional BibTeX styles and bibliography data(bases), notably
including BibLaTeX.

%package -n texlive-collection-binextra
Version:        %{texlive_version}.%{texlive_noarch}.svn66381
Release:        60.1
License:        LPPL-1.0
Summary:        TeX auxiliary programs
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      tetex-bin <= %{texlive_previous}
Obsoletes:      texlive-bin <= %{texlive_previous}
Obsoletes:      texlive-dvilj <= %{texlive_previous}
Requires:       texlive-a2ping >= %{texlive_version}
#!BuildIgnore: texlive-a2ping
Requires:       texlive-adhocfilelist >= %{texlive_version}
#!BuildIgnore: texlive-adhocfilelist
Requires:       texlive-arara >= %{texlive_version}
#!BuildIgnore: texlive-arara
Requires:       texlive-asymptote >= %{texlive_version}
#!BuildIgnore: texlive-asymptote
Requires:       texlive-bibtex8 >= %{texlive_version}
#!BuildIgnore: texlive-bibtex8
Requires:       texlive-bibtexu >= %{texlive_version}
#!BuildIgnore: texlive-bibtexu
Requires:       texlive-bundledoc >= %{texlive_version}
#!BuildIgnore: texlive-bundledoc
Requires:       texlive-checklistings >= %{texlive_version}
#!BuildIgnore: texlive-checklistings
Requires:       texlive-chklref >= %{texlive_version}
#!BuildIgnore: texlive-chklref
Requires:       texlive-chktex >= %{texlive_version}
#!BuildIgnore: texlive-chktex
Requires:       texlive-clojure-pamphlet >= %{texlive_version}
#!BuildIgnore: texlive-clojure-pamphlet
Requires:       texlive-cluttex >= %{texlive_version}
#!BuildIgnore: texlive-cluttex
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-ctan-o-mat >= %{texlive_version}
#!BuildIgnore: texlive-ctan-o-mat
Requires:       texlive-ctan_chk >= %{texlive_version}
#!BuildIgnore: texlive-ctan_chk
Requires:       texlive-ctanbib >= %{texlive_version}
#!BuildIgnore: texlive-ctanbib
Requires:       texlive-ctanify >= %{texlive_version}
#!BuildIgnore: texlive-ctanify
Requires:       texlive-ctanupload >= %{texlive_version}
#!BuildIgnore: texlive-ctanupload
Requires:       texlive-ctie >= %{texlive_version}
#!BuildIgnore: texlive-ctie
Requires:       texlive-cweb >= %{texlive_version}
#!BuildIgnore: texlive-cweb
Requires:       texlive-de-macro >= %{texlive_version}
#!BuildIgnore: texlive-de-macro
Requires:       texlive-detex >= %{texlive_version}
#!BuildIgnore: texlive-detex
Requires:       texlive-digestif >= %{texlive_version}
#!BuildIgnore: texlive-digestif
Requires:       texlive-dtl >= %{texlive_version}
#!BuildIgnore: texlive-dtl
Requires:       texlive-dtxgen >= %{texlive_version}
#!BuildIgnore: texlive-dtxgen
Requires:       texlive-dviasm >= %{texlive_version}
#!BuildIgnore: texlive-dviasm
Requires:       texlive-dvicopy >= %{texlive_version}
#!BuildIgnore: texlive-dvicopy
Requires:       texlive-dvidvi >= %{texlive_version}
#!BuildIgnore: texlive-dvidvi
Requires:       texlive-dviinfox >= %{texlive_version}
#!BuildIgnore: texlive-dviinfox
Requires:       texlive-dviljk >= %{texlive_version}
#!BuildIgnore: texlive-dviljk
Requires:       texlive-dviout-util >= %{texlive_version}
#!BuildIgnore: texlive-dviout-util
Requires:       texlive-dvipng >= %{texlive_version}
#!BuildIgnore: texlive-dvipng
Requires:       texlive-dvipos >= %{texlive_version}
#!BuildIgnore: texlive-dvipos
Requires:       texlive-dvisvgm >= %{texlive_version}
#!BuildIgnore: texlive-dvisvgm
Requires:       texlive-findhyph >= %{texlive_version}
#!BuildIgnore: texlive-findhyph
Requires:       texlive-fragmaster >= %{texlive_version}
#!BuildIgnore: texlive-fragmaster
Requires:       texlive-git-latexdiff >= %{texlive_version}
#!BuildIgnore: texlive-git-latexdiff
Requires:       texlive-gsftopk >= %{texlive_version}
#!BuildIgnore: texlive-gsftopk
Requires:       texlive-hook-pre-commit-pkg >= %{texlive_version}
#!BuildIgnore: texlive-hook-pre-commit-pkg
Requires:       texlive-ketcindy >= %{texlive_version}
#!BuildIgnore: texlive-ketcindy
Requires:       texlive-lacheck >= %{texlive_version}
#!BuildIgnore: texlive-lacheck
Requires:       texlive-latex-git-log >= %{texlive_version}
#!BuildIgnore: texlive-latex-git-log
Requires:       texlive-latex-papersize >= %{texlive_version}
#!BuildIgnore: texlive-latex-papersize
Requires:       texlive-latex2man >= %{texlive_version}
#!BuildIgnore: texlive-latex2man
Requires:       texlive-latex2nemeth >= %{texlive_version}
#!BuildIgnore: texlive-latex2nemeth
Requires:       texlive-latexdiff >= %{texlive_version}
#!BuildIgnore: texlive-latexdiff
Requires:       texlive-latexfileversion >= %{texlive_version}
#!BuildIgnore: texlive-latexfileversion
Requires:       texlive-latexindent >= %{texlive_version}
#!BuildIgnore: texlive-latexindent
Requires:       texlive-latexmk >= %{texlive_version}
#!BuildIgnore: texlive-latexmk
Requires:       texlive-latexpand >= %{texlive_version}
#!BuildIgnore: texlive-latexpand
Requires:       texlive-light-latex-make >= %{texlive_version}
#!BuildIgnore: texlive-light-latex-make
Requires:       texlive-listings-ext >= %{texlive_version}
#!BuildIgnore: texlive-listings-ext
Requires:       texlive-ltxfileinfo >= %{texlive_version}
#!BuildIgnore: texlive-ltxfileinfo
Requires:       texlive-ltximg >= %{texlive_version}
#!BuildIgnore: texlive-ltximg
Requires:       texlive-luajittex >= %{texlive_version}
#!BuildIgnore: texlive-luajittex
Requires:       texlive-make4ht >= %{texlive_version}
#!BuildIgnore: texlive-make4ht
Requires:       texlive-match_parens >= %{texlive_version}
#!BuildIgnore: texlive-match_parens
Requires:       texlive-mflua >= %{texlive_version}
#!BuildIgnore: texlive-mflua
Requires:       texlive-mkjobtexmf >= %{texlive_version}
#!BuildIgnore: texlive-mkjobtexmf
Requires:       texlive-optexcount >= %{texlive_version}
#!BuildIgnore: texlive-optexcount
Requires:       texlive-patgen >= %{texlive_version}
#!BuildIgnore: texlive-patgen
Requires:       texlive-pdfbook2 >= %{texlive_version}
#!BuildIgnore: texlive-pdfbook2
Requires:       texlive-pdfcrop >= %{texlive_version}
#!BuildIgnore: texlive-pdfcrop
Requires:       texlive-pdfjam >= %{texlive_version}
#!BuildIgnore: texlive-pdfjam
Requires:       texlive-pdflatexpicscale >= %{texlive_version}
#!BuildIgnore: texlive-pdflatexpicscale
Requires:       texlive-pdftex-quiet >= %{texlive_version}
#!BuildIgnore: texlive-pdftex-quiet
Requires:       texlive-pdftosrc >= %{texlive_version}
#!BuildIgnore: texlive-pdftosrc
Requires:       texlive-pdfxup >= %{texlive_version}
#!BuildIgnore: texlive-pdfxup
Requires:       texlive-pfarrei >= %{texlive_version}
#!BuildIgnore: texlive-pfarrei
Requires:       texlive-pkfix >= %{texlive_version}
#!BuildIgnore: texlive-pkfix
Requires:       texlive-pkfix-helper >= %{texlive_version}
#!BuildIgnore: texlive-pkfix-helper
Requires:       texlive-purifyeps >= %{texlive_version}
#!BuildIgnore: texlive-purifyeps
Requires:       texlive-pythontex >= %{texlive_version}
#!BuildIgnore: texlive-pythontex
Requires:       texlive-seetexk >= %{texlive_version}
#!BuildIgnore: texlive-seetexk
Requires:       texlive-spix >= %{texlive_version}
#!BuildIgnore: texlive-spix
Requires:       texlive-srcredact >= %{texlive_version}
#!BuildIgnore: texlive-srcredact
Requires:       texlive-sty2dtx >= %{texlive_version}
#!BuildIgnore: texlive-sty2dtx
Requires:       texlive-synctex >= %{texlive_version}
#!BuildIgnore: texlive-synctex
Requires:       texlive-tex4ebook >= %{texlive_version}
#!BuildIgnore: texlive-tex4ebook
Requires:       texlive-texaccents >= %{texlive_version}
#!BuildIgnore: texlive-texaccents
Requires:       texlive-texcount >= %{texlive_version}
#!BuildIgnore: texlive-texcount
Requires:       texlive-texdef >= %{texlive_version}
#!BuildIgnore: texlive-texdef
Requires:       texlive-texdiff >= %{texlive_version}
#!BuildIgnore: texlive-texdiff
Requires:       texlive-texdirflatten >= %{texlive_version}
#!BuildIgnore: texlive-texdirflatten
Requires:       texlive-texdoc >= %{texlive_version}
#!BuildIgnore: texlive-texdoc
Requires:       texlive-texdoctk >= %{texlive_version}
#!BuildIgnore: texlive-texdoctk
Requires:       texlive-texfot >= %{texlive_version}
#!BuildIgnore: texlive-texfot
Requires:       texlive-scripts-extra >= %{texlive_version}
#!BuildIgnore: texlive-scripts-extra
Requires:       texlive-texliveonfly >= %{texlive_version}
#!BuildIgnore: texlive-texliveonfly
Requires:       texlive-texloganalyser >= %{texlive_version}
#!BuildIgnore: texlive-texloganalyser
Requires:       texlive-texlogfilter >= %{texlive_version}
#!BuildIgnore: texlive-texlogfilter
Requires:       texlive-texlogsieve >= %{texlive_version}
#!BuildIgnore: texlive-texlogsieve
Requires:       texlive-texosquery >= %{texlive_version}
#!BuildIgnore: texlive-texosquery
Requires:       texlive-texplate >= %{texlive_version}
#!BuildIgnore: texlive-texplate
Requires:       texlive-texware >= %{texlive_version}
#!BuildIgnore: texlive-texware
Requires:       texlive-tie >= %{texlive_version}
#!BuildIgnore: texlive-tie
Requires:       texlive-tpic2pdftex >= %{texlive_version}
#!BuildIgnore: texlive-tpic2pdftex
Requires:       texlive-typeoutfileinfo >= %{texlive_version}
#!BuildIgnore: texlive-typeoutfileinfo
Requires:       texlive-upmendex >= %{texlive_version}
#!BuildIgnore: texlive-upmendex
Requires:       texlive-web >= %{texlive_version}
#!BuildIgnore: texlive-web
Requires:       texlive-xindex >= %{texlive_version}
#!BuildIgnore: texlive-xindex
Requires:       texlive-xpdfopen >= %{texlive_version}
#!BuildIgnore: texlive-xpdfopen
BuildArch:      noarch

%description -n texlive-collection-binextra
Myriad additional TeX-related support programs. Includes
programs and macros for DVI file manipulation, literate
programming, patgen, and plenty more.

%package -n texlive-collection-context
Version:        %{texlive_version}.%{texlive_noarch}.svn66171
Release:        60.1
License:        LPPL-1.0
Summary:        ConTeXt and packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-context <= %{texlive_previous}
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-context >= %{texlive_version}
#!BuildIgnore: texlive-context
Requires:       texlive-context-account >= %{texlive_version}
#!BuildIgnore: texlive-context-account
Requires:       texlive-context-algorithmic >= %{texlive_version}
#!BuildIgnore: texlive-context-algorithmic
Requires:       texlive-context-animation >= %{texlive_version}
#!BuildIgnore: texlive-context-animation
Requires:       texlive-context-annotation >= %{texlive_version}
#!BuildIgnore: texlive-context-annotation
Requires:       texlive-context-bnf >= %{texlive_version}
#!BuildIgnore: texlive-context-bnf
Requires:       texlive-context-chromato >= %{texlive_version}
#!BuildIgnore: texlive-context-chromato
Requires:       texlive-context-cmscbf >= %{texlive_version}
#!BuildIgnore: texlive-context-cmscbf
Requires:       texlive-context-cmttbf >= %{texlive_version}
#!BuildIgnore: texlive-context-cmttbf
Requires:       texlive-context-construction-plan >= %{texlive_version}
#!BuildIgnore: texlive-context-construction-plan
Requires:       texlive-context-cyrillicnumbers >= %{texlive_version}
#!BuildIgnore: texlive-context-cyrillicnumbers
Requires:       texlive-context-degrade >= %{texlive_version}
#!BuildIgnore: texlive-context-degrade
Requires:       texlive-context-fancybreak >= %{texlive_version}
#!BuildIgnore: texlive-context-fancybreak
Requires:       texlive-context-filter >= %{texlive_version}
#!BuildIgnore: texlive-context-filter
Requires:       texlive-context-french >= %{texlive_version}
#!BuildIgnore: texlive-context-french
Requires:       texlive-context-fullpage >= %{texlive_version}
#!BuildIgnore: texlive-context-fullpage
Requires:       texlive-context-gantt >= %{texlive_version}
#!BuildIgnore: texlive-context-gantt
Requires:       texlive-context-gnuplot >= %{texlive_version}
#!BuildIgnore: texlive-context-gnuplot
Requires:       texlive-context-handlecsv >= %{texlive_version}
#!BuildIgnore: texlive-context-handlecsv
Requires:       texlive-context-layout >= %{texlive_version}
#!BuildIgnore: texlive-context-layout
Requires:       texlive-context-letter >= %{texlive_version}
#!BuildIgnore: texlive-context-letter
Requires:       texlive-context-lettrine >= %{texlive_version}
#!BuildIgnore: texlive-context-lettrine
Requires:       texlive-context-mathsets >= %{texlive_version}
#!BuildIgnore: texlive-context-mathsets
Requires:       texlive-context-rst >= %{texlive_version}
#!BuildIgnore: texlive-context-rst
Requires:       texlive-context-ruby >= %{texlive_version}
#!BuildIgnore: texlive-context-ruby
Requires:       texlive-context-simplefonts >= %{texlive_version}
#!BuildIgnore: texlive-context-simplefonts
Requires:       texlive-context-simpleslides >= %{texlive_version}
#!BuildIgnore: texlive-context-simpleslides
Requires:       texlive-context-title >= %{texlive_version}
#!BuildIgnore: texlive-context-title
Requires:       texlive-context-transliterator >= %{texlive_version}
#!BuildIgnore: texlive-context-transliterator
Requires:       texlive-context-typearea >= %{texlive_version}
#!BuildIgnore: texlive-context-typearea
Requires:       texlive-context-typescripts >= %{texlive_version}
#!BuildIgnore: texlive-context-typescripts
Requires:       texlive-context-vim >= %{texlive_version}
#!BuildIgnore: texlive-context-vim
Requires:       texlive-context-visualcounter >= %{texlive_version}
#!BuildIgnore: texlive-context-visualcounter
Requires:       texlive-jmn >= %{texlive_version}
#!BuildIgnore: texlive-jmn
BuildArch:      noarch

%description -n texlive-collection-context
Hans Hagen's powerful ConTeXt system, http://pragma-ade.com.
Also includes third-party ConTeXt packages.

%package -n texlive-collection-fontsextra
Version:        %{texlive_version}.%{texlive_noarch}.svn64952
Release:        60.1
License:        LPPL-1.0
Summary:        Additional fonts
Group:          Productivity/Publishing/TeX/Fonts
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-fonts-extra <= %{texlive_previous}
Obsoletes:      texlive-fonts-extra-doc <= %{texlive_previous}
Requires:       texlive-aboensis >= %{texlive_version}
#!BuildIgnore: texlive-aboensis
Requires:       texlive-academicons >= %{texlive_version}
#!BuildIgnore: texlive-academicons
Requires:       texlive-accanthis >= %{texlive_version}
#!BuildIgnore: texlive-accanthis
Requires:       texlive-adforn >= %{texlive_version}
#!BuildIgnore: texlive-adforn
Requires:       texlive-adfsymbols >= %{texlive_version}
#!BuildIgnore: texlive-adfsymbols
Requires:       texlive-aesupp >= %{texlive_version}
#!BuildIgnore: texlive-aesupp
Requires:       texlive-alegreya >= %{texlive_version}
#!BuildIgnore: texlive-alegreya
Requires:       texlive-alfaslabone >= %{texlive_version}
#!BuildIgnore: texlive-alfaslabone
Requires:       texlive-algolrevived >= %{texlive_version}
#!BuildIgnore: texlive-algolrevived
Requires:       texlive-allrunes >= %{texlive_version}
#!BuildIgnore: texlive-allrunes
Requires:       texlive-almendra >= %{texlive_version}
#!BuildIgnore: texlive-almendra
Requires:       texlive-almfixed >= %{texlive_version}
#!BuildIgnore: texlive-almfixed
Requires:       texlive-andika >= %{texlive_version}
#!BuildIgnore: texlive-andika
Requires:       texlive-anonymouspro >= %{texlive_version}
#!BuildIgnore: texlive-anonymouspro
Requires:       texlive-antiqua >= %{texlive_version}
#!BuildIgnore: texlive-antiqua
Requires:       texlive-antt >= %{texlive_version}
#!BuildIgnore: texlive-antt
Requires:       texlive-archaic >= %{texlive_version}
#!BuildIgnore: texlive-archaic
Requires:       texlive-archivo >= %{texlive_version}
#!BuildIgnore: texlive-archivo
Requires:       texlive-arev >= %{texlive_version}
#!BuildIgnore: texlive-arev
Requires:       texlive-arimo >= %{texlive_version}
#!BuildIgnore: texlive-arimo
Requires:       texlive-arvo >= %{texlive_version}
#!BuildIgnore: texlive-arvo
Requires:       texlive-asana-math >= %{texlive_version}
#!BuildIgnore: texlive-asana-math
Requires:       texlive-asapsym >= %{texlive_version}
#!BuildIgnore: texlive-asapsym
Requires:       texlive-ascii-font >= %{texlive_version}
#!BuildIgnore: texlive-ascii-font
Requires:       texlive-aspectratio >= %{texlive_version}
#!BuildIgnore: texlive-aspectratio
Requires:       texlive-astro >= %{texlive_version}
#!BuildIgnore: texlive-astro
Requires:       texlive-atkinson >= %{texlive_version}
#!BuildIgnore: texlive-atkinson
Requires:       texlive-augie >= %{texlive_version}
#!BuildIgnore: texlive-augie
Requires:       texlive-auncial-new >= %{texlive_version}
#!BuildIgnore: texlive-auncial-new
Requires:       texlive-aurical >= %{texlive_version}
#!BuildIgnore: texlive-aurical
Requires:       texlive-b1encoding >= %{texlive_version}
#!BuildIgnore: texlive-b1encoding
Requires:       texlive-barcodes >= %{texlive_version}
#!BuildIgnore: texlive-barcodes
Requires:       texlive-baskervald >= %{texlive_version}
#!BuildIgnore: texlive-baskervald
Requires:       texlive-baskervaldx >= %{texlive_version}
#!BuildIgnore: texlive-baskervaldx
Requires:       texlive-baskervillef >= %{texlive_version}
#!BuildIgnore: texlive-baskervillef
Requires:       texlive-bbding >= %{texlive_version}
#!BuildIgnore: texlive-bbding
Requires:       texlive-bbm >= %{texlive_version}
#!BuildIgnore: texlive-bbm
Requires:       texlive-bbm-macros >= %{texlive_version}
#!BuildIgnore: texlive-bbm-macros
Requires:       texlive-bbold >= %{texlive_version}
#!BuildIgnore: texlive-bbold
Requires:       texlive-bbold-type1 >= %{texlive_version}
#!BuildIgnore: texlive-bbold-type1
Requires:       texlive-bboldx >= %{texlive_version}
#!BuildIgnore: texlive-bboldx
Requires:       texlive-belleek >= %{texlive_version}
#!BuildIgnore: texlive-belleek
Requires:       texlive-bera >= %{texlive_version}
#!BuildIgnore: texlive-bera
Requires:       texlive-berenisadf >= %{texlive_version}
#!BuildIgnore: texlive-berenisadf
Requires:       texlive-beuron >= %{texlive_version}
#!BuildIgnore: texlive-beuron
Requires:       texlive-bguq >= %{texlive_version}
#!BuildIgnore: texlive-bguq
Requires:       texlive-bitter >= %{texlive_version}
#!BuildIgnore: texlive-bitter
Requires:       texlive-blacklettert1 >= %{texlive_version}
#!BuildIgnore: texlive-blacklettert1
Requires:       texlive-boisik >= %{texlive_version}
#!BuildIgnore: texlive-boisik
Requires:       texlive-bookhands >= %{texlive_version}
#!BuildIgnore: texlive-bookhands
Requires:       texlive-boondox >= %{texlive_version}
#!BuildIgnore: texlive-boondox
Requires:       texlive-braille >= %{texlive_version}
#!BuildIgnore: texlive-braille
Requires:       texlive-brushscr >= %{texlive_version}
#!BuildIgnore: texlive-brushscr
Requires:       texlive-cabin >= %{texlive_version}
#!BuildIgnore: texlive-cabin
Requires:       texlive-caladea >= %{texlive_version}
#!BuildIgnore: texlive-caladea
Requires:       texlive-calligra >= %{texlive_version}
#!BuildIgnore: texlive-calligra
Requires:       texlive-calligra-type1 >= %{texlive_version}
#!BuildIgnore: texlive-calligra-type1
Requires:       texlive-cantarell >= %{texlive_version}
#!BuildIgnore: texlive-cantarell
Requires:       texlive-carlito >= %{texlive_version}
#!BuildIgnore: texlive-carlito
Requires:       texlive-carolmin-ps >= %{texlive_version}
#!BuildIgnore: texlive-carolmin-ps
Requires:       texlive-cascadia-code >= %{texlive_version}
#!BuildIgnore: texlive-cascadia-code
Requires:       texlive-ccicons >= %{texlive_version}
#!BuildIgnore: texlive-ccicons
Requires:       texlive-cfr-initials >= %{texlive_version}
#!BuildIgnore: texlive-cfr-initials
Requires:       texlive-cfr-lm >= %{texlive_version}
#!BuildIgnore: texlive-cfr-lm
Requires:       texlive-charissil >= %{texlive_version}
#!BuildIgnore: texlive-charissil
Requires:       texlive-cherokee >= %{texlive_version}
#!BuildIgnore: texlive-cherokee
Requires:       texlive-chivo >= %{texlive_version}
#!BuildIgnore: texlive-chivo
Requires:       texlive-cinzel >= %{texlive_version}
#!BuildIgnore: texlive-cinzel
Requires:       texlive-clara >= %{texlive_version}
#!BuildIgnore: texlive-clara
Requires:       texlive-clearsans >= %{texlive_version}
#!BuildIgnore: texlive-clearsans
Requires:       texlive-cm-lgc >= %{texlive_version}
#!BuildIgnore: texlive-cm-lgc
Requires:       texlive-cm-mf-extra-bold >= %{texlive_version}
#!BuildIgnore: texlive-cm-mf-extra-bold
Requires:       texlive-cm-unicode >= %{texlive_version}
#!BuildIgnore: texlive-cm-unicode
Requires:       texlive-cmathbb >= %{texlive_version}
#!BuildIgnore: texlive-cmathbb
Requires:       texlive-cmbright >= %{texlive_version}
#!BuildIgnore: texlive-cmbright
Requires:       texlive-cmexb >= %{texlive_version}
#!BuildIgnore: texlive-cmexb
Requires:       texlive-cmll >= %{texlive_version}
#!BuildIgnore: texlive-cmll
Requires:       texlive-cmpica >= %{texlive_version}
#!BuildIgnore: texlive-cmpica
Requires:       texlive-cmsrb >= %{texlive_version}
#!BuildIgnore: texlive-cmsrb
Requires:       texlive-cmtiup >= %{texlive_version}
#!BuildIgnore: texlive-cmtiup
Requires:       texlive-cmupint >= %{texlive_version}
#!BuildIgnore: texlive-cmupint
Requires:       texlive-cochineal >= %{texlive_version}
#!BuildIgnore: texlive-cochineal
Requires:       texlive-coelacanth >= %{texlive_version}
#!BuildIgnore: texlive-coelacanth
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-comfortaa >= %{texlive_version}
#!BuildIgnore: texlive-comfortaa
Requires:       texlive-comicneue >= %{texlive_version}
#!BuildIgnore: texlive-comicneue
Requires:       texlive-concmath-fonts >= %{texlive_version}
#!BuildIgnore: texlive-concmath-fonts
Requires:       texlive-concmath-otf >= %{texlive_version}
#!BuildIgnore: texlive-concmath-otf
Requires:       texlive-cookingsymbols >= %{texlive_version}
#!BuildIgnore: texlive-cookingsymbols
Requires:       texlive-cooperhewitt >= %{texlive_version}
#!BuildIgnore: texlive-cooperhewitt
Requires:       texlive-cormorantgaramond >= %{texlive_version}
#!BuildIgnore: texlive-cormorantgaramond
Requires:       texlive-countriesofeurope >= %{texlive_version}
#!BuildIgnore: texlive-countriesofeurope
Requires:       texlive-courier-scaled >= %{texlive_version}
#!BuildIgnore: texlive-courier-scaled
Requires:       texlive-courierten >= %{texlive_version}
#!BuildIgnore: texlive-courierten
Requires:       texlive-crimson >= %{texlive_version}
#!BuildIgnore: texlive-crimson
Requires:       texlive-crimsonpro >= %{texlive_version}
#!BuildIgnore: texlive-crimsonpro
Requires:       texlive-cryst >= %{texlive_version}
#!BuildIgnore: texlive-cryst
Requires:       texlive-cuprum >= %{texlive_version}
#!BuildIgnore: texlive-cuprum
Requires:       texlive-cyklop >= %{texlive_version}
#!BuildIgnore: texlive-cyklop
Requires:       texlive-dancers >= %{texlive_version}
#!BuildIgnore: texlive-dancers
Requires:       texlive-dantelogo >= %{texlive_version}
#!BuildIgnore: texlive-dantelogo
Requires:       texlive-dejavu >= %{texlive_version}
#!BuildIgnore: texlive-dejavu
Requires:       texlive-dejavu-otf >= %{texlive_version}
#!BuildIgnore: texlive-dejavu-otf
Requires:       texlive-dice >= %{texlive_version}
#!BuildIgnore: texlive-dice
Requires:       texlive-dictsym >= %{texlive_version}
#!BuildIgnore: texlive-dictsym
Requires:       texlive-dingbat >= %{texlive_version}
#!BuildIgnore: texlive-dingbat
Requires:       texlive-domitian >= %{texlive_version}
#!BuildIgnore: texlive-domitian
Requires:       texlive-doublestroke >= %{texlive_version}
#!BuildIgnore: texlive-doublestroke
Requires:       texlive-doulossil >= %{texlive_version}
#!BuildIgnore: texlive-doulossil
Requires:       texlive-dozenal >= %{texlive_version}
#!BuildIgnore: texlive-dozenal
Requires:       texlive-drm >= %{texlive_version}
#!BuildIgnore: texlive-drm
Requires:       texlive-droid >= %{texlive_version}
#!BuildIgnore: texlive-droid
Requires:       texlive-dsserif >= %{texlive_version}
#!BuildIgnore: texlive-dsserif
Requires:       texlive-duerer >= %{texlive_version}
#!BuildIgnore: texlive-duerer
Requires:       texlive-duerer-latex >= %{texlive_version}
#!BuildIgnore: texlive-duerer-latex
Requires:       texlive-dutchcal >= %{texlive_version}
#!BuildIgnore: texlive-dutchcal
Requires:       texlive-ean >= %{texlive_version}
#!BuildIgnore: texlive-ean
Requires:       texlive-ebgaramond >= %{texlive_version}
#!BuildIgnore: texlive-ebgaramond
Requires:       texlive-ebgaramond-maths >= %{texlive_version}
#!BuildIgnore: texlive-ebgaramond-maths
Requires:       texlive-ecc >= %{texlive_version}
#!BuildIgnore: texlive-ecc
Requires:       texlive-eco >= %{texlive_version}
#!BuildIgnore: texlive-eco
Requires:       texlive-eczar >= %{texlive_version}
#!BuildIgnore: texlive-eczar
Requires:       texlive-eiad >= %{texlive_version}
#!BuildIgnore: texlive-eiad
Requires:       texlive-eiad-ltx >= %{texlive_version}
#!BuildIgnore: texlive-eiad-ltx
Requires:       texlive-ektype-tanka >= %{texlive_version}
#!BuildIgnore: texlive-ektype-tanka
Requires:       texlive-electrum >= %{texlive_version}
#!BuildIgnore: texlive-electrum
Requires:       texlive-elvish >= %{texlive_version}
#!BuildIgnore: texlive-elvish
Requires:       texlive-epigrafica >= %{texlive_version}
#!BuildIgnore: texlive-epigrafica
Requires:       texlive-epsdice >= %{texlive_version}
#!BuildIgnore: texlive-epsdice
Requires:       texlive-erewhon >= %{texlive_version}
#!BuildIgnore: texlive-erewhon
Requires:       texlive-erewhon-math >= %{texlive_version}
#!BuildIgnore: texlive-erewhon-math
Requires:       texlive-esrelation >= %{texlive_version}
#!BuildIgnore: texlive-esrelation
Requires:       texlive-esstix >= %{texlive_version}
#!BuildIgnore: texlive-esstix
Requires:       texlive-esvect >= %{texlive_version}
#!BuildIgnore: texlive-esvect
Requires:       texlive-etbb >= %{texlive_version}
#!BuildIgnore: texlive-etbb
Requires:       texlive-euler-math >= %{texlive_version}
#!BuildIgnore: texlive-euler-math
Requires:       texlive-eulervm >= %{texlive_version}
#!BuildIgnore: texlive-eulervm
Requires:       texlive-euxm >= %{texlive_version}
#!BuildIgnore: texlive-euxm
Requires:       texlive-fbb >= %{texlive_version}
#!BuildIgnore: texlive-fbb
Requires:       texlive-fdsymbol >= %{texlive_version}
#!BuildIgnore: texlive-fdsymbol
Requires:       texlive-fetamont >= %{texlive_version}
#!BuildIgnore: texlive-fetamont
Requires:       texlive-feyn >= %{texlive_version}
#!BuildIgnore: texlive-feyn
Requires:       texlive-fge >= %{texlive_version}
#!BuildIgnore: texlive-fge
Requires:       texlive-fira >= %{texlive_version}
#!BuildIgnore: texlive-fira
Requires:       texlive-firamath >= %{texlive_version}
#!BuildIgnore: texlive-firamath
Requires:       texlive-firamath-otf >= %{texlive_version}
#!BuildIgnore: texlive-firamath-otf
Requires:       texlive-foekfont >= %{texlive_version}
#!BuildIgnore: texlive-foekfont
Requires:       texlive-fonetika >= %{texlive_version}
#!BuildIgnore: texlive-fonetika
Requires:       texlive-fontawesome >= %{texlive_version}
#!BuildIgnore: texlive-fontawesome
Requires:       texlive-fontawesome5 >= %{texlive_version}
#!BuildIgnore: texlive-fontawesome5
Requires:       texlive-fontmfizz >= %{texlive_version}
#!BuildIgnore: texlive-fontmfizz
Requires:       texlive-fonts-churchslavonic >= %{texlive_version}
#!BuildIgnore: texlive-fonts-churchslavonic
Requires:       texlive-forum >= %{texlive_version}
#!BuildIgnore: texlive-forum
Requires:       texlive-fourier >= %{texlive_version}
#!BuildIgnore: texlive-fourier
Requires:       texlive-fouriernc >= %{texlive_version}
#!BuildIgnore: texlive-fouriernc
Requires:       texlive-frcursive >= %{texlive_version}
#!BuildIgnore: texlive-frcursive
Requires:       texlive-frederika2016 >= %{texlive_version}
#!BuildIgnore: texlive-frederika2016
Requires:       texlive-frimurer >= %{texlive_version}
#!BuildIgnore: texlive-frimurer
Requires:       texlive-garamond-libre >= %{texlive_version}
#!BuildIgnore: texlive-garamond-libre
Requires:       texlive-garamond-math >= %{texlive_version}
#!BuildIgnore: texlive-garamond-math
Requires:       texlive-genealogy >= %{texlive_version}
#!BuildIgnore: texlive-genealogy
Requires:       texlive-gentium-tug >= %{texlive_version}
#!BuildIgnore: texlive-gentium-tug
Requires:       texlive-gfsartemisia >= %{texlive_version}
#!BuildIgnore: texlive-gfsartemisia
Requires:       texlive-gfsbodoni >= %{texlive_version}
#!BuildIgnore: texlive-gfsbodoni
Requires:       texlive-gfscomplutum >= %{texlive_version}
#!BuildIgnore: texlive-gfscomplutum
Requires:       texlive-gfsdidot >= %{texlive_version}
#!BuildIgnore: texlive-gfsdidot
Requires:       texlive-gfsdidotclassic >= %{texlive_version}
#!BuildIgnore: texlive-gfsdidotclassic
Requires:       texlive-gfsneohellenic >= %{texlive_version}
#!BuildIgnore: texlive-gfsneohellenic
Requires:       texlive-gfsneohellenicmath >= %{texlive_version}
#!BuildIgnore: texlive-gfsneohellenicmath
Requires:       texlive-gfssolomos >= %{texlive_version}
#!BuildIgnore: texlive-gfssolomos
Requires:       texlive-gillcm >= %{texlive_version}
#!BuildIgnore: texlive-gillcm
Requires:       texlive-gillius >= %{texlive_version}
#!BuildIgnore: texlive-gillius
Requires:       texlive-gnu-freefont >= %{texlive_version}
#!BuildIgnore: texlive-gnu-freefont
Requires:       texlive-gofonts >= %{texlive_version}
#!BuildIgnore: texlive-gofonts
Requires:       texlive-gothic >= %{texlive_version}
#!BuildIgnore: texlive-gothic
Requires:       texlive-greenpoint >= %{texlive_version}
#!BuildIgnore: texlive-greenpoint
Requires:       texlive-grotesq >= %{texlive_version}
#!BuildIgnore: texlive-grotesq
Requires:       texlive-gudea >= %{texlive_version}
#!BuildIgnore: texlive-gudea
Requires:       texlive-hacm >= %{texlive_version}
#!BuildIgnore: texlive-hacm
Requires:       texlive-hamnosys >= %{texlive_version}
#!BuildIgnore: texlive-hamnosys
Requires:       texlive-hands >= %{texlive_version}
#!BuildIgnore: texlive-hands
Requires:       texlive-hep-font >= %{texlive_version}
#!BuildIgnore: texlive-hep-font
Requires:       texlive-hep-math-font >= %{texlive_version}
#!BuildIgnore: texlive-hep-math-font
Requires:       texlive-heros-otf >= %{texlive_version}
#!BuildIgnore: texlive-heros-otf
Requires:       texlive-heuristica >= %{texlive_version}
#!BuildIgnore: texlive-heuristica
Requires:       texlive-hfbright >= %{texlive_version}
#!BuildIgnore: texlive-hfbright
Requires:       texlive-hfoldsty >= %{texlive_version}
#!BuildIgnore: texlive-hfoldsty
Requires:       texlive-hindmadurai >= %{texlive_version}
#!BuildIgnore: texlive-hindmadurai
Requires:       texlive-ibarra >= %{texlive_version}
#!BuildIgnore: texlive-ibarra
Requires:       texlive-ifsym >= %{texlive_version}
#!BuildIgnore: texlive-ifsym
Requires:       texlive-imfellenglish >= %{texlive_version}
#!BuildIgnore: texlive-imfellenglish
Requires:       texlive-inconsolata >= %{texlive_version}
#!BuildIgnore: texlive-inconsolata
Requires:       texlive-initials >= %{texlive_version}
#!BuildIgnore: texlive-initials
Requires:       texlive-inriafonts >= %{texlive_version}
#!BuildIgnore: texlive-inriafonts
Requires:       texlive-inter >= %{texlive_version}
#!BuildIgnore: texlive-inter
Requires:       texlive-ipaex-type1 >= %{texlive_version}
#!BuildIgnore: texlive-ipaex-type1
Requires:       texlive-iwona >= %{texlive_version}
#!BuildIgnore: texlive-iwona
Requires:       texlive-jablantile >= %{texlive_version}
#!BuildIgnore: texlive-jablantile
Requires:       texlive-jamtimes >= %{texlive_version}
#!BuildIgnore: texlive-jamtimes
Requires:       texlive-josefin >= %{texlive_version}
#!BuildIgnore: texlive-josefin
Requires:       texlive-junicode >= %{texlive_version}
#!BuildIgnore: texlive-junicode
Requires:       texlive-kixfont >= %{texlive_version}
#!BuildIgnore: texlive-kixfont
Requires:       texlive-kpfonts >= %{texlive_version}
#!BuildIgnore: texlive-kpfonts
Requires:       texlive-kpfonts-otf >= %{texlive_version}
#!BuildIgnore: texlive-kpfonts-otf
Requires:       texlive-kurier >= %{texlive_version}
#!BuildIgnore: texlive-kurier
Requires:       texlive-lato >= %{texlive_version}
#!BuildIgnore: texlive-lato
Requires:       texlive-lexend >= %{texlive_version}
#!BuildIgnore: texlive-lexend
Requires:       texlive-lfb >= %{texlive_version}
#!BuildIgnore: texlive-lfb
Requires:       texlive-libertine >= %{texlive_version}
#!BuildIgnore: texlive-libertine
Requires:       texlive-libertinegc >= %{texlive_version}
#!BuildIgnore: texlive-libertinegc
Requires:       texlive-libertinus >= %{texlive_version}
#!BuildIgnore: texlive-libertinus
Requires:       texlive-libertinus-fonts >= %{texlive_version}
#!BuildIgnore: texlive-libertinus-fonts
Requires:       texlive-libertinus-otf >= %{texlive_version}
#!BuildIgnore: texlive-libertinus-otf
Requires:       texlive-libertinus-type1 >= %{texlive_version}
#!BuildIgnore: texlive-libertinus-type1
Requires:       texlive-libertinust1math >= %{texlive_version}
#!BuildIgnore: texlive-libertinust1math
Requires:       texlive-librebaskerville >= %{texlive_version}
#!BuildIgnore: texlive-librebaskerville
Requires:       texlive-librebodoni >= %{texlive_version}
#!BuildIgnore: texlive-librebodoni
Requires:       texlive-librecaslon >= %{texlive_version}
#!BuildIgnore: texlive-librecaslon
Requires:       texlive-librefranklin >= %{texlive_version}
#!BuildIgnore: texlive-librefranklin
Requires:       texlive-libris >= %{texlive_version}
#!BuildIgnore: texlive-libris
Requires:       texlive-lineara >= %{texlive_version}
#!BuildIgnore: texlive-lineara
Requires:       texlive-linguisticspro >= %{texlive_version}
#!BuildIgnore: texlive-linguisticspro
Requires:       texlive-lobster2 >= %{texlive_version}
#!BuildIgnore: texlive-lobster2
Requires:       texlive-logix >= %{texlive_version}
#!BuildIgnore: texlive-logix
Requires:       texlive-lxfonts >= %{texlive_version}
#!BuildIgnore: texlive-lxfonts
Requires:       texlive-ly1 >= %{texlive_version}
#!BuildIgnore: texlive-ly1
Requires:       texlive-magra >= %{texlive_version}
#!BuildIgnore: texlive-magra
Requires:       texlive-marcellus >= %{texlive_version}
#!BuildIgnore: texlive-marcellus
Requires:       texlive-mathabx >= %{texlive_version}
#!BuildIgnore: texlive-mathabx
Requires:       texlive-mathabx-type1 >= %{texlive_version}
#!BuildIgnore: texlive-mathabx-type1
Requires:       texlive-mathdesign >= %{texlive_version}
#!BuildIgnore: texlive-mathdesign
Requires:       texlive-mdputu >= %{texlive_version}
#!BuildIgnore: texlive-mdputu
Requires:       texlive-mdsymbol >= %{texlive_version}
#!BuildIgnore: texlive-mdsymbol
Requires:       texlive-merriweather >= %{texlive_version}
#!BuildIgnore: texlive-merriweather
Requires:       texlive-miama >= %{texlive_version}
#!BuildIgnore: texlive-miama
Requires:       texlive-mintspirit >= %{texlive_version}
#!BuildIgnore: texlive-mintspirit
Requires:       texlive-missaali >= %{texlive_version}
#!BuildIgnore: texlive-missaali
Requires:       texlive-mlmodern >= %{texlive_version}
#!BuildIgnore: texlive-mlmodern
Requires:       texlive-mnsymbol >= %{texlive_version}
#!BuildIgnore: texlive-mnsymbol
Requires:       texlive-montserrat >= %{texlive_version}
#!BuildIgnore: texlive-montserrat
Requires:       texlive-mpfonts >= %{texlive_version}
#!BuildIgnore: texlive-mpfonts
Requires:       texlive-mweights >= %{texlive_version}
#!BuildIgnore: texlive-mweights
Requires:       texlive-newcomputermodern >= %{texlive_version}
#!BuildIgnore: texlive-newcomputermodern
Requires:       texlive-newpx >= %{texlive_version}
#!BuildIgnore: texlive-newpx
Requires:       texlive-newtx >= %{texlive_version}
#!BuildIgnore: texlive-newtx
Requires:       texlive-newtxsf >= %{texlive_version}
#!BuildIgnore: texlive-newtxsf
Requires:       texlive-newtxtt >= %{texlive_version}
#!BuildIgnore: texlive-newtxtt
Requires:       texlive-niceframe-type1 >= %{texlive_version}
#!BuildIgnore: texlive-niceframe-type1
Requires:       texlive-nimbus15 >= %{texlive_version}
#!BuildIgnore: texlive-nimbus15
Requires:       texlive-nkarta >= %{texlive_version}
#!BuildIgnore: texlive-nkarta
Requires:       texlive-noto >= %{texlive_version}
#!BuildIgnore: texlive-noto
Requires:       texlive-noto-emoji >= %{texlive_version}
#!BuildIgnore: texlive-noto-emoji
Requires:       texlive-notomath >= %{texlive_version}
#!BuildIgnore: texlive-notomath
Requires:       texlive-nunito >= %{texlive_version}
#!BuildIgnore: texlive-nunito
Requires:       texlive-obnov >= %{texlive_version}
#!BuildIgnore: texlive-obnov
Requires:       texlive-ocherokee >= %{texlive_version}
#!BuildIgnore: texlive-ocherokee
Requires:       texlive-ocr-b >= %{texlive_version}
#!BuildIgnore: texlive-ocr-b
Requires:       texlive-ocr-b-outline >= %{texlive_version}
#!BuildIgnore: texlive-ocr-b-outline
Requires:       texlive-ogham >= %{texlive_version}
#!BuildIgnore: texlive-ogham
Requires:       texlive-oinuit >= %{texlive_version}
#!BuildIgnore: texlive-oinuit
Requires:       texlive-old-arrows >= %{texlive_version}
#!BuildIgnore: texlive-old-arrows
Requires:       texlive-oldlatin >= %{texlive_version}
#!BuildIgnore: texlive-oldlatin
Requires:       texlive-oldstandard >= %{texlive_version}
#!BuildIgnore: texlive-oldstandard
Requires:       texlive-opensans >= %{texlive_version}
#!BuildIgnore: texlive-opensans
Requires:       texlive-orkhun >= %{texlive_version}
#!BuildIgnore: texlive-orkhun
Requires:       texlive-oswald >= %{texlive_version}
#!BuildIgnore: texlive-oswald
Requires:       texlive-overlock >= %{texlive_version}
#!BuildIgnore: texlive-overlock
Requires:       texlive-pacioli >= %{texlive_version}
#!BuildIgnore: texlive-pacioli
Requires:       texlive-pagella-otf >= %{texlive_version}
#!BuildIgnore: texlive-pagella-otf
Requires:       texlive-paratype >= %{texlive_version}
#!BuildIgnore: texlive-paratype
Requires:       texlive-phaistos >= %{texlive_version}
#!BuildIgnore: texlive-phaistos
Requires:       texlive-phonetic >= %{texlive_version}
#!BuildIgnore: texlive-phonetic
Requires:       texlive-pigpen >= %{texlive_version}
#!BuildIgnore: texlive-pigpen
Requires:       texlive-playfair >= %{texlive_version}
#!BuildIgnore: texlive-playfair
Requires:       texlive-plex >= %{texlive_version}
#!BuildIgnore: texlive-plex
Requires:       texlive-plex-otf >= %{texlive_version}
#!BuildIgnore: texlive-plex-otf
Requires:       texlive-plimsoll >= %{texlive_version}
#!BuildIgnore: texlive-plimsoll
Requires:       texlive-poiretone >= %{texlive_version}
#!BuildIgnore: texlive-poiretone
Requires:       texlive-poltawski >= %{texlive_version}
#!BuildIgnore: texlive-poltawski
Requires:       texlive-prodint >= %{texlive_version}
#!BuildIgnore: texlive-prodint
Requires:       texlive-punk >= %{texlive_version}
#!BuildIgnore: texlive-punk
Requires:       texlive-punk-latex >= %{texlive_version}
#!BuildIgnore: texlive-punk-latex
Requires:       texlive-punknova >= %{texlive_version}
#!BuildIgnore: texlive-punknova
Requires:       texlive-pxtxalfa >= %{texlive_version}
#!BuildIgnore: texlive-pxtxalfa
Requires:       texlive-qualitype >= %{texlive_version}
#!BuildIgnore: texlive-qualitype
Requires:       texlive-quattrocento >= %{texlive_version}
#!BuildIgnore: texlive-quattrocento
Requires:       texlive-raleway >= %{texlive_version}
#!BuildIgnore: texlive-raleway
Requires:       texlive-recycle >= %{texlive_version}
#!BuildIgnore: texlive-recycle
Requires:       texlive-roboto >= %{texlive_version}
#!BuildIgnore: texlive-roboto
Requires:       texlive-romande >= %{texlive_version}
#!BuildIgnore: texlive-romande
Requires:       texlive-rosario >= %{texlive_version}
#!BuildIgnore: texlive-rosario
Requires:       texlive-rsfso >= %{texlive_version}
#!BuildIgnore: texlive-rsfso
Requires:       texlive-sansmathaccent >= %{texlive_version}
#!BuildIgnore: texlive-sansmathaccent
Requires:       texlive-sansmathfonts >= %{texlive_version}
#!BuildIgnore: texlive-sansmathfonts
Requires:       texlive-sauter >= %{texlive_version}
#!BuildIgnore: texlive-sauter
Requires:       texlive-sauterfonts >= %{texlive_version}
#!BuildIgnore: texlive-sauterfonts
Requires:       texlive-schola-otf >= %{texlive_version}
#!BuildIgnore: texlive-schola-otf
Requires:       texlive-scholax >= %{texlive_version}
#!BuildIgnore: texlive-scholax
Requires:       texlive-schulschriften >= %{texlive_version}
#!BuildIgnore: texlive-schulschriften
Requires:       texlive-semaphor >= %{texlive_version}
#!BuildIgnore: texlive-semaphor
Requires:       texlive-shobhika >= %{texlive_version}
#!BuildIgnore: texlive-shobhika
Requires:       texlive-simpleicons >= %{texlive_version}
#!BuildIgnore: texlive-simpleicons
Requires:       texlive-skull >= %{texlive_version}
#!BuildIgnore: texlive-skull
Requires:       texlive-sourcecodepro >= %{texlive_version}
#!BuildIgnore: texlive-sourcecodepro
Requires:       texlive-sourcesanspro >= %{texlive_version}
#!BuildIgnore: texlive-sourcesanspro
Requires:       texlive-sourceserifpro >= %{texlive_version}
#!BuildIgnore: texlive-sourceserifpro
Requires:       texlive-spectral >= %{texlive_version}
#!BuildIgnore: texlive-spectral
Requires:       texlive-srbtiks >= %{texlive_version}
#!BuildIgnore: texlive-srbtiks
Requires:       texlive-starfont >= %{texlive_version}
#!BuildIgnore: texlive-starfont
Requires:       texlive-staves >= %{texlive_version}
#!BuildIgnore: texlive-staves
Requires:       texlive-step >= %{texlive_version}
#!BuildIgnore: texlive-step
Requires:       texlive-stepgreek >= %{texlive_version}
#!BuildIgnore: texlive-stepgreek
Requires:       texlive-stickstoo >= %{texlive_version}
#!BuildIgnore: texlive-stickstoo
Requires:       texlive-stix >= %{texlive_version}
#!BuildIgnore: texlive-stix
Requires:       texlive-stix2-otf >= %{texlive_version}
#!BuildIgnore: texlive-stix2-otf
Requires:       texlive-stix2-type1 >= %{texlive_version}
#!BuildIgnore: texlive-stix2-type1
Requires:       texlive-superiors >= %{texlive_version}
#!BuildIgnore: texlive-superiors
Requires:       texlive-svrsymbols >= %{texlive_version}
#!BuildIgnore: texlive-svrsymbols
Requires:       texlive-symbats3 >= %{texlive_version}
#!BuildIgnore: texlive-symbats3
Requires:       texlive-tapir >= %{texlive_version}
#!BuildIgnore: texlive-tapir
Requires:       texlive-tempora >= %{texlive_version}
#!BuildIgnore: texlive-tempora
Requires:       texlive-tengwarscript >= %{texlive_version}
#!BuildIgnore: texlive-tengwarscript
Requires:       texlive-termes-otf >= %{texlive_version}
#!BuildIgnore: texlive-termes-otf
Requires:       texlive-tfrupee >= %{texlive_version}
#!BuildIgnore: texlive-tfrupee
Requires:       texlive-theanodidot >= %{texlive_version}
#!BuildIgnore: texlive-theanodidot
Requires:       texlive-theanomodern >= %{texlive_version}
#!BuildIgnore: texlive-theanomodern
Requires:       texlive-theanooldstyle >= %{texlive_version}
#!BuildIgnore: texlive-theanooldstyle
Requires:       texlive-tinos >= %{texlive_version}
#!BuildIgnore: texlive-tinos
Requires:       texlive-tpslifonts >= %{texlive_version}
#!BuildIgnore: texlive-tpslifonts
Requires:       texlive-trajan >= %{texlive_version}
#!BuildIgnore: texlive-trajan
Requires:       texlive-twemoji-colr >= %{texlive_version}
#!BuildIgnore: texlive-twemoji-colr
Requires:       texlive-txfontsb >= %{texlive_version}
#!BuildIgnore: texlive-txfontsb
Requires:       texlive-txuprcal >= %{texlive_version}
#!BuildIgnore: texlive-txuprcal
Requires:       texlive-typicons >= %{texlive_version}
#!BuildIgnore: texlive-typicons
Requires:       texlive-umtypewriter >= %{texlive_version}
#!BuildIgnore: texlive-umtypewriter
Requires:       texlive-universa >= %{texlive_version}
#!BuildIgnore: texlive-universa
Requires:       texlive-universalis >= %{texlive_version}
#!BuildIgnore: texlive-universalis
Requires:       texlive-uppunctlm >= %{texlive_version}
#!BuildIgnore: texlive-uppunctlm
Requires:       texlive-urwchancal >= %{texlive_version}
#!BuildIgnore: texlive-urwchancal
Requires:       texlive-venturisadf >= %{texlive_version}
#!BuildIgnore: texlive-venturisadf
Requires:       texlive-wsuipa >= %{texlive_version}
#!BuildIgnore: texlive-wsuipa
Requires:       texlive-xcharter >= %{texlive_version}
#!BuildIgnore: texlive-xcharter
Requires:       texlive-xcharter-math >= %{texlive_version}
#!BuildIgnore: texlive-xcharter-math
Requires:       texlive-xits >= %{texlive_version}
#!BuildIgnore: texlive-xits
Requires:       texlive-yfonts >= %{texlive_version}
#!BuildIgnore: texlive-yfonts
Requires:       texlive-yfonts-otf >= %{texlive_version}
#!BuildIgnore: texlive-yfonts-otf
Requires:       texlive-yfonts-t1 >= %{texlive_version}
#!BuildIgnore: texlive-yfonts-t1
Requires:       texlive-yinit-otf >= %{texlive_version}
#!BuildIgnore: texlive-yinit-otf
Requires:       texlive-zlmtt >= %{texlive_version}
#!BuildIgnore: texlive-zlmtt
BuildArch:      noarch

%description -n texlive-collection-fontsextra
The collection-fontsextra package

%package -n texlive-collection-fontsrecommended
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Recommended fonts
Group:          Productivity/Publishing/TeX/Fonts
URL:            https://www.tug.org/texlive/
Requires:       texlive-avantgar >= %{texlive_version}
#!BuildIgnore: texlive-avantgar
Requires:       texlive-bookman >= %{texlive_version}
#!BuildIgnore: texlive-bookman
Requires:       texlive-charter >= %{texlive_version}
#!BuildIgnore: texlive-charter
Requires:       texlive-cm-super >= %{texlive_version}
#!BuildIgnore: texlive-cm-super
Requires:       texlive-cmextra >= %{texlive_version}
#!BuildIgnore: texlive-cmextra
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-courier >= %{texlive_version}
#!BuildIgnore: texlive-courier
Requires:       texlive-euro >= %{texlive_version}
#!BuildIgnore: texlive-euro
Requires:       texlive-euro-ce >= %{texlive_version}
#!BuildIgnore: texlive-euro-ce
Requires:       texlive-eurosym >= %{texlive_version}
#!BuildIgnore: texlive-eurosym
Requires:       texlive-fpl >= %{texlive_version}
#!BuildIgnore: texlive-fpl
Requires:       texlive-helvetic >= %{texlive_version}
#!BuildIgnore: texlive-helvetic
Requires:       texlive-lm >= %{texlive_version}
#!BuildIgnore: texlive-lm
Requires:       texlive-lm-math >= %{texlive_version}
#!BuildIgnore: texlive-lm-math
Requires:       texlive-manfnt-font >= %{texlive_version}
#!BuildIgnore: texlive-manfnt-font
Requires:       texlive-marvosym >= %{texlive_version}
#!BuildIgnore: texlive-marvosym
Requires:       texlive-mathpazo >= %{texlive_version}
#!BuildIgnore: texlive-mathpazo
Requires:       texlive-mflogo-font >= %{texlive_version}
#!BuildIgnore: texlive-mflogo-font
Requires:       texlive-ncntrsbk >= %{texlive_version}
#!BuildIgnore: texlive-ncntrsbk
Requires:       texlive-palatino >= %{texlive_version}
#!BuildIgnore: texlive-palatino
Requires:       texlive-pxfonts >= %{texlive_version}
#!BuildIgnore: texlive-pxfonts
Requires:       texlive-rsfs >= %{texlive_version}
#!BuildIgnore: texlive-rsfs
Requires:       texlive-symbol >= %{texlive_version}
#!BuildIgnore: texlive-symbol
Requires:       texlive-tex-gyre >= %{texlive_version}
#!BuildIgnore: texlive-tex-gyre
Requires:       texlive-tex-gyre-math >= %{texlive_version}
#!BuildIgnore: texlive-tex-gyre-math
Requires:       texlive-times >= %{texlive_version}
#!BuildIgnore: texlive-times
Requires:       texlive-tipa >= %{texlive_version}
#!BuildIgnore: texlive-tipa
Requires:       texlive-txfonts >= %{texlive_version}
#!BuildIgnore: texlive-txfonts
Requires:       texlive-utopia >= %{texlive_version}
#!BuildIgnore: texlive-utopia
Requires:       texlive-wasy >= %{texlive_version}
#!BuildIgnore: texlive-wasy
Requires:       texlive-wasy-type1 >= %{texlive_version}
#!BuildIgnore: texlive-wasy-type1
Requires:       texlive-wasysym >= %{texlive_version}
#!BuildIgnore: texlive-wasysym
Requires:       texlive-zapfchan >= %{texlive_version}
#!BuildIgnore: texlive-zapfchan
Requires:       texlive-zapfding >= %{texlive_version}
#!BuildIgnore: texlive-zapfding
BuildArch:      noarch

%description -n texlive-collection-fontsrecommended
Recommended fonts, including the base 35 PostScript fonts,
Latin Modern, TeX Gyre, and T1 and other encoding support for
Computer Modern, in outline form.

%package -n texlive-collection-fontutils
Version:        %{texlive_version}.%{texlive_noarch}.svn61207
Release:        60.1
License:        LPPL-1.0
Summary:        Graphics and font utilities
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       psutils
Requires:       texlive-accfonts >= %{texlive_version}
#!BuildIgnore: texlive-accfonts
Requires:       texlive-afm2pl >= %{texlive_version}
#!BuildIgnore: texlive-afm2pl
Requires:       texlive-albatross >= %{texlive_version}
#!BuildIgnore: texlive-albatross
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-dosepsbin >= %{texlive_version}
#!BuildIgnore: texlive-dosepsbin
Requires:       texlive-dvipsconfig >= %{texlive_version}
#!BuildIgnore: texlive-dvipsconfig
Requires:       texlive-epstopdf >= %{texlive_version}
#!BuildIgnore: texlive-epstopdf
Requires:       texlive-fontinst >= %{texlive_version}
#!BuildIgnore: texlive-fontinst
Requires:       texlive-fontools >= %{texlive_version}
#!BuildIgnore: texlive-fontools
Requires:       texlive-fontware >= %{texlive_version}
#!BuildIgnore: texlive-fontware
Requires:       texlive-lcdftypetools >= %{texlive_version}
#!BuildIgnore: texlive-lcdftypetools
Requires:       texlive-luafindfont >= %{texlive_version}
#!BuildIgnore: texlive-luafindfont
Requires:       texlive-metatype1 >= %{texlive_version}
#!BuildIgnore: texlive-metatype1
Requires:       texlive-mf2pt1 >= %{texlive_version}
#!BuildIgnore: texlive-mf2pt1
Requires:       texlive-ps2eps >= %{texlive_version}
#!BuildIgnore: texlive-ps2eps
Requires:       texlive-ps2pk >= %{texlive_version}
#!BuildIgnore: texlive-ps2pk
Requires:       texlive-ttfutils >= %{texlive_version}
#!BuildIgnore: texlive-ttfutils
BuildArch:      noarch

%description -n texlive-collection-fontutils
Programs for conversion between font formats, testing fonts,
virtual fonts, .gf and .pk manipulation, mft, fontinst, etc.
Manipulating OpenType, TrueType, Type 1,and for manipulation of
PostScript and other image formats.

%package -n texlive-collection-formatsextra
Version:        %{texlive_version}.%{texlive_noarch}.svn62226
Release:        60.1
License:        LPPL-1.0
Summary:        Additional formats
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-aleph >= %{texlive_version}
#!BuildIgnore: texlive-aleph
Requires:       texlive-antomega >= %{texlive_version}
#!BuildIgnore: texlive-antomega
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-edmac >= %{texlive_version}
#!BuildIgnore: texlive-edmac
Requires:       texlive-eplain >= %{texlive_version}
#!BuildIgnore: texlive-eplain
Requires:       texlive-hitex >= %{texlive_version}
#!BuildIgnore: texlive-hitex
Requires:       texlive-jadetex >= %{texlive_version}
#!BuildIgnore: texlive-jadetex
Requires:       texlive-lambda >= %{texlive_version}
#!BuildIgnore: texlive-lambda
Requires:       texlive-lollipop >= %{texlive_version}
#!BuildIgnore: texlive-lollipop
Requires:       texlive-mltex >= %{texlive_version}
#!BuildIgnore: texlive-mltex
Requires:       texlive-mxedruli >= %{texlive_version}
#!BuildIgnore: texlive-mxedruli
Requires:       texlive-omega >= %{texlive_version}
#!BuildIgnore: texlive-omega
Requires:       texlive-omegaware >= %{texlive_version}
#!BuildIgnore: texlive-omegaware
Requires:       texlive-otibet >= %{texlive_version}
#!BuildIgnore: texlive-otibet
Requires:       texlive-passivetex >= %{texlive_version}
#!BuildIgnore: texlive-passivetex
Requires:       texlive-psizzl >= %{texlive_version}
#!BuildIgnore: texlive-psizzl
Requires:       texlive-startex >= %{texlive_version}
#!BuildIgnore: texlive-startex
Requires:       texlive-texsis >= %{texlive_version}
#!BuildIgnore: texlive-texsis
Requires:       texlive-xmltex >= %{texlive_version}
#!BuildIgnore: texlive-xmltex
Requires:       texlive-xmltexconfig >= %{texlive_version}
#!BuildIgnore: texlive-xmltexconfig
BuildArch:      noarch

%description -n texlive-collection-formatsextra
Collected TeX `formats', i.e., large-scale macro packages
designed to be dumped into .fmt files -- excluding the most
common ones, such as latex and context, which have their own
package(s). It also includes the Aleph engine and related Omega
formats and packages, and the HiTeX engine and related.

%package -n texlive-collection-games
Version:        %{texlive_version}.%{texlive_noarch}.svn65631
Release:        60.1
License:        LPPL-1.0
Summary:        Games typesetting
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-bartel-chess-fonts >= %{texlive_version}
#!BuildIgnore: texlive-bartel-chess-fonts
Requires:       texlive-chess >= %{texlive_version}
#!BuildIgnore: texlive-chess
Requires:       texlive-chess-problem-diagrams >= %{texlive_version}
#!BuildIgnore: texlive-chess-problem-diagrams
Requires:       texlive-chessboard >= %{texlive_version}
#!BuildIgnore: texlive-chessboard
Requires:       texlive-chessfss >= %{texlive_version}
#!BuildIgnore: texlive-chessfss
Requires:       texlive-chinesechess >= %{texlive_version}
#!BuildIgnore: texlive-chinesechess
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-crossword >= %{texlive_version}
#!BuildIgnore: texlive-crossword
Requires:       texlive-crosswrd >= %{texlive_version}
#!BuildIgnore: texlive-crosswrd
Requires:       texlive-customdice >= %{texlive_version}
#!BuildIgnore: texlive-customdice
Requires:       texlive-egameps >= %{texlive_version}
#!BuildIgnore: texlive-egameps
Requires:       texlive-gamebook >= %{texlive_version}
#!BuildIgnore: texlive-gamebook
Requires:       texlive-gamebooklib >= %{texlive_version}
#!BuildIgnore: texlive-gamebooklib
Requires:       texlive-go >= %{texlive_version}
#!BuildIgnore: texlive-go
Requires:       texlive-hanoi >= %{texlive_version}
#!BuildIgnore: texlive-hanoi
Requires:       texlive-havannah >= %{texlive_version}
#!BuildIgnore: texlive-havannah
Requires:       texlive-hexboard >= %{texlive_version}
#!BuildIgnore: texlive-hexboard
Requires:       texlive-hexgame >= %{texlive_version}
#!BuildIgnore: texlive-hexgame
Requires:       texlive-hmtrump >= %{texlive_version}
#!BuildIgnore: texlive-hmtrump
Requires:       texlive-horoscop >= %{texlive_version}
#!BuildIgnore: texlive-horoscop
Requires:       texlive-jeuxcartes >= %{texlive_version}
#!BuildIgnore: texlive-jeuxcartes
Requires:       texlive-jigsaw >= %{texlive_version}
#!BuildIgnore: texlive-jigsaw
Requires:       texlive-labyrinth >= %{texlive_version}
#!BuildIgnore: texlive-labyrinth
Requires:       texlive-logicpuzzle >= %{texlive_version}
#!BuildIgnore: texlive-logicpuzzle
Requires:       texlive-mahjong >= %{texlive_version}
#!BuildIgnore: texlive-mahjong
Requires:       texlive-maze >= %{texlive_version}
#!BuildIgnore: texlive-maze
Requires:       texlive-musikui >= %{texlive_version}
#!BuildIgnore: texlive-musikui
Requires:       texlive-nimsticks >= %{texlive_version}
#!BuildIgnore: texlive-nimsticks
Requires:       texlive-onedown >= %{texlive_version}
#!BuildIgnore: texlive-onedown
Requires:       texlive-othello >= %{texlive_version}
#!BuildIgnore: texlive-othello
Requires:       texlive-othelloboard >= %{texlive_version}
#!BuildIgnore: texlive-othelloboard
Requires:       texlive-pas-crosswords >= %{texlive_version}
#!BuildIgnore: texlive-pas-crosswords
Requires:       texlive-psgo >= %{texlive_version}
#!BuildIgnore: texlive-psgo
Requires:       texlive-realtranspose >= %{texlive_version}
#!BuildIgnore: texlive-realtranspose
Requires:       texlive-reverxii >= %{texlive_version}
#!BuildIgnore: texlive-reverxii
Requires:       texlive-rubik >= %{texlive_version}
#!BuildIgnore: texlive-rubik
Requires:       texlive-schwalbe-chess >= %{texlive_version}
#!BuildIgnore: texlive-schwalbe-chess
Requires:       texlive-scrabble >= %{texlive_version}
#!BuildIgnore: texlive-scrabble
Requires:       texlive-sgame >= %{texlive_version}
#!BuildIgnore: texlive-sgame
Requires:       texlive-skak >= %{texlive_version}
#!BuildIgnore: texlive-skak
Requires:       texlive-skaknew >= %{texlive_version}
#!BuildIgnore: texlive-skaknew
Requires:       texlive-soup >= %{texlive_version}
#!BuildIgnore: texlive-soup
Requires:       texlive-sudoku >= %{texlive_version}
#!BuildIgnore: texlive-sudoku
Requires:       texlive-sudokubundle >= %{texlive_version}
#!BuildIgnore: texlive-sudokubundle
Requires:       texlive-tangramtikz >= %{texlive_version}
#!BuildIgnore: texlive-tangramtikz
Requires:       texlive-wargame >= %{texlive_version}
#!BuildIgnore: texlive-wargame
Requires:       texlive-xq >= %{texlive_version}
#!BuildIgnore: texlive-xq
Requires:       texlive-xskak >= %{texlive_version}
#!BuildIgnore: texlive-xskak
BuildArch:      noarch

%description -n texlive-collection-games
Setups for typesetting various games, including chess.

%package -n texlive-collection-humanities
Version:        %{texlive_version}.%{texlive_noarch}.svn65216
Release:        60.1
License:        LPPL-1.0
Summary:        Humanities packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-adtrees >= %{texlive_version}
#!BuildIgnore: texlive-adtrees
Requires:       texlive-bibleref >= %{texlive_version}
#!BuildIgnore: texlive-bibleref
Requires:       texlive-bibleref-lds >= %{texlive_version}
#!BuildIgnore: texlive-bibleref-lds
Requires:       texlive-bibleref-mouth >= %{texlive_version}
#!BuildIgnore: texlive-bibleref-mouth
Requires:       texlive-bibleref-parse >= %{texlive_version}
#!BuildIgnore: texlive-bibleref-parse
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-covington >= %{texlive_version}
#!BuildIgnore: texlive-covington
Requires:       texlive-diadia >= %{texlive_version}
#!BuildIgnore: texlive-diadia
Requires:       texlive-dramatist >= %{texlive_version}
#!BuildIgnore: texlive-dramatist
Requires:       texlive-dvgloss >= %{texlive_version}
#!BuildIgnore: texlive-dvgloss
Requires:       texlive-ecltree >= %{texlive_version}
#!BuildIgnore: texlive-ecltree
Requires:       texlive-edfnotes >= %{texlive_version}
#!BuildIgnore: texlive-edfnotes
Requires:       texlive-eledform >= %{texlive_version}
#!BuildIgnore: texlive-eledform
Requires:       texlive-eledmac >= %{texlive_version}
#!BuildIgnore: texlive-eledmac
Requires:       texlive-expex >= %{texlive_version}
#!BuildIgnore: texlive-expex
Requires:       texlive-gb4e >= %{texlive_version}
#!BuildIgnore: texlive-gb4e
Requires:       texlive-gmverse >= %{texlive_version}
#!BuildIgnore: texlive-gmverse
Requires:       texlive-jura >= %{texlive_version}
#!BuildIgnore: texlive-jura
Requires:       texlive-juraabbrev >= %{texlive_version}
#!BuildIgnore: texlive-juraabbrev
Requires:       texlive-juramisc >= %{texlive_version}
#!BuildIgnore: texlive-juramisc
Requires:       texlive-jurarsp >= %{texlive_version}
#!BuildIgnore: texlive-jurarsp
Requires:       texlive-langnames >= %{texlive_version}
#!BuildIgnore: texlive-langnames
Requires:       texlive-ledmac >= %{texlive_version}
#!BuildIgnore: texlive-ledmac
Requires:       texlive-lexikon >= %{texlive_version}
#!BuildIgnore: texlive-lexikon
Requires:       texlive-lexref >= %{texlive_version}
#!BuildIgnore: texlive-lexref
Requires:       texlive-ling-macros >= %{texlive_version}
#!BuildIgnore: texlive-ling-macros
Requires:       texlive-linguex >= %{texlive_version}
#!BuildIgnore: texlive-linguex
Requires:       texlive-liturg >= %{texlive_version}
#!BuildIgnore: texlive-liturg
Requires:       texlive-metrix >= %{texlive_version}
#!BuildIgnore: texlive-metrix
Requires:       texlive-nnext >= %{texlive_version}
#!BuildIgnore: texlive-nnext
Requires:       texlive-parallel >= %{texlive_version}
#!BuildIgnore: texlive-parallel
Requires:       texlive-parrun >= %{texlive_version}
#!BuildIgnore: texlive-parrun
Requires:       texlive-phonrule >= %{texlive_version}
#!BuildIgnore: texlive-phonrule
Requires:       texlive-plari >= %{texlive_version}
#!BuildIgnore: texlive-plari
Requires:       texlive-play >= %{texlive_version}
#!BuildIgnore: texlive-play
Requires:       texlive-poemscol >= %{texlive_version}
#!BuildIgnore: texlive-poemscol
Requires:       texlive-poetry >= %{texlive_version}
#!BuildIgnore: texlive-poetry
Requires:       texlive-poetrytex >= %{texlive_version}
#!BuildIgnore: texlive-poetrytex
Requires:       texlive-qobitree >= %{texlive_version}
#!BuildIgnore: texlive-qobitree
Requires:       texlive-qtree >= %{texlive_version}
#!BuildIgnore: texlive-qtree
Requires:       texlive-reledmac >= %{texlive_version}
#!BuildIgnore: texlive-reledmac
Requires:       texlive-rrgtrees >= %{texlive_version}
#!BuildIgnore: texlive-rrgtrees
Requires:       texlive-rtklage >= %{texlive_version}
#!BuildIgnore: texlive-rtklage
Requires:       texlive-screenplay >= %{texlive_version}
#!BuildIgnore: texlive-screenplay
Requires:       texlive-screenplay-pkg >= %{texlive_version}
#!BuildIgnore: texlive-screenplay-pkg
Requires:       texlive-sides >= %{texlive_version}
#!BuildIgnore: texlive-sides
Requires:       texlive-stage >= %{texlive_version}
#!BuildIgnore: texlive-stage
Requires:       texlive-textglos >= %{texlive_version}
#!BuildIgnore: texlive-textglos
Requires:       texlive-thalie >= %{texlive_version}
#!BuildIgnore: texlive-thalie
Requires:       texlive-theatre >= %{texlive_version}
#!BuildIgnore: texlive-theatre
Requires:       texlive-tree-dvips >= %{texlive_version}
#!BuildIgnore: texlive-tree-dvips
Requires:       texlive-verse >= %{texlive_version}
#!BuildIgnore: texlive-verse
Requires:       texlive-xyling >= %{texlive_version}
#!BuildIgnore: texlive-xyling
BuildArch:      noarch

%description -n texlive-collection-humanities
Packages for law, linguistics, social sciences, humanities,
etc.

%package -n texlive-collection-langarabic
Version:        %{texlive_version}.%{texlive_noarch}.svn59594
Release:        60.1
License:        LPPL-1.0
Summary:        Arabic
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-arab <= %{texlive_previous}
Requires:       texlive-alkalami >= %{texlive_version}
#!BuildIgnore: texlive-alkalami
Requires:       texlive-alpha-persian >= %{texlive_version}
#!BuildIgnore: texlive-alpha-persian
Requires:       texlive-amiri >= %{texlive_version}
#!BuildIgnore: texlive-amiri
Requires:       texlive-arabi >= %{texlive_version}
#!BuildIgnore: texlive-arabi
Requires:       texlive-arabi-add >= %{texlive_version}
#!BuildIgnore: texlive-arabi-add
Requires:       texlive-arabic-book >= %{texlive_version}
#!BuildIgnore: texlive-arabic-book
Requires:       texlive-arabluatex >= %{texlive_version}
#!BuildIgnore: texlive-arabluatex
Requires:       texlive-arabtex >= %{texlive_version}
#!BuildIgnore: texlive-arabtex
Requires:       texlive-bidi >= %{texlive_version}
#!BuildIgnore: texlive-bidi
Requires:       texlive-bidihl >= %{texlive_version}
#!BuildIgnore: texlive-bidihl
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-dad >= %{texlive_version}
#!BuildIgnore: texlive-dad
Requires:       texlive-ghab >= %{texlive_version}
#!BuildIgnore: texlive-ghab
Requires:       texlive-hvarabic >= %{texlive_version}
#!BuildIgnore: texlive-hvarabic
Requires:       texlive-hyphen-arabic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-arabic
Requires:       texlive-hyphen-farsi >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-farsi
Requires:       texlive-imsproc >= %{texlive_version}
#!BuildIgnore: texlive-imsproc
Requires:       texlive-kurdishlipsum >= %{texlive_version}
#!BuildIgnore: texlive-kurdishlipsum
Requires:       texlive-lshort-persian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-persian
Requires:       texlive-luabidi >= %{texlive_version}
#!BuildIgnore: texlive-luabidi
Requires:       texlive-na-box >= %{texlive_version}
#!BuildIgnore: texlive-na-box
Requires:       texlive-persian-bib >= %{texlive_version}
#!BuildIgnore: texlive-persian-bib
Requires:       texlive-quran >= %{texlive_version}
#!BuildIgnore: texlive-quran
Requires:       texlive-sexam >= %{texlive_version}
#!BuildIgnore: texlive-sexam
Requires:       texlive-simurgh >= %{texlive_version}
#!BuildIgnore: texlive-simurgh
Requires:       texlive-texnegar >= %{texlive_version}
#!BuildIgnore: texlive-texnegar
Requires:       texlive-tram >= %{texlive_version}
#!BuildIgnore: texlive-tram
Requires:       texlive-xepersian >= %{texlive_version}
#!BuildIgnore: texlive-xepersian
Requires:       texlive-xepersian-hm >= %{texlive_version}
#!BuildIgnore: texlive-xepersian-hm
BuildArch:      noarch

%description -n texlive-collection-langarabic
Support for Arabic and Persian.

%package -n texlive-collection-langchinese
Version:        %{texlive_version}.%{texlive_noarch}.svn63995
Release:        60.1
License:        LPPL-1.0
Summary:        Chinese
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-arphic >= %{texlive_version}
#!BuildIgnore: texlive-arphic
Requires:       texlive-arphic-ttf >= %{texlive_version}
#!BuildIgnore: texlive-arphic-ttf
Requires:       texlive-asymptote-by-example-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-asymptote-by-example-zh-cn
Requires:       texlive-asymptote-faq-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-asymptote-faq-zh-cn
Requires:       texlive-asymptote-manual-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-asymptote-manual-zh-cn
Requires:       texlive-cns >= %{texlive_version}
#!BuildIgnore: texlive-cns
Requires:       texlive-collection-langcjk >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcjk
Requires:       texlive-ctex >= %{texlive_version}
#!BuildIgnore: texlive-ctex
Requires:       texlive-ctex-faq >= %{texlive_version}
#!BuildIgnore: texlive-ctex-faq
Requires:       texlive-exam-zh >= %{texlive_version}
#!BuildIgnore: texlive-exam-zh
Requires:       texlive-fandol >= %{texlive_version}
#!BuildIgnore: texlive-fandol
Requires:       texlive-fduthesis >= %{texlive_version}
#!BuildIgnore: texlive-fduthesis
Requires:       texlive-hanzibox >= %{texlive_version}
#!BuildIgnore: texlive-hanzibox
Requires:       texlive-hyphen-chinese >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-chinese
Requires:       texlive-impatient-cn >= %{texlive_version}
#!BuildIgnore: texlive-impatient-cn
Requires:       texlive-install-latex-guide-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-install-latex-guide-zh-cn
Requires:       texlive-latex-notes-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-latex-notes-zh-cn
Requires:       texlive-lshort-chinese >= %{texlive_version}
#!BuildIgnore: texlive-lshort-chinese
Requires:       texlive-nanicolle >= %{texlive_version}
#!BuildIgnore: texlive-nanicolle
Requires:       texlive-njurepo >= %{texlive_version}
#!BuildIgnore: texlive-njurepo
Requires:       texlive-pgfornament-han >= %{texlive_version}
#!BuildIgnore: texlive-pgfornament-han
Requires:       texlive-qyxf-book >= %{texlive_version}
#!BuildIgnore: texlive-qyxf-book
Requires:       texlive-texlive-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-texlive-zh-cn
Requires:       texlive-texproposal >= %{texlive_version}
#!BuildIgnore: texlive-texproposal
Requires:       texlive-tlmgr-intro-zh-cn >= %{texlive_version}
#!BuildIgnore: texlive-tlmgr-intro-zh-cn
Requires:       texlive-upzhkinsoku >= %{texlive_version}
#!BuildIgnore: texlive-upzhkinsoku
Requires:       texlive-xpinyin >= %{texlive_version}
#!BuildIgnore: texlive-xpinyin
Requires:       texlive-xtuthesis >= %{texlive_version}
#!BuildIgnore: texlive-xtuthesis
Requires:       texlive-zhlineskip >= %{texlive_version}
#!BuildIgnore: texlive-zhlineskip
Requires:       texlive-zhlipsum >= %{texlive_version}
#!BuildIgnore: texlive-zhlipsum
Requires:       texlive-zhmetrics >= %{texlive_version}
#!BuildIgnore: texlive-zhmetrics
Requires:       texlive-zhmetrics-uptex >= %{texlive_version}
#!BuildIgnore: texlive-zhmetrics-uptex
Requires:       texlive-zhnumber >= %{texlive_version}
#!BuildIgnore: texlive-zhnumber
Requires:       texlive-zhspacing >= %{texlive_version}
#!BuildIgnore: texlive-zhspacing
BuildArch:      noarch

%description -n texlive-collection-langchinese
Support for Chinese; additional packages in collection-langcjk.

%package -n texlive-collection-langcjk
Version:        %{texlive_version}.%{texlive_noarch}.svn65824
Release:        60.1
License:        LPPL-1.0
Summary:        Chinese/Japanese/Korean (base)
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-cjk <= %{texlive_previous}
Obsoletes:      texlive-cjk-latex-extras <= %{texlive_previous}
Requires:       texlive-adobemapping >= %{texlive_version}
#!BuildIgnore: texlive-adobemapping
Requires:       texlive-c90 >= %{texlive_version}
#!BuildIgnore: texlive-c90
Requires:       texlive-cjk >= %{texlive_version}
#!BuildIgnore: texlive-cjk
Requires:       texlive-cjk-gs-integrate >= %{texlive_version}
#!BuildIgnore: texlive-cjk-gs-integrate
Requires:       texlive-cjkpunct >= %{texlive_version}
#!BuildIgnore: texlive-cjkpunct
Requires:       texlive-cjkutils >= %{texlive_version}
#!BuildIgnore: texlive-cjkutils
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-dnp >= %{texlive_version}
#!BuildIgnore: texlive-dnp
Requires:       texlive-evangelion-jfm >= %{texlive_version}
#!BuildIgnore: texlive-evangelion-jfm
Requires:       texlive-fixjfm >= %{texlive_version}
#!BuildIgnore: texlive-fixjfm
Requires:       texlive-garuda-c90 >= %{texlive_version}
#!BuildIgnore: texlive-garuda-c90
Requires:       texlive-jfmutil >= %{texlive_version}
#!BuildIgnore: texlive-jfmutil
Requires:       texlive-norasi-c90 >= %{texlive_version}
#!BuildIgnore: texlive-norasi-c90
Requires:       texlive-pxtatescale >= %{texlive_version}
#!BuildIgnore: texlive-pxtatescale
Requires:       texlive-xcjk2uni >= %{texlive_version}
#!BuildIgnore: texlive-xcjk2uni
Requires:       texlive-xecjk >= %{texlive_version}
#!BuildIgnore: texlive-xecjk
Requires:       texlive-zitie >= %{texlive_version}
#!BuildIgnore: texlive-zitie
Requires:       texlive-zxjafont >= %{texlive_version}
#!BuildIgnore: texlive-zxjafont
BuildArch:      noarch

%description -n texlive-collection-langcjk
Packages supporting a combination of Chinese, Japanese, Korean,
including macros, fonts, documentation. Also Thai in the c90
encoding, since there is some overlap in those fonts; standard
Thai support is in collection-langother. Additional packages
for CJK are in their individual language collections.

%package -n texlive-collection-langcyrillic
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Cyrillic
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-belarusian >= %{texlive_version}
#!BuildIgnore: texlive-babel-belarusian
Requires:       texlive-babel-bulgarian >= %{texlive_version}
#!BuildIgnore: texlive-babel-bulgarian
Requires:       texlive-babel-russian >= %{texlive_version}
#!BuildIgnore: texlive-babel-russian
Requires:       texlive-babel-serbian >= %{texlive_version}
#!BuildIgnore: texlive-babel-serbian
Requires:       texlive-babel-serbianc >= %{texlive_version}
#!BuildIgnore: texlive-babel-serbianc
Requires:       texlive-babel-ukrainian >= %{texlive_version}
#!BuildIgnore: texlive-babel-ukrainian
Requires:       texlive-churchslavonic >= %{texlive_version}
#!BuildIgnore: texlive-churchslavonic
Requires:       texlive-cmcyr >= %{texlive_version}
#!BuildIgnore: texlive-cmcyr
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-cyrillic >= %{texlive_version}
#!BuildIgnore: texlive-cyrillic
Requires:       texlive-cyrillic-bin >= %{texlive_version}
#!BuildIgnore: texlive-cyrillic-bin
Requires:       texlive-cyrplain >= %{texlive_version}
#!BuildIgnore: texlive-cyrplain
Requires:       texlive-disser >= %{texlive_version}
#!BuildIgnore: texlive-disser
Requires:       texlive-eskd >= %{texlive_version}
#!BuildIgnore: texlive-eskd
Requires:       texlive-eskdx >= %{texlive_version}
#!BuildIgnore: texlive-eskdx
Requires:       texlive-gost >= %{texlive_version}
#!BuildIgnore: texlive-gost
Requires:       texlive-hyphen-belarusian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-belarusian
Requires:       texlive-hyphen-bulgarian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-bulgarian
Requires:       texlive-hyphen-churchslavonic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-churchslavonic
Requires:       texlive-hyphen-mongolian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-mongolian
Requires:       texlive-hyphen-russian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-russian
Requires:       texlive-hyphen-serbian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-serbian
Requires:       texlive-hyphen-ukrainian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-ukrainian
Requires:       texlive-lcyw >= %{texlive_version}
#!BuildIgnore: texlive-lcyw
Requires:       texlive-lh >= %{texlive_version}
#!BuildIgnore: texlive-lh
Requires:       texlive-lhcyr >= %{texlive_version}
#!BuildIgnore: texlive-lhcyr
Requires:       texlive-lshort-bulgarian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-bulgarian
Requires:       texlive-lshort-mongol >= %{texlive_version}
#!BuildIgnore: texlive-lshort-mongol
Requires:       texlive-lshort-russian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-russian
Requires:       texlive-lshort-ukr >= %{texlive_version}
#!BuildIgnore: texlive-lshort-ukr
Requires:       texlive-mongolian-babel >= %{texlive_version}
#!BuildIgnore: texlive-mongolian-babel
Requires:       texlive-montex >= %{texlive_version}
#!BuildIgnore: texlive-montex
Requires:       texlive-mpman-ru >= %{texlive_version}
#!BuildIgnore: texlive-mpman-ru
Requires:       texlive-numnameru >= %{texlive_version}
#!BuildIgnore: texlive-numnameru
Requires:       texlive-pst-eucl-translation-bg >= %{texlive_version}
#!BuildIgnore: texlive-pst-eucl-translation-bg
Requires:       texlive-ruhyphen >= %{texlive_version}
#!BuildIgnore: texlive-ruhyphen
Requires:       texlive-russ >= %{texlive_version}
#!BuildIgnore: texlive-russ
Requires:       texlive-serbian-apostrophe >= %{texlive_version}
#!BuildIgnore: texlive-serbian-apostrophe
Requires:       texlive-serbian-date-lat >= %{texlive_version}
#!BuildIgnore: texlive-serbian-date-lat
Requires:       texlive-serbian-def-cyr >= %{texlive_version}
#!BuildIgnore: texlive-serbian-def-cyr
Requires:       texlive-serbian-lig >= %{texlive_version}
#!BuildIgnore: texlive-serbian-lig
Requires:       texlive-t2 >= %{texlive_version}
#!BuildIgnore: texlive-t2
Requires:       texlive-texlive-ru >= %{texlive_version}
#!BuildIgnore: texlive-texlive-ru
Requires:       texlive-texlive-sr >= %{texlive_version}
#!BuildIgnore: texlive-texlive-sr
Requires:       texlive-ukrhyph >= %{texlive_version}
#!BuildIgnore: texlive-ukrhyph
Requires:       texlive-xecyrmongolian >= %{texlive_version}
#!BuildIgnore: texlive-xecyrmongolian
BuildArch:      noarch

%description -n texlive-collection-langcyrillic
Support for Cyrillic scripts (Bulgarian, Russian, Serbian,
Ukrainian), even if Latin alphabets may also be used.

%package -n texlive-collection-langczechslovak
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Czech/Slovak
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-czech >= %{texlive_version}
#!BuildIgnore: texlive-babel-czech
Requires:       texlive-babel-slovak >= %{texlive_version}
#!BuildIgnore: texlive-babel-slovak
Requires:       texlive-cnbwp >= %{texlive_version}
#!BuildIgnore: texlive-cnbwp
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-cs >= %{texlive_version}
#!BuildIgnore: texlive-cs
Requires:       texlive-csbulletin >= %{texlive_version}
#!BuildIgnore: texlive-csbulletin
Requires:       texlive-cslatex >= %{texlive_version}
#!BuildIgnore: texlive-cslatex
Requires:       texlive-csplain >= %{texlive_version}
#!BuildIgnore: texlive-csplain
Requires:       texlive-cstex >= %{texlive_version}
#!BuildIgnore: texlive-cstex
Requires:       texlive-hyphen-czech >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-czech
Requires:       texlive-hyphen-slovak >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-slovak
Requires:       texlive-lshort-czech >= %{texlive_version}
#!BuildIgnore: texlive-lshort-czech
Requires:       texlive-lshort-slovak >= %{texlive_version}
#!BuildIgnore: texlive-lshort-slovak
Requires:       texlive-texlive-cz >= %{texlive_version}
#!BuildIgnore: texlive-texlive-cz
Requires:       texlive-vlna >= %{texlive_version}
#!BuildIgnore: texlive-vlna
BuildArch:      noarch

%description -n texlive-collection-langczechslovak
Support for Czech/Slovak.

%package -n texlive-collection-langenglish
Version:        %{texlive_version}.%{texlive_noarch}.svn65496
Release:        60.1
License:        LPPL-1.0
Summary:        US and UK English
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-amiweb2c-guide >= %{texlive_version}
#!BuildIgnore: texlive-amiweb2c-guide
Requires:       texlive-amscls-doc >= %{texlive_version}
#!BuildIgnore: texlive-amscls-doc
Requires:       texlive-amslatex-primer >= %{texlive_version}
#!BuildIgnore: texlive-amslatex-primer
Requires:       texlive-around-the-bend >= %{texlive_version}
#!BuildIgnore: texlive-around-the-bend
Requires:       texlive-ascii-chart >= %{texlive_version}
#!BuildIgnore: texlive-ascii-chart
Requires:       texlive-biblatex-cheatsheet >= %{texlive_version}
#!BuildIgnore: texlive-biblatex-cheatsheet
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-components >= %{texlive_version}
#!BuildIgnore: texlive-components
Requires:       texlive-comprehensive >= %{texlive_version}
#!BuildIgnore: texlive-comprehensive
Requires:       texlive-dickimaw >= %{texlive_version}
#!BuildIgnore: texlive-dickimaw
Requires:       texlive-docsurvey >= %{texlive_version}
#!BuildIgnore: texlive-docsurvey
Requires:       texlive-dtxtut >= %{texlive_version}
#!BuildIgnore: texlive-dtxtut
Requires:       texlive-first-latex-doc >= %{texlive_version}
#!BuildIgnore: texlive-first-latex-doc
Requires:       texlive-fontinstallationguide >= %{texlive_version}
#!BuildIgnore: texlive-fontinstallationguide
Requires:       texlive-forest-quickstart >= %{texlive_version}
#!BuildIgnore: texlive-forest-quickstart
Requires:       texlive-gentle >= %{texlive_version}
#!BuildIgnore: texlive-gentle
Requires:       texlive-guide-to-latex >= %{texlive_version}
#!BuildIgnore: texlive-guide-to-latex
Requires:       texlive-happy4th >= %{texlive_version}
#!BuildIgnore: texlive-happy4th
Requires:       texlive-hyphen-english >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-english
Requires:       texlive-impatient >= %{texlive_version}
#!BuildIgnore: texlive-impatient
Requires:       texlive-intro-scientific >= %{texlive_version}
#!BuildIgnore: texlive-intro-scientific
Requires:       texlive-knuth-errata >= %{texlive_version}
#!BuildIgnore: texlive-knuth-errata
Requires:       texlive-knuth-hint >= %{texlive_version}
#!BuildIgnore: texlive-knuth-hint
Requires:       texlive-knuth-pdf >= %{texlive_version}
#!BuildIgnore: texlive-knuth-pdf
Requires:       texlive-l2tabu-english >= %{texlive_version}
#!BuildIgnore: texlive-l2tabu-english
Requires:       texlive-latex-brochure >= %{texlive_version}
#!BuildIgnore: texlive-latex-brochure
Requires:       texlive-latex-course >= %{texlive_version}
#!BuildIgnore: texlive-latex-course
Requires:       texlive-latex-doc-ptr >= %{texlive_version}
#!BuildIgnore: texlive-latex-doc-ptr
Requires:       texlive-latex-for-undergraduates >= %{texlive_version}
#!BuildIgnore: texlive-latex-for-undergraduates
Requires:       texlive-latex-graphics-companion >= %{texlive_version}
#!BuildIgnore: texlive-latex-graphics-companion
Requires:       texlive-latex-refsheet >= %{texlive_version}
#!BuildIgnore: texlive-latex-refsheet
Requires:       texlive-latex-veryshortguide >= %{texlive_version}
#!BuildIgnore: texlive-latex-veryshortguide
Requires:       texlive-latex-web-companion >= %{texlive_version}
#!BuildIgnore: texlive-latex-web-companion
Requires:       texlive-latex2e-help-texinfo >= %{texlive_version}
#!BuildIgnore: texlive-latex2e-help-texinfo
Requires:       texlive-latex4wp >= %{texlive_version}
#!BuildIgnore: texlive-latex4wp
Requires:       texlive-latexcheat >= %{texlive_version}
#!BuildIgnore: texlive-latexcheat
Requires:       texlive-latexcourse-rug >= %{texlive_version}
#!BuildIgnore: texlive-latexcourse-rug
Requires:       texlive-latexfileinfo-pkgs >= %{texlive_version}
#!BuildIgnore: texlive-latexfileinfo-pkgs
Requires:       texlive-lshort-english >= %{texlive_version}
#!BuildIgnore: texlive-lshort-english
Requires:       texlive-macros2e >= %{texlive_version}
#!BuildIgnore: texlive-macros2e
Requires:       texlive-math-into-latex-4 >= %{texlive_version}
#!BuildIgnore: texlive-math-into-latex-4
Requires:       texlive-maths-symbols >= %{texlive_version}
#!BuildIgnore: texlive-maths-symbols
Requires:       texlive-memdesign >= %{texlive_version}
#!BuildIgnore: texlive-memdesign
Requires:       texlive-memoirchapterstyles >= %{texlive_version}
#!BuildIgnore: texlive-memoirchapterstyles
Requires:       texlive-metafont-beginners >= %{texlive_version}
#!BuildIgnore: texlive-metafont-beginners
Requires:       texlive-metapost-examples >= %{texlive_version}
#!BuildIgnore: texlive-metapost-examples
Requires:       texlive-patgen2-tutorial >= %{texlive_version}
#!BuildIgnore: texlive-patgen2-tutorial
Requires:       texlive-pictexsum >= %{texlive_version}
#!BuildIgnore: texlive-pictexsum
Requires:       texlive-plain-doc >= %{texlive_version}
#!BuildIgnore: texlive-plain-doc
Requires:       texlive-short-math-guide >= %{texlive_version}
#!BuildIgnore: texlive-short-math-guide
Requires:       texlive-simplified-latex >= %{texlive_version}
#!BuildIgnore: texlive-simplified-latex
Requires:       texlive-svg-inkscape >= %{texlive_version}
#!BuildIgnore: texlive-svg-inkscape
Requires:       texlive-tamethebeast >= %{texlive_version}
#!BuildIgnore: texlive-tamethebeast
Requires:       texlive-tds >= %{texlive_version}
#!BuildIgnore: texlive-tds
Requires:       texlive-tex-font-errors-cheatsheet >= %{texlive_version}
#!BuildIgnore: texlive-tex-font-errors-cheatsheet
Requires:       texlive-tex-nutshell >= %{texlive_version}
#!BuildIgnore: texlive-tex-nutshell
Requires:       texlive-tex-overview >= %{texlive_version}
#!BuildIgnore: texlive-tex-overview
Requires:       texlive-tex-refs >= %{texlive_version}
#!BuildIgnore: texlive-tex-refs
Requires:       texlive-tex-vpat >= %{texlive_version}
#!BuildIgnore: texlive-tex-vpat
Requires:       texlive-texbytopic >= %{texlive_version}
#!BuildIgnore: texlive-texbytopic
Requires:       texlive-texonly >= %{texlive_version}
#!BuildIgnore: texlive-texonly
Requires:       texlive-titlepages >= %{texlive_version}
#!BuildIgnore: texlive-titlepages
Requires:       texlive-tlc2 >= %{texlive_version}
#!BuildIgnore: texlive-tlc2
Requires:       texlive-tlc3-examples >= %{texlive_version}
#!BuildIgnore: texlive-tlc3-examples
Requires:       texlive-tlmgrbasics >= %{texlive_version}
#!BuildIgnore: texlive-tlmgrbasics
Requires:       texlive-undergradmath >= %{texlive_version}
#!BuildIgnore: texlive-undergradmath
Requires:       texlive-visualfaq >= %{texlive_version}
#!BuildIgnore: texlive-visualfaq
Requires:       texlive-webguide >= %{texlive_version}
#!BuildIgnore: texlive-webguide
Requires:       texlive-xetexref >= %{texlive_version}
#!BuildIgnore: texlive-xetexref
Requires:       texlive-yet-another-guide-latex2e >= %{texlive_version}
#!BuildIgnore: texlive-yet-another-guide-latex2e
BuildArch:      noarch

%description -n texlive-collection-langenglish
Support for, and documentation in, English.

%package -n texlive-collection-langeuropean
Version:        %{texlive_version}.%{texlive_noarch}.svn66432
Release:        60.1
License:        LPPL-1.0
Summary:        Other European languages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-armtex >= %{texlive_version}
#!BuildIgnore: texlive-armtex
Requires:       texlive-babel-albanian >= %{texlive_version}
#!BuildIgnore: texlive-babel-albanian
Requires:       texlive-babel-bosnian >= %{texlive_version}
#!BuildIgnore: texlive-babel-bosnian
Requires:       texlive-babel-breton >= %{texlive_version}
#!BuildIgnore: texlive-babel-breton
Requires:       texlive-babel-croatian >= %{texlive_version}
#!BuildIgnore: texlive-babel-croatian
Requires:       texlive-babel-danish >= %{texlive_version}
#!BuildIgnore: texlive-babel-danish
Requires:       texlive-babel-dutch >= %{texlive_version}
#!BuildIgnore: texlive-babel-dutch
Requires:       texlive-babel-estonian >= %{texlive_version}
#!BuildIgnore: texlive-babel-estonian
Requires:       texlive-babel-finnish >= %{texlive_version}
#!BuildIgnore: texlive-babel-finnish
Requires:       texlive-babel-friulan >= %{texlive_version}
#!BuildIgnore: texlive-babel-friulan
Requires:       texlive-babel-hungarian >= %{texlive_version}
#!BuildIgnore: texlive-babel-hungarian
Requires:       texlive-babel-icelandic >= %{texlive_version}
#!BuildIgnore: texlive-babel-icelandic
Requires:       texlive-babel-irish >= %{texlive_version}
#!BuildIgnore: texlive-babel-irish
Requires:       texlive-babel-kurmanji >= %{texlive_version}
#!BuildIgnore: texlive-babel-kurmanji
Requires:       texlive-babel-latin >= %{texlive_version}
#!BuildIgnore: texlive-babel-latin
Requires:       texlive-babel-latvian >= %{texlive_version}
#!BuildIgnore: texlive-babel-latvian
Requires:       texlive-babel-lithuanian >= %{texlive_version}
#!BuildIgnore: texlive-babel-lithuanian
Requires:       texlive-babel-macedonian >= %{texlive_version}
#!BuildIgnore: texlive-babel-macedonian
Requires:       texlive-babel-norsk >= %{texlive_version}
#!BuildIgnore: texlive-babel-norsk
Requires:       texlive-babel-occitan >= %{texlive_version}
#!BuildIgnore: texlive-babel-occitan
Requires:       texlive-babel-piedmontese >= %{texlive_version}
#!BuildIgnore: texlive-babel-piedmontese
Requires:       texlive-babel-romanian >= %{texlive_version}
#!BuildIgnore: texlive-babel-romanian
Requires:       texlive-babel-romansh >= %{texlive_version}
#!BuildIgnore: texlive-babel-romansh
Requires:       texlive-babel-samin >= %{texlive_version}
#!BuildIgnore: texlive-babel-samin
Requires:       texlive-babel-scottish >= %{texlive_version}
#!BuildIgnore: texlive-babel-scottish
Requires:       texlive-babel-slovenian >= %{texlive_version}
#!BuildIgnore: texlive-babel-slovenian
Requires:       texlive-babel-swedish >= %{texlive_version}
#!BuildIgnore: texlive-babel-swedish
Requires:       texlive-babel-turkish >= %{texlive_version}
#!BuildIgnore: texlive-babel-turkish
Requires:       texlive-babel-welsh >= %{texlive_version}
#!BuildIgnore: texlive-babel-welsh
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-finbib >= %{texlive_version}
#!BuildIgnore: texlive-finbib
Requires:       texlive-gloss-occitan >= %{texlive_version}
#!BuildIgnore: texlive-gloss-occitan
Requires:       texlive-hrlatex >= %{texlive_version}
#!BuildIgnore: texlive-hrlatex
Requires:       texlive-huaz >= %{texlive_version}
#!BuildIgnore: texlive-huaz
Requires:       texlive-hulipsum >= %{texlive_version}
#!BuildIgnore: texlive-hulipsum
Requires:       texlive-hyphen-croatian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-croatian
Requires:       texlive-hyphen-danish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-danish
Requires:       texlive-hyphen-dutch >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-dutch
Requires:       texlive-hyphen-estonian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-estonian
Requires:       texlive-hyphen-finnish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-finnish
Requires:       texlive-hyphen-friulan >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-friulan
Requires:       texlive-hyphen-hungarian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-hungarian
Requires:       texlive-hyphen-icelandic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-icelandic
Requires:       texlive-hyphen-irish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-irish
Requires:       texlive-hyphen-kurmanji >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-kurmanji
Requires:       texlive-hyphen-latin >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-latin
Requires:       texlive-hyphen-latvian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-latvian
Requires:       texlive-hyphen-lithuanian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-lithuanian
Requires:       texlive-hyphen-macedonian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-macedonian
Requires:       texlive-hyphen-norwegian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-norwegian
Requires:       texlive-hyphen-occitan >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-occitan
Requires:       texlive-hyphen-piedmontese >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-piedmontese
Requires:       texlive-hyphen-romanian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-romanian
Requires:       texlive-hyphen-romansh >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-romansh
Requires:       texlive-hyphen-slovenian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-slovenian
Requires:       texlive-hyphen-swedish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-swedish
Requires:       texlive-hyphen-turkish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-turkish
Requires:       texlive-hyphen-uppersorbian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-uppersorbian
Requires:       texlive-hyphen-welsh >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-welsh
Requires:       texlive-kaytannollista-latexia >= %{texlive_version}
#!BuildIgnore: texlive-kaytannollista-latexia
Requires:       texlive-lithuanian >= %{texlive_version}
#!BuildIgnore: texlive-lithuanian
Requires:       texlive-lshort-dutch >= %{texlive_version}
#!BuildIgnore: texlive-lshort-dutch
Requires:       texlive-lshort-estonian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-estonian
Requires:       texlive-lshort-finnish >= %{texlive_version}
#!BuildIgnore: texlive-lshort-finnish
Requires:       texlive-lshort-slovenian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-slovenian
Requires:       texlive-lshort-turkish >= %{texlive_version}
#!BuildIgnore: texlive-lshort-turkish
Requires:       texlive-nevelok >= %{texlive_version}
#!BuildIgnore: texlive-nevelok
Requires:       texlive-rojud >= %{texlive_version}
#!BuildIgnore: texlive-rojud
Requires:       texlive-swebib >= %{texlive_version}
#!BuildIgnore: texlive-swebib
Requires:       texlive-turkmen >= %{texlive_version}
#!BuildIgnore: texlive-turkmen
BuildArch:      noarch

%description -n texlive-collection-langeuropean
Support for a number of European languages; others (Greek,
German, French, ...) have their own collections, depending
simply on the size of the support.

%package -n texlive-collection-langfrench
Version:        %{texlive_version}.%{texlive_noarch}.svn63147
Release:        60.1
License:        LPPL-1.0
Summary:        French
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-aeguill >= %{texlive_version}
#!BuildIgnore: texlive-aeguill
Requires:       texlive-annee-scolaire >= %{texlive_version}
#!BuildIgnore: texlive-annee-scolaire
Requires:       texlive-apprendre-a-programmer-en-tex >= %{texlive_version}
#!BuildIgnore: texlive-apprendre-a-programmer-en-tex
Requires:       texlive-apprends-latex >= %{texlive_version}
#!BuildIgnore: texlive-apprends-latex
Requires:       texlive-babel-basque >= %{texlive_version}
#!BuildIgnore: texlive-babel-basque
Requires:       texlive-babel-french >= %{texlive_version}
#!BuildIgnore: texlive-babel-french
Requires:       texlive-basque-book >= %{texlive_version}
#!BuildIgnore: texlive-basque-book
Requires:       texlive-basque-date >= %{texlive_version}
#!BuildIgnore: texlive-basque-date
Requires:       texlive-bib-fr >= %{texlive_version}
#!BuildIgnore: texlive-bib-fr
Requires:       texlive-bibleref-french >= %{texlive_version}
#!BuildIgnore: texlive-bibleref-french
Requires:       texlive-booktabs-fr >= %{texlive_version}
#!BuildIgnore: texlive-booktabs-fr
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-droit-fr >= %{texlive_version}
#!BuildIgnore: texlive-droit-fr
Requires:       texlive-e-french >= %{texlive_version}
#!BuildIgnore: texlive-e-french
Requires:       texlive-epslatex-fr >= %{texlive_version}
#!BuildIgnore: texlive-epslatex-fr
Requires:       texlive-expose-expl3-dunkerque-2019 >= %{texlive_version}
#!BuildIgnore: texlive-expose-expl3-dunkerque-2019
Requires:       texlive-facture >= %{texlive_version}
#!BuildIgnore: texlive-facture
Requires:       texlive-formation-latex-ul >= %{texlive_version}
#!BuildIgnore: texlive-formation-latex-ul
Requires:       texlive-frenchmath >= %{texlive_version}
#!BuildIgnore: texlive-frenchmath
Requires:       texlive-frletter >= %{texlive_version}
#!BuildIgnore: texlive-frletter
Requires:       texlive-frpseudocode >= %{texlive_version}
#!BuildIgnore: texlive-frpseudocode
Requires:       texlive-hyphen-basque >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-basque
Requires:       texlive-hyphen-french >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-french
Requires:       texlive-impatient-fr >= %{texlive_version}
#!BuildIgnore: texlive-impatient-fr
Requires:       texlive-impnattypo >= %{texlive_version}
#!BuildIgnore: texlive-impnattypo
Requires:       texlive-l2tabu-french >= %{texlive_version}
#!BuildIgnore: texlive-l2tabu-french
Requires:       texlive-latex2e-help-texinfo-fr >= %{texlive_version}
#!BuildIgnore: texlive-latex2e-help-texinfo-fr
Requires:       texlive-letgut >= %{texlive_version}
#!BuildIgnore: texlive-letgut
Requires:       texlive-lshort-french >= %{texlive_version}
#!BuildIgnore: texlive-lshort-french
Requires:       texlive-mafr >= %{texlive_version}
#!BuildIgnore: texlive-mafr
Requires:       texlive-matapli >= %{texlive_version}
#!BuildIgnore: texlive-matapli
Requires:       texlive-profcollege >= %{texlive_version}
#!BuildIgnore: texlive-profcollege
Requires:       texlive-proflabo >= %{texlive_version}
#!BuildIgnore: texlive-proflabo
Requires:       texlive-proflycee >= %{texlive_version}
#!BuildIgnore: texlive-proflycee
Requires:       texlive-tabvar >= %{texlive_version}
#!BuildIgnore: texlive-tabvar
Requires:       texlive-tdsfrmath >= %{texlive_version}
#!BuildIgnore: texlive-tdsfrmath
Requires:       texlive-texlive-fr >= %{texlive_version}
#!BuildIgnore: texlive-texlive-fr
Requires:       texlive-translation-array-fr >= %{texlive_version}
#!BuildIgnore: texlive-translation-array-fr
Requires:       texlive-translation-dcolumn-fr >= %{texlive_version}
#!BuildIgnore: texlive-translation-dcolumn-fr
Requires:       texlive-translation-natbib-fr >= %{texlive_version}
#!BuildIgnore: texlive-translation-natbib-fr
Requires:       texlive-translation-tabbing-fr >= %{texlive_version}
#!BuildIgnore: texlive-translation-tabbing-fr
Requires:       texlive-variations >= %{texlive_version}
#!BuildIgnore: texlive-variations
Requires:       texlive-visualfaq-fr >= %{texlive_version}
#!BuildIgnore: texlive-visualfaq-fr
Requires:       texlive-visualtikz >= %{texlive_version}
#!BuildIgnore: texlive-visualtikz
BuildArch:      noarch

%description -n texlive-collection-langfrench
Support for French and Basque.

%package -n texlive-collection-langgerman
Version:        %{texlive_version}.%{texlive_noarch}.svn55706
Release:        60.1
License:        LPPL-1.0
Summary:        German
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-apalike-german >= %{texlive_version}
#!BuildIgnore: texlive-apalike-german
Requires:       texlive-babel-german >= %{texlive_version}
#!BuildIgnore: texlive-babel-german
Requires:       texlive-bibleref-german >= %{texlive_version}
#!BuildIgnore: texlive-bibleref-german
Requires:       texlive-booktabs-de >= %{texlive_version}
#!BuildIgnore: texlive-booktabs-de
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-csquotes-de >= %{texlive_version}
#!BuildIgnore: texlive-csquotes-de
Requires:       texlive-dehyph >= %{texlive_version}
#!BuildIgnore: texlive-dehyph
Requires:       texlive-dehyph-exptl >= %{texlive_version}
#!BuildIgnore: texlive-dehyph-exptl
Requires:       texlive-dhua >= %{texlive_version}
#!BuildIgnore: texlive-dhua
Requires:       texlive-dtk-bibliography >= %{texlive_version}
#!BuildIgnore: texlive-dtk-bibliography
Requires:       texlive-etdipa >= %{texlive_version}
#!BuildIgnore: texlive-etdipa
Requires:       texlive-etoolbox-de >= %{texlive_version}
#!BuildIgnore: texlive-etoolbox-de
Requires:       texlive-fifinddo-info >= %{texlive_version}
#!BuildIgnore: texlive-fifinddo-info
Requires:       texlive-german >= %{texlive_version}
#!BuildIgnore: texlive-german
Requires:       texlive-germbib >= %{texlive_version}
#!BuildIgnore: texlive-germbib
Requires:       texlive-germkorr >= %{texlive_version}
#!BuildIgnore: texlive-germkorr
Requires:       texlive-hausarbeit-jura >= %{texlive_version}
#!BuildIgnore: texlive-hausarbeit-jura
Requires:       texlive-hyphen-german >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-german
Requires:       texlive-koma-script-examples >= %{texlive_version}
#!BuildIgnore: texlive-koma-script-examples
Requires:       texlive-l2picfaq >= %{texlive_version}
#!BuildIgnore: texlive-l2picfaq
Requires:       texlive-l2tabu >= %{texlive_version}
#!BuildIgnore: texlive-l2tabu
Requires:       texlive-latexcheat-de >= %{texlive_version}
#!BuildIgnore: texlive-latexcheat-de
Requires:       texlive-lshort-german >= %{texlive_version}
#!BuildIgnore: texlive-lshort-german
Requires:       texlive-lualatex-doc-de >= %{texlive_version}
#!BuildIgnore: texlive-lualatex-doc-de
Requires:       texlive-microtype-de >= %{texlive_version}
#!BuildIgnore: texlive-microtype-de
Requires:       texlive-milog >= %{texlive_version}
#!BuildIgnore: texlive-milog
Requires:       texlive-quran-de >= %{texlive_version}
#!BuildIgnore: texlive-quran-de
Requires:       texlive-r_und_s >= %{texlive_version}
#!BuildIgnore: texlive-r_und_s
Requires:       texlive-schulmathematik >= %{texlive_version}
#!BuildIgnore: texlive-schulmathematik
Requires:       texlive-templates-fenn >= %{texlive_version}
#!BuildIgnore: texlive-templates-fenn
Requires:       texlive-templates-sommer >= %{texlive_version}
#!BuildIgnore: texlive-templates-sommer
Requires:       texlive-termcal-de >= %{texlive_version}
#!BuildIgnore: texlive-termcal-de
Requires:       texlive-texlive-de >= %{texlive_version}
#!BuildIgnore: texlive-texlive-de
Requires:       texlive-tipa-de >= %{texlive_version}
#!BuildIgnore: texlive-tipa-de
Requires:       texlive-translation-arsclassica-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-arsclassica-de
Requires:       texlive-translation-biblatex-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-biblatex-de
Requires:       texlive-translation-chemsym-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-chemsym-de
Requires:       texlive-translation-ecv-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-ecv-de
Requires:       texlive-translation-enumitem-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-enumitem-de
Requires:       texlive-translation-europecv-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-europecv-de
Requires:       texlive-translation-filecontents-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-filecontents-de
Requires:       texlive-translation-moreverb-de >= %{texlive_version}
#!BuildIgnore: texlive-translation-moreverb-de
Requires:       texlive-udesoftec >= %{texlive_version}
#!BuildIgnore: texlive-udesoftec
Requires:       texlive-uhrzeit >= %{texlive_version}
#!BuildIgnore: texlive-uhrzeit
Requires:       texlive-umlaute >= %{texlive_version}
#!BuildIgnore: texlive-umlaute
Requires:       texlive-voss-mathcol >= %{texlive_version}
#!BuildIgnore: texlive-voss-mathcol
BuildArch:      noarch

%description -n texlive-collection-langgerman
Support for German.

%package -n texlive-collection-langgreek
Version:        %{texlive_version}.%{texlive_noarch}.svn65038
Release:        60.1
License:        LPPL-1.0
Summary:        Greek
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-greek >= %{texlive_version}
#!BuildIgnore: texlive-babel-greek
Requires:       texlive-begingreek >= %{texlive_version}
#!BuildIgnore: texlive-begingreek
Requires:       texlive-betababel >= %{texlive_version}
#!BuildIgnore: texlive-betababel
Requires:       texlive-cbfonts >= %{texlive_version}
#!BuildIgnore: texlive-cbfonts
Requires:       texlive-cbfonts-fd >= %{texlive_version}
#!BuildIgnore: texlive-cbfonts-fd
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-gfsbaskerville >= %{texlive_version}
#!BuildIgnore: texlive-gfsbaskerville
Requires:       texlive-gfsporson >= %{texlive_version}
#!BuildIgnore: texlive-gfsporson
Requires:       texlive-greek-fontenc >= %{texlive_version}
#!BuildIgnore: texlive-greek-fontenc
Requires:       texlive-greek-inputenc >= %{texlive_version}
#!BuildIgnore: texlive-greek-inputenc
Requires:       texlive-greekdates >= %{texlive_version}
#!BuildIgnore: texlive-greekdates
Requires:       texlive-greektex >= %{texlive_version}
#!BuildIgnore: texlive-greektex
Requires:       texlive-greektonoi >= %{texlive_version}
#!BuildIgnore: texlive-greektonoi
Requires:       texlive-hyphen-ancientgreek >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-ancientgreek
Requires:       texlive-hyphen-greek >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-greek
Requires:       texlive-ibycus-babel >= %{texlive_version}
#!BuildIgnore: texlive-ibycus-babel
Requires:       texlive-ibygrk >= %{texlive_version}
#!BuildIgnore: texlive-ibygrk
Requires:       texlive-kerkis >= %{texlive_version}
#!BuildIgnore: texlive-kerkis
Requires:       texlive-levy >= %{texlive_version}
#!BuildIgnore: texlive-levy
Requires:       texlive-lgreek >= %{texlive_version}
#!BuildIgnore: texlive-lgreek
Requires:       texlive-lgrmath >= %{texlive_version}
#!BuildIgnore: texlive-lgrmath
Requires:       texlive-mkgrkindex >= %{texlive_version}
#!BuildIgnore: texlive-mkgrkindex
Requires:       texlive-talos >= %{texlive_version}
#!BuildIgnore: texlive-talos
Requires:       texlive-teubner >= %{texlive_version}
#!BuildIgnore: texlive-teubner
Requires:       texlive-xgreek >= %{texlive_version}
#!BuildIgnore: texlive-xgreek
Requires:       texlive-yannisgr >= %{texlive_version}
#!BuildIgnore: texlive-yannisgr
BuildArch:      noarch

%description -n texlive-collection-langgreek
Support for Greek.

%package -n texlive-collection-langitalian
Version:        %{texlive_version}.%{texlive_noarch}.svn55129
Release:        60.1
License:        LPPL-1.0
Summary:        Italian
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-amsldoc-it >= %{texlive_version}
#!BuildIgnore: texlive-amsldoc-it
Requires:       texlive-amsmath-it >= %{texlive_version}
#!BuildIgnore: texlive-amsmath-it
Requires:       texlive-amsthdoc-it >= %{texlive_version}
#!BuildIgnore: texlive-amsthdoc-it
Requires:       texlive-antanilipsum >= %{texlive_version}
#!BuildIgnore: texlive-antanilipsum
Requires:       texlive-babel-italian >= %{texlive_version}
#!BuildIgnore: texlive-babel-italian
Requires:       texlive-codicefiscaleitaliano >= %{texlive_version}
#!BuildIgnore: texlive-codicefiscaleitaliano
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-fancyhdr-it >= %{texlive_version}
#!BuildIgnore: texlive-fancyhdr-it
Requires:       texlive-fixltxhyph >= %{texlive_version}
#!BuildIgnore: texlive-fixltxhyph
Requires:       texlive-frontespizio >= %{texlive_version}
#!BuildIgnore: texlive-frontespizio
Requires:       texlive-hyphen-italian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-italian
Requires:       texlive-itnumpar >= %{texlive_version}
#!BuildIgnore: texlive-itnumpar
Requires:       texlive-l2tabu-italian >= %{texlive_version}
#!BuildIgnore: texlive-l2tabu-italian
Requires:       texlive-latex4wp-it >= %{texlive_version}
#!BuildIgnore: texlive-latex4wp-it
Requires:       texlive-layaureo >= %{texlive_version}
#!BuildIgnore: texlive-layaureo
Requires:       texlive-lshort-italian >= %{texlive_version}
#!BuildIgnore: texlive-lshort-italian
Requires:       texlive-psfrag-italian >= %{texlive_version}
#!BuildIgnore: texlive-psfrag-italian
Requires:       texlive-texlive-it >= %{texlive_version}
#!BuildIgnore: texlive-texlive-it
Requires:       texlive-verifica >= %{texlive_version}
#!BuildIgnore: texlive-verifica
BuildArch:      noarch

%description -n texlive-collection-langitalian
Support for Italian.

%package -n texlive-collection-langjapanese
Version:        %{texlive_version}.%{texlive_noarch}.svn64603
Release:        60.1
License:        LPPL-1.0
Summary:        Japanese
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-ascmac >= %{texlive_version}
#!BuildIgnore: texlive-ascmac
Requires:       texlive-asternote >= %{texlive_version}
#!BuildIgnore: texlive-asternote
Requires:       texlive-babel-japanese >= %{texlive_version}
#!BuildIgnore: texlive-babel-japanese
Requires:       texlive-bxbase >= %{texlive_version}
#!BuildIgnore: texlive-bxbase
Requires:       texlive-bxcjkjatype >= %{texlive_version}
#!BuildIgnore: texlive-bxcjkjatype
Requires:       texlive-bxghost >= %{texlive_version}
#!BuildIgnore: texlive-bxghost
Requires:       texlive-bxjaholiday >= %{texlive_version}
#!BuildIgnore: texlive-bxjaholiday
Requires:       texlive-bxjalipsum >= %{texlive_version}
#!BuildIgnore: texlive-bxjalipsum
Requires:       texlive-bxjaprnind >= %{texlive_version}
#!BuildIgnore: texlive-bxjaprnind
Requires:       texlive-bxjatoucs >= %{texlive_version}
#!BuildIgnore: texlive-bxjatoucs
Requires:       texlive-bxjscls >= %{texlive_version}
#!BuildIgnore: texlive-bxjscls
Requires:       texlive-bxorigcapt >= %{texlive_version}
#!BuildIgnore: texlive-bxorigcapt
Requires:       texlive-bxwareki >= %{texlive_version}
#!BuildIgnore: texlive-bxwareki
Requires:       texlive-collection-langcjk >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcjk
Requires:       texlive-convbkmk >= %{texlive_version}
#!BuildIgnore: texlive-convbkmk
Requires:       texlive-endnotesj >= %{texlive_version}
#!BuildIgnore: texlive-endnotesj
Requires:       texlive-gckanbun >= %{texlive_version}
#!BuildIgnore: texlive-gckanbun
Requires:       texlive-gentombow >= %{texlive_version}
#!BuildIgnore: texlive-gentombow
Requires:       texlive-haranoaji >= %{texlive_version}
#!BuildIgnore: texlive-haranoaji
Requires:       texlive-haranoaji-extra >= %{texlive_version}
#!BuildIgnore: texlive-haranoaji-extra
Requires:       texlive-ieejtran >= %{texlive_version}
#!BuildIgnore: texlive-ieejtran
Requires:       texlive-ifptex >= %{texlive_version}
#!BuildIgnore: texlive-ifptex
Requires:       texlive-ifxptex >= %{texlive_version}
#!BuildIgnore: texlive-ifxptex
Requires:       texlive-ipaex >= %{texlive_version}
#!BuildIgnore: texlive-ipaex
Requires:       texlive-japanese-mathformulas >= %{texlive_version}
#!BuildIgnore: texlive-japanese-mathformulas
Requires:       texlive-japanese-otf >= %{texlive_version}
#!BuildIgnore: texlive-japanese-otf
Requires:       texlive-jieeetran >= %{texlive_version}
#!BuildIgnore: texlive-jieeetran
Requires:       texlive-jlreq >= %{texlive_version}
#!BuildIgnore: texlive-jlreq
Requires:       texlive-jlreq-deluxe >= %{texlive_version}
#!BuildIgnore: texlive-jlreq-deluxe
Requires:       texlive-jpneduenumerate >= %{texlive_version}
#!BuildIgnore: texlive-jpneduenumerate
Requires:       texlive-jpnedumathsymbols >= %{texlive_version}
#!BuildIgnore: texlive-jpnedumathsymbols
Requires:       texlive-jsclasses >= %{texlive_version}
#!BuildIgnore: texlive-jsclasses
Requires:       texlive-kanbun >= %{texlive_version}
#!BuildIgnore: texlive-kanbun
Requires:       texlive-lshort-japanese >= %{texlive_version}
#!BuildIgnore: texlive-lshort-japanese
Requires:       texlive-luatexja >= %{texlive_version}
#!BuildIgnore: texlive-luatexja
Requires:       texlive-mendex-doc >= %{texlive_version}
#!BuildIgnore: texlive-mendex-doc
Requires:       texlive-morisawa >= %{texlive_version}
#!BuildIgnore: texlive-morisawa
Requires:       texlive-pbibtex-base >= %{texlive_version}
#!BuildIgnore: texlive-pbibtex-base
Requires:       texlive-pbibtex-manual >= %{texlive_version}
#!BuildIgnore: texlive-pbibtex-manual
Requires:       texlive-platex >= %{texlive_version}
#!BuildIgnore: texlive-platex
Requires:       texlive-platex-tools >= %{texlive_version}
#!BuildIgnore: texlive-platex-tools
Requires:       texlive-platexcheat >= %{texlive_version}
#!BuildIgnore: texlive-platexcheat
Requires:       texlive-plautopatch >= %{texlive_version}
#!BuildIgnore: texlive-plautopatch
Requires:       texlive-ptex >= %{texlive_version}
#!BuildIgnore: texlive-ptex
Requires:       texlive-ptex-base >= %{texlive_version}
#!BuildIgnore: texlive-ptex-base
Requires:       texlive-ptex-fontmaps >= %{texlive_version}
#!BuildIgnore: texlive-ptex-fontmaps
Requires:       texlive-ptex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-ptex-fonts
Requires:       texlive-ptex-manual >= %{texlive_version}
#!BuildIgnore: texlive-ptex-manual
Requires:       texlive-ptex2pdf >= %{texlive_version}
#!BuildIgnore: texlive-ptex2pdf
Requires:       texlive-pxbase >= %{texlive_version}
#!BuildIgnore: texlive-pxbase
Requires:       texlive-pxchfon >= %{texlive_version}
#!BuildIgnore: texlive-pxchfon
Requires:       texlive-pxcjkcat >= %{texlive_version}
#!BuildIgnore: texlive-pxcjkcat
Requires:       texlive-pxjahyper >= %{texlive_version}
#!BuildIgnore: texlive-pxjahyper
Requires:       texlive-pxjodel >= %{texlive_version}
#!BuildIgnore: texlive-pxjodel
Requires:       texlive-pxrubrica >= %{texlive_version}
#!BuildIgnore: texlive-pxrubrica
Requires:       texlive-pxufont >= %{texlive_version}
#!BuildIgnore: texlive-pxufont
Requires:       texlive-texlive-ja >= %{texlive_version}
#!BuildIgnore: texlive-texlive-ja
Requires:       texlive-uplatex >= %{texlive_version}
#!BuildIgnore: texlive-uplatex
Requires:       texlive-uptex >= %{texlive_version}
#!BuildIgnore: texlive-uptex
Requires:       texlive-uptex-base >= %{texlive_version}
#!BuildIgnore: texlive-uptex-base
Requires:       texlive-uptex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-uptex-fonts
Requires:       texlive-wadalab >= %{texlive_version}
#!BuildIgnore: texlive-wadalab
Requires:       texlive-zxjafbfont >= %{texlive_version}
#!BuildIgnore: texlive-zxjafbfont
Requires:       texlive-zxjatype >= %{texlive_version}
#!BuildIgnore: texlive-zxjatype
BuildArch:      noarch

%description -n texlive-collection-langjapanese
Support for Japanese; additional packages are in
collection-langcjk.

%package -n texlive-collection-langkorean
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Korean
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-baekmuk >= %{texlive_version}
#!BuildIgnore: texlive-baekmuk
Requires:       texlive-cjk-ko >= %{texlive_version}
#!BuildIgnore: texlive-cjk-ko
Requires:       texlive-collection-langcjk >= %{texlive_version}
#!BuildIgnore: texlive-collection-langcjk
Requires:       texlive-kotex-oblivoir >= %{texlive_version}
#!BuildIgnore: texlive-kotex-oblivoir
Requires:       texlive-kotex-plain >= %{texlive_version}
#!BuildIgnore: texlive-kotex-plain
Requires:       texlive-kotex-utf >= %{texlive_version}
#!BuildIgnore: texlive-kotex-utf
Requires:       texlive-kotex-utils >= %{texlive_version}
#!BuildIgnore: texlive-kotex-utils
Requires:       texlive-lshort-korean >= %{texlive_version}
#!BuildIgnore: texlive-lshort-korean
Requires:       texlive-nanumtype1 >= %{texlive_version}
#!BuildIgnore: texlive-nanumtype1
Requires:       texlive-pmhanguljamo >= %{texlive_version}
#!BuildIgnore: texlive-pmhanguljamo
Requires:       texlive-uhc >= %{texlive_version}
#!BuildIgnore: texlive-uhc
Requires:       texlive-unfonts-core >= %{texlive_version}
#!BuildIgnore: texlive-unfonts-core
Requires:       texlive-unfonts-extra >= %{texlive_version}
#!BuildIgnore: texlive-unfonts-extra
BuildArch:      noarch

%description -n texlive-collection-langkorean
Support for Korean; additional packages in collection-langcjk.

%package -n texlive-collection-langother
Version:        %{texlive_version}.%{texlive_noarch}.svn59564
Release:        60.1
License:        LPPL-1.0
Summary:        Other languages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-aalok >= %{texlive_version}
#!BuildIgnore: texlive-aalok
Requires:       texlive-akshar >= %{texlive_version}
#!BuildIgnore: texlive-akshar
Requires:       texlive-amsldoc-vn >= %{texlive_version}
#!BuildIgnore: texlive-amsldoc-vn
Requires:       texlive-aramaic-serto >= %{texlive_version}
#!BuildIgnore: texlive-aramaic-serto
Requires:       texlive-babel-azerbaijani >= %{texlive_version}
#!BuildIgnore: texlive-babel-azerbaijani
Requires:       texlive-babel-esperanto >= %{texlive_version}
#!BuildIgnore: texlive-babel-esperanto
Requires:       texlive-babel-georgian >= %{texlive_version}
#!BuildIgnore: texlive-babel-georgian
Requires:       texlive-babel-hebrew >= %{texlive_version}
#!BuildIgnore: texlive-babel-hebrew
Requires:       texlive-babel-indonesian >= %{texlive_version}
#!BuildIgnore: texlive-babel-indonesian
Requires:       texlive-babel-interlingua >= %{texlive_version}
#!BuildIgnore: texlive-babel-interlingua
Requires:       texlive-babel-malay >= %{texlive_version}
#!BuildIgnore: texlive-babel-malay
Requires:       texlive-babel-sorbian >= %{texlive_version}
#!BuildIgnore: texlive-babel-sorbian
Requires:       texlive-babel-thai >= %{texlive_version}
#!BuildIgnore: texlive-babel-thai
Requires:       texlive-babel-vietnamese >= %{texlive_version}
#!BuildIgnore: texlive-babel-vietnamese
Requires:       texlive-bangla >= %{texlive_version}
#!BuildIgnore: texlive-bangla
Requires:       texlive-bangtex >= %{texlive_version}
#!BuildIgnore: texlive-bangtex
Requires:       texlive-bengali >= %{texlive_version}
#!BuildIgnore: texlive-bengali
Requires:       texlive-burmese >= %{texlive_version}
#!BuildIgnore: texlive-burmese
Requires:       texlive-chhaya >= %{texlive_version}
#!BuildIgnore: texlive-chhaya
Requires:       texlive-cjhebrew >= %{texlive_version}
#!BuildIgnore: texlive-cjhebrew
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-ctib >= %{texlive_version}
#!BuildIgnore: texlive-ctib
Requires:       texlive-ethiop >= %{texlive_version}
#!BuildIgnore: texlive-ethiop
Requires:       texlive-ethiop-t1 >= %{texlive_version}
#!BuildIgnore: texlive-ethiop-t1
Requires:       texlive-fc >= %{texlive_version}
#!BuildIgnore: texlive-fc
Requires:       texlive-fonts-tlwg >= %{texlive_version}
#!BuildIgnore: texlive-fonts-tlwg
Requires:       texlive-hindawi-latex-template >= %{texlive_version}
#!BuildIgnore: texlive-hindawi-latex-template
Requires:       texlive-hyphen-afrikaans >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-afrikaans
Requires:       texlive-hyphen-armenian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-armenian
Requires:       texlive-hyphen-coptic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-coptic
Requires:       texlive-hyphen-esperanto >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-esperanto
Requires:       texlive-hyphen-ethiopic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-ethiopic
Requires:       texlive-hyphen-georgian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-georgian
Requires:       texlive-hyphen-indic >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-indic
Requires:       texlive-hyphen-indonesian >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-indonesian
Requires:       texlive-hyphen-interlingua >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-interlingua
Requires:       texlive-hyphen-sanskrit >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-sanskrit
Requires:       texlive-hyphen-thai >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-thai
Requires:       texlive-hyphen-turkmen >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-turkmen
Requires:       texlive-latex-mr >= %{texlive_version}
#!BuildIgnore: texlive-latex-mr
Requires:       texlive-latexbangla >= %{texlive_version}
#!BuildIgnore: texlive-latexbangla
Requires:       texlive-latino-sine-flexione >= %{texlive_version}
#!BuildIgnore: texlive-latino-sine-flexione
Requires:       texlive-lshort-thai >= %{texlive_version}
#!BuildIgnore: texlive-lshort-thai
Requires:       texlive-lshort-vietnamese >= %{texlive_version}
#!BuildIgnore: texlive-lshort-vietnamese
Requires:       texlive-marathi >= %{texlive_version}
#!BuildIgnore: texlive-marathi
Requires:       texlive-ntheorem-vn >= %{texlive_version}
#!BuildIgnore: texlive-ntheorem-vn
Requires:       texlive-padauk >= %{texlive_version}
#!BuildIgnore: texlive-padauk
Requires:       texlive-quran-bn >= %{texlive_version}
#!BuildIgnore: texlive-quran-bn
Requires:       texlive-quran-ur >= %{texlive_version}
#!BuildIgnore: texlive-quran-ur
Requires:       texlive-sanskrit >= %{texlive_version}
#!BuildIgnore: texlive-sanskrit
Requires:       texlive-sanskrit-t1 >= %{texlive_version}
#!BuildIgnore: texlive-sanskrit-t1
Requires:       texlive-thaienum >= %{texlive_version}
#!BuildIgnore: texlive-thaienum
Requires:       texlive-thaispec >= %{texlive_version}
#!BuildIgnore: texlive-thaispec
Requires:       texlive-unicode-alphabets >= %{texlive_version}
#!BuildIgnore: texlive-unicode-alphabets
Requires:       texlive-velthuis >= %{texlive_version}
#!BuildIgnore: texlive-velthuis
Requires:       texlive-vntex >= %{texlive_version}
#!BuildIgnore: texlive-vntex
Requires:       texlive-wnri >= %{texlive_version}
#!BuildIgnore: texlive-wnri
Requires:       texlive-wnri-latex >= %{texlive_version}
#!BuildIgnore: texlive-wnri-latex
Requires:       texlive-xetex-devanagari >= %{texlive_version}
#!BuildIgnore: texlive-xetex-devanagari
BuildArch:      noarch

%description -n texlive-collection-langother
Support for languages not otherwise listed, including Indic,
Thai, Vietnamese, Hebrew, Indonesian, African languages, and
plenty more. The split is made simply on the basis of the size
of the support, to keep both collection sizes and the number of
collections reasonable.

%package -n texlive-collection-langpolish
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Polish
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-polish >= %{texlive_version}
#!BuildIgnore: texlive-babel-polish
Requires:       texlive-bredzenie >= %{texlive_version}
#!BuildIgnore: texlive-bredzenie
Requires:       texlive-cc-pl >= %{texlive_version}
#!BuildIgnore: texlive-cc-pl
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-gustlib >= %{texlive_version}
#!BuildIgnore: texlive-gustlib
Requires:       texlive-gustprog >= %{texlive_version}
#!BuildIgnore: texlive-gustprog
Requires:       texlive-hyphen-polish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-polish
Requires:       texlive-lshort-polish >= %{texlive_version}
#!BuildIgnore: texlive-lshort-polish
Requires:       texlive-mex >= %{texlive_version}
#!BuildIgnore: texlive-mex
Requires:       texlive-mwcls >= %{texlive_version}
#!BuildIgnore: texlive-mwcls
Requires:       texlive-pl >= %{texlive_version}
#!BuildIgnore: texlive-pl
Requires:       texlive-polski >= %{texlive_version}
#!BuildIgnore: texlive-polski
Requires:       texlive-przechlewski-book >= %{texlive_version}
#!BuildIgnore: texlive-przechlewski-book
Requires:       texlive-qpxqtx >= %{texlive_version}
#!BuildIgnore: texlive-qpxqtx
Requires:       texlive-tap >= %{texlive_version}
#!BuildIgnore: texlive-tap
Requires:       texlive-tex-virtual-academy-pl >= %{texlive_version}
#!BuildIgnore: texlive-tex-virtual-academy-pl
Requires:       texlive-texlive-pl >= %{texlive_version}
#!BuildIgnore: texlive-texlive-pl
Requires:       texlive-utf8mex >= %{texlive_version}
#!BuildIgnore: texlive-utf8mex
BuildArch:      noarch

%description -n texlive-collection-langpolish
Support for Polish.

%package -n texlive-collection-langportuguese
Version:        %{texlive_version}.%{texlive_noarch}.svn54074
Release:        60.1
License:        LPPL-1.0
Summary:        Portuguese
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-portuges >= %{texlive_version}
#!BuildIgnore: texlive-babel-portuges
Requires:       texlive-beamer-tut-pt >= %{texlive_version}
#!BuildIgnore: texlive-beamer-tut-pt
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-cursolatex >= %{texlive_version}
#!BuildIgnore: texlive-cursolatex
Requires:       texlive-feupphdteses >= %{texlive_version}
#!BuildIgnore: texlive-feupphdteses
Requires:       texlive-hyphen-portuguese >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-portuguese
Requires:       texlive-latex-via-exemplos >= %{texlive_version}
#!BuildIgnore: texlive-latex-via-exemplos
Requires:       texlive-latexcheat-ptbr >= %{texlive_version}
#!BuildIgnore: texlive-latexcheat-ptbr
Requires:       texlive-lshort-portuguese >= %{texlive_version}
#!BuildIgnore: texlive-lshort-portuguese
Requires:       texlive-numberpt >= %{texlive_version}
#!BuildIgnore: texlive-numberpt
Requires:       texlive-ordinalpt >= %{texlive_version}
#!BuildIgnore: texlive-ordinalpt
Requires:       texlive-xypic-tut-pt >= %{texlive_version}
#!BuildIgnore: texlive-xypic-tut-pt
BuildArch:      noarch

%description -n texlive-collection-langportuguese
Support for Portuguese.

%package -n texlive-collection-langspanish
Version:        %{texlive_version}.%{texlive_noarch}.svn54141
Release:        60.1
License:        LPPL-1.0
Summary:        Spanish
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-babel-catalan >= %{texlive_version}
#!BuildIgnore: texlive-babel-catalan
Requires:       texlive-babel-galician >= %{texlive_version}
#!BuildIgnore: texlive-babel-galician
Requires:       texlive-babel-spanish >= %{texlive_version}
#!BuildIgnore: texlive-babel-spanish
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-es-tex-faq >= %{texlive_version}
#!BuildIgnore: texlive-es-tex-faq
Requires:       texlive-hyphen-catalan >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-catalan
Requires:       texlive-hyphen-galician >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-galician
Requires:       texlive-hyphen-spanish >= %{texlive_version}
#!BuildIgnore: texlive-hyphen-spanish
Requires:       texlive-l2tabu-spanish >= %{texlive_version}
#!BuildIgnore: texlive-l2tabu-spanish
Requires:       texlive-latex2e-help-texinfo-spanish >= %{texlive_version}
#!BuildIgnore: texlive-latex2e-help-texinfo-spanish
Requires:       texlive-latexcheat-esmx >= %{texlive_version}
#!BuildIgnore: texlive-latexcheat-esmx
Requires:       texlive-lshort-spanish >= %{texlive_version}
#!BuildIgnore: texlive-lshort-spanish
Requires:       texlive-texlive-es >= %{texlive_version}
#!BuildIgnore: texlive-texlive-es
BuildArch:      noarch

%description -n texlive-collection-langspanish
Support for Spanish.

%package -n texlive-collection-latex
Version:        %{texlive_version}.%{texlive_noarch}.svn63515
Release:        60.1
License:        LPPL-1.0
Summary:        LaTeX fundamental packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-latex <= %{texlive_previous}
Obsoletes:      texlive-latex-doc <= %{texlive_previous}
Requires:       texlive-ae >= %{texlive_version}
#!BuildIgnore: texlive-ae
Requires:       texlive-amscls >= %{texlive_version}
#!BuildIgnore: texlive-amscls
Requires:       texlive-amsmath >= %{texlive_version}
#!BuildIgnore: texlive-amsmath
Requires:       texlive-atbegshi >= %{texlive_version}
#!BuildIgnore: texlive-atbegshi
Requires:       texlive-atveryend >= %{texlive_version}
#!BuildIgnore: texlive-atveryend
Requires:       texlive-auxhook >= %{texlive_version}
#!BuildIgnore: texlive-auxhook
Requires:       texlive-babel >= %{texlive_version}
#!BuildIgnore: texlive-babel
Requires:       texlive-babel-english >= %{texlive_version}
#!BuildIgnore: texlive-babel-english
Requires:       texlive-babelbib >= %{texlive_version}
#!BuildIgnore: texlive-babelbib
Requires:       texlive-bigintcalc >= %{texlive_version}
#!BuildIgnore: texlive-bigintcalc
Requires:       texlive-bitset >= %{texlive_version}
#!BuildIgnore: texlive-bitset
Requires:       texlive-bookmark >= %{texlive_version}
#!BuildIgnore: texlive-bookmark
Requires:       texlive-carlisle >= %{texlive_version}
#!BuildIgnore: texlive-carlisle
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-colortbl >= %{texlive_version}
#!BuildIgnore: texlive-colortbl
Requires:       texlive-epstopdf-pkg >= %{texlive_version}
#!BuildIgnore: texlive-epstopdf-pkg
Requires:       texlive-etexcmds >= %{texlive_version}
#!BuildIgnore: texlive-etexcmds
Requires:       texlive-fancyhdr >= %{texlive_version}
#!BuildIgnore: texlive-fancyhdr
Requires:       texlive-firstaid >= %{texlive_version}
#!BuildIgnore: texlive-firstaid
Requires:       texlive-fix2col >= %{texlive_version}
#!BuildIgnore: texlive-fix2col
Requires:       texlive-geometry >= %{texlive_version}
#!BuildIgnore: texlive-geometry
Requires:       texlive-gettitlestring >= %{texlive_version}
#!BuildIgnore: texlive-gettitlestring
Requires:       texlive-graphics >= %{texlive_version}
#!BuildIgnore: texlive-graphics
Requires:       texlive-graphics-cfg >= %{texlive_version}
#!BuildIgnore: texlive-graphics-cfg
Requires:       texlive-grfext >= %{texlive_version}
#!BuildIgnore: texlive-grfext
Requires:       texlive-hopatch >= %{texlive_version}
#!BuildIgnore: texlive-hopatch
Requires:       texlive-hycolor >= %{texlive_version}
#!BuildIgnore: texlive-hycolor
Requires:       texlive-hyperref >= %{texlive_version}
#!BuildIgnore: texlive-hyperref
Requires:       texlive-intcalc >= %{texlive_version}
#!BuildIgnore: texlive-intcalc
Requires:       texlive-kvdefinekeys >= %{texlive_version}
#!BuildIgnore: texlive-kvdefinekeys
Requires:       texlive-kvoptions >= %{texlive_version}
#!BuildIgnore: texlive-kvoptions
Requires:       texlive-kvsetkeys >= %{texlive_version}
#!BuildIgnore: texlive-kvsetkeys
Requires:       texlive-l3backend >= %{texlive_version}
#!BuildIgnore: texlive-l3backend
Requires:       texlive-l3kernel >= %{texlive_version}
#!BuildIgnore: texlive-l3kernel
Requires:       texlive-l3packages >= %{texlive_version}
#!BuildIgnore: texlive-l3packages
Requires:       texlive-latex >= %{texlive_version}
#!BuildIgnore: texlive-latex
Requires:       texlive-latex-bin >= %{texlive_version}
#!BuildIgnore: texlive-latex-bin
Requires:       texlive-latex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-latex-fonts
Requires:       texlive-latex-lab >= %{texlive_version}
#!BuildIgnore: texlive-latex-lab
Requires:       texlive-latexconfig >= %{texlive_version}
#!BuildIgnore: texlive-latexconfig
Requires:       texlive-letltxmacro >= %{texlive_version}
#!BuildIgnore: texlive-letltxmacro
Requires:       texlive-ltxcmds >= %{texlive_version}
#!BuildIgnore: texlive-ltxcmds
Requires:       texlive-ltxmisc >= %{texlive_version}
#!BuildIgnore: texlive-ltxmisc
Requires:       texlive-mfnfss >= %{texlive_version}
#!BuildIgnore: texlive-mfnfss
Requires:       texlive-mptopdf >= %{texlive_version}
#!BuildIgnore: texlive-mptopdf
Requires:       texlive-natbib >= %{texlive_version}
#!BuildIgnore: texlive-natbib
Requires:       texlive-oberdiek >= %{texlive_version}
#!BuildIgnore: texlive-oberdiek
Requires:       texlive-pagesel >= %{texlive_version}
#!BuildIgnore: texlive-pagesel
Requires:       texlive-pdfescape >= %{texlive_version}
#!BuildIgnore: texlive-pdfescape
Requires:       texlive-pslatex >= %{texlive_version}
#!BuildIgnore: texlive-pslatex
Requires:       texlive-psnfss >= %{texlive_version}
#!BuildIgnore: texlive-psnfss
Requires:       texlive-pspicture >= %{texlive_version}
#!BuildIgnore: texlive-pspicture
Requires:       texlive-refcount >= %{texlive_version}
#!BuildIgnore: texlive-refcount
Requires:       texlive-rerunfilecheck >= %{texlive_version}
#!BuildIgnore: texlive-rerunfilecheck
Requires:       texlive-stringenc >= %{texlive_version}
#!BuildIgnore: texlive-stringenc
Requires:       texlive-tools >= %{texlive_version}
#!BuildIgnore: texlive-tools
Requires:       texlive-uniquecounter >= %{texlive_version}
#!BuildIgnore: texlive-uniquecounter
Requires:       texlive-url >= %{texlive_version}
#!BuildIgnore: texlive-url
Provides:       tex(latex)
BuildArch:      noarch

%description -n texlive-collection-latex
These packages are either mandated by the core LaTeX team, or
very widely used and strongly recommended in practice.

%package -n texlive-collection-latexextra
Version:        %{texlive_version}.%{texlive_noarch}.svn66548
Release:        60.1
License:        LPPL-1.0
Summary:        LaTeX additional packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-2up >= %{texlive_version}
#!BuildIgnore: texlive-2up
Requires:       texlive-a0poster >= %{texlive_version}
#!BuildIgnore: texlive-a0poster
Requires:       texlive-a4wide >= %{texlive_version}
#!BuildIgnore: texlive-a4wide
Requires:       texlive-a5comb >= %{texlive_version}
#!BuildIgnore: texlive-a5comb
Requires:       texlive-abraces >= %{texlive_version}
#!BuildIgnore: texlive-abraces
Requires:       texlive-abspos >= %{texlive_version}
#!BuildIgnore: texlive-abspos
Requires:       texlive-abstract >= %{texlive_version}
#!BuildIgnore: texlive-abstract
Requires:       texlive-accessibility >= %{texlive_version}
#!BuildIgnore: texlive-accessibility
Requires:       texlive-accsupp >= %{texlive_version}
#!BuildIgnore: texlive-accsupp
Requires:       texlive-achemso >= %{texlive_version}
#!BuildIgnore: texlive-achemso
Requires:       texlive-acro >= %{texlive_version}
#!BuildIgnore: texlive-acro
Requires:       texlive-acronym >= %{texlive_version}
#!BuildIgnore: texlive-acronym
Requires:       texlive-acroterm >= %{texlive_version}
#!BuildIgnore: texlive-acroterm
Requires:       texlive-actuarialangle >= %{texlive_version}
#!BuildIgnore: texlive-actuarialangle
Requires:       texlive-actuarialsymbol >= %{texlive_version}
#!BuildIgnore: texlive-actuarialsymbol
Requires:       texlive-addfont >= %{texlive_version}
#!BuildIgnore: texlive-addfont
Requires:       texlive-addlines >= %{texlive_version}
#!BuildIgnore: texlive-addlines
Requires:       texlive-adjmulticol >= %{texlive_version}
#!BuildIgnore: texlive-adjmulticol
Requires:       texlive-adjustbox >= %{texlive_version}
#!BuildIgnore: texlive-adjustbox
Requires:       texlive-adrconv >= %{texlive_version}
#!BuildIgnore: texlive-adrconv
Requires:       texlive-advdate >= %{texlive_version}
#!BuildIgnore: texlive-advdate
Requires:       texlive-akktex >= %{texlive_version}
#!BuildIgnore: texlive-akktex
Requires:       texlive-akletter >= %{texlive_version}
#!BuildIgnore: texlive-akletter
Requires:       texlive-alchemist >= %{texlive_version}
#!BuildIgnore: texlive-alchemist
Requires:       texlive-alertmessage >= %{texlive_version}
#!BuildIgnore: texlive-alertmessage
Requires:       texlive-alnumsec >= %{texlive_version}
#!BuildIgnore: texlive-alnumsec
Requires:       texlive-alphalph >= %{texlive_version}
#!BuildIgnore: texlive-alphalph
Requires:       texlive-alterqcm >= %{texlive_version}
#!BuildIgnore: texlive-alterqcm
Requires:       texlive-altfont >= %{texlive_version}
#!BuildIgnore: texlive-altfont
Requires:       texlive-altsubsup >= %{texlive_version}
#!BuildIgnore: texlive-altsubsup
Requires:       texlive-amsaddr >= %{texlive_version}
#!BuildIgnore: texlive-amsaddr
Requires:       texlive-animate >= %{texlive_version}
#!BuildIgnore: texlive-animate
Requires:       texlive-anonchap >= %{texlive_version}
#!BuildIgnore: texlive-anonchap
Requires:       texlive-answers >= %{texlive_version}
#!BuildIgnore: texlive-answers
Requires:       texlive-anyfontsize >= %{texlive_version}
#!BuildIgnore: texlive-anyfontsize
Requires:       texlive-appendix >= %{texlive_version}
#!BuildIgnore: texlive-appendix
Requires:       texlive-appendixnumberbeamer >= %{texlive_version}
#!BuildIgnore: texlive-appendixnumberbeamer
Requires:       texlive-apptools >= %{texlive_version}
#!BuildIgnore: texlive-apptools
Requires:       texlive-arabicfront >= %{texlive_version}
#!BuildIgnore: texlive-arabicfront
Requires:       texlive-arcs >= %{texlive_version}
#!BuildIgnore: texlive-arcs
Requires:       texlive-arraycols >= %{texlive_version}
#!BuildIgnore: texlive-arraycols
Requires:       texlive-arrayjobx >= %{texlive_version}
#!BuildIgnore: texlive-arrayjobx
Requires:       texlive-arraysort >= %{texlive_version}
#!BuildIgnore: texlive-arraysort
Requires:       texlive-arydshln >= %{texlive_version}
#!BuildIgnore: texlive-arydshln
Requires:       texlive-asciilist >= %{texlive_version}
#!BuildIgnore: texlive-asciilist
Requires:       texlive-askinclude >= %{texlive_version}
#!BuildIgnore: texlive-askinclude
Requires:       texlive-assignment >= %{texlive_version}
#!BuildIgnore: texlive-assignment
Requires:       texlive-assoccnt >= %{texlive_version}
#!BuildIgnore: texlive-assoccnt
Requires:       texlive-association-matrix >= %{texlive_version}
#!BuildIgnore: texlive-association-matrix
Requires:       texlive-atenddvi >= %{texlive_version}
#!BuildIgnore: texlive-atenddvi
Requires:       texlive-atendofenv >= %{texlive_version}
#!BuildIgnore: texlive-atendofenv
Requires:       texlive-attachfile >= %{texlive_version}
#!BuildIgnore: texlive-attachfile
Requires:       texlive-aurl >= %{texlive_version}
#!BuildIgnore: texlive-aurl
Requires:       texlive-authoraftertitle >= %{texlive_version}
#!BuildIgnore: texlive-authoraftertitle
Requires:       texlive-authorarchive >= %{texlive_version}
#!BuildIgnore: texlive-authorarchive
Requires:       texlive-authorindex >= %{texlive_version}
#!BuildIgnore: texlive-authorindex
Requires:       texlive-autofancyhdr >= %{texlive_version}
#!BuildIgnore: texlive-autofancyhdr
Requires:       texlive-autonum >= %{texlive_version}
#!BuildIgnore: texlive-autonum
Requires:       texlive-autopdf >= %{texlive_version}
#!BuildIgnore: texlive-autopdf
Requires:       texlive-autopuncitems >= %{texlive_version}
#!BuildIgnore: texlive-autopuncitems
Requires:       texlive-avremu >= %{texlive_version}
#!BuildIgnore: texlive-avremu
Requires:       texlive-axessibility >= %{texlive_version}
#!BuildIgnore: texlive-axessibility
Requires:       texlive-background >= %{texlive_version}
#!BuildIgnore: texlive-background
Requires:       texlive-bankstatement >= %{texlive_version}
#!BuildIgnore: texlive-bankstatement
Requires:       texlive-bashful >= %{texlive_version}
#!BuildIgnore: texlive-bashful
Requires:       texlive-basicarith >= %{texlive_version}
#!BuildIgnore: texlive-basicarith
Requires:       texlive-bchart >= %{texlive_version}
#!BuildIgnore: texlive-bchart
Requires:       texlive-beamer-rl >= %{texlive_version}
#!BuildIgnore: texlive-beamer-rl
Requires:       texlive-beamer2thesis >= %{texlive_version}
#!BuildIgnore: texlive-beamer2thesis
Requires:       texlive-beamerappendixnote >= %{texlive_version}
#!BuildIgnore: texlive-beamerappendixnote
Requires:       texlive-beameraudience >= %{texlive_version}
#!BuildIgnore: texlive-beameraudience
Requires:       texlive-beamerauxtheme >= %{texlive_version}
#!BuildIgnore: texlive-beamerauxtheme
Requires:       texlive-beamercolorthemeowl >= %{texlive_version}
#!BuildIgnore: texlive-beamercolorthemeowl
Requires:       texlive-beamerdarkthemes >= %{texlive_version}
#!BuildIgnore: texlive-beamerdarkthemes
Requires:       texlive-beamerposter >= %{texlive_version}
#!BuildIgnore: texlive-beamerposter
Requires:       texlive-beamersubframe >= %{texlive_version}
#!BuildIgnore: texlive-beamersubframe
Requires:       texlive-beamertheme-arguelles >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-arguelles
Requires:       texlive-beamertheme-cuerna >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-cuerna
Requires:       texlive-beamertheme-detlevcm >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-detlevcm
Requires:       texlive-beamertheme-epyt >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-epyt
Requires:       texlive-beamertheme-focus >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-focus
Requires:       texlive-beamertheme-light >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-light
Requires:       texlive-beamertheme-metropolis >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-metropolis
Requires:       texlive-beamertheme-npbt >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-npbt
Requires:       texlive-beamertheme-phnompenh >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-phnompenh
Requires:       texlive-beamertheme-pure-minimalistic >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-pure-minimalistic
Requires:       texlive-beamertheme-saintpetersburg >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-saintpetersburg
Requires:       texlive-beamertheme-simpledarkblue >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-simpledarkblue
Requires:       texlive-beamertheme-simpleplus >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-simpleplus
Requires:       texlive-beamertheme-tcolorbox >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-tcolorbox
Requires:       texlive-beamertheme-trigon >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-trigon
Requires:       texlive-beamertheme-upenn-bc >= %{texlive_version}
#!BuildIgnore: texlive-beamertheme-upenn-bc
Requires:       texlive-beamerthemeamurmaple >= %{texlive_version}
#!BuildIgnore: texlive-beamerthemeamurmaple
Requires:       texlive-beamerthemejltree >= %{texlive_version}
#!BuildIgnore: texlive-beamerthemejltree
Requires:       texlive-beamerthemelalic >= %{texlive_version}
#!BuildIgnore: texlive-beamerthemelalic
Requires:       texlive-beamerthemenirma >= %{texlive_version}
#!BuildIgnore: texlive-beamerthemenirma
Requires:       texlive-beamerthemenord >= %{texlive_version}
#!BuildIgnore: texlive-beamerthemenord
Requires:       texlive-bearwear >= %{texlive_version}
#!BuildIgnore: texlive-bearwear
Requires:       texlive-beaulivre >= %{texlive_version}
#!BuildIgnore: texlive-beaulivre
Requires:       texlive-beton >= %{texlive_version}
#!BuildIgnore: texlive-beton
Requires:       texlive-bewerbung >= %{texlive_version}
#!BuildIgnore: texlive-bewerbung
Requires:       texlive-bez123 >= %{texlive_version}
#!BuildIgnore: texlive-bez123
Requires:       texlive-bhcexam >= %{texlive_version}
#!BuildIgnore: texlive-bhcexam
Requires:       texlive-bibletext >= %{texlive_version}
#!BuildIgnore: texlive-bibletext
Requires:       texlive-bigfoot >= %{texlive_version}
#!BuildIgnore: texlive-bigfoot
Requires:       texlive-bigints >= %{texlive_version}
#!BuildIgnore: texlive-bigints
Requires:       texlive-bilingualpages >= %{texlive_version}
#!BuildIgnore: texlive-bilingualpages
Requires:       texlive-biochemistry-colors >= %{texlive_version}
#!BuildIgnore: texlive-biochemistry-colors
Requires:       texlive-bithesis >= %{texlive_version}
#!BuildIgnore: texlive-bithesis
Requires:       texlive-bizcard >= %{texlive_version}
#!BuildIgnore: texlive-bizcard
Requires:       texlive-blindtext >= %{texlive_version}
#!BuildIgnore: texlive-blindtext
Requires:       texlive-blkarray >= %{texlive_version}
#!BuildIgnore: texlive-blkarray
Requires:       texlive-block >= %{texlive_version}
#!BuildIgnore: texlive-block
Requires:       texlive-blowup >= %{texlive_version}
#!BuildIgnore: texlive-blowup
Requires:       texlive-bnumexpr >= %{texlive_version}
#!BuildIgnore: texlive-bnumexpr
Requires:       texlive-boites >= %{texlive_version}
#!BuildIgnore: texlive-boites
Requires:       texlive-bold-extra >= %{texlive_version}
#!BuildIgnore: texlive-bold-extra
Requires:       texlive-book-of-common-prayer >= %{texlive_version}
#!BuildIgnore: texlive-book-of-common-prayer
Requires:       texlive-bookcover >= %{texlive_version}
#!BuildIgnore: texlive-bookcover
Requires:       texlive-bookest >= %{texlive_version}
#!BuildIgnore: texlive-bookest
Requires:       texlive-booklet >= %{texlive_version}
#!BuildIgnore: texlive-booklet
Requires:       texlive-bookshelf >= %{texlive_version}
#!BuildIgnore: texlive-bookshelf
Requires:       texlive-boolexpr >= %{texlive_version}
#!BuildIgnore: texlive-boolexpr
Requires:       texlive-bophook >= %{texlive_version}
#!BuildIgnore: texlive-bophook
Requires:       texlive-boxedminipage >= %{texlive_version}
#!BuildIgnore: texlive-boxedminipage
Requires:       texlive-boxhandler >= %{texlive_version}
#!BuildIgnore: texlive-boxhandler
Requires:       texlive-bracketkey >= %{texlive_version}
#!BuildIgnore: texlive-bracketkey
Requires:       texlive-braket >= %{texlive_version}
#!BuildIgnore: texlive-braket
Requires:       texlive-breakurl >= %{texlive_version}
#!BuildIgnore: texlive-breakurl
Requires:       texlive-bubblesort >= %{texlive_version}
#!BuildIgnore: texlive-bubblesort
Requires:       texlive-bullcntr >= %{texlive_version}
#!BuildIgnore: texlive-bullcntr
Requires:       texlive-bxcalc >= %{texlive_version}
#!BuildIgnore: texlive-bxcalc
Requires:       texlive-bxdpx-beamer >= %{texlive_version}
#!BuildIgnore: texlive-bxdpx-beamer
Requires:       texlive-bxdvidriver >= %{texlive_version}
#!BuildIgnore: texlive-bxdvidriver
Requires:       texlive-bxenclose >= %{texlive_version}
#!BuildIgnore: texlive-bxenclose
Requires:       texlive-bxnewfont >= %{texlive_version}
#!BuildIgnore: texlive-bxnewfont
Requires:       texlive-bxpapersize >= %{texlive_version}
#!BuildIgnore: texlive-bxpapersize
Requires:       texlive-bxpdfver >= %{texlive_version}
#!BuildIgnore: texlive-bxpdfver
Requires:       texlive-bxtexlogo >= %{texlive_version}
#!BuildIgnore: texlive-bxtexlogo
Requires:       texlive-calcage >= %{texlive_version}
#!BuildIgnore: texlive-calcage
Requires:       texlive-calctab >= %{texlive_version}
#!BuildIgnore: texlive-calctab
Requires:       texlive-calculator >= %{texlive_version}
#!BuildIgnore: texlive-calculator
Requires:       texlive-calrsfs >= %{texlive_version}
#!BuildIgnore: texlive-calrsfs
Requires:       texlive-cals >= %{texlive_version}
#!BuildIgnore: texlive-cals
Requires:       texlive-calxxxx-yyyy >= %{texlive_version}
#!BuildIgnore: texlive-calxxxx-yyyy
Requires:       texlive-cancel >= %{texlive_version}
#!BuildIgnore: texlive-cancel
Requires:       texlive-canoniclayout >= %{texlive_version}
#!BuildIgnore: texlive-canoniclayout
Requires:       texlive-capt-of >= %{texlive_version}
#!BuildIgnore: texlive-capt-of
Requires:       texlive-captcont >= %{texlive_version}
#!BuildIgnore: texlive-captcont
Requires:       texlive-captdef >= %{texlive_version}
#!BuildIgnore: texlive-captdef
Requires:       texlive-carbohydrates >= %{texlive_version}
#!BuildIgnore: texlive-carbohydrates
Requires:       texlive-cases >= %{texlive_version}
#!BuildIgnore: texlive-cases
Requires:       texlive-casyl >= %{texlive_version}
#!BuildIgnore: texlive-casyl
Requires:       texlive-catchfile >= %{texlive_version}
#!BuildIgnore: texlive-catchfile
Requires:       texlive-catchfilebetweentags >= %{texlive_version}
#!BuildIgnore: texlive-catchfilebetweentags
Requires:       texlive-catechis >= %{texlive_version}
#!BuildIgnore: texlive-catechis
Requires:       texlive-catoptions >= %{texlive_version}
#!BuildIgnore: texlive-catoptions
Requires:       texlive-cbcoptic >= %{texlive_version}
#!BuildIgnore: texlive-cbcoptic
Requires:       texlive-ccaption >= %{texlive_version}
#!BuildIgnore: texlive-ccaption
Requires:       texlive-cclicenses >= %{texlive_version}
#!BuildIgnore: texlive-cclicenses
Requires:       texlive-cd >= %{texlive_version}
#!BuildIgnore: texlive-cd
Requires:       texlive-cd-cover >= %{texlive_version}
#!BuildIgnore: texlive-cd-cover
Requires:       texlive-cdcmd >= %{texlive_version}
#!BuildIgnore: texlive-cdcmd
Requires:       texlive-cdpbundl >= %{texlive_version}
#!BuildIgnore: texlive-cdpbundl
Requires:       texlive-cellprops >= %{texlive_version}
#!BuildIgnore: texlive-cellprops
Requires:       texlive-cellspace >= %{texlive_version}
#!BuildIgnore: texlive-cellspace
Requires:       texlive-censor >= %{texlive_version}
#!BuildIgnore: texlive-censor
Requires:       texlive-centeredline >= %{texlive_version}
#!BuildIgnore: texlive-centeredline
Requires:       texlive-centerlastline >= %{texlive_version}
#!BuildIgnore: texlive-centerlastline
Requires:       texlive-changebar >= %{texlive_version}
#!BuildIgnore: texlive-changebar
Requires:       texlive-changelayout >= %{texlive_version}
#!BuildIgnore: texlive-changelayout
Requires:       texlive-changelog >= %{texlive_version}
#!BuildIgnore: texlive-changelog
Requires:       texlive-changepage >= %{texlive_version}
#!BuildIgnore: texlive-changepage
Requires:       texlive-changes >= %{texlive_version}
#!BuildIgnore: texlive-changes
Requires:       texlive-chappg >= %{texlive_version}
#!BuildIgnore: texlive-chappg
Requires:       texlive-chapterfolder >= %{texlive_version}
#!BuildIgnore: texlive-chapterfolder
Requires:       texlive-cheatsheet >= %{texlive_version}
#!BuildIgnore: texlive-cheatsheet
Requires:       texlive-checkend >= %{texlive_version}
#!BuildIgnore: texlive-checkend
Requires:       texlive-chet >= %{texlive_version}
#!BuildIgnore: texlive-chet
Requires:       texlive-chextras >= %{texlive_version}
#!BuildIgnore: texlive-chextras
Requires:       texlive-childdoc >= %{texlive_version}
#!BuildIgnore: texlive-childdoc
Requires:       texlive-chkfloat >= %{texlive_version}
#!BuildIgnore: texlive-chkfloat
Requires:       texlive-chletter >= %{texlive_version}
#!BuildIgnore: texlive-chletter
Requires:       texlive-chngcntr >= %{texlive_version}
#!BuildIgnore: texlive-chngcntr
Requires:       texlive-chronology >= %{texlive_version}
#!BuildIgnore: texlive-chronology
Requires:       texlive-circ >= %{texlive_version}
#!BuildIgnore: texlive-circ
Requires:       texlive-circledsteps >= %{texlive_version}
#!BuildIgnore: texlive-circledsteps
Requires:       texlive-circledtext >= %{texlive_version}
#!BuildIgnore: texlive-circledtext
Requires:       texlive-classics >= %{texlive_version}
#!BuildIgnore: texlive-classics
Requires:       texlive-classpack >= %{texlive_version}
#!BuildIgnore: texlive-classpack
Requires:       texlive-clefval >= %{texlive_version}
#!BuildIgnore: texlive-clefval
Requires:       texlive-cleveref >= %{texlive_version}
#!BuildIgnore: texlive-cleveref
Requires:       texlive-clicks >= %{texlive_version}
#!BuildIgnore: texlive-clicks
Requires:       texlive-clipboard >= %{texlive_version}
#!BuildIgnore: texlive-clipboard
Requires:       texlive-clistmap >= %{texlive_version}
#!BuildIgnore: texlive-clistmap
Requires:       texlive-clock >= %{texlive_version}
#!BuildIgnore: texlive-clock
Requires:       texlive-clrdblpg >= %{texlive_version}
#!BuildIgnore: texlive-clrdblpg
Requires:       texlive-clrstrip >= %{texlive_version}
#!BuildIgnore: texlive-clrstrip
Requires:       texlive-cmdstring >= %{texlive_version}
#!BuildIgnore: texlive-cmdstring
Requires:       texlive-cmdtrack >= %{texlive_version}
#!BuildIgnore: texlive-cmdtrack
Requires:       texlive-cmsd >= %{texlive_version}
#!BuildIgnore: texlive-cmsd
Requires:       texlive-cnltx >= %{texlive_version}
#!BuildIgnore: texlive-cnltx
Requires:       texlive-cntformats >= %{texlive_version}
#!BuildIgnore: texlive-cntformats
Requires:       texlive-cntperchap >= %{texlive_version}
#!BuildIgnore: texlive-cntperchap
Requires:       texlive-codebox >= %{texlive_version}
#!BuildIgnore: texlive-codebox
Requires:       texlive-codedoc >= %{texlive_version}
#!BuildIgnore: texlive-codedoc
Requires:       texlive-codehigh >= %{texlive_version}
#!BuildIgnore: texlive-codehigh
Requires:       texlive-codepage >= %{texlive_version}
#!BuildIgnore: texlive-codepage
Requires:       texlive-codesection >= %{texlive_version}
#!BuildIgnore: texlive-codesection
Requires:       texlive-collcell >= %{texlive_version}
#!BuildIgnore: texlive-collcell
Requires:       texlive-collectbox >= %{texlive_version}
#!BuildIgnore: texlive-collectbox
Requires:       texlive-collection-latexrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-latexrecommended
Requires:       texlive-collection-pictures >= %{texlive_version}
#!BuildIgnore: texlive-collection-pictures
Requires:       texlive-colophon >= %{texlive_version}
#!BuildIgnore: texlive-colophon
Requires:       texlive-color-edits >= %{texlive_version}
#!BuildIgnore: texlive-color-edits
Requires:       texlive-colordoc >= %{texlive_version}
#!BuildIgnore: texlive-colordoc
Requires:       texlive-colorframed >= %{texlive_version}
#!BuildIgnore: texlive-colorframed
Requires:       texlive-colorinfo >= %{texlive_version}
#!BuildIgnore: texlive-colorinfo
Requires:       texlive-coloring >= %{texlive_version}
#!BuildIgnore: texlive-coloring
Requires:       texlive-colorist >= %{texlive_version}
#!BuildIgnore: texlive-colorist
Requires:       texlive-colorspace >= %{texlive_version}
#!BuildIgnore: texlive-colorspace
Requires:       texlive-colortab >= %{texlive_version}
#!BuildIgnore: texlive-colortab
Requires:       texlive-colorwav >= %{texlive_version}
#!BuildIgnore: texlive-colorwav
Requires:       texlive-colorweb >= %{texlive_version}
#!BuildIgnore: texlive-colorweb
Requires:       texlive-colourchange >= %{texlive_version}
#!BuildIgnore: texlive-colourchange
Requires:       texlive-combelow >= %{texlive_version}
#!BuildIgnore: texlive-combelow
Requires:       texlive-combine >= %{texlive_version}
#!BuildIgnore: texlive-combine
Requires:       texlive-comma >= %{texlive_version}
#!BuildIgnore: texlive-comma
Requires:       texlive-commado >= %{texlive_version}
#!BuildIgnore: texlive-commado
Requires:       texlive-commedit >= %{texlive_version}
#!BuildIgnore: texlive-commedit
Requires:       texlive-comment >= %{texlive_version}
#!BuildIgnore: texlive-comment
Requires:       texlive-commonunicode >= %{texlive_version}
#!BuildIgnore: texlive-commonunicode
Requires:       texlive-competences >= %{texlive_version}
#!BuildIgnore: texlive-competences
Requires:       texlive-concepts >= %{texlive_version}
#!BuildIgnore: texlive-concepts
Requires:       texlive-concprog >= %{texlive_version}
#!BuildIgnore: texlive-concprog
Requires:       texlive-conditext >= %{texlive_version}
#!BuildIgnore: texlive-conditext
Requires:       texlive-constants >= %{texlive_version}
#!BuildIgnore: texlive-constants
Requires:       texlive-continue >= %{texlive_version}
#!BuildIgnore: texlive-continue
Requires:       texlive-contour >= %{texlive_version}
#!BuildIgnore: texlive-contour
Requires:       texlive-contracard >= %{texlive_version}
#!BuildIgnore: texlive-contracard
Requires:       texlive-conv-xkv >= %{texlive_version}
#!BuildIgnore: texlive-conv-xkv
Requires:       texlive-cooking >= %{texlive_version}
#!BuildIgnore: texlive-cooking
Requires:       texlive-cooking-units >= %{texlive_version}
#!BuildIgnore: texlive-cooking-units
Requires:       texlive-cool >= %{texlive_version}
#!BuildIgnore: texlive-cool
Requires:       texlive-coolfn >= %{texlive_version}
#!BuildIgnore: texlive-coolfn
Requires:       texlive-coollist >= %{texlive_version}
#!BuildIgnore: texlive-coollist
Requires:       texlive-coolstr >= %{texlive_version}
#!BuildIgnore: texlive-coolstr
Requires:       texlive-coolthms >= %{texlive_version}
#!BuildIgnore: texlive-coolthms
Requires:       texlive-cooltooltips >= %{texlive_version}
#!BuildIgnore: texlive-cooltooltips
Requires:       texlive-coop-writing >= %{texlive_version}
#!BuildIgnore: texlive-coop-writing
Requires:       texlive-coordsys >= %{texlive_version}
#!BuildIgnore: texlive-coordsys
Requires:       texlive-copyedit >= %{texlive_version}
#!BuildIgnore: texlive-copyedit
Requires:       texlive-copyrightbox >= %{texlive_version}
#!BuildIgnore: texlive-copyrightbox
Requires:       texlive-coseoul >= %{texlive_version}
#!BuildIgnore: texlive-coseoul
Requires:       texlive-counttexruns >= %{texlive_version}
#!BuildIgnore: texlive-counttexruns
Requires:       texlive-courseoutline >= %{texlive_version}
#!BuildIgnore: texlive-courseoutline
Requires:       texlive-coursepaper >= %{texlive_version}
#!BuildIgnore: texlive-coursepaper
Requires:       texlive-coverpage >= %{texlive_version}
#!BuildIgnore: texlive-coverpage
Requires:       texlive-cprotect >= %{texlive_version}
#!BuildIgnore: texlive-cprotect
Requires:       texlive-cprotectinside >= %{texlive_version}
#!BuildIgnore: texlive-cprotectinside
Requires:       texlive-crbox >= %{texlive_version}
#!BuildIgnore: texlive-crbox
Requires:       texlive-create-theorem >= %{texlive_version}
#!BuildIgnore: texlive-create-theorem
Requires:       texlive-crefthe >= %{texlive_version}
#!BuildIgnore: texlive-crefthe
Requires:       texlive-crossreference >= %{texlive_version}
#!BuildIgnore: texlive-crossreference
Requires:       texlive-crossreftools >= %{texlive_version}
#!BuildIgnore: texlive-crossreftools
Requires:       texlive-crumbs >= %{texlive_version}
#!BuildIgnore: texlive-crumbs
Requires:       texlive-csquotes >= %{texlive_version}
#!BuildIgnore: texlive-csquotes
Requires:       texlive-css-colors >= %{texlive_version}
#!BuildIgnore: texlive-css-colors
Requires:       texlive-csvmerge >= %{texlive_version}
#!BuildIgnore: texlive-csvmerge
Requires:       texlive-csvsimple >= %{texlive_version}
#!BuildIgnore: texlive-csvsimple
Requires:       texlive-cuisine >= %{texlive_version}
#!BuildIgnore: texlive-cuisine
Requires:       texlive-currency >= %{texlive_version}
#!BuildIgnore: texlive-currency
Requires:       texlive-currfile >= %{texlive_version}
#!BuildIgnore: texlive-currfile
Requires:       texlive-currvita >= %{texlive_version}
#!BuildIgnore: texlive-currvita
Requires:       texlive-cutwin >= %{texlive_version}
#!BuildIgnore: texlive-cutwin
Requires:       texlive-cv >= %{texlive_version}
#!BuildIgnore: texlive-cv
Requires:       texlive-cv4tw >= %{texlive_version}
#!BuildIgnore: texlive-cv4tw
Requires:       texlive-cweb-latex >= %{texlive_version}
#!BuildIgnore: texlive-cweb-latex
Requires:       texlive-cyber >= %{texlive_version}
#!BuildIgnore: texlive-cyber
Requires:       texlive-cybercic >= %{texlive_version}
#!BuildIgnore: texlive-cybercic
Requires:       texlive-darkmode >= %{texlive_version}
#!BuildIgnore: texlive-darkmode
Requires:       texlive-dashbox >= %{texlive_version}
#!BuildIgnore: texlive-dashbox
Requires:       texlive-dashrule >= %{texlive_version}
#!BuildIgnore: texlive-dashrule
Requires:       texlive-dashundergaps >= %{texlive_version}
#!BuildIgnore: texlive-dashundergaps
Requires:       texlive-dataref >= %{texlive_version}
#!BuildIgnore: texlive-dataref
Requires:       texlive-datatool >= %{texlive_version}
#!BuildIgnore: texlive-datatool
Requires:       texlive-datax >= %{texlive_version}
#!BuildIgnore: texlive-datax
Requires:       texlive-dateiliste >= %{texlive_version}
#!BuildIgnore: texlive-dateiliste
Requires:       texlive-datenumber >= %{texlive_version}
#!BuildIgnore: texlive-datenumber
Requires:       texlive-datestamp >= %{texlive_version}
#!BuildIgnore: texlive-datestamp
Requires:       texlive-datetime >= %{texlive_version}
#!BuildIgnore: texlive-datetime
Requires:       texlive-datetime2 >= %{texlive_version}
#!BuildIgnore: texlive-datetime2
Requires:       texlive-datetime2-bahasai >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-bahasai
Requires:       texlive-datetime2-basque >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-basque
Requires:       texlive-datetime2-breton >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-breton
Requires:       texlive-datetime2-bulgarian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-bulgarian
Requires:       texlive-datetime2-catalan >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-catalan
Requires:       texlive-datetime2-croatian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-croatian
Requires:       texlive-datetime2-czech >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-czech
Requires:       texlive-datetime2-danish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-danish
Requires:       texlive-datetime2-dutch >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-dutch
Requires:       texlive-datetime2-en-fulltext >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-en-fulltext
Requires:       texlive-datetime2-english >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-english
Requires:       texlive-datetime2-esperanto >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-esperanto
Requires:       texlive-datetime2-estonian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-estonian
Requires:       texlive-datetime2-finnish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-finnish
Requires:       texlive-datetime2-french >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-french
Requires:       texlive-datetime2-galician >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-galician
Requires:       texlive-datetime2-german >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-german
Requires:       texlive-datetime2-greek >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-greek
Requires:       texlive-datetime2-hebrew >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-hebrew
Requires:       texlive-datetime2-icelandic >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-icelandic
Requires:       texlive-datetime2-irish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-irish
Requires:       texlive-datetime2-it-fulltext >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-it-fulltext
Requires:       texlive-datetime2-italian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-italian
Requires:       texlive-datetime2-latin >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-latin
Requires:       texlive-datetime2-lsorbian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-lsorbian
Requires:       texlive-datetime2-magyar >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-magyar
Requires:       texlive-datetime2-norsk >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-norsk
Requires:       texlive-datetime2-polish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-polish
Requires:       texlive-datetime2-portuges >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-portuges
Requires:       texlive-datetime2-romanian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-romanian
Requires:       texlive-datetime2-russian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-russian
Requires:       texlive-datetime2-samin >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-samin
Requires:       texlive-datetime2-scottish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-scottish
Requires:       texlive-datetime2-serbian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-serbian
Requires:       texlive-datetime2-slovak >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-slovak
Requires:       texlive-datetime2-slovene >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-slovene
Requires:       texlive-datetime2-spanish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-spanish
Requires:       texlive-datetime2-swedish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-swedish
Requires:       texlive-datetime2-turkish >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-turkish
Requires:       texlive-datetime2-ukrainian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-ukrainian
Requires:       texlive-datetime2-usorbian >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-usorbian
Requires:       texlive-datetime2-welsh >= %{texlive_version}
#!BuildIgnore: texlive-datetime2-welsh
Requires:       texlive-dblfloatfix >= %{texlive_version}
#!BuildIgnore: texlive-dblfloatfix
Requires:       texlive-dbshow >= %{texlive_version}
#!BuildIgnore: texlive-dbshow
Requires:       texlive-debate >= %{texlive_version}
#!BuildIgnore: texlive-debate
Requires:       texlive-decimal >= %{texlive_version}
#!BuildIgnore: texlive-decimal
Requires:       texlive-decorule >= %{texlive_version}
#!BuildIgnore: texlive-decorule
Requires:       texlive-delimtxt >= %{texlive_version}
#!BuildIgnore: texlive-delimtxt
Requires:       texlive-democodetools >= %{texlive_version}
#!BuildIgnore: texlive-democodetools
Requires:       texlive-denisbdoc >= %{texlive_version}
#!BuildIgnore: texlive-denisbdoc
Requires:       texlive-diabetes-logbook >= %{texlive_version}
#!BuildIgnore: texlive-diabetes-logbook
Requires:       texlive-diagbox >= %{texlive_version}
#!BuildIgnore: texlive-diagbox
Requires:       texlive-diagnose >= %{texlive_version}
#!BuildIgnore: texlive-diagnose
Requires:       texlive-dialogl >= %{texlive_version}
#!BuildIgnore: texlive-dialogl
Requires:       texlive-dichokey >= %{texlive_version}
#!BuildIgnore: texlive-dichokey
Requires:       texlive-dimnum >= %{texlive_version}
#!BuildIgnore: texlive-dimnum
Requires:       texlive-dinbrief >= %{texlive_version}
#!BuildIgnore: texlive-dinbrief
Requires:       texlive-directory >= %{texlive_version}
#!BuildIgnore: texlive-directory
Requires:       texlive-dirtytalk >= %{texlive_version}
#!BuildIgnore: texlive-dirtytalk
Requires:       texlive-dlfltxb >= %{texlive_version}
#!BuildIgnore: texlive-dlfltxb
Requires:       texlive-dnaseq >= %{texlive_version}
#!BuildIgnore: texlive-dnaseq
Requires:       texlive-doclicense >= %{texlive_version}
#!BuildIgnore: texlive-doclicense
Requires:       texlive-docmfp >= %{texlive_version}
#!BuildIgnore: texlive-docmfp
Requires:       texlive-docmute >= %{texlive_version}
#!BuildIgnore: texlive-docmute
Requires:       texlive-docshots >= %{texlive_version}
#!BuildIgnore: texlive-docshots
Requires:       texlive-doctools >= %{texlive_version}
#!BuildIgnore: texlive-doctools
Requires:       texlive-documentation >= %{texlive_version}
#!BuildIgnore: texlive-documentation
Requires:       texlive-docutils >= %{texlive_version}
#!BuildIgnore: texlive-docutils
Requires:       texlive-doi >= %{texlive_version}
#!BuildIgnore: texlive-doi
Requires:       texlive-dotarrow >= %{texlive_version}
#!BuildIgnore: texlive-dotarrow
Requires:       texlive-dotlessi >= %{texlive_version}
#!BuildIgnore: texlive-dotlessi
Requires:       texlive-dotseqn >= %{texlive_version}
#!BuildIgnore: texlive-dotseqn
Requires:       texlive-download >= %{texlive_version}
#!BuildIgnore: texlive-download
Requires:       texlive-dox >= %{texlive_version}
#!BuildIgnore: texlive-dox
Requires:       texlive-dpfloat >= %{texlive_version}
#!BuildIgnore: texlive-dpfloat
Requires:       texlive-dprogress >= %{texlive_version}
#!BuildIgnore: texlive-dprogress
Requires:       texlive-drac >= %{texlive_version}
#!BuildIgnore: texlive-drac
Requires:       texlive-draftcopy >= %{texlive_version}
#!BuildIgnore: texlive-draftcopy
Requires:       texlive-draftfigure >= %{texlive_version}
#!BuildIgnore: texlive-draftfigure
Requires:       texlive-draftwatermark >= %{texlive_version}
#!BuildIgnore: texlive-draftwatermark
Requires:       texlive-dtk >= %{texlive_version}
#!BuildIgnore: texlive-dtk
Requires:       texlive-dtxdescribe >= %{texlive_version}
#!BuildIgnore: texlive-dtxdescribe
Requires:       texlive-dtxgallery >= %{texlive_version}
#!BuildIgnore: texlive-dtxgallery
Requires:       texlive-ducksay >= %{texlive_version}
#!BuildIgnore: texlive-ducksay
Requires:       texlive-duckuments >= %{texlive_version}
#!BuildIgnore: texlive-duckuments
Requires:       texlive-dvdcoll >= %{texlive_version}
#!BuildIgnore: texlive-dvdcoll
Requires:       texlive-dynamicnumber >= %{texlive_version}
#!BuildIgnore: texlive-dynamicnumber
Requires:       texlive-dynblocks >= %{texlive_version}
#!BuildIgnore: texlive-dynblocks
Requires:       texlive-ean13isbn >= %{texlive_version}
#!BuildIgnore: texlive-ean13isbn
Requires:       texlive-easy >= %{texlive_version}
#!BuildIgnore: texlive-easy
Requires:       texlive-easy-todo >= %{texlive_version}
#!BuildIgnore: texlive-easy-todo
Requires:       texlive-easybook >= %{texlive_version}
#!BuildIgnore: texlive-easybook
Requires:       texlive-easyfig >= %{texlive_version}
#!BuildIgnore: texlive-easyfig
Requires:       texlive-easyfloats >= %{texlive_version}
#!BuildIgnore: texlive-easyfloats
Requires:       texlive-easyformat >= %{texlive_version}
#!BuildIgnore: texlive-easyformat
Requires:       texlive-easylist >= %{texlive_version}
#!BuildIgnore: texlive-easylist
Requires:       texlive-easyreview >= %{texlive_version}
#!BuildIgnore: texlive-easyreview
Requires:       texlive-ebezier >= %{texlive_version}
#!BuildIgnore: texlive-ebezier
Requires:       texlive-ecclesiastic >= %{texlive_version}
#!BuildIgnore: texlive-ecclesiastic
Requires:       texlive-econlipsum >= %{texlive_version}
#!BuildIgnore: texlive-econlipsum
Requires:       texlive-ecv >= %{texlive_version}
#!BuildIgnore: texlive-ecv
Requires:       texlive-ed >= %{texlive_version}
#!BuildIgnore: texlive-ed
Requires:       texlive-edichokey >= %{texlive_version}
#!BuildIgnore: texlive-edichokey
Requires:       texlive-edmargin >= %{texlive_version}
#!BuildIgnore: texlive-edmargin
Requires:       texlive-eemeir >= %{texlive_version}
#!BuildIgnore: texlive-eemeir
Requires:       texlive-efbox >= %{texlive_version}
#!BuildIgnore: texlive-efbox
Requires:       texlive-egplot >= %{texlive_version}
#!BuildIgnore: texlive-egplot
Requires:       texlive-ehhline >= %{texlive_version}
#!BuildIgnore: texlive-ehhline
Requires:       texlive-einfart >= %{texlive_version}
#!BuildIgnore: texlive-einfart
Requires:       texlive-elements >= %{texlive_version}
#!BuildIgnore: texlive-elements
Requires:       texlive-ellipsis >= %{texlive_version}
#!BuildIgnore: texlive-ellipsis
Requires:       texlive-elmath >= %{texlive_version}
#!BuildIgnore: texlive-elmath
Requires:       texlive-elocalloc >= %{texlive_version}
#!BuildIgnore: texlive-elocalloc
Requires:       texlive-elpres >= %{texlive_version}
#!BuildIgnore: texlive-elpres
Requires:       texlive-elzcards >= %{texlive_version}
#!BuildIgnore: texlive-elzcards
Requires:       texlive-emarks >= %{texlive_version}
#!BuildIgnore: texlive-emarks
Requires:       texlive-embedall >= %{texlive_version}
#!BuildIgnore: texlive-embedall
Requires:       texlive-embedfile >= %{texlive_version}
#!BuildIgnore: texlive-embedfile
Requires:       texlive-embrac >= %{texlive_version}
#!BuildIgnore: texlive-embrac
Requires:       texlive-emptypage >= %{texlive_version}
#!BuildIgnore: texlive-emptypage
Requires:       texlive-emulateapj >= %{texlive_version}
#!BuildIgnore: texlive-emulateapj
Requires:       texlive-endfloat >= %{texlive_version}
#!BuildIgnore: texlive-endfloat
Requires:       texlive-endheads >= %{texlive_version}
#!BuildIgnore: texlive-endheads
Requires:       texlive-endnotes >= %{texlive_version}
#!BuildIgnore: texlive-endnotes
Requires:       texlive-endnotes-hy >= %{texlive_version}
#!BuildIgnore: texlive-endnotes-hy
Requires:       texlive-engpron >= %{texlive_version}
#!BuildIgnore: texlive-engpron
Requires:       texlive-engrec >= %{texlive_version}
#!BuildIgnore: texlive-engrec
Requires:       texlive-enotez >= %{texlive_version}
#!BuildIgnore: texlive-enotez
Requires:       texlive-enumitem >= %{texlive_version}
#!BuildIgnore: texlive-enumitem
Requires:       texlive-enumitem-zref >= %{texlive_version}
#!BuildIgnore: texlive-enumitem-zref
Requires:       texlive-envbig >= %{texlive_version}
#!BuildIgnore: texlive-envbig
Requires:       texlive-environ >= %{texlive_version}
#!BuildIgnore: texlive-environ
Requires:       texlive-envlab >= %{texlive_version}
#!BuildIgnore: texlive-envlab
Requires:       texlive-epigraph >= %{texlive_version}
#!BuildIgnore: texlive-epigraph
Requires:       texlive-epigraph-keys >= %{texlive_version}
#!BuildIgnore: texlive-epigraph-keys
Requires:       texlive-epiolmec >= %{texlive_version}
#!BuildIgnore: texlive-epiolmec
Requires:       texlive-eq-pin2corr >= %{texlive_version}
#!BuildIgnore: texlive-eq-pin2corr
Requires:       texlive-eqell >= %{texlive_version}
#!BuildIgnore: texlive-eqell
Requires:       texlive-eqlist >= %{texlive_version}
#!BuildIgnore: texlive-eqlist
Requires:       texlive-eqnalign >= %{texlive_version}
#!BuildIgnore: texlive-eqnalign
Requires:       texlive-eqname >= %{texlive_version}
#!BuildIgnore: texlive-eqname
Requires:       texlive-eqparbox >= %{texlive_version}
#!BuildIgnore: texlive-eqparbox
Requires:       texlive-errata >= %{texlive_version}
#!BuildIgnore: texlive-errata
Requires:       texlive-erw-l3 >= %{texlive_version}
#!BuildIgnore: texlive-erw-l3
Requires:       texlive-esami >= %{texlive_version}
#!BuildIgnore: texlive-esami
Requires:       texlive-esdiff >= %{texlive_version}
#!BuildIgnore: texlive-esdiff
Requires:       texlive-esieecv >= %{texlive_version}
#!BuildIgnore: texlive-esieecv
Requires:       texlive-esindex >= %{texlive_version}
#!BuildIgnore: texlive-esindex
Requires:       texlive-esint >= %{texlive_version}
#!BuildIgnore: texlive-esint
Requires:       texlive-esint-type1 >= %{texlive_version}
#!BuildIgnore: texlive-esint-type1
Requires:       texlive-etaremune >= %{texlive_version}
#!BuildIgnore: texlive-etaremune
Requires:       texlive-etextools >= %{texlive_version}
#!BuildIgnore: texlive-etextools
Requires:       texlive-etl >= %{texlive_version}
#!BuildIgnore: texlive-etl
Requires:       texlive-etoc >= %{texlive_version}
#!BuildIgnore: texlive-etoc
Requires:       texlive-eukdate >= %{texlive_version}
#!BuildIgnore: texlive-eukdate
Requires:       texlive-eulerpx >= %{texlive_version}
#!BuildIgnore: texlive-eulerpx
Requires:       texlive-europasscv >= %{texlive_version}
#!BuildIgnore: texlive-europasscv
Requires:       texlive-europecv >= %{texlive_version}
#!BuildIgnore: texlive-europecv
Requires:       texlive-everyhook >= %{texlive_version}
#!BuildIgnore: texlive-everyhook
Requires:       texlive-everypage >= %{texlive_version}
#!BuildIgnore: texlive-everypage
Requires:       texlive-exam >= %{texlive_version}
#!BuildIgnore: texlive-exam
Requires:       texlive-exam-lite >= %{texlive_version}
#!BuildIgnore: texlive-exam-lite
Requires:       texlive-exam-n >= %{texlive_version}
#!BuildIgnore: texlive-exam-n
Requires:       texlive-exam-randomizechoices >= %{texlive_version}
#!BuildIgnore: texlive-exam-randomizechoices
Requires:       texlive-examdesign >= %{texlive_version}
#!BuildIgnore: texlive-examdesign
Requires:       texlive-example >= %{texlive_version}
#!BuildIgnore: texlive-example
Requires:       texlive-examplep >= %{texlive_version}
#!BuildIgnore: texlive-examplep
Requires:       texlive-exceltex >= %{texlive_version}
#!BuildIgnore: texlive-exceltex
Requires:       texlive-excludeonly >= %{texlive_version}
#!BuildIgnore: texlive-excludeonly
Requires:       texlive-exercise >= %{texlive_version}
#!BuildIgnore: texlive-exercise
Requires:       texlive-exercisebank >= %{texlive_version}
#!BuildIgnore: texlive-exercisebank
Requires:       texlive-exercisepoints >= %{texlive_version}
#!BuildIgnore: texlive-exercisepoints
Requires:       texlive-exercises >= %{texlive_version}
#!BuildIgnore: texlive-exercises
Requires:       texlive-exesheet >= %{texlive_version}
#!BuildIgnore: texlive-exesheet
Requires:       texlive-exframe >= %{texlive_version}
#!BuildIgnore: texlive-exframe
Requires:       texlive-exp-testopt >= %{texlive_version}
#!BuildIgnore: texlive-exp-testopt
Requires:       texlive-expdlist >= %{texlive_version}
#!BuildIgnore: texlive-expdlist
Requires:       texlive-export >= %{texlive_version}
#!BuildIgnore: texlive-export
Requires:       texlive-exsheets >= %{texlive_version}
#!BuildIgnore: texlive-exsheets
Requires:       texlive-exsol >= %{texlive_version}
#!BuildIgnore: texlive-exsol
Requires:       texlive-extract >= %{texlive_version}
#!BuildIgnore: texlive-extract
Requires:       texlive-facsimile >= %{texlive_version}
#!BuildIgnore: texlive-facsimile
Requires:       texlive-factura >= %{texlive_version}
#!BuildIgnore: texlive-factura
Requires:       texlive-familytree >= %{texlive_version}
#!BuildIgnore: texlive-familytree
Requires:       texlive-fancyhandout >= %{texlive_version}
#!BuildIgnore: texlive-fancyhandout
Requires:       texlive-fancylabel >= %{texlive_version}
#!BuildIgnore: texlive-fancylabel
Requires:       texlive-fancynum >= %{texlive_version}
#!BuildIgnore: texlive-fancynum
Requires:       texlive-fancypar >= %{texlive_version}
#!BuildIgnore: texlive-fancypar
Requires:       texlive-fancyqr >= %{texlive_version}
#!BuildIgnore: texlive-fancyqr
Requires:       texlive-fancyslides >= %{texlive_version}
#!BuildIgnore: texlive-fancyslides
Requires:       texlive-fancytabs >= %{texlive_version}
#!BuildIgnore: texlive-fancytabs
Requires:       texlive-fancytooltips >= %{texlive_version}
#!BuildIgnore: texlive-fancytooltips
Requires:       texlive-fbox >= %{texlive_version}
#!BuildIgnore: texlive-fbox
Requires:       texlive-fcolumn >= %{texlive_version}
#!BuildIgnore: texlive-fcolumn
Requires:       texlive-fetchcls >= %{texlive_version}
#!BuildIgnore: texlive-fetchcls
Requires:       texlive-fewerfloatpages >= %{texlive_version}
#!BuildIgnore: texlive-fewerfloatpages
Requires:       texlive-ffcode >= %{texlive_version}
#!BuildIgnore: texlive-ffcode
Requires:       texlive-ffslides >= %{texlive_version}
#!BuildIgnore: texlive-ffslides
Requires:       texlive-fgruler >= %{texlive_version}
#!BuildIgnore: texlive-fgruler
Requires:       texlive-fifo-stack >= %{texlive_version}
#!BuildIgnore: texlive-fifo-stack
Requires:       texlive-figsize >= %{texlive_version}
#!BuildIgnore: texlive-figsize
Requires:       texlive-filecontents >= %{texlive_version}
#!BuildIgnore: texlive-filecontents
Requires:       texlive-filecontentsdef >= %{texlive_version}
#!BuildIgnore: texlive-filecontentsdef
Requires:       texlive-filedate >= %{texlive_version}
#!BuildIgnore: texlive-filedate
Requires:       texlive-fileinfo >= %{texlive_version}
#!BuildIgnore: texlive-fileinfo
Requires:       texlive-filemod >= %{texlive_version}
#!BuildIgnore: texlive-filemod
Requires:       texlive-fink >= %{texlive_version}
#!BuildIgnore: texlive-fink
Requires:       texlive-finstrut >= %{texlive_version}
#!BuildIgnore: texlive-finstrut
Requires:       texlive-fistrum >= %{texlive_version}
#!BuildIgnore: texlive-fistrum
Requires:       texlive-fithesis >= %{texlive_version}
#!BuildIgnore: texlive-fithesis
Requires:       texlive-fixcmex >= %{texlive_version}
#!BuildIgnore: texlive-fixcmex
Requires:       texlive-fixfoot >= %{texlive_version}
#!BuildIgnore: texlive-fixfoot
Requires:       texlive-fixme >= %{texlive_version}
#!BuildIgnore: texlive-fixme
Requires:       texlive-fixmetodonotes >= %{texlive_version}
#!BuildIgnore: texlive-fixmetodonotes
Requires:       texlive-fjodor >= %{texlive_version}
#!BuildIgnore: texlive-fjodor
Requires:       texlive-flabels >= %{texlive_version}
#!BuildIgnore: texlive-flabels
Requires:       texlive-flacards >= %{texlive_version}
#!BuildIgnore: texlive-flacards
Requires:       texlive-flagderiv >= %{texlive_version}
#!BuildIgnore: texlive-flagderiv
Requires:       texlive-flashcards >= %{texlive_version}
#!BuildIgnore: texlive-flashcards
Requires:       texlive-flashmovie >= %{texlive_version}
#!BuildIgnore: texlive-flashmovie
Requires:       texlive-flexipage >= %{texlive_version}
#!BuildIgnore: texlive-flexipage
Requires:       texlive-flipbook >= %{texlive_version}
#!BuildIgnore: texlive-flipbook
Requires:       texlive-flippdf >= %{texlive_version}
#!BuildIgnore: texlive-flippdf
Requires:       texlive-floatrow >= %{texlive_version}
#!BuildIgnore: texlive-floatrow
Requires:       texlive-flowfram >= %{texlive_version}
#!BuildIgnore: texlive-flowfram
Requires:       texlive-fmp >= %{texlive_version}
#!BuildIgnore: texlive-fmp
Requires:       texlive-fmtcount >= %{texlive_version}
#!BuildIgnore: texlive-fmtcount
Requires:       texlive-fn2end >= %{texlive_version}
#!BuildIgnore: texlive-fn2end
Requires:       texlive-fnbreak >= %{texlive_version}
#!BuildIgnore: texlive-fnbreak
Requires:       texlive-fncychap >= %{texlive_version}
#!BuildIgnore: texlive-fncychap
Requires:       texlive-fncylab >= %{texlive_version}
#!BuildIgnore: texlive-fncylab
Requires:       texlive-fnpara >= %{texlive_version}
#!BuildIgnore: texlive-fnpara
Requires:       texlive-fnpct >= %{texlive_version}
#!BuildIgnore: texlive-fnpct
Requires:       texlive-fnumprint >= %{texlive_version}
#!BuildIgnore: texlive-fnumprint
Requires:       texlive-foilhtml >= %{texlive_version}
#!BuildIgnore: texlive-foilhtml
Requires:       texlive-foliono >= %{texlive_version}
#!BuildIgnore: texlive-foliono
Requires:       texlive-fontaxes >= %{texlive_version}
#!BuildIgnore: texlive-fontaxes
Requires:       texlive-fontsetup >= %{texlive_version}
#!BuildIgnore: texlive-fontsetup
Requires:       texlive-fontsize >= %{texlive_version}
#!BuildIgnore: texlive-fontsize
Requires:       texlive-fonttable >= %{texlive_version}
#!BuildIgnore: texlive-fonttable
Requires:       texlive-footmisc >= %{texlive_version}
#!BuildIgnore: texlive-footmisc
Requires:       texlive-footmisx >= %{texlive_version}
#!BuildIgnore: texlive-footmisx
Requires:       texlive-footnotebackref >= %{texlive_version}
#!BuildIgnore: texlive-footnotebackref
Requires:       texlive-footnoterange >= %{texlive_version}
#!BuildIgnore: texlive-footnoterange
Requires:       texlive-footnpag >= %{texlive_version}
#!BuildIgnore: texlive-footnpag
Requires:       texlive-forarray >= %{texlive_version}
#!BuildIgnore: texlive-forarray
Requires:       texlive-foreign >= %{texlive_version}
#!BuildIgnore: texlive-foreign
Requires:       texlive-forloop >= %{texlive_version}
#!BuildIgnore: texlive-forloop
Requires:       texlive-formlett >= %{texlive_version}
#!BuildIgnore: texlive-formlett
Requires:       texlive-forms16be >= %{texlive_version}
#!BuildIgnore: texlive-forms16be
Requires:       texlive-formular >= %{texlive_version}
#!BuildIgnore: texlive-formular
Requires:       texlive-fragments >= %{texlive_version}
#!BuildIgnore: texlive-fragments
Requires:       texlive-frame >= %{texlive_version}
#!BuildIgnore: texlive-frame
Requires:       texlive-framed >= %{texlive_version}
#!BuildIgnore: texlive-framed
Requires:       texlive-frankenstein >= %{texlive_version}
#!BuildIgnore: texlive-frankenstein
Requires:       texlive-frege >= %{texlive_version}
#!BuildIgnore: texlive-frege
Requires:       texlive-froufrou >= %{texlive_version}
#!BuildIgnore: texlive-froufrou
Requires:       texlive-ftcap >= %{texlive_version}
#!BuildIgnore: texlive-ftcap
Requires:       texlive-ftnxtra >= %{texlive_version}
#!BuildIgnore: texlive-ftnxtra
Requires:       texlive-fullblck >= %{texlive_version}
#!BuildIgnore: texlive-fullblck
Requires:       texlive-fullminipage >= %{texlive_version}
#!BuildIgnore: texlive-fullminipage
Requires:       texlive-fullwidth >= %{texlive_version}
#!BuildIgnore: texlive-fullwidth
Requires:       texlive-functional >= %{texlive_version}
#!BuildIgnore: texlive-functional
Requires:       texlive-fundus-calligra >= %{texlive_version}
#!BuildIgnore: texlive-fundus-calligra
Requires:       texlive-fundus-cyr >= %{texlive_version}
#!BuildIgnore: texlive-fundus-cyr
Requires:       texlive-fundus-sueterlin >= %{texlive_version}
#!BuildIgnore: texlive-fundus-sueterlin
Requires:       texlive-fvextra >= %{texlive_version}
#!BuildIgnore: texlive-fvextra
Requires:       texlive-fwlw >= %{texlive_version}
#!BuildIgnore: texlive-fwlw
Requires:       texlive-g-brief >= %{texlive_version}
#!BuildIgnore: texlive-g-brief
Requires:       texlive-gatherenum >= %{texlive_version}
#!BuildIgnore: texlive-gatherenum
Requires:       texlive-gauss >= %{texlive_version}
#!BuildIgnore: texlive-gauss
Requires:       texlive-gcard >= %{texlive_version}
#!BuildIgnore: texlive-gcard
Requires:       texlive-gcite >= %{texlive_version}
#!BuildIgnore: texlive-gcite
Requires:       texlive-gender >= %{texlive_version}
#!BuildIgnore: texlive-gender
Requires:       texlive-genmpage >= %{texlive_version}
#!BuildIgnore: texlive-genmpage
Requires:       texlive-gensymb >= %{texlive_version}
#!BuildIgnore: texlive-gensymb
Requires:       texlive-getfiledate >= %{texlive_version}
#!BuildIgnore: texlive-getfiledate
Requires:       texlive-getitems >= %{texlive_version}
#!BuildIgnore: texlive-getitems
Requires:       texlive-gindex >= %{texlive_version}
#!BuildIgnore: texlive-gindex
Requires:       texlive-ginpenc >= %{texlive_version}
#!BuildIgnore: texlive-ginpenc
Requires:       texlive-gitfile-info >= %{texlive_version}
#!BuildIgnore: texlive-gitfile-info
Requires:       texlive-gitinfo >= %{texlive_version}
#!BuildIgnore: texlive-gitinfo
Requires:       texlive-gitinfo2 >= %{texlive_version}
#!BuildIgnore: texlive-gitinfo2
Requires:       texlive-gitlog >= %{texlive_version}
#!BuildIgnore: texlive-gitlog
Requires:       texlive-gitstatus >= %{texlive_version}
#!BuildIgnore: texlive-gitstatus
Requires:       texlive-gitver >= %{texlive_version}
#!BuildIgnore: texlive-gitver
Requires:       texlive-globalvals >= %{texlive_version}
#!BuildIgnore: texlive-globalvals
Requires:       texlive-gloss >= %{texlive_version}
#!BuildIgnore: texlive-gloss
Requires:       texlive-glossaries >= %{texlive_version}
#!BuildIgnore: texlive-glossaries
Requires:       texlive-glossaries-danish >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-danish
Requires:       texlive-glossaries-dutch >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-dutch
Requires:       texlive-glossaries-english >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-english
Requires:       texlive-glossaries-estonian >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-estonian
Requires:       texlive-glossaries-extra >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-extra
Requires:       texlive-glossaries-finnish >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-finnish
Requires:       texlive-glossaries-french >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-french
Requires:       texlive-glossaries-german >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-german
Requires:       texlive-glossaries-irish >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-irish
Requires:       texlive-glossaries-italian >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-italian
Requires:       texlive-glossaries-magyar >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-magyar
Requires:       texlive-glossaries-nynorsk >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-nynorsk
Requires:       texlive-glossaries-polish >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-polish
Requires:       texlive-glossaries-portuges >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-portuges
Requires:       texlive-glossaries-serbian >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-serbian
Requires:       texlive-glossaries-slovene >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-slovene
Requires:       texlive-glossaries-spanish >= %{texlive_version}
#!BuildIgnore: texlive-glossaries-spanish
Requires:       texlive-gmdoc >= %{texlive_version}
#!BuildIgnore: texlive-gmdoc
Requires:       texlive-gmdoc-enhance >= %{texlive_version}
#!BuildIgnore: texlive-gmdoc-enhance
Requires:       texlive-gmiflink >= %{texlive_version}
#!BuildIgnore: texlive-gmiflink
Requires:       texlive-gmutils >= %{texlive_version}
#!BuildIgnore: texlive-gmutils
Requires:       texlive-gmverb >= %{texlive_version}
#!BuildIgnore: texlive-gmverb
Requires:       texlive-grabbox >= %{texlive_version}
#!BuildIgnore: texlive-grabbox
Requires:       texlive-gradient-text >= %{texlive_version}
#!BuildIgnore: texlive-gradient-text
Requires:       texlive-grading-scheme >= %{texlive_version}
#!BuildIgnore: texlive-grading-scheme
Requires:       texlive-graphbox >= %{texlive_version}
#!BuildIgnore: texlive-graphbox
Requires:       texlive-graphicscache >= %{texlive_version}
#!BuildIgnore: texlive-graphicscache
Requires:       texlive-graphicx-psmin >= %{texlive_version}
#!BuildIgnore: texlive-graphicx-psmin
Requires:       texlive-graphicxbox >= %{texlive_version}
#!BuildIgnore: texlive-graphicxbox
Requires:       texlive-graphpaper >= %{texlive_version}
#!BuildIgnore: texlive-graphpaper
Requires:       texlive-grayhints >= %{texlive_version}
#!BuildIgnore: texlive-grayhints
Requires:       texlive-grfpaste >= %{texlive_version}
#!BuildIgnore: texlive-grfpaste
Requires:       texlive-grid >= %{texlive_version}
#!BuildIgnore: texlive-grid
Requires:       texlive-grid-system >= %{texlive_version}
#!BuildIgnore: texlive-grid-system
Requires:       texlive-gridpapers >= %{texlive_version}
#!BuildIgnore: texlive-gridpapers
Requires:       texlive-gridset >= %{texlive_version}
#!BuildIgnore: texlive-gridset
Requires:       texlive-gridslides >= %{texlive_version}
#!BuildIgnore: texlive-gridslides
Requires:       texlive-gs1 >= %{texlive_version}
#!BuildIgnore: texlive-gs1
Requires:       texlive-guitlogo >= %{texlive_version}
#!BuildIgnore: texlive-guitlogo
Requires:       texlive-ha-prosper >= %{texlive_version}
#!BuildIgnore: texlive-ha-prosper
Requires:       texlive-hackthefootline >= %{texlive_version}
#!BuildIgnore: texlive-hackthefootline
Requires:       texlive-halloweenmath >= %{texlive_version}
#!BuildIgnore: texlive-halloweenmath
Requires:       texlive-handin >= %{texlive_version}
#!BuildIgnore: texlive-handin
Requires:       texlive-handout >= %{texlive_version}
#!BuildIgnore: texlive-handout
Requires:       texlive-handoutwithnotes >= %{texlive_version}
#!BuildIgnore: texlive-handoutwithnotes
Requires:       texlive-hang >= %{texlive_version}
#!BuildIgnore: texlive-hang
Requires:       texlive-hanging >= %{texlive_version}
#!BuildIgnore: texlive-hanging
Requires:       texlive-hardwrap >= %{texlive_version}
#!BuildIgnore: texlive-hardwrap
Requires:       texlive-harnon-cv >= %{texlive_version}
#!BuildIgnore: texlive-harnon-cv
Requires:       texlive-harpoon >= %{texlive_version}
#!BuildIgnore: texlive-harpoon
Requires:       texlive-hc >= %{texlive_version}
#!BuildIgnore: texlive-hc
Requires:       texlive-he-she >= %{texlive_version}
#!BuildIgnore: texlive-he-she
Requires:       texlive-hep-acronym >= %{texlive_version}
#!BuildIgnore: texlive-hep-acronym
Requires:       texlive-hep-float >= %{texlive_version}
#!BuildIgnore: texlive-hep-float
Requires:       texlive-hep-math >= %{texlive_version}
#!BuildIgnore: texlive-hep-math
Requires:       texlive-hep-text >= %{texlive_version}
#!BuildIgnore: texlive-hep-text
Requires:       texlive-hep-title >= %{texlive_version}
#!BuildIgnore: texlive-hep-title
Requires:       texlive-hereapplies >= %{texlive_version}
#!BuildIgnore: texlive-hereapplies
Requires:       texlive-hhtensor >= %{texlive_version}
#!BuildIgnore: texlive-hhtensor
Requires:       texlive-hideanswer >= %{texlive_version}
#!BuildIgnore: texlive-hideanswer
Requires:       texlive-highlightlatex >= %{texlive_version}
#!BuildIgnore: texlive-highlightlatex
Requires:       texlive-histogr >= %{texlive_version}
#!BuildIgnore: texlive-histogr
Requires:       texlive-hitec >= %{texlive_version}
#!BuildIgnore: texlive-hitec
Requires:       texlive-hitreport >= %{texlive_version}
#!BuildIgnore: texlive-hitreport
Requires:       texlive-hletter >= %{texlive_version}
#!BuildIgnore: texlive-hletter
Requires:       texlive-hobsub >= %{texlive_version}
#!BuildIgnore: texlive-hobsub
Requires:       texlive-hpsdiss >= %{texlive_version}
#!BuildIgnore: texlive-hpsdiss
Requires:       texlive-href-ul >= %{texlive_version}
#!BuildIgnore: texlive-href-ul
Requires:       texlive-hrefhide >= %{texlive_version}
#!BuildIgnore: texlive-hrefhide
Requires:       texlive-huawei >= %{texlive_version}
#!BuildIgnore: texlive-huawei
Requires:       texlive-hvextern >= %{texlive_version}
#!BuildIgnore: texlive-hvextern
Requires:       texlive-hvindex >= %{texlive_version}
#!BuildIgnore: texlive-hvindex
Requires:       texlive-hvlogos >= %{texlive_version}
#!BuildIgnore: texlive-hvlogos
Requires:       texlive-hvpygmentex >= %{texlive_version}
#!BuildIgnore: texlive-hvpygmentex
Requires:       texlive-hvqrurl >= %{texlive_version}
#!BuildIgnore: texlive-hvqrurl
Requires:       texlive-hwemoji >= %{texlive_version}
#!BuildIgnore: texlive-hwemoji
Requires:       texlive-hypdestopt >= %{texlive_version}
#!BuildIgnore: texlive-hypdestopt
Requires:       texlive-hypdoc >= %{texlive_version}
#!BuildIgnore: texlive-hypdoc
Requires:       texlive-hypdvips >= %{texlive_version}
#!BuildIgnore: texlive-hypdvips
Requires:       texlive-hyper >= %{texlive_version}
#!BuildIgnore: texlive-hyper
Requires:       texlive-hyperbar >= %{texlive_version}
#!BuildIgnore: texlive-hyperbar
Requires:       texlive-hypernat >= %{texlive_version}
#!BuildIgnore: texlive-hypernat
Requires:       texlive-hyperxmp >= %{texlive_version}
#!BuildIgnore: texlive-hyperxmp
Requires:       texlive-hyphenat >= %{texlive_version}
#!BuildIgnore: texlive-hyphenat
Requires:       texlive-identkey >= %{texlive_version}
#!BuildIgnore: texlive-identkey
Requires:       texlive-idxcmds >= %{texlive_version}
#!BuildIgnore: texlive-idxcmds
Requires:       texlive-idxlayout >= %{texlive_version}
#!BuildIgnore: texlive-idxlayout
Requires:       texlive-iexec >= %{texlive_version}
#!BuildIgnore: texlive-iexec
Requires:       texlive-ifallfalse >= %{texlive_version}
#!BuildIgnore: texlive-ifallfalse
Requires:       texlive-iffont >= %{texlive_version}
#!BuildIgnore: texlive-iffont
Requires:       texlive-ifmslide >= %{texlive_version}
#!BuildIgnore: texlive-ifmslide
Requires:       texlive-ifmtarg >= %{texlive_version}
#!BuildIgnore: texlive-ifmtarg
Requires:       texlive-ifnextok >= %{texlive_version}
#!BuildIgnore: texlive-ifnextok
Requires:       texlive-ifoddpage >= %{texlive_version}
#!BuildIgnore: texlive-ifoddpage
Requires:       texlive-ifthenx >= %{texlive_version}
#!BuildIgnore: texlive-ifthenx
Requires:       texlive-iitem >= %{texlive_version}
#!BuildIgnore: texlive-iitem
Requires:       texlive-image-gallery >= %{texlive_version}
#!BuildIgnore: texlive-image-gallery
Requires:       texlive-imakeidx >= %{texlive_version}
#!BuildIgnore: texlive-imakeidx
Requires:       texlive-import >= %{texlive_version}
#!BuildIgnore: texlive-import
Requires:       texlive-incgraph >= %{texlive_version}
#!BuildIgnore: texlive-incgraph
Requires:       texlive-indextools >= %{texlive_version}
#!BuildIgnore: texlive-indextools
Requires:       texlive-inline-images >= %{texlive_version}
#!BuildIgnore: texlive-inline-images
Requires:       texlive-inlinedef >= %{texlive_version}
#!BuildIgnore: texlive-inlinedef
Requires:       texlive-inlinelabel >= %{texlive_version}
#!BuildIgnore: texlive-inlinelabel
Requires:       texlive-inputenx >= %{texlive_version}
#!BuildIgnore: texlive-inputenx
Requires:       texlive-inputtrc >= %{texlive_version}
#!BuildIgnore: texlive-inputtrc
Requires:       texlive-interactiveworkbook >= %{texlive_version}
#!BuildIgnore: texlive-interactiveworkbook
Requires:       texlive-interfaces >= %{texlive_version}
#!BuildIgnore: texlive-interfaces
Requires:       texlive-intopdf >= %{texlive_version}
#!BuildIgnore: texlive-intopdf
Requires:       texlive-inversepath >= %{texlive_version}
#!BuildIgnore: texlive-inversepath
Requires:       texlive-invoice >= %{texlive_version}
#!BuildIgnore: texlive-invoice
Requires:       texlive-invoice-class >= %{texlive_version}
#!BuildIgnore: texlive-invoice-class
Requires:       texlive-invoice2 >= %{texlive_version}
#!BuildIgnore: texlive-invoice2
Requires:       texlive-iso >= %{texlive_version}
#!BuildIgnore: texlive-iso
Requires:       texlive-iso10303 >= %{texlive_version}
#!BuildIgnore: texlive-iso10303
Requires:       texlive-isodate >= %{texlive_version}
#!BuildIgnore: texlive-isodate
Requires:       texlive-isodoc >= %{texlive_version}
#!BuildIgnore: texlive-isodoc
Requires:       texlive-isonums >= %{texlive_version}
#!BuildIgnore: texlive-isonums
Requires:       texlive-isopt >= %{texlive_version}
#!BuildIgnore: texlive-isopt
Requires:       texlive-isorot >= %{texlive_version}
#!BuildIgnore: texlive-isorot
Requires:       texlive-isotope >= %{texlive_version}
#!BuildIgnore: texlive-isotope
Requires:       texlive-issuulinks >= %{texlive_version}
#!BuildIgnore: texlive-issuulinks
Requires:       texlive-iwhdp >= %{texlive_version}
#!BuildIgnore: texlive-iwhdp
Requires:       texlive-jlabels >= %{texlive_version}
#!BuildIgnore: texlive-jlabels
Requires:       texlive-jmsdelim >= %{texlive_version}
#!BuildIgnore: texlive-jmsdelim
Requires:       texlive-jobname-suffix >= %{texlive_version}
#!BuildIgnore: texlive-jobname-suffix
Requires:       texlive-jslectureplanner >= %{texlive_version}
#!BuildIgnore: texlive-jslectureplanner
Requires:       texlive-jumplines >= %{texlive_version}
#!BuildIgnore: texlive-jumplines
Requires:       texlive-jvlisting >= %{texlive_version}
#!BuildIgnore: texlive-jvlisting
Requires:       texlive-kalendarium >= %{texlive_version}
#!BuildIgnore: texlive-kalendarium
Requires:       texlive-kantlipsum >= %{texlive_version}
#!BuildIgnore: texlive-kantlipsum
Requires:       texlive-kerntest >= %{texlive_version}
#!BuildIgnore: texlive-kerntest
Requires:       texlive-keycommand >= %{texlive_version}
#!BuildIgnore: texlive-keycommand
Requires:       texlive-keyfloat >= %{texlive_version}
#!BuildIgnore: texlive-keyfloat
Requires:       texlive-keyindex >= %{texlive_version}
#!BuildIgnore: texlive-keyindex
Requires:       texlive-keyparse >= %{texlive_version}
#!BuildIgnore: texlive-keyparse
Requires:       texlive-keyreader >= %{texlive_version}
#!BuildIgnore: texlive-keyreader
Requires:       texlive-keystroke >= %{texlive_version}
#!BuildIgnore: texlive-keystroke
Requires:       texlive-keyval2e >= %{texlive_version}
#!BuildIgnore: texlive-keyval2e
Requires:       texlive-keyvaltable >= %{texlive_version}
#!BuildIgnore: texlive-keyvaltable
Requires:       texlive-kix >= %{texlive_version}
#!BuildIgnore: texlive-kix
Requires:       texlive-knowledge >= %{texlive_version}
#!BuildIgnore: texlive-knowledge
Requires:       texlive-koma-moderncvclassic >= %{texlive_version}
#!BuildIgnore: texlive-koma-moderncvclassic
Requires:       texlive-koma-script-sfs >= %{texlive_version}
#!BuildIgnore: texlive-koma-script-sfs
Requires:       texlive-komacv >= %{texlive_version}
#!BuildIgnore: texlive-komacv
Requires:       texlive-komacv-rg >= %{texlive_version}
#!BuildIgnore: texlive-komacv-rg
Requires:       texlive-ktv-texdata >= %{texlive_version}
#!BuildIgnore: texlive-ktv-texdata
Requires:       texlive-l3build >= %{texlive_version}
#!BuildIgnore: texlive-l3build
Requires:       texlive-labbook >= %{texlive_version}
#!BuildIgnore: texlive-labbook
Requires:       texlive-labels >= %{texlive_version}
#!BuildIgnore: texlive-labels
Requires:       texlive-labels4easylist >= %{texlive_version}
#!BuildIgnore: texlive-labels4easylist
Requires:       texlive-labelschanged >= %{texlive_version}
#!BuildIgnore: texlive-labelschanged
Requires:       texlive-lambdax >= %{texlive_version}
#!BuildIgnore: texlive-lambdax
Requires:       texlive-lastpackage >= %{texlive_version}
#!BuildIgnore: texlive-lastpackage
Requires:       texlive-lastpage >= %{texlive_version}
#!BuildIgnore: texlive-lastpage
Requires:       texlive-latex-amsmath-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-amsmath-dev
Requires:       texlive-latex-base-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-base-dev
Requires:       texlive-latex-bin-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-bin-dev
Requires:       texlive-latex-firstaid-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-firstaid-dev
Requires:       texlive-latex-graphics-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-graphics-dev
Requires:       texlive-latex-lab-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-lab-dev
Requires:       texlive-latex-tools-dev >= %{texlive_version}
#!BuildIgnore: texlive-latex-tools-dev
Requires:       texlive-latex-uni8 >= %{texlive_version}
#!BuildIgnore: texlive-latex-uni8
Requires:       texlive-latexcolors >= %{texlive_version}
#!BuildIgnore: texlive-latexcolors
Requires:       texlive-latexdemo >= %{texlive_version}
#!BuildIgnore: texlive-latexdemo
Requires:       texlive-latexgit >= %{texlive_version}
#!BuildIgnore: texlive-latexgit
Requires:       texlive-layouts >= %{texlive_version}
#!BuildIgnore: texlive-layouts
Requires:       texlive-lazylist >= %{texlive_version}
#!BuildIgnore: texlive-lazylist
Requires:       texlive-lccaps >= %{texlive_version}
#!BuildIgnore: texlive-lccaps
Requires:       texlive-lcd >= %{texlive_version}
#!BuildIgnore: texlive-lcd
Requires:       texlive-lcg >= %{texlive_version}
#!BuildIgnore: texlive-lcg
Requires:       texlive-leading >= %{texlive_version}
#!BuildIgnore: texlive-leading
Requires:       texlive-leaflet >= %{texlive_version}
#!BuildIgnore: texlive-leaflet
Requires:       texlive-lebhart >= %{texlive_version}
#!BuildIgnore: texlive-lebhart
Requires:       texlive-lectures >= %{texlive_version}
#!BuildIgnore: texlive-lectures
Requires:       texlive-lectureslides >= %{texlive_version}
#!BuildIgnore: texlive-lectureslides
Requires:       texlive-leftidx >= %{texlive_version}
#!BuildIgnore: texlive-leftidx
Requires:       texlive-leftindex >= %{texlive_version}
#!BuildIgnore: texlive-leftindex
Requires:       texlive-leipzig >= %{texlive_version}
#!BuildIgnore: texlive-leipzig
Requires:       texlive-lengthconvert >= %{texlive_version}
#!BuildIgnore: texlive-lengthconvert
Requires:       texlive-lettre >= %{texlive_version}
#!BuildIgnore: texlive-lettre
Requires:       texlive-lettrine >= %{texlive_version}
#!BuildIgnore: texlive-lettrine
Requires:       texlive-lewis >= %{texlive_version}
#!BuildIgnore: texlive-lewis
Requires:       texlive-lhelp >= %{texlive_version}
#!BuildIgnore: texlive-lhelp
Requires:       texlive-libgreek >= %{texlive_version}
#!BuildIgnore: texlive-libgreek
Requires:       texlive-limap >= %{texlive_version}
#!BuildIgnore: texlive-limap
Requires:       texlive-linegoal >= %{texlive_version}
#!BuildIgnore: texlive-linegoal
Requires:       texlive-linop >= %{texlive_version}
#!BuildIgnore: texlive-linop
Requires:       texlive-lipsum >= %{texlive_version}
#!BuildIgnore: texlive-lipsum
Requires:       texlive-lisp-on-tex >= %{texlive_version}
#!BuildIgnore: texlive-lisp-on-tex
Requires:       texlive-listing >= %{texlive_version}
#!BuildIgnore: texlive-listing
Requires:       texlive-listingsutf8 >= %{texlive_version}
#!BuildIgnore: texlive-listingsutf8
Requires:       texlive-listlbls >= %{texlive_version}
#!BuildIgnore: texlive-listlbls
Requires:       texlive-listliketab >= %{texlive_version}
#!BuildIgnore: texlive-listliketab
Requires:       texlive-listofsymbols >= %{texlive_version}
#!BuildIgnore: texlive-listofsymbols
Requires:       texlive-lkproof >= %{texlive_version}
#!BuildIgnore: texlive-lkproof
Requires:       texlive-lmake >= %{texlive_version}
#!BuildIgnore: texlive-lmake
Requires:       texlive-locality >= %{texlive_version}
#!BuildIgnore: texlive-locality
Requires:       texlive-logbox >= %{texlive_version}
#!BuildIgnore: texlive-logbox
Requires:       texlive-logical-markup-utils >= %{texlive_version}
#!BuildIgnore: texlive-logical-markup-utils
Requires:       texlive-logpap >= %{texlive_version}
#!BuildIgnore: texlive-logpap
Requires:       texlive-longfbox >= %{texlive_version}
#!BuildIgnore: texlive-longfbox
Requires:       texlive-longfigure >= %{texlive_version}
#!BuildIgnore: texlive-longfigure
Requires:       texlive-longnamefilelist >= %{texlive_version}
#!BuildIgnore: texlive-longnamefilelist
Requires:       texlive-loops >= %{texlive_version}
#!BuildIgnore: texlive-loops
Requires:       texlive-lsc >= %{texlive_version}
#!BuildIgnore: texlive-lsc
Requires:       texlive-lstaddons >= %{texlive_version}
#!BuildIgnore: texlive-lstaddons
Requires:       texlive-lstfiracode >= %{texlive_version}
#!BuildIgnore: texlive-lstfiracode
Requires:       texlive-lt3graph >= %{texlive_version}
#!BuildIgnore: texlive-lt3graph
Requires:       texlive-lt3rawobjects >= %{texlive_version}
#!BuildIgnore: texlive-lt3rawobjects
Requires:       texlive-ltablex >= %{texlive_version}
#!BuildIgnore: texlive-ltablex
Requires:       texlive-ltabptch >= %{texlive_version}
#!BuildIgnore: texlive-ltabptch
Requires:       texlive-ltxdockit >= %{texlive_version}
#!BuildIgnore: texlive-ltxdockit
Requires:       texlive-ltxguidex >= %{texlive_version}
#!BuildIgnore: texlive-ltxguidex
Requires:       texlive-ltxkeys >= %{texlive_version}
#!BuildIgnore: texlive-ltxkeys
Requires:       texlive-ltxnew >= %{texlive_version}
#!BuildIgnore: texlive-ltxnew
Requires:       texlive-ltxtools >= %{texlive_version}
#!BuildIgnore: texlive-ltxtools
Requires:       texlive-lua-check-hyphen >= %{texlive_version}
#!BuildIgnore: texlive-lua-check-hyphen
Requires:       texlive-lua-physical >= %{texlive_version}
#!BuildIgnore: texlive-lua-physical
Requires:       texlive-luatodonotes >= %{texlive_version}
#!BuildIgnore: texlive-luatodonotes
Requires:       texlive-macrolist >= %{texlive_version}
#!BuildIgnore: texlive-macrolist
Requires:       texlive-macroswap >= %{texlive_version}
#!BuildIgnore: texlive-macroswap
Requires:       texlive-magaz >= %{texlive_version}
#!BuildIgnore: texlive-magaz
Requires:       texlive-magicnum >= %{texlive_version}
#!BuildIgnore: texlive-magicnum
Requires:       texlive-magicwatermark >= %{texlive_version}
#!BuildIgnore: texlive-magicwatermark
Requires:       texlive-mailing >= %{texlive_version}
#!BuildIgnore: texlive-mailing
Requires:       texlive-mailmerge >= %{texlive_version}
#!BuildIgnore: texlive-mailmerge
Requires:       texlive-makebarcode >= %{texlive_version}
#!BuildIgnore: texlive-makebarcode
Requires:       texlive-makebase >= %{texlive_version}
#!BuildIgnore: texlive-makebase
Requires:       texlive-makebox >= %{texlive_version}
#!BuildIgnore: texlive-makebox
Requires:       texlive-makecell >= %{texlive_version}
#!BuildIgnore: texlive-makecell
Requires:       texlive-makecirc >= %{texlive_version}
#!BuildIgnore: texlive-makecirc
Requires:       texlive-makecmds >= %{texlive_version}
#!BuildIgnore: texlive-makecmds
Requires:       texlive-makecookbook >= %{texlive_version}
#!BuildIgnore: texlive-makecookbook
Requires:       texlive-makedtx >= %{texlive_version}
#!BuildIgnore: texlive-makedtx
Requires:       texlive-makeglos >= %{texlive_version}
#!BuildIgnore: texlive-makeglos
Requires:       texlive-makelabels >= %{texlive_version}
#!BuildIgnore: texlive-makelabels
Requires:       texlive-makerobust >= %{texlive_version}
#!BuildIgnore: texlive-makerobust
Requires:       texlive-mandi >= %{texlive_version}
#!BuildIgnore: texlive-mandi
Requires:       texlive-manfnt >= %{texlive_version}
#!BuildIgnore: texlive-manfnt
Requires:       texlive-manuscript >= %{texlive_version}
#!BuildIgnore: texlive-manuscript
Requires:       texlive-manyind >= %{texlive_version}
#!BuildIgnore: texlive-manyind
Requires:       texlive-marginfit >= %{texlive_version}
#!BuildIgnore: texlive-marginfit
Requires:       texlive-marginfix >= %{texlive_version}
#!BuildIgnore: texlive-marginfix
Requires:       texlive-marginnote >= %{texlive_version}
#!BuildIgnore: texlive-marginnote
Requires:       texlive-markdown >= %{texlive_version}
#!BuildIgnore: texlive-markdown
Requires:       texlive-mathalpha >= %{texlive_version}
#!BuildIgnore: texlive-mathalpha
Requires:       texlive-mathastext >= %{texlive_version}
#!BuildIgnore: texlive-mathastext
Requires:       texlive-mathexam >= %{texlive_version}
#!BuildIgnore: texlive-mathexam
Requires:       texlive-mathfam256 >= %{texlive_version}
#!BuildIgnore: texlive-mathfam256
Requires:       texlive-mathfont >= %{texlive_version}
#!BuildIgnore: texlive-mathfont
Requires:       texlive-maybemath >= %{texlive_version}
#!BuildIgnore: texlive-maybemath
Requires:       texlive-mcaption >= %{texlive_version}
#!BuildIgnore: texlive-mcaption
Requires:       texlive-mceinleger >= %{texlive_version}
#!BuildIgnore: texlive-mceinleger
Requires:       texlive-mcexam >= %{texlive_version}
#!BuildIgnore: texlive-mcexam
Requires:       texlive-mcite >= %{texlive_version}
#!BuildIgnore: texlive-mcite
Requires:       texlive-mciteplus >= %{texlive_version}
#!BuildIgnore: texlive-mciteplus
Requires:       texlive-mdframed >= %{texlive_version}
#!BuildIgnore: texlive-mdframed
Requires:       texlive-media4svg >= %{texlive_version}
#!BuildIgnore: texlive-media4svg
Requires:       texlive-media9 >= %{texlive_version}
#!BuildIgnore: texlive-media9
Requires:       texlive-medstarbeamer >= %{texlive_version}
#!BuildIgnore: texlive-medstarbeamer
Requires:       texlive-meetingmins >= %{texlive_version}
#!BuildIgnore: texlive-meetingmins
Requires:       texlive-memexsupp >= %{texlive_version}
#!BuildIgnore: texlive-memexsupp
Requires:       texlive-memory >= %{texlive_version}
#!BuildIgnore: texlive-memory
Requires:       texlive-mensa-tex >= %{texlive_version}
#!BuildIgnore: texlive-mensa-tex
Requires:       texlive-menu >= %{texlive_version}
#!BuildIgnore: texlive-menu
Requires:       texlive-menucard >= %{texlive_version}
#!BuildIgnore: texlive-menucard
Requires:       texlive-menukeys >= %{texlive_version}
#!BuildIgnore: texlive-menukeys
Requires:       texlive-metalogox >= %{texlive_version}
#!BuildIgnore: texlive-metalogox
Requires:       texlive-metanorma >= %{texlive_version}
#!BuildIgnore: texlive-metanorma
Requires:       texlive-metastr >= %{texlive_version}
#!BuildIgnore: texlive-metastr
Requires:       texlive-method >= %{texlive_version}
#!BuildIgnore: texlive-method
Requires:       texlive-metre >= %{texlive_version}
#!BuildIgnore: texlive-metre
Requires:       texlive-mfirstuc >= %{texlive_version}
#!BuildIgnore: texlive-mfirstuc
Requires:       texlive-mftinc >= %{texlive_version}
#!BuildIgnore: texlive-mftinc
Requires:       texlive-mi-solns >= %{texlive_version}
#!BuildIgnore: texlive-mi-solns
Requires:       texlive-midpage >= %{texlive_version}
#!BuildIgnore: texlive-midpage
Requires:       texlive-mindflow >= %{texlive_version}
#!BuildIgnore: texlive-mindflow
Requires:       texlive-minibox >= %{texlive_version}
#!BuildIgnore: texlive-minibox
Requires:       texlive-minidocument >= %{texlive_version}
#!BuildIgnore: texlive-minidocument
Requires:       texlive-minifp >= %{texlive_version}
#!BuildIgnore: texlive-minifp
Requires:       texlive-minimalist >= %{texlive_version}
#!BuildIgnore: texlive-minimalist
Requires:       texlive-minipage-marginpar >= %{texlive_version}
#!BuildIgnore: texlive-minipage-marginpar
Requires:       texlive-minitoc >= %{texlive_version}
#!BuildIgnore: texlive-minitoc
Requires:       texlive-minorrevision >= %{texlive_version}
#!BuildIgnore: texlive-minorrevision
Requires:       texlive-minted >= %{texlive_version}
#!BuildIgnore: texlive-minted
Requires:       texlive-minutes >= %{texlive_version}
#!BuildIgnore: texlive-minutes
Requires:       texlive-mla-paper >= %{texlive_version}
#!BuildIgnore: texlive-mla-paper
Requires:       texlive-mleftright >= %{texlive_version}
#!BuildIgnore: texlive-mleftright
Requires:       texlive-mlist >= %{texlive_version}
#!BuildIgnore: texlive-mlist
Requires:       texlive-mmap >= %{texlive_version}
#!BuildIgnore: texlive-mmap
Requires:       texlive-mnotes >= %{texlive_version}
#!BuildIgnore: texlive-mnotes
Requires:       texlive-moderncv >= %{texlive_version}
#!BuildIgnore: texlive-moderncv
Requires:       texlive-modernposter >= %{texlive_version}
#!BuildIgnore: texlive-modernposter
Requires:       texlive-moderntimeline >= %{texlive_version}
#!BuildIgnore: texlive-moderntimeline
Requires:       texlive-modref >= %{texlive_version}
#!BuildIgnore: texlive-modref
Requires:       texlive-modroman >= %{texlive_version}
#!BuildIgnore: texlive-modroman
Requires:       texlive-modular >= %{texlive_version}
#!BuildIgnore: texlive-modular
Requires:       texlive-monofill >= %{texlive_version}
#!BuildIgnore: texlive-monofill
Requires:       texlive-moodle >= %{texlive_version}
#!BuildIgnore: texlive-moodle
Requires:       texlive-moreenum >= %{texlive_version}
#!BuildIgnore: texlive-moreenum
Requires:       texlive-morefloats >= %{texlive_version}
#!BuildIgnore: texlive-morefloats
Requires:       texlive-morehype >= %{texlive_version}
#!BuildIgnore: texlive-morehype
Requires:       texlive-moresize >= %{texlive_version}
#!BuildIgnore: texlive-moresize
Requires:       texlive-moreverb >= %{texlive_version}
#!BuildIgnore: texlive-moreverb
Requires:       texlive-morewrites >= %{texlive_version}
#!BuildIgnore: texlive-morewrites
Requires:       texlive-movie15 >= %{texlive_version}
#!BuildIgnore: texlive-movie15
Requires:       texlive-mparhack >= %{texlive_version}
#!BuildIgnore: texlive-mparhack
Requires:       texlive-mpostinl >= %{texlive_version}
#!BuildIgnore: texlive-mpostinl
Requires:       texlive-msc >= %{texlive_version}
#!BuildIgnore: texlive-msc
Requires:       texlive-msg >= %{texlive_version}
#!BuildIgnore: texlive-msg
Requires:       texlive-mslapa >= %{texlive_version}
#!BuildIgnore: texlive-mslapa
Requires:       texlive-mtgreek >= %{texlive_version}
#!BuildIgnore: texlive-mtgreek
Requires:       texlive-multenum >= %{texlive_version}
#!BuildIgnore: texlive-multenum
Requires:       texlive-multiaudience >= %{texlive_version}
#!BuildIgnore: texlive-multiaudience
Requires:       texlive-multibbl >= %{texlive_version}
#!BuildIgnore: texlive-multibbl
Requires:       texlive-multicap >= %{texlive_version}
#!BuildIgnore: texlive-multicap
Requires:       texlive-multicolrule >= %{texlive_version}
#!BuildIgnore: texlive-multicolrule
Requires:       texlive-multidef >= %{texlive_version}
#!BuildIgnore: texlive-multidef
Requires:       texlive-multienv >= %{texlive_version}
#!BuildIgnore: texlive-multienv
Requires:       texlive-multiexpand >= %{texlive_version}
#!BuildIgnore: texlive-multiexpand
Requires:       texlive-multifootnote >= %{texlive_version}
#!BuildIgnore: texlive-multifootnote
Requires:       texlive-multilang >= %{texlive_version}
#!BuildIgnore: texlive-multilang
Requires:       texlive-multiple-choice >= %{texlive_version}
#!BuildIgnore: texlive-multiple-choice
Requires:       texlive-multirow >= %{texlive_version}
#!BuildIgnore: texlive-multirow
Requires:       texlive-mversion >= %{texlive_version}
#!BuildIgnore: texlive-mversion
Requires:       texlive-mwe >= %{texlive_version}
#!BuildIgnore: texlive-mwe
Requires:       texlive-mycv >= %{texlive_version}
#!BuildIgnore: texlive-mycv
Requires:       texlive-mylatex >= %{texlive_version}
#!BuildIgnore: texlive-mylatex
Requires:       texlive-mylatexformat >= %{texlive_version}
#!BuildIgnore: texlive-mylatexformat
Requires:       texlive-nag >= %{texlive_version}
#!BuildIgnore: texlive-nag
Requires:       texlive-nameauth >= %{texlive_version}
#!BuildIgnore: texlive-nameauth
Requires:       texlive-namespc >= %{texlive_version}
#!BuildIgnore: texlive-namespc
Requires:       texlive-ncclatex >= %{texlive_version}
#!BuildIgnore: texlive-ncclatex
Requires:       texlive-ncctools >= %{texlive_version}
#!BuildIgnore: texlive-ncctools
Requires:       texlive-needspace >= %{texlive_version}
#!BuildIgnore: texlive-needspace
Requires:       texlive-nestquot >= %{texlive_version}
#!BuildIgnore: texlive-nestquot
Requires:       texlive-newcommand >= %{texlive_version}
#!BuildIgnore: texlive-newcommand
Requires:       texlive-newenviron >= %{texlive_version}
#!BuildIgnore: texlive-newenviron
Requires:       texlive-newfile >= %{texlive_version}
#!BuildIgnore: texlive-newfile
Requires:       texlive-newlfm >= %{texlive_version}
#!BuildIgnore: texlive-newlfm
Requires:       texlive-newspaper >= %{texlive_version}
#!BuildIgnore: texlive-newspaper
Requires:       texlive-newunicodechar >= %{texlive_version}
#!BuildIgnore: texlive-newunicodechar
Requires:       texlive-newvbtm >= %{texlive_version}
#!BuildIgnore: texlive-newvbtm
Requires:       texlive-newverbs >= %{texlive_version}
#!BuildIgnore: texlive-newverbs
Requires:       texlive-nextpage >= %{texlive_version}
#!BuildIgnore: texlive-nextpage
Requires:       texlive-nfssext-cfr >= %{texlive_version}
#!BuildIgnore: texlive-nfssext-cfr
Requires:       texlive-nicefilelist >= %{texlive_version}
#!BuildIgnore: texlive-nicefilelist
Requires:       texlive-niceframe >= %{texlive_version}
#!BuildIgnore: texlive-niceframe
Requires:       texlive-nicetext >= %{texlive_version}
#!BuildIgnore: texlive-nicetext
Requires:       texlive-nidanfloat >= %{texlive_version}
#!BuildIgnore: texlive-nidanfloat
Requires:       texlive-ninecolors >= %{texlive_version}
#!BuildIgnore: texlive-ninecolors
Requires:       texlive-nlctdoc >= %{texlive_version}
#!BuildIgnore: texlive-nlctdoc
Requires:       texlive-noconflict >= %{texlive_version}
#!BuildIgnore: texlive-noconflict
Requires:       texlive-noindentafter >= %{texlive_version}
#!BuildIgnore: texlive-noindentafter
Requires:       texlive-noitcrul >= %{texlive_version}
#!BuildIgnore: texlive-noitcrul
Requires:       texlive-nolbreaks >= %{texlive_version}
#!BuildIgnore: texlive-nolbreaks
Requires:       texlive-nomencl >= %{texlive_version}
#!BuildIgnore: texlive-nomencl
Requires:       texlive-nomentbl >= %{texlive_version}
#!BuildIgnore: texlive-nomentbl
Requires:       texlive-nonfloat >= %{texlive_version}
#!BuildIgnore: texlive-nonfloat
Requires:       texlive-nonumonpart >= %{texlive_version}
#!BuildIgnore: texlive-nonumonpart
Requires:       texlive-nopageno >= %{texlive_version}
#!BuildIgnore: texlive-nopageno
Requires:       texlive-normalcolor >= %{texlive_version}
#!BuildIgnore: texlive-normalcolor
Requires:       texlive-notes >= %{texlive_version}
#!BuildIgnore: texlive-notes
Requires:       texlive-notespages >= %{texlive_version}
#!BuildIgnore: texlive-notespages
Requires:       texlive-notestex >= %{texlive_version}
#!BuildIgnore: texlive-notestex
Requires:       texlive-notoccite >= %{texlive_version}
#!BuildIgnore: texlive-notoccite
Requires:       texlive-nowidow >= %{texlive_version}
#!BuildIgnore: texlive-nowidow
Requires:       texlive-nox >= %{texlive_version}
#!BuildIgnore: texlive-nox
Requires:       texlive-ntheorem >= %{texlive_version}
#!BuildIgnore: texlive-ntheorem
Requires:       texlive-numberedblock >= %{texlive_version}
#!BuildIgnore: texlive-numberedblock
Requires:       texlive-numname >= %{texlive_version}
#!BuildIgnore: texlive-numname
Requires:       texlive-numprint >= %{texlive_version}
#!BuildIgnore: texlive-numprint
Requires:       texlive-numspell >= %{texlive_version}
#!BuildIgnore: texlive-numspell
Requires:       texlive-ocg-p >= %{texlive_version}
#!BuildIgnore: texlive-ocg-p
Requires:       texlive-ocgx >= %{texlive_version}
#!BuildIgnore: texlive-ocgx
Requires:       texlive-ocgx2 >= %{texlive_version}
#!BuildIgnore: texlive-ocgx2
Requires:       texlive-ocr-latex >= %{texlive_version}
#!BuildIgnore: texlive-ocr-latex
Requires:       texlive-octavo >= %{texlive_version}
#!BuildIgnore: texlive-octavo
Requires:       texlive-oldstyle >= %{texlive_version}
#!BuildIgnore: texlive-oldstyle
Requires:       texlive-onlyamsmath >= %{texlive_version}
#!BuildIgnore: texlive-onlyamsmath
Requires:       texlive-opcit >= %{texlive_version}
#!BuildIgnore: texlive-opcit
Requires:       texlive-opencolor >= %{texlive_version}
#!BuildIgnore: texlive-opencolor
Requires:       texlive-optidef >= %{texlive_version}
#!BuildIgnore: texlive-optidef
Requires:       texlive-optional >= %{texlive_version}
#!BuildIgnore: texlive-optional
Requires:       texlive-options >= %{texlive_version}
#!BuildIgnore: texlive-options
Requires:       texlive-orcidlink >= %{texlive_version}
#!BuildIgnore: texlive-orcidlink
Requires:       texlive-orientation >= %{texlive_version}
#!BuildIgnore: texlive-orientation
Requires:       texlive-outline >= %{texlive_version}
#!BuildIgnore: texlive-outline
Requires:       texlive-outliner >= %{texlive_version}
#!BuildIgnore: texlive-outliner
Requires:       texlive-outlines >= %{texlive_version}
#!BuildIgnore: texlive-outlines
Requires:       texlive-outlining >= %{texlive_version}
#!BuildIgnore: texlive-outlining
Requires:       texlive-overlays >= %{texlive_version}
#!BuildIgnore: texlive-overlays
Requires:       texlive-overpic >= %{texlive_version}
#!BuildIgnore: texlive-overpic
Requires:       texlive-padcount >= %{texlive_version}
#!BuildIgnore: texlive-padcount
Requires:       texlive-pagecolor >= %{texlive_version}
#!BuildIgnore: texlive-pagecolor
Requires:       texlive-pagecont >= %{texlive_version}
#!BuildIgnore: texlive-pagecont
Requires:       texlive-pagegrid >= %{texlive_version}
#!BuildIgnore: texlive-pagegrid
Requires:       texlive-pagelayout >= %{texlive_version}
#!BuildIgnore: texlive-pagelayout
Requires:       texlive-pagenote >= %{texlive_version}
#!BuildIgnore: texlive-pagenote
Requires:       texlive-pagerange >= %{texlive_version}
#!BuildIgnore: texlive-pagerange
Requires:       texlive-pageslts >= %{texlive_version}
#!BuildIgnore: texlive-pageslts
Requires:       texlive-palette >= %{texlive_version}
#!BuildIgnore: texlive-palette
Requires:       texlive-pangram >= %{texlive_version}
#!BuildIgnore: texlive-pangram
Requires:       texlive-paper >= %{texlive_version}
#!BuildIgnore: texlive-paper
Requires:       texlive-papercdcase >= %{texlive_version}
#!BuildIgnore: texlive-papercdcase
Requires:       texlive-papermas >= %{texlive_version}
#!BuildIgnore: texlive-papermas
Requires:       texlive-papertex >= %{texlive_version}
#!BuildIgnore: texlive-papertex
Requires:       texlive-paracol >= %{texlive_version}
#!BuildIgnore: texlive-paracol
Requires:       texlive-parades >= %{texlive_version}
#!BuildIgnore: texlive-parades
Requires:       texlive-paralist >= %{texlive_version}
#!BuildIgnore: texlive-paralist
Requires:       texlive-paresse >= %{texlive_version}
#!BuildIgnore: texlive-paresse
Requires:       texlive-parnotes >= %{texlive_version}
#!BuildIgnore: texlive-parnotes
Requires:       texlive-parsa >= %{texlive_version}
#!BuildIgnore: texlive-parsa
Requires:       texlive-parselines >= %{texlive_version}
#!BuildIgnore: texlive-parselines
Requires:       texlive-pas-cours >= %{texlive_version}
#!BuildIgnore: texlive-pas-cours
Requires:       texlive-pas-cv >= %{texlive_version}
#!BuildIgnore: texlive-pas-cv
Requires:       texlive-pas-tableur >= %{texlive_version}
#!BuildIgnore: texlive-pas-tableur
Requires:       texlive-patch >= %{texlive_version}
#!BuildIgnore: texlive-patch
Requires:       texlive-patchcmd >= %{texlive_version}
#!BuildIgnore: texlive-patchcmd
Requires:       texlive-pauldoc >= %{texlive_version}
#!BuildIgnore: texlive-pauldoc
Requires:       texlive-pawpict >= %{texlive_version}
#!BuildIgnore: texlive-pawpict
Requires:       texlive-pax >= %{texlive_version}
#!BuildIgnore: texlive-pax
Requires:       texlive-pbalance >= %{texlive_version}
#!BuildIgnore: texlive-pbalance
Requires:       texlive-pbox >= %{texlive_version}
#!BuildIgnore: texlive-pbox
Requires:       texlive-pbsheet >= %{texlive_version}
#!BuildIgnore: texlive-pbsheet
Requires:       texlive-pdf14 >= %{texlive_version}
#!BuildIgnore: texlive-pdf14
Requires:       texlive-pdfcol >= %{texlive_version}
#!BuildIgnore: texlive-pdfcol
Requires:       texlive-pdfcolmk >= %{texlive_version}
#!BuildIgnore: texlive-pdfcolmk
Requires:       texlive-pdfcomment >= %{texlive_version}
#!BuildIgnore: texlive-pdfcomment
Requires:       texlive-pdfcprot >= %{texlive_version}
#!BuildIgnore: texlive-pdfcprot
Requires:       texlive-pdfmarginpar >= %{texlive_version}
#!BuildIgnore: texlive-pdfmarginpar
Requires:       texlive-pdfoverlay >= %{texlive_version}
#!BuildIgnore: texlive-pdfoverlay
Requires:       texlive-pdfpagediff >= %{texlive_version}
#!BuildIgnore: texlive-pdfpagediff
Requires:       texlive-pdfpc >= %{texlive_version}
#!BuildIgnore: texlive-pdfpc
Requires:       texlive-pdfpc-movie >= %{texlive_version}
#!BuildIgnore: texlive-pdfpc-movie
Requires:       texlive-pdfprivacy >= %{texlive_version}
#!BuildIgnore: texlive-pdfprivacy
Requires:       texlive-pdfreview >= %{texlive_version}
#!BuildIgnore: texlive-pdfreview
Requires:       texlive-pdfscreen >= %{texlive_version}
#!BuildIgnore: texlive-pdfscreen
Requires:       texlive-pdfslide >= %{texlive_version}
#!BuildIgnore: texlive-pdfslide
Requires:       texlive-pdfsync >= %{texlive_version}
#!BuildIgnore: texlive-pdfsync
Requires:       texlive-pdfwin >= %{texlive_version}
#!BuildIgnore: texlive-pdfwin
Requires:       texlive-pdfx >= %{texlive_version}
#!BuildIgnore: texlive-pdfx
Requires:       texlive-pecha >= %{texlive_version}
#!BuildIgnore: texlive-pecha
Requires:       texlive-perltex >= %{texlive_version}
#!BuildIgnore: texlive-perltex
Requires:       texlive-permute >= %{texlive_version}
#!BuildIgnore: texlive-permute
Requires:       texlive-petiteannonce >= %{texlive_version}
#!BuildIgnore: texlive-petiteannonce
Requires:       texlive-pgfmath-xfp >= %{texlive_version}
#!BuildIgnore: texlive-pgfmath-xfp
Requires:       texlive-phfcc >= %{texlive_version}
#!BuildIgnore: texlive-phfcc
Requires:       texlive-phfextendedabstract >= %{texlive_version}
#!BuildIgnore: texlive-phfextendedabstract
Requires:       texlive-phffullpagefigure >= %{texlive_version}
#!BuildIgnore: texlive-phffullpagefigure
Requires:       texlive-phfnote >= %{texlive_version}
#!BuildIgnore: texlive-phfnote
Requires:       texlive-phfparen >= %{texlive_version}
#!BuildIgnore: texlive-phfparen
Requires:       texlive-phfqit >= %{texlive_version}
#!BuildIgnore: texlive-phfqit
Requires:       texlive-phfquotetext >= %{texlive_version}
#!BuildIgnore: texlive-phfquotetext
Requires:       texlive-phfsvnwatermark >= %{texlive_version}
#!BuildIgnore: texlive-phfsvnwatermark
Requires:       texlive-phfthm >= %{texlive_version}
#!BuildIgnore: texlive-phfthm
Requires:       texlive-philex >= %{texlive_version}
#!BuildIgnore: texlive-philex
Requires:       texlive-phonenumbers >= %{texlive_version}
#!BuildIgnore: texlive-phonenumbers
Requires:       texlive-photo >= %{texlive_version}
#!BuildIgnore: texlive-photo
Requires:       texlive-photobook >= %{texlive_version}
#!BuildIgnore: texlive-photobook
Requires:       texlive-picture >= %{texlive_version}
#!BuildIgnore: texlive-picture
Requires:       texlive-piff >= %{texlive_version}
#!BuildIgnore: texlive-piff
Requires:       texlive-pkgloader >= %{texlive_version}
#!BuildIgnore: texlive-pkgloader
Requires:       texlive-placeins >= %{texlive_version}
#!BuildIgnore: texlive-placeins
Requires:       texlive-plantslabels >= %{texlive_version}
#!BuildIgnore: texlive-plantslabels
Requires:       texlive-plates >= %{texlive_version}
#!BuildIgnore: texlive-plates
Requires:       texlive-plweb >= %{texlive_version}
#!BuildIgnore: texlive-plweb
Requires:       texlive-pmboxdraw >= %{texlive_version}
#!BuildIgnore: texlive-pmboxdraw
Requires:       texlive-polynom >= %{texlive_version}
#!BuildIgnore: texlive-polynom
Requires:       texlive-polynomial >= %{texlive_version}
#!BuildIgnore: texlive-polynomial
Requires:       texlive-polytable >= %{texlive_version}
#!BuildIgnore: texlive-polytable
Requires:       texlive-postcards >= %{texlive_version}
#!BuildIgnore: texlive-postcards
Requires:       texlive-poster-mac >= %{texlive_version}
#!BuildIgnore: texlive-poster-mac
Requires:       texlive-postnotes >= %{texlive_version}
#!BuildIgnore: texlive-postnotes
Requires:       texlive-powerdot >= %{texlive_version}
#!BuildIgnore: texlive-powerdot
Requires:       texlive-ppr-prv >= %{texlive_version}
#!BuildIgnore: texlive-ppr-prv
Requires:       texlive-ppt-slides >= %{texlive_version}
#!BuildIgnore: texlive-ppt-slides
Requires:       texlive-practicalreports >= %{texlive_version}
#!BuildIgnore: texlive-practicalreports
Requires:       texlive-precattl >= %{texlive_version}
#!BuildIgnore: texlive-precattl
Requires:       texlive-prelim2e >= %{texlive_version}
#!BuildIgnore: texlive-prelim2e
Requires:       texlive-preprint >= %{texlive_version}
#!BuildIgnore: texlive-preprint
Requires:       texlive-pressrelease >= %{texlive_version}
#!BuildIgnore: texlive-pressrelease
Requires:       texlive-prettyref >= %{texlive_version}
#!BuildIgnore: texlive-prettyref
Requires:       texlive-prettytok >= %{texlive_version}
#!BuildIgnore: texlive-prettytok
Requires:       texlive-preview >= %{texlive_version}
#!BuildIgnore: texlive-preview
Requires:       texlive-printlen >= %{texlive_version}
#!BuildIgnore: texlive-printlen
Requires:       texlive-probsoln >= %{texlive_version}
#!BuildIgnore: texlive-probsoln
Requires:       texlive-program >= %{texlive_version}
#!BuildIgnore: texlive-program
Requires:       texlive-progress >= %{texlive_version}
#!BuildIgnore: texlive-progress
Requires:       texlive-progressbar >= %{texlive_version}
#!BuildIgnore: texlive-progressbar
Requires:       texlive-projlib >= %{texlive_version}
#!BuildIgnore: texlive-projlib
Requires:       texlive-proofread >= %{texlive_version}
#!BuildIgnore: texlive-proofread
Requires:       texlive-properties >= %{texlive_version}
#!BuildIgnore: texlive-properties
Requires:       texlive-prosper >= %{texlive_version}
#!BuildIgnore: texlive-prosper
Requires:       texlive-protex >= %{texlive_version}
#!BuildIgnore: texlive-protex
Requires:       texlive-protocol >= %{texlive_version}
#!BuildIgnore: texlive-protocol
Requires:       texlive-psfragx >= %{texlive_version}
#!BuildIgnore: texlive-psfragx
Requires:       texlive-pstool >= %{texlive_version}
#!BuildIgnore: texlive-pstool
Requires:       texlive-pstring >= %{texlive_version}
#!BuildIgnore: texlive-pstring
Requires:       texlive-pxgreeks >= %{texlive_version}
#!BuildIgnore: texlive-pxgreeks
Requires:       texlive-pygmentex >= %{texlive_version}
#!BuildIgnore: texlive-pygmentex
Requires:       texlive-python >= %{texlive_version}
#!BuildIgnore: texlive-python
Requires:       texlive-pythonimmediate >= %{texlive_version}
#!BuildIgnore: texlive-pythonimmediate
Requires:       texlive-qcm >= %{texlive_version}
#!BuildIgnore: texlive-qcm
Requires:       texlive-qstest >= %{texlive_version}
#!BuildIgnore: texlive-qstest
Requires:       texlive-qsymbols >= %{texlive_version}
#!BuildIgnore: texlive-qsymbols
Requires:       texlive-quicktype >= %{texlive_version}
#!BuildIgnore: texlive-quicktype
Requires:       texlive-quiz2socrative >= %{texlive_version}
#!BuildIgnore: texlive-quiz2socrative
Requires:       texlive-quotchap >= %{texlive_version}
#!BuildIgnore: texlive-quotchap
Requires:       texlive-quoting >= %{texlive_version}
#!BuildIgnore: texlive-quoting
Requires:       texlive-quotmark >= %{texlive_version}
#!BuildIgnore: texlive-quotmark
Requires:       texlive-ran_toks >= %{texlive_version}
#!BuildIgnore: texlive-ran_toks
Requires:       texlive-randtext >= %{texlive_version}
#!BuildIgnore: texlive-randtext
Requires:       texlive-rccol >= %{texlive_version}
#!BuildIgnore: texlive-rccol
Requires:       texlive-rcs-multi >= %{texlive_version}
#!BuildIgnore: texlive-rcs-multi
Requires:       texlive-rcsinfo >= %{texlive_version}
#!BuildIgnore: texlive-rcsinfo
Requires:       texlive-readablecv >= %{texlive_version}
#!BuildIgnore: texlive-readablecv
Requires:       texlive-readarray >= %{texlive_version}
#!BuildIgnore: texlive-readarray
Requires:       texlive-realboxes >= %{texlive_version}
#!BuildIgnore: texlive-realboxes
Requires:       texlive-recipe >= %{texlive_version}
#!BuildIgnore: texlive-recipe
Requires:       texlive-recipebook >= %{texlive_version}
#!BuildIgnore: texlive-recipebook
Requires:       texlive-recipecard >= %{texlive_version}
#!BuildIgnore: texlive-recipecard
Requires:       texlive-rectopma >= %{texlive_version}
#!BuildIgnore: texlive-rectopma
Requires:       texlive-refcheck >= %{texlive_version}
#!BuildIgnore: texlive-refcheck
Requires:       texlive-refenums >= %{texlive_version}
#!BuildIgnore: texlive-refenums
Requires:       texlive-reflectgraphics >= %{texlive_version}
#!BuildIgnore: texlive-reflectgraphics
Requires:       texlive-refman >= %{texlive_version}
#!BuildIgnore: texlive-refman
Requires:       texlive-refstyle >= %{texlive_version}
#!BuildIgnore: texlive-refstyle
Requires:       texlive-regcount >= %{texlive_version}
#!BuildIgnore: texlive-regcount
Requires:       texlive-regexpatch >= %{texlive_version}
#!BuildIgnore: texlive-regexpatch
Requires:       texlive-register >= %{texlive_version}
#!BuildIgnore: texlive-register
Requires:       texlive-regstats >= %{texlive_version}
#!BuildIgnore: texlive-regstats
Requires:       texlive-relenc >= %{texlive_version}
#!BuildIgnore: texlive-relenc
Requires:       texlive-relsize >= %{texlive_version}
#!BuildIgnore: texlive-relsize
Requires:       texlive-repeatindex >= %{texlive_version}
#!BuildIgnore: texlive-repeatindex
Requires:       texlive-repltext >= %{texlive_version}
#!BuildIgnore: texlive-repltext
Requires:       texlive-rescansync >= %{texlive_version}
#!BuildIgnore: texlive-rescansync
Requires:       texlive-resmes >= %{texlive_version}
#!BuildIgnore: texlive-resmes
Requires:       texlive-returntogrid >= %{texlive_version}
#!BuildIgnore: texlive-returntogrid
Requires:       texlive-rgltxdoc >= %{texlive_version}
#!BuildIgnore: texlive-rgltxdoc
Requires:       texlive-rjlparshap >= %{texlive_version}
#!BuildIgnore: texlive-rjlparshap
Requires:       texlive-rlepsf >= %{texlive_version}
#!BuildIgnore: texlive-rlepsf
Requires:       texlive-rmpage >= %{texlive_version}
#!BuildIgnore: texlive-rmpage
Requires:       texlive-robustcommand >= %{texlive_version}
#!BuildIgnore: texlive-robustcommand
Requires:       texlive-robustindex >= %{texlive_version}
#!BuildIgnore: texlive-robustindex
Requires:       texlive-romanbar >= %{texlive_version}
#!BuildIgnore: texlive-romanbar
Requires:       texlive-romanbarpagenumber >= %{texlive_version}
#!BuildIgnore: texlive-romanbarpagenumber
Requires:       texlive-romanneg >= %{texlive_version}
#!BuildIgnore: texlive-romanneg
Requires:       texlive-romannum >= %{texlive_version}
#!BuildIgnore: texlive-romannum
Requires:       texlive-rotfloat >= %{texlive_version}
#!BuildIgnore: texlive-rotfloat
Requires:       texlive-rotpages >= %{texlive_version}
#!BuildIgnore: texlive-rotpages
Requires:       texlive-roundbox >= %{texlive_version}
#!BuildIgnore: texlive-roundbox
Requires:       texlive-rterface >= %{texlive_version}
#!BuildIgnore: texlive-rterface
Requires:       texlive-rtkinenc >= %{texlive_version}
#!BuildIgnore: texlive-rtkinenc
Requires:       texlive-rulerbox >= %{texlive_version}
#!BuildIgnore: texlive-rulerbox
Requires:       texlive-rulercompass >= %{texlive_version}
#!BuildIgnore: texlive-rulercompass
Requires:       texlive-runcode >= %{texlive_version}
#!BuildIgnore: texlive-runcode
Requires:       texlive-rvwrite >= %{texlive_version}
#!BuildIgnore: texlive-rvwrite
Requires:       texlive-sanitize-umlaut >= %{texlive_version}
#!BuildIgnore: texlive-sanitize-umlaut
Requires:       texlive-sauerj >= %{texlive_version}
#!BuildIgnore: texlive-sauerj
Requires:       texlive-saveenv >= %{texlive_version}
#!BuildIgnore: texlive-saveenv
Requires:       texlive-savefnmark >= %{texlive_version}
#!BuildIgnore: texlive-savefnmark
Requires:       texlive-savesym >= %{texlive_version}
#!BuildIgnore: texlive-savesym
Requires:       texlive-savetrees >= %{texlive_version}
#!BuildIgnore: texlive-savetrees
Requires:       texlive-scale >= %{texlive_version}
#!BuildIgnore: texlive-scale
Requires:       texlive-scalebar >= %{texlive_version}
#!BuildIgnore: texlive-scalebar
Requires:       texlive-scalerel >= %{texlive_version}
#!BuildIgnore: texlive-scalerel
Requires:       texlive-scanpages >= %{texlive_version}
#!BuildIgnore: texlive-scanpages
Requires:       texlive-schedule >= %{texlive_version}
#!BuildIgnore: texlive-schedule
Requires:       texlive-schooldocs >= %{texlive_version}
#!BuildIgnore: texlive-schooldocs
Requires:       texlive-scontents >= %{texlive_version}
#!BuildIgnore: texlive-scontents
Requires:       texlive-scrambledenvs >= %{texlive_version}
#!BuildIgnore: texlive-scrambledenvs
Requires:       texlive-scrlayer-fancyhdr >= %{texlive_version}
#!BuildIgnore: texlive-scrlayer-fancyhdr
Requires:       texlive-scrlttr2copy >= %{texlive_version}
#!BuildIgnore: texlive-scrlttr2copy
Requires:       texlive-sdaps >= %{texlive_version}
#!BuildIgnore: texlive-sdaps
Requires:       texlive-sdrt >= %{texlive_version}
#!BuildIgnore: texlive-sdrt
Requires:       texlive-secdot >= %{texlive_version}
#!BuildIgnore: texlive-secdot
Requires:       texlive-secnum >= %{texlive_version}
#!BuildIgnore: texlive-secnum
Requires:       texlive-sectionbox >= %{texlive_version}
#!BuildIgnore: texlive-sectionbox
Requires:       texlive-sectionbreak >= %{texlive_version}
#!BuildIgnore: texlive-sectionbreak
Requires:       texlive-sectsty >= %{texlive_version}
#!BuildIgnore: texlive-sectsty
Requires:       texlive-seealso >= %{texlive_version}
#!BuildIgnore: texlive-seealso
Requires:       texlive-selectp >= %{texlive_version}
#!BuildIgnore: texlive-selectp
Requires:       texlive-selinput >= %{texlive_version}
#!BuildIgnore: texlive-selinput
Requires:       texlive-semantex >= %{texlive_version}
#!BuildIgnore: texlive-semantex
Requires:       texlive-semantic >= %{texlive_version}
#!BuildIgnore: texlive-semantic
Requires:       texlive-semantic-markup >= %{texlive_version}
#!BuildIgnore: texlive-semantic-markup
Requires:       texlive-semesterplanner >= %{texlive_version}
#!BuildIgnore: texlive-semesterplanner
Requires:       texlive-semioneside >= %{texlive_version}
#!BuildIgnore: texlive-semioneside
Requires:       texlive-semproc >= %{texlive_version}
#!BuildIgnore: texlive-semproc
Requires:       texlive-semtex >= %{texlive_version}
#!BuildIgnore: texlive-semtex
Requires:       texlive-sepfootnotes >= %{texlive_version}
#!BuildIgnore: texlive-sepfootnotes
Requires:       texlive-seqsplit >= %{texlive_version}
#!BuildIgnore: texlive-seqsplit
Requires:       texlive-sesstime >= %{texlive_version}
#!BuildIgnore: texlive-sesstime
Requires:       texlive-sf298 >= %{texlive_version}
#!BuildIgnore: texlive-sf298
Requires:       texlive-sffms >= %{texlive_version}
#!BuildIgnore: texlive-sffms
Requires:       texlive-sfmath >= %{texlive_version}
#!BuildIgnore: texlive-sfmath
Requires:       texlive-shadethm >= %{texlive_version}
#!BuildIgnore: texlive-shadethm
Requires:       texlive-shadow >= %{texlive_version}
#!BuildIgnore: texlive-shadow
Requires:       texlive-shadowtext >= %{texlive_version}
#!BuildIgnore: texlive-shadowtext
Requires:       texlive-shapepar >= %{texlive_version}
#!BuildIgnore: texlive-shapepar
Requires:       texlive-shdoc >= %{texlive_version}
#!BuildIgnore: texlive-shdoc
Requires:       texlive-shipunov >= %{texlive_version}
#!BuildIgnore: texlive-shipunov
Requires:       texlive-shorttoc >= %{texlive_version}
#!BuildIgnore: texlive-shorttoc
Requires:       texlive-show2e >= %{texlive_version}
#!BuildIgnore: texlive-show2e
Requires:       texlive-showcharinbox >= %{texlive_version}
#!BuildIgnore: texlive-showcharinbox
Requires:       texlive-showdim >= %{texlive_version}
#!BuildIgnore: texlive-showdim
Requires:       texlive-showexpl >= %{texlive_version}
#!BuildIgnore: texlive-showexpl
Requires:       texlive-showlabels >= %{texlive_version}
#!BuildIgnore: texlive-showlabels
Requires:       texlive-sidecap >= %{texlive_version}
#!BuildIgnore: texlive-sidecap
Requires:       texlive-sidenotes >= %{texlive_version}
#!BuildIgnore: texlive-sidenotes
Requires:       texlive-sidenotesplus >= %{texlive_version}
#!BuildIgnore: texlive-sidenotesplus
Requires:       texlive-silence >= %{texlive_version}
#!BuildIgnore: texlive-silence
Requires:       texlive-sillypage >= %{texlive_version}
#!BuildIgnore: texlive-sillypage
Requires:       texlive-simplecd >= %{texlive_version}
#!BuildIgnore: texlive-simplecd
Requires:       texlive-simplecv >= %{texlive_version}
#!BuildIgnore: texlive-simplecv
Requires:       texlive-simpleinvoice >= %{texlive_version}
#!BuildIgnore: texlive-simpleinvoice
Requires:       texlive-simplivre >= %{texlive_version}
#!BuildIgnore: texlive-simplivre
Requires:       texlive-sitem >= %{texlive_version}
#!BuildIgnore: texlive-sitem
Requires:       texlive-skb >= %{texlive_version}
#!BuildIgnore: texlive-skb
Requires:       texlive-skdoc >= %{texlive_version}
#!BuildIgnore: texlive-skdoc
Requires:       texlive-skeldoc >= %{texlive_version}
#!BuildIgnore: texlive-skeldoc
Requires:       texlive-skeycommand >= %{texlive_version}
#!BuildIgnore: texlive-skeycommand
Requires:       texlive-skeyval >= %{texlive_version}
#!BuildIgnore: texlive-skeyval
Requires:       texlive-skills >= %{texlive_version}
#!BuildIgnore: texlive-skills
Requires:       texlive-skrapport >= %{texlive_version}
#!BuildIgnore: texlive-skrapport
Requires:       texlive-slantsc >= %{texlive_version}
#!BuildIgnore: texlive-slantsc
Requires:       texlive-smalltableof >= %{texlive_version}
#!BuildIgnore: texlive-smalltableof
Requires:       texlive-smart-eqn >= %{texlive_version}
#!BuildIgnore: texlive-smart-eqn
Requires:       texlive-smartref >= %{texlive_version}
#!BuildIgnore: texlive-smartref
Requires:       texlive-smartunits >= %{texlive_version}
#!BuildIgnore: texlive-smartunits
Requires:       texlive-snapshot >= %{texlive_version}
#!BuildIgnore: texlive-snapshot
Requires:       texlive-snaptodo >= %{texlive_version}
#!BuildIgnore: texlive-snaptodo
Requires:       texlive-snotez >= %{texlive_version}
#!BuildIgnore: texlive-snotez
Requires:       texlive-soulpos >= %{texlive_version}
#!BuildIgnore: texlive-soulpos
Requires:       texlive-spacingtricks >= %{texlive_version}
#!BuildIgnore: texlive-spacingtricks
Requires:       texlive-spark-otf >= %{texlive_version}
#!BuildIgnore: texlive-spark-otf
Requires:       texlive-sparklines >= %{texlive_version}
#!BuildIgnore: texlive-sparklines
Requires:       texlive-splitindex >= %{texlive_version}
#!BuildIgnore: texlive-splitindex
Requires:       texlive-spot >= %{texlive_version}
#!BuildIgnore: texlive-spot
Requires:       texlive-spotcolor >= %{texlive_version}
#!BuildIgnore: texlive-spotcolor
Requires:       texlive-spreadtab >= %{texlive_version}
#!BuildIgnore: texlive-spreadtab
Requires:       texlive-spverbatim >= %{texlive_version}
#!BuildIgnore: texlive-spverbatim
Requires:       texlive-srbook-mem >= %{texlive_version}
#!BuildIgnore: texlive-srbook-mem
Requires:       texlive-srcltx >= %{texlive_version}
#!BuildIgnore: texlive-srcltx
Requires:       texlive-sseq >= %{texlive_version}
#!BuildIgnore: texlive-sseq
Requires:       texlive-sslides >= %{texlive_version}
#!BuildIgnore: texlive-sslides
Requires:       texlive-stack >= %{texlive_version}
#!BuildIgnore: texlive-stack
Requires:       texlive-stackengine >= %{texlive_version}
#!BuildIgnore: texlive-stackengine
Requires:       texlive-standalone >= %{texlive_version}
#!BuildIgnore: texlive-standalone
Requires:       texlive-stdclsdv >= %{texlive_version}
#!BuildIgnore: texlive-stdclsdv
Requires:       texlive-stdpage >= %{texlive_version}
#!BuildIgnore: texlive-stdpage
Requires:       texlive-stealcaps >= %{texlive_version}
#!BuildIgnore: texlive-stealcaps
Requires:       texlive-stex >= %{texlive_version}
#!BuildIgnore: texlive-stex
Requires:       texlive-storebox >= %{texlive_version}
#!BuildIgnore: texlive-storebox
Requires:       texlive-storecmd >= %{texlive_version}
#!BuildIgnore: texlive-storecmd
Requires:       texlive-stringstrings >= %{texlive_version}
#!BuildIgnore: texlive-stringstrings
Requires:       texlive-sttools >= %{texlive_version}
#!BuildIgnore: texlive-sttools
Requires:       texlive-stubs >= %{texlive_version}
#!BuildIgnore: texlive-stubs
Requires:       texlive-studenthandouts >= %{texlive_version}
#!BuildIgnore: texlive-studenthandouts
Requires:       texlive-styledcmd >= %{texlive_version}
#!BuildIgnore: texlive-styledcmd
Requires:       texlive-subdepth >= %{texlive_version}
#!BuildIgnore: texlive-subdepth
Requires:       texlive-subdocs >= %{texlive_version}
#!BuildIgnore: texlive-subdocs
Requires:       texlive-subeqn >= %{texlive_version}
#!BuildIgnore: texlive-subeqn
Requires:       texlive-subeqnarray >= %{texlive_version}
#!BuildIgnore: texlive-subeqnarray
Requires:       texlive-subfigmat >= %{texlive_version}
#!BuildIgnore: texlive-subfigmat
Requires:       texlive-subfigure >= %{texlive_version}
#!BuildIgnore: texlive-subfigure
Requires:       texlive-subfiles >= %{texlive_version}
#!BuildIgnore: texlive-subfiles
Requires:       texlive-subfloat >= %{texlive_version}
#!BuildIgnore: texlive-subfloat
Requires:       texlive-substitutefont >= %{texlive_version}
#!BuildIgnore: texlive-substitutefont
Requires:       texlive-substr >= %{texlive_version}
#!BuildIgnore: texlive-substr
Requires:       texlive-supertabular >= %{texlive_version}
#!BuildIgnore: texlive-supertabular
Requires:       texlive-suppose >= %{texlive_version}
#!BuildIgnore: texlive-suppose
Requires:       texlive-svg >= %{texlive_version}
#!BuildIgnore: texlive-svg
Requires:       texlive-svgcolor >= %{texlive_version}
#!BuildIgnore: texlive-svgcolor
Requires:       texlive-svn >= %{texlive_version}
#!BuildIgnore: texlive-svn
Requires:       texlive-svn-multi >= %{texlive_version}
#!BuildIgnore: texlive-svn-multi
Requires:       texlive-svn-prov >= %{texlive_version}
#!BuildIgnore: texlive-svn-prov
Requires:       texlive-svninfo >= %{texlive_version}
#!BuildIgnore: texlive-svninfo
Requires:       texlive-swfigure >= %{texlive_version}
#!BuildIgnore: texlive-swfigure
Requires:       texlive-swungdash >= %{texlive_version}
#!BuildIgnore: texlive-swungdash
Requires:       texlive-syntax >= %{texlive_version}
#!BuildIgnore: texlive-syntax
Requires:       texlive-syntrace >= %{texlive_version}
#!BuildIgnore: texlive-syntrace
Requires:       texlive-synttree >= %{texlive_version}
#!BuildIgnore: texlive-synttree
Requires:       texlive-tabbing >= %{texlive_version}
#!BuildIgnore: texlive-tabbing
Requires:       texlive-tabfigures >= %{texlive_version}
#!BuildIgnore: texlive-tabfigures
Requires:       texlive-tableaux >= %{texlive_version}
#!BuildIgnore: texlive-tableaux
Requires:       texlive-tablefootnote >= %{texlive_version}
#!BuildIgnore: texlive-tablefootnote
Requires:       texlive-tableof >= %{texlive_version}
#!BuildIgnore: texlive-tableof
Requires:       texlive-tablists >= %{texlive_version}
#!BuildIgnore: texlive-tablists
Requires:       texlive-tabls >= %{texlive_version}
#!BuildIgnore: texlive-tabls
Requires:       texlive-tablvar >= %{texlive_version}
#!BuildIgnore: texlive-tablvar
Requires:       texlive-tabstackengine >= %{texlive_version}
#!BuildIgnore: texlive-tabstackengine
Requires:       texlive-tabto-ltx >= %{texlive_version}
#!BuildIgnore: texlive-tabto-ltx
Requires:       texlive-tabu >= %{texlive_version}
#!BuildIgnore: texlive-tabu
Requires:       texlive-tabularborder >= %{texlive_version}
#!BuildIgnore: texlive-tabularborder
Requires:       texlive-tabularcalc >= %{texlive_version}
#!BuildIgnore: texlive-tabularcalc
Requires:       texlive-tabularew >= %{texlive_version}
#!BuildIgnore: texlive-tabularew
Requires:       texlive-tabularray >= %{texlive_version}
#!BuildIgnore: texlive-tabularray
Requires:       texlive-tabulary >= %{texlive_version}
#!BuildIgnore: texlive-tabulary
Requires:       texlive-tagging >= %{texlive_version}
#!BuildIgnore: texlive-tagging
Requires:       texlive-tagpair >= %{texlive_version}
#!BuildIgnore: texlive-tagpair
Requires:       texlive-tagpdf >= %{texlive_version}
#!BuildIgnore: texlive-tagpdf
Requires:       texlive-talk >= %{texlive_version}
#!BuildIgnore: texlive-talk
Requires:       texlive-tamefloats >= %{texlive_version}
#!BuildIgnore: texlive-tamefloats
Requires:       texlive-tasks >= %{texlive_version}
#!BuildIgnore: texlive-tasks
Requires:       texlive-tcldoc >= %{texlive_version}
#!BuildIgnore: texlive-tcldoc
Requires:       texlive-tcolorbox >= %{texlive_version}
#!BuildIgnore: texlive-tcolorbox
Requires:       texlive-tdclock >= %{texlive_version}
#!BuildIgnore: texlive-tdclock
Requires:       texlive-technics >= %{texlive_version}
#!BuildIgnore: texlive-technics
Requires:       texlive-ted >= %{texlive_version}
#!BuildIgnore: texlive-ted
Requires:       texlive-templatetools >= %{texlive_version}
#!BuildIgnore: texlive-templatetools
Requires:       texlive-termcal >= %{texlive_version}
#!BuildIgnore: texlive-termcal
Requires:       texlive-termlist >= %{texlive_version}
#!BuildIgnore: texlive-termlist
Requires:       texlive-termsim >= %{texlive_version}
#!BuildIgnore: texlive-termsim
Requires:       texlive-testhyphens >= %{texlive_version}
#!BuildIgnore: texlive-testhyphens
Requires:       texlive-testidx >= %{texlive_version}
#!BuildIgnore: texlive-testidx
Requires:       texlive-tex-label >= %{texlive_version}
#!BuildIgnore: texlive-tex-label
Requires:       texlive-tex-locale >= %{texlive_version}
#!BuildIgnore: texlive-tex-locale
Requires:       texlive-texlogos >= %{texlive_version}
#!BuildIgnore: texlive-texlogos
Requires:       texlive-texmate >= %{texlive_version}
#!BuildIgnore: texlive-texmate
Requires:       texlive-texments >= %{texlive_version}
#!BuildIgnore: texlive-texments
Requires:       texlive-texpower >= %{texlive_version}
#!BuildIgnore: texlive-texpower
Requires:       texlive-texshade >= %{texlive_version}
#!BuildIgnore: texlive-texshade
Requires:       texlive-texsurgery >= %{texlive_version}
#!BuildIgnore: texlive-texsurgery
Requires:       texlive-textcsc >= %{texlive_version}
#!BuildIgnore: texlive-textcsc
Requires:       texlive-textfit >= %{texlive_version}
#!BuildIgnore: texlive-textfit
Requires:       texlive-textmerg >= %{texlive_version}
#!BuildIgnore: texlive-textmerg
Requires:       texlive-textpos >= %{texlive_version}
#!BuildIgnore: texlive-textpos
Requires:       texlive-textualicomma >= %{texlive_version}
#!BuildIgnore: texlive-textualicomma
Requires:       texlive-texvc >= %{texlive_version}
#!BuildIgnore: texlive-texvc
Requires:       texlive-theoremref >= %{texlive_version}
#!BuildIgnore: texlive-theoremref
Requires:       texlive-thinsp >= %{texlive_version}
#!BuildIgnore: texlive-thinsp
Requires:       texlive-thmtools >= %{texlive_version}
#!BuildIgnore: texlive-thmtools
Requires:       texlive-threadcol >= %{texlive_version}
#!BuildIgnore: texlive-threadcol
Requires:       texlive-threeparttable >= %{texlive_version}
#!BuildIgnore: texlive-threeparttable
Requires:       texlive-threeparttablex >= %{texlive_version}
#!BuildIgnore: texlive-threeparttablex
Requires:       texlive-thumb >= %{texlive_version}
#!BuildIgnore: texlive-thumb
Requires:       texlive-thumbs >= %{texlive_version}
#!BuildIgnore: texlive-thumbs
Requires:       texlive-thumby >= %{texlive_version}
#!BuildIgnore: texlive-thumby
Requires:       texlive-ticket >= %{texlive_version}
#!BuildIgnore: texlive-ticket
Requires:       texlive-tipauni >= %{texlive_version}
#!BuildIgnore: texlive-tipauni
Requires:       texlive-titlecaps >= %{texlive_version}
#!BuildIgnore: texlive-titlecaps
Requires:       texlive-titlefoot >= %{texlive_version}
#!BuildIgnore: texlive-titlefoot
Requires:       texlive-titlepic >= %{texlive_version}
#!BuildIgnore: texlive-titlepic
Requires:       texlive-titleref >= %{texlive_version}
#!BuildIgnore: texlive-titleref
Requires:       texlive-titlesec >= %{texlive_version}
#!BuildIgnore: texlive-titlesec
Requires:       texlive-titling >= %{texlive_version}
#!BuildIgnore: texlive-titling
Requires:       texlive-to-be-determined >= %{texlive_version}
#!BuildIgnore: texlive-to-be-determined
Requires:       texlive-tocbibind >= %{texlive_version}
#!BuildIgnore: texlive-tocbibind
Requires:       texlive-tocdata >= %{texlive_version}
#!BuildIgnore: texlive-tocdata
Requires:       texlive-tocloft >= %{texlive_version}
#!BuildIgnore: texlive-tocloft
Requires:       texlive-tocvsec2 >= %{texlive_version}
#!BuildIgnore: texlive-tocvsec2
Requires:       texlive-todo >= %{texlive_version}
#!BuildIgnore: texlive-todo
Requires:       texlive-todonotes >= %{texlive_version}
#!BuildIgnore: texlive-todonotes
Requires:       texlive-tokcycle >= %{texlive_version}
#!BuildIgnore: texlive-tokcycle
Requires:       texlive-tokenizer >= %{texlive_version}
#!BuildIgnore: texlive-tokenizer
Requires:       texlive-toolbox >= %{texlive_version}
#!BuildIgnore: texlive-toolbox
Requires:       texlive-topfloat >= %{texlive_version}
#!BuildIgnore: texlive-topfloat
Requires:       texlive-topiclongtable >= %{texlive_version}
#!BuildIgnore: texlive-topiclongtable
Requires:       texlive-totalcount >= %{texlive_version}
#!BuildIgnore: texlive-totalcount
Requires:       texlive-totcount >= %{texlive_version}
#!BuildIgnore: texlive-totcount
Requires:       texlive-totpages >= %{texlive_version}
#!BuildIgnore: texlive-totpages
Requires:       texlive-tramlines >= %{texlive_version}
#!BuildIgnore: texlive-tramlines
Requires:       texlive-translations >= %{texlive_version}
#!BuildIgnore: texlive-translations
Requires:       texlive-transparent >= %{texlive_version}
#!BuildIgnore: texlive-transparent
Requires:       texlive-trfsigns >= %{texlive_version}
#!BuildIgnore: texlive-trfsigns
Requires:       texlive-trimspaces >= %{texlive_version}
#!BuildIgnore: texlive-trimspaces
Requires:       texlive-trivfloat >= %{texlive_version}
#!BuildIgnore: texlive-trivfloat
Requires:       texlive-trsym >= %{texlive_version}
#!BuildIgnore: texlive-trsym
Requires:       texlive-truncate >= %{texlive_version}
#!BuildIgnore: texlive-truncate
Requires:       texlive-tucv >= %{texlive_version}
#!BuildIgnore: texlive-tucv
Requires:       texlive-turnthepage >= %{texlive_version}
#!BuildIgnore: texlive-turnthepage
Requires:       texlive-twoinone >= %{texlive_version}
#!BuildIgnore: texlive-twoinone
Requires:       texlive-twoup >= %{texlive_version}
#!BuildIgnore: texlive-twoup
Requires:       texlive-txgreeks >= %{texlive_version}
#!BuildIgnore: texlive-txgreeks
Requires:       texlive-type1cm >= %{texlive_version}
#!BuildIgnore: texlive-type1cm
Requires:       texlive-typed-checklist >= %{texlive_version}
#!BuildIgnore: texlive-typed-checklist
Requires:       texlive-typeface >= %{texlive_version}
#!BuildIgnore: texlive-typeface
Requires:       texlive-typoaid >= %{texlive_version}
#!BuildIgnore: texlive-typoaid
Requires:       texlive-typogrid >= %{texlive_version}
#!BuildIgnore: texlive-typogrid
Requires:       texlive-uassign >= %{texlive_version}
#!BuildIgnore: texlive-uassign
Requires:       texlive-ucs >= %{texlive_version}
#!BuildIgnore: texlive-ucs
Requires:       texlive-uebungsblatt >= %{texlive_version}
#!BuildIgnore: texlive-uebungsblatt
Requires:       texlive-umoline >= %{texlive_version}
#!BuildIgnore: texlive-umoline
Requires:       texlive-underlin >= %{texlive_version}
#!BuildIgnore: texlive-underlin
Requires:       texlive-underoverlap >= %{texlive_version}
#!BuildIgnore: texlive-underoverlap
Requires:       texlive-undolabl >= %{texlive_version}
#!BuildIgnore: texlive-undolabl
Requires:       texlive-uni-titlepage >= %{texlive_version}
#!BuildIgnore: texlive-uni-titlepage
Requires:       texlive-unicodefonttable >= %{texlive_version}
#!BuildIgnore: texlive-unicodefonttable
Requires:       texlive-unisc >= %{texlive_version}
#!BuildIgnore: texlive-unisc
Requires:       texlive-unitconv >= %{texlive_version}
#!BuildIgnore: texlive-unitconv
Requires:       texlive-units >= %{texlive_version}
#!BuildIgnore: texlive-units
Requires:       texlive-unravel >= %{texlive_version}
#!BuildIgnore: texlive-unravel
Requires:       texlive-upmethodology >= %{texlive_version}
#!BuildIgnore: texlive-upmethodology
Requires:       texlive-upquote >= %{texlive_version}
#!BuildIgnore: texlive-upquote
Requires:       texlive-uri >= %{texlive_version}
#!BuildIgnore: texlive-uri
Requires:       texlive-ushort >= %{texlive_version}
#!BuildIgnore: texlive-ushort
Requires:       texlive-uspace >= %{texlive_version}
#!BuildIgnore: texlive-uspace
Requires:       texlive-utf8add >= %{texlive_version}
#!BuildIgnore: texlive-utf8add
Requires:       texlive-uwmslide >= %{texlive_version}
#!BuildIgnore: texlive-uwmslide
Requires:       texlive-variablelm >= %{texlive_version}
#!BuildIgnore: texlive-variablelm
Requires:       texlive-varindex >= %{texlive_version}
#!BuildIgnore: texlive-varindex
Requires:       texlive-varsfromjobname >= %{texlive_version}
#!BuildIgnore: texlive-varsfromjobname
Requires:       texlive-varwidth >= %{texlive_version}
#!BuildIgnore: texlive-varwidth
Requires:       texlive-vcell >= %{texlive_version}
#!BuildIgnore: texlive-vcell
Requires:       texlive-vdmlisting >= %{texlive_version}
#!BuildIgnore: texlive-vdmlisting
Requires:       texlive-verbasef >= %{texlive_version}
#!BuildIgnore: texlive-verbasef
Requires:       texlive-verbatimbox >= %{texlive_version}
#!BuildIgnore: texlive-verbatimbox
Requires:       texlive-verbatimcopy >= %{texlive_version}
#!BuildIgnore: texlive-verbatimcopy
Requires:       texlive-verbdef >= %{texlive_version}
#!BuildIgnore: texlive-verbdef
Requires:       texlive-verbments >= %{texlive_version}
#!BuildIgnore: texlive-verbments
Requires:       texlive-verifiche >= %{texlive_version}
#!BuildIgnore: texlive-verifiche
Requires:       texlive-version >= %{texlive_version}
#!BuildIgnore: texlive-version
Requires:       texlive-versions >= %{texlive_version}
#!BuildIgnore: texlive-versions
Requires:       texlive-versonotes >= %{texlive_version}
#!BuildIgnore: texlive-versonotes
Requires:       texlive-vertbars >= %{texlive_version}
#!BuildIgnore: texlive-vertbars
Requires:       texlive-vgrid >= %{texlive_version}
#!BuildIgnore: texlive-vgrid
Requires:       texlive-vhistory >= %{texlive_version}
#!BuildIgnore: texlive-vhistory
Requires:       texlive-vmargin >= %{texlive_version}
#!BuildIgnore: texlive-vmargin
Requires:       texlive-volumes >= %{texlive_version}
#!BuildIgnore: texlive-volumes
Requires:       texlive-vpe >= %{texlive_version}
#!BuildIgnore: texlive-vpe
Requires:       texlive-vruler >= %{texlive_version}
#!BuildIgnore: texlive-vruler
Requires:       texlive-vtable >= %{texlive_version}
#!BuildIgnore: texlive-vtable
Requires:       texlive-vwcol >= %{texlive_version}
#!BuildIgnore: texlive-vwcol
Requires:       texlive-wallcalendar >= %{texlive_version}
#!BuildIgnore: texlive-wallcalendar
Requires:       texlive-wallpaper >= %{texlive_version}
#!BuildIgnore: texlive-wallpaper
Requires:       texlive-warning >= %{texlive_version}
#!BuildIgnore: texlive-warning
Requires:       texlive-warpcol >= %{texlive_version}
#!BuildIgnore: texlive-warpcol
Requires:       texlive-was >= %{texlive_version}
#!BuildIgnore: texlive-was
Requires:       texlive-webquiz >= %{texlive_version}
#!BuildIgnore: texlive-webquiz
Requires:       texlive-widetable >= %{texlive_version}
#!BuildIgnore: texlive-widetable
Requires:       texlive-widows-and-orphans >= %{texlive_version}
#!BuildIgnore: texlive-widows-and-orphans
Requires:       texlive-williams >= %{texlive_version}
#!BuildIgnore: texlive-williams
Requires:       texlive-willowtreebook >= %{texlive_version}
#!BuildIgnore: texlive-willowtreebook
Requires:       texlive-withargs >= %{texlive_version}
#!BuildIgnore: texlive-withargs
Requires:       texlive-wordcount >= %{texlive_version}
#!BuildIgnore: texlive-wordcount
Requires:       texlive-wordlike >= %{texlive_version}
#!BuildIgnore: texlive-wordlike
Requires:       texlive-worksheet >= %{texlive_version}
#!BuildIgnore: texlive-worksheet
Requires:       texlive-wrapfig >= %{texlive_version}
#!BuildIgnore: texlive-wrapfig
Requires:       texlive-wrapfig2 >= %{texlive_version}
#!BuildIgnore: texlive-wrapfig2
Requires:       texlive-wrapstuff >= %{texlive_version}
#!BuildIgnore: texlive-wrapstuff
Requires:       texlive-writeongrid >= %{texlive_version}
#!BuildIgnore: texlive-writeongrid
Requires:       texlive-wtref >= %{texlive_version}
#!BuildIgnore: texlive-wtref
Requires:       texlive-xargs >= %{texlive_version}
#!BuildIgnore: texlive-xargs
Requires:       texlive-xassoccnt >= %{texlive_version}
#!BuildIgnore: texlive-xassoccnt
Requires:       texlive-xbmks >= %{texlive_version}
#!BuildIgnore: texlive-xbmks
Requires:       texlive-xcntperchap >= %{texlive_version}
#!BuildIgnore: texlive-xcntperchap
Requires:       texlive-xcolor-material >= %{texlive_version}
#!BuildIgnore: texlive-xcolor-material
Requires:       texlive-xcolor-solarized >= %{texlive_version}
#!BuildIgnore: texlive-xcolor-solarized
Requires:       texlive-xcomment >= %{texlive_version}
#!BuildIgnore: texlive-xcomment
Requires:       texlive-xcookybooky >= %{texlive_version}
#!BuildIgnore: texlive-xcookybooky
Requires:       texlive-xcpdftips >= %{texlive_version}
#!BuildIgnore: texlive-xcpdftips
Requires:       texlive-xdoc >= %{texlive_version}
#!BuildIgnore: texlive-xdoc
Requires:       texlive-xellipsis >= %{texlive_version}
#!BuildIgnore: texlive-xellipsis
Requires:       texlive-xfakebold >= %{texlive_version}
#!BuildIgnore: texlive-xfakebold
Requires:       texlive-xfor >= %{texlive_version}
#!BuildIgnore: texlive-xfor
Requires:       texlive-xhfill >= %{texlive_version}
#!BuildIgnore: texlive-xhfill
Requires:       texlive-xifthen >= %{texlive_version}
#!BuildIgnore: texlive-xifthen
Requires:       texlive-xint >= %{texlive_version}
#!BuildIgnore: texlive-xint
Requires:       texlive-xkcdcolors >= %{texlive_version}
#!BuildIgnore: texlive-xkcdcolors
Requires:       texlive-xltabular >= %{texlive_version}
#!BuildIgnore: texlive-xltabular
Requires:       texlive-xmpincl >= %{texlive_version}
#!BuildIgnore: texlive-xmpincl
Requires:       texlive-xnewcommand >= %{texlive_version}
#!BuildIgnore: texlive-xnewcommand
Requires:       texlive-xoptarg >= %{texlive_version}
#!BuildIgnore: texlive-xoptarg
Requires:       texlive-xpatch >= %{texlive_version}
#!BuildIgnore: texlive-xpatch
Requires:       texlive-xpeek >= %{texlive_version}
#!BuildIgnore: texlive-xpeek
Requires:       texlive-xprintlen >= %{texlive_version}
#!BuildIgnore: texlive-xprintlen
Requires:       texlive-xpunctuate >= %{texlive_version}
#!BuildIgnore: texlive-xpunctuate
Requires:       texlive-xsavebox >= %{texlive_version}
#!BuildIgnore: texlive-xsavebox
Requires:       texlive-xsim >= %{texlive_version}
#!BuildIgnore: texlive-xsim
Requires:       texlive-xstring >= %{texlive_version}
#!BuildIgnore: texlive-xstring
Requires:       texlive-xtab >= %{texlive_version}
#!BuildIgnore: texlive-xtab
Requires:       texlive-xurl >= %{texlive_version}
#!BuildIgnore: texlive-xurl
Requires:       texlive-xwatermark >= %{texlive_version}
#!BuildIgnore: texlive-xwatermark
Requires:       texlive-xytree >= %{texlive_version}
#!BuildIgnore: texlive-xytree
Requires:       texlive-yafoot >= %{texlive_version}
#!BuildIgnore: texlive-yafoot
Requires:       texlive-yagusylo >= %{texlive_version}
#!BuildIgnore: texlive-yagusylo
Requires:       texlive-yaletter >= %{texlive_version}
#!BuildIgnore: texlive-yaletter
Requires:       texlive-ycbook >= %{texlive_version}
#!BuildIgnore: texlive-ycbook
Requires:       texlive-ydoc >= %{texlive_version}
#!BuildIgnore: texlive-ydoc
Requires:       texlive-yplan >= %{texlive_version}
#!BuildIgnore: texlive-yplan
Requires:       texlive-zebra-goodies >= %{texlive_version}
#!BuildIgnore: texlive-zebra-goodies
Requires:       texlive-zed-csp >= %{texlive_version}
#!BuildIgnore: texlive-zed-csp
Requires:       texlive-zennote >= %{texlive_version}
#!BuildIgnore: texlive-zennote
Requires:       texlive-ziffer >= %{texlive_version}
#!BuildIgnore: texlive-ziffer
Requires:       texlive-zref >= %{texlive_version}
#!BuildIgnore: texlive-zref
Requires:       texlive-zref-check >= %{texlive_version}
#!BuildIgnore: texlive-zref-check
Requires:       texlive-zref-clever >= %{texlive_version}
#!BuildIgnore: texlive-zref-clever
Requires:       texlive-zref-vario >= %{texlive_version}
#!BuildIgnore: texlive-zref-vario
Requires:       texlive-zwgetfdate >= %{texlive_version}
#!BuildIgnore: texlive-zwgetfdate
Requires:       texlive-zwpagelayout >= %{texlive_version}
#!BuildIgnore: texlive-zwpagelayout
BuildArch:      noarch

%description -n texlive-collection-latexextra
A very large collection of add-on packages for LaTeX.

%package -n texlive-collection-latexrecommended
Version:        %{texlive_version}.%{texlive_noarch}.svn65512
Release:        60.1
License:        LPPL-1.0
Summary:        LaTeX recommended packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Requires:       texlive-anysize >= %{texlive_version}
#!BuildIgnore: texlive-anysize
Requires:       texlive-attachfile2 >= %{texlive_version}
#!BuildIgnore: texlive-attachfile2
Requires:       texlive-beamer >= %{texlive_version}
#!BuildIgnore: texlive-beamer
Requires:       texlive-booktabs >= %{texlive_version}
#!BuildIgnore: texlive-booktabs
Requires:       texlive-breqn >= %{texlive_version}
#!BuildIgnore: texlive-breqn
Requires:       texlive-caption >= %{texlive_version}
#!BuildIgnore: texlive-caption
Requires:       texlive-cite >= %{texlive_version}
#!BuildIgnore: texlive-cite
Requires:       texlive-cmap >= %{texlive_version}
#!BuildIgnore: texlive-cmap
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-crop >= %{texlive_version}
#!BuildIgnore: texlive-crop
Requires:       texlive-ctable >= %{texlive_version}
#!BuildIgnore: texlive-ctable
Requires:       texlive-eso-pic >= %{texlive_version}
#!BuildIgnore: texlive-eso-pic
Requires:       texlive-etoolbox >= %{texlive_version}
#!BuildIgnore: texlive-etoolbox
Requires:       texlive-euenc >= %{texlive_version}
#!BuildIgnore: texlive-euenc
Requires:       texlive-euler >= %{texlive_version}
#!BuildIgnore: texlive-euler
Requires:       texlive-everysel >= %{texlive_version}
#!BuildIgnore: texlive-everysel
Requires:       texlive-everyshi >= %{texlive_version}
#!BuildIgnore: texlive-everyshi
Requires:       texlive-extsizes >= %{texlive_version}
#!BuildIgnore: texlive-extsizes
Requires:       texlive-fancybox >= %{texlive_version}
#!BuildIgnore: texlive-fancybox
Requires:       texlive-fancyref >= %{texlive_version}
#!BuildIgnore: texlive-fancyref
Requires:       texlive-fancyvrb >= %{texlive_version}
#!BuildIgnore: texlive-fancyvrb
Requires:       texlive-filehook >= %{texlive_version}
#!BuildIgnore: texlive-filehook
Requires:       texlive-float >= %{texlive_version}
#!BuildIgnore: texlive-float
Requires:       texlive-fontspec >= %{texlive_version}
#!BuildIgnore: texlive-fontspec
Requires:       texlive-footnotehyper >= %{texlive_version}
#!BuildIgnore: texlive-footnotehyper
Requires:       texlive-fp >= %{texlive_version}
#!BuildIgnore: texlive-fp
Requires:       texlive-grffile >= %{texlive_version}
#!BuildIgnore: texlive-grffile
Requires:       texlive-hologo >= %{texlive_version}
#!BuildIgnore: texlive-hologo
Requires:       texlive-index >= %{texlive_version}
#!BuildIgnore: texlive-index
Requires:       texlive-infwarerr >= %{texlive_version}
#!BuildIgnore: texlive-infwarerr
Requires:       texlive-jknapltx >= %{texlive_version}
#!BuildIgnore: texlive-jknapltx
Requires:       texlive-koma-script >= %{texlive_version}
#!BuildIgnore: texlive-koma-script
Requires:       texlive-l3experimental >= %{texlive_version}
#!BuildIgnore: texlive-l3experimental
Requires:       texlive-latexbug >= %{texlive_version}
#!BuildIgnore: texlive-latexbug
Requires:       texlive-lineno >= %{texlive_version}
#!BuildIgnore: texlive-lineno
Requires:       texlive-listings >= %{texlive_version}
#!BuildIgnore: texlive-listings
Requires:       texlive-lwarp >= %{texlive_version}
#!BuildIgnore: texlive-lwarp
Requires:       texlive-mathspec >= %{texlive_version}
#!BuildIgnore: texlive-mathspec
Requires:       texlive-mathtools >= %{texlive_version}
#!BuildIgnore: texlive-mathtools
Requires:       texlive-mdwtools >= %{texlive_version}
#!BuildIgnore: texlive-mdwtools
Requires:       texlive-memoir >= %{texlive_version}
#!BuildIgnore: texlive-memoir
Requires:       texlive-metalogo >= %{texlive_version}
#!BuildIgnore: texlive-metalogo
Requires:       texlive-microtype >= %{texlive_version}
#!BuildIgnore: texlive-microtype
Requires:       texlive-ms >= %{texlive_version}
#!BuildIgnore: texlive-ms
Requires:       texlive-newfloat >= %{texlive_version}
#!BuildIgnore: texlive-newfloat
Requires:       texlive-ntgclass >= %{texlive_version}
#!BuildIgnore: texlive-ntgclass
Requires:       texlive-parskip >= %{texlive_version}
#!BuildIgnore: texlive-parskip
Requires:       texlive-pdfcolfoot >= %{texlive_version}
#!BuildIgnore: texlive-pdfcolfoot
Requires:       texlive-pdflscape >= %{texlive_version}
#!BuildIgnore: texlive-pdflscape
Requires:       texlive-pdfmanagement-testphase >= %{texlive_version}
#!BuildIgnore: texlive-pdfmanagement-testphase
Requires:       texlive-pdfpages >= %{texlive_version}
#!BuildIgnore: texlive-pdfpages
Requires:       texlive-pdftexcmds >= %{texlive_version}
#!BuildIgnore: texlive-pdftexcmds
Requires:       texlive-polyglossia >= %{texlive_version}
#!BuildIgnore: texlive-polyglossia
Requires:       texlive-psfrag >= %{texlive_version}
#!BuildIgnore: texlive-psfrag
Requires:       texlive-ragged2e >= %{texlive_version}
#!BuildIgnore: texlive-ragged2e
Requires:       texlive-rcs >= %{texlive_version}
#!BuildIgnore: texlive-rcs
Requires:       texlive-sansmath >= %{texlive_version}
#!BuildIgnore: texlive-sansmath
Requires:       texlive-section >= %{texlive_version}
#!BuildIgnore: texlive-section
Requires:       texlive-seminar >= %{texlive_version}
#!BuildIgnore: texlive-seminar
Requires:       texlive-sepnum >= %{texlive_version}
#!BuildIgnore: texlive-sepnum
Requires:       texlive-setspace >= %{texlive_version}
#!BuildIgnore: texlive-setspace
Requires:       texlive-subfig >= %{texlive_version}
#!BuildIgnore: texlive-subfig
Requires:       texlive-textcase >= %{texlive_version}
#!BuildIgnore: texlive-textcase
Requires:       texlive-thumbpdf >= %{texlive_version}
#!BuildIgnore: texlive-thumbpdf
Requires:       texlive-translator >= %{texlive_version}
#!BuildIgnore: texlive-translator
Requires:       texlive-typehtml >= %{texlive_version}
#!BuildIgnore: texlive-typehtml
Requires:       texlive-ucharcat >= %{texlive_version}
#!BuildIgnore: texlive-ucharcat
Requires:       texlive-underscore >= %{texlive_version}
#!BuildIgnore: texlive-underscore
Requires:       texlive-unicode-math >= %{texlive_version}
#!BuildIgnore: texlive-unicode-math
Requires:       texlive-xcolor >= %{texlive_version}
#!BuildIgnore: texlive-xcolor
Requires:       texlive-xkeyval >= %{texlive_version}
#!BuildIgnore: texlive-xkeyval
Requires:       texlive-xltxtra >= %{texlive_version}
#!BuildIgnore: texlive-xltxtra
Requires:       texlive-xunicode >= %{texlive_version}
#!BuildIgnore: texlive-xunicode
BuildArch:      noarch

%description -n texlive-collection-latexrecommended
A collection of recommended add-on packages for LaTeX which
have widespread use.

%package -n texlive-collection-luatex
Version:        %{texlive_version}.%{texlive_noarch}.svn65791
Release:        60.1
License:        LPPL-1.0
Summary:        LuaTeX packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-addliga >= %{texlive_version}
#!BuildIgnore: texlive-addliga
Requires:       texlive-auto-pst-pdf-lua >= %{texlive_version}
#!BuildIgnore: texlive-auto-pst-pdf-lua
Requires:       texlive-barracuda >= %{texlive_version}
#!BuildIgnore: texlive-barracuda
Requires:       texlive-bezierplot >= %{texlive_version}
#!BuildIgnore: texlive-bezierplot
Requires:       texlive-blopentype >= %{texlive_version}
#!BuildIgnore: texlive-blopentype
Requires:       texlive-checkcites >= %{texlive_version}
#!BuildIgnore: texlive-checkcites
Requires:       texlive-chickenize >= %{texlive_version}
#!BuildIgnore: texlive-chickenize
Requires:       texlive-chinese-jfm >= %{texlive_version}
#!BuildIgnore: texlive-chinese-jfm
Requires:       texlive-cloze >= %{texlive_version}
#!BuildIgnore: texlive-cloze
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-combofont >= %{texlive_version}
#!BuildIgnore: texlive-combofont
Requires:       texlive-cstypo >= %{texlive_version}
#!BuildIgnore: texlive-cstypo
Requires:       texlive-ctablestack >= %{texlive_version}
#!BuildIgnore: texlive-ctablestack
Requires:       texlive-ekdosis >= %{texlive_version}
#!BuildIgnore: texlive-ekdosis
Requires:       texlive-emoji >= %{texlive_version}
#!BuildIgnore: texlive-emoji
Requires:       texlive-emojicite >= %{texlive_version}
#!BuildIgnore: texlive-emojicite
Requires:       texlive-enigma >= %{texlive_version}
#!BuildIgnore: texlive-enigma
Requires:       texlive-innerscript >= %{texlive_version}
#!BuildIgnore: texlive-innerscript
Requires:       texlive-interpreter >= %{texlive_version}
#!BuildIgnore: texlive-interpreter
Requires:       texlive-kanaparser >= %{texlive_version}
#!BuildIgnore: texlive-kanaparser
Requires:       texlive-ligtype >= %{texlive_version}
#!BuildIgnore: texlive-ligtype
Requires:       texlive-linebreaker >= %{texlive_version}
#!BuildIgnore: texlive-linebreaker
Requires:       texlive-lparse >= %{texlive_version}
#!BuildIgnore: texlive-lparse
Requires:       texlive-lt3luabridge >= %{texlive_version}
#!BuildIgnore: texlive-lt3luabridge
Requires:       texlive-lua-typo >= %{texlive_version}
#!BuildIgnore: texlive-lua-typo
Requires:       texlive-lua-uca >= %{texlive_version}
#!BuildIgnore: texlive-lua-uca
Requires:       texlive-lua-ul >= %{texlive_version}
#!BuildIgnore: texlive-lua-ul
Requires:       texlive-lua-uni-algos >= %{texlive_version}
#!BuildIgnore: texlive-lua-uni-algos
Requires:       texlive-lua-visual-debug >= %{texlive_version}
#!BuildIgnore: texlive-lua-visual-debug
Requires:       texlive-lua-widow-control >= %{texlive_version}
#!BuildIgnore: texlive-lua-widow-control
Requires:       texlive-luaaddplot >= %{texlive_version}
#!BuildIgnore: texlive-luaaddplot
Requires:       texlive-luacas >= %{texlive_version}
#!BuildIgnore: texlive-luacas
Requires:       texlive-luacensor >= %{texlive_version}
#!BuildIgnore: texlive-luacensor
Requires:       texlive-luacode >= %{texlive_version}
#!BuildIgnore: texlive-luacode
Requires:       texlive-luacolor >= %{texlive_version}
#!BuildIgnore: texlive-luacolor
Requires:       texlive-luacomplex >= %{texlive_version}
#!BuildIgnore: texlive-luacomplex
Requires:       texlive-luagcd >= %{texlive_version}
#!BuildIgnore: texlive-luagcd
Requires:       texlive-luahyphenrules >= %{texlive_version}
#!BuildIgnore: texlive-luahyphenrules
Requires:       texlive-luaimageembed >= %{texlive_version}
#!BuildIgnore: texlive-luaimageembed
Requires:       texlive-luaindex >= %{texlive_version}
#!BuildIgnore: texlive-luaindex
Requires:       texlive-luainputenc >= %{texlive_version}
#!BuildIgnore: texlive-luainputenc
Requires:       texlive-luaintro >= %{texlive_version}
#!BuildIgnore: texlive-luaintro
Requires:       texlive-luakeys >= %{texlive_version}
#!BuildIgnore: texlive-luakeys
Requires:       texlive-lualatex-doc >= %{texlive_version}
#!BuildIgnore: texlive-lualatex-doc
Requires:       texlive-lualatex-math >= %{texlive_version}
#!BuildIgnore: texlive-lualatex-math
Requires:       texlive-lualatex-truncate >= %{texlive_version}
#!BuildIgnore: texlive-lualatex-truncate
Requires:       texlive-lualibs >= %{texlive_version}
#!BuildIgnore: texlive-lualibs
Requires:       texlive-lualinalg >= %{texlive_version}
#!BuildIgnore: texlive-lualinalg
Requires:       texlive-luamathalign >= %{texlive_version}
#!BuildIgnore: texlive-luamathalign
Requires:       texlive-luamaths >= %{texlive_version}
#!BuildIgnore: texlive-luamaths
Requires:       texlive-luamodulartables >= %{texlive_version}
#!BuildIgnore: texlive-luamodulartables
Requires:       texlive-luamplib >= %{texlive_version}
#!BuildIgnore: texlive-luamplib
Requires:       texlive-luaoptions >= %{texlive_version}
#!BuildIgnore: texlive-luaoptions
Requires:       texlive-luaotfload >= %{texlive_version}
#!BuildIgnore: texlive-luaotfload
Requires:       texlive-luapackageloader >= %{texlive_version}
#!BuildIgnore: texlive-luapackageloader
Requires:       texlive-luaprogtable >= %{texlive_version}
#!BuildIgnore: texlive-luaprogtable
Requires:       texlive-luaquotes >= %{texlive_version}
#!BuildIgnore: texlive-luaquotes
Requires:       texlive-luarandom >= %{texlive_version}
#!BuildIgnore: texlive-luarandom
Requires:       texlive-luaset >= %{texlive_version}
#!BuildIgnore: texlive-luaset
Requires:       texlive-luatex85 >= %{texlive_version}
#!BuildIgnore: texlive-luatex85
Requires:       texlive-luatexbase >= %{texlive_version}
#!BuildIgnore: texlive-luatexbase
Requires:       texlive-luatexko >= %{texlive_version}
#!BuildIgnore: texlive-luatexko
Requires:       texlive-luatextra >= %{texlive_version}
#!BuildIgnore: texlive-luatextra
Requires:       texlive-luatruthtable >= %{texlive_version}
#!BuildIgnore: texlive-luatruthtable
Requires:       texlive-luavlna >= %{texlive_version}
#!BuildIgnore: texlive-luavlna
Requires:       texlive-luaxml >= %{texlive_version}
#!BuildIgnore: texlive-luaxml
Requires:       texlive-lutabulartools >= %{texlive_version}
#!BuildIgnore: texlive-lutabulartools
Requires:       texlive-minim >= %{texlive_version}
#!BuildIgnore: texlive-minim
Requires:       texlive-minim-math >= %{texlive_version}
#!BuildIgnore: texlive-minim-math
Requires:       texlive-minim-mp >= %{texlive_version}
#!BuildIgnore: texlive-minim-mp
Requires:       texlive-minim-pdf >= %{texlive_version}
#!BuildIgnore: texlive-minim-pdf
Requires:       texlive-minim-xmp >= %{texlive_version}
#!BuildIgnore: texlive-minim-xmp
Requires:       texlive-newpax >= %{texlive_version}
#!BuildIgnore: texlive-newpax
Requires:       texlive-nodetree >= %{texlive_version}
#!BuildIgnore: texlive-nodetree
Requires:       texlive-odsfile >= %{texlive_version}
#!BuildIgnore: texlive-odsfile
Requires:       texlive-optex >= %{texlive_version}
#!BuildIgnore: texlive-optex
Requires:       texlive-pdfarticle >= %{texlive_version}
#!BuildIgnore: texlive-pdfarticle
Requires:       texlive-pdfextra >= %{texlive_version}
#!BuildIgnore: texlive-pdfextra
Requires:       texlive-penlight >= %{texlive_version}
#!BuildIgnore: texlive-penlight
Requires:       texlive-piton >= %{texlive_version}
#!BuildIgnore: texlive-piton
Requires:       texlive-placeat >= %{texlive_version}
#!BuildIgnore: texlive-placeat
Requires:       texlive-plantuml >= %{texlive_version}
#!BuildIgnore: texlive-plantuml
Requires:       texlive-pyluatex >= %{texlive_version}
#!BuildIgnore: texlive-pyluatex
Requires:       texlive-scikgtex >= %{texlive_version}
#!BuildIgnore: texlive-scikgtex
Requires:       texlive-selnolig >= %{texlive_version}
#!BuildIgnore: texlive-selnolig
Requires:       texlive-showhyphenation >= %{texlive_version}
#!BuildIgnore: texlive-showhyphenation
Requires:       texlive-showkerning >= %{texlive_version}
#!BuildIgnore: texlive-showkerning
Requires:       texlive-spacekern >= %{texlive_version}
#!BuildIgnore: texlive-spacekern
Requires:       texlive-spelling >= %{texlive_version}
#!BuildIgnore: texlive-spelling
Requires:       texlive-stricttex >= %{texlive_version}
#!BuildIgnore: texlive-stricttex
Requires:       texlive-truthtable >= %{texlive_version}
#!BuildIgnore: texlive-truthtable
Requires:       texlive-tsvtemplate >= %{texlive_version}
#!BuildIgnore: texlive-tsvtemplate
Requires:       texlive-typewriter >= %{texlive_version}
#!BuildIgnore: texlive-typewriter
Requires:       texlive-uninormalize >= %{texlive_version}
#!BuildIgnore: texlive-uninormalize
Requires:       texlive-yamlvars >= %{texlive_version}
#!BuildIgnore: texlive-yamlvars
BuildArch:      noarch

%description -n texlive-collection-luatex
Packages for LuaTeX, a TeX engine using Lua as an embedded
scripting and extension language, with native support for
Unicode, OpenType/TrueType fonts, and both PDF and DVI output.
The LuaTeX engine itself (and plain formats) are in
collection-basic.

%package -n texlive-collection-mathscience
Version:        %{texlive_version}.%{texlive_noarch}.svn65753
Release:        60.1
License:        LPPL-1.0
Summary:        Mathematics, natural sciences, computer science packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-12many >= %{texlive_version}
#!BuildIgnore: texlive-12many
Requires:       texlive-accents >= %{texlive_version}
#!BuildIgnore: texlive-accents
Requires:       texlive-alg >= %{texlive_version}
#!BuildIgnore: texlive-alg
Requires:       texlive-algobox >= %{texlive_version}
#!BuildIgnore: texlive-algobox
Requires:       texlive-algorithm2e >= %{texlive_version}
#!BuildIgnore: texlive-algorithm2e
Requires:       texlive-algorithmicx >= %{texlive_version}
#!BuildIgnore: texlive-algorithmicx
Requires:       texlive-algorithms >= %{texlive_version}
#!BuildIgnore: texlive-algorithms
Requires:       texlive-algpseudocodex >= %{texlive_version}
#!BuildIgnore: texlive-algpseudocodex
Requires:       texlive-algxpar >= %{texlive_version}
#!BuildIgnore: texlive-algxpar
Requires:       texlive-aligned-overset >= %{texlive_version}
#!BuildIgnore: texlive-aligned-overset
Requires:       texlive-amscdx >= %{texlive_version}
#!BuildIgnore: texlive-amscdx
Requires:       texlive-amstex >= %{texlive_version}
#!BuildIgnore: texlive-amstex
Requires:       texlive-annotate-equations >= %{texlive_version}
#!BuildIgnore: texlive-annotate-equations
Requires:       texlive-apxproof >= %{texlive_version}
#!BuildIgnore: texlive-apxproof
Requires:       texlive-autobreak >= %{texlive_version}
#!BuildIgnore: texlive-autobreak
Requires:       texlive-axodraw2 >= %{texlive_version}
#!BuildIgnore: texlive-axodraw2
Requires:       texlive-backnaur >= %{texlive_version}
#!BuildIgnore: texlive-backnaur
Requires:       texlive-begriff >= %{texlive_version}
#!BuildIgnore: texlive-begriff
Requires:       texlive-binomexp >= %{texlive_version}
#!BuildIgnore: texlive-binomexp
Requires:       texlive-biocon >= %{texlive_version}
#!BuildIgnore: texlive-biocon
Requires:       texlive-bitpattern >= %{texlive_version}
#!BuildIgnore: texlive-bitpattern
Requires:       texlive-bodeplot >= %{texlive_version}
#!BuildIgnore: texlive-bodeplot
Requires:       texlive-bohr >= %{texlive_version}
#!BuildIgnore: texlive-bohr
Requires:       texlive-boldtensors >= %{texlive_version}
#!BuildIgnore: texlive-boldtensors
Requires:       texlive-bosisio >= %{texlive_version}
#!BuildIgnore: texlive-bosisio
Requires:       texlive-bpchem >= %{texlive_version}
#!BuildIgnore: texlive-bpchem
Requires:       texlive-bropd >= %{texlive_version}
#!BuildIgnore: texlive-bropd
Requires:       texlive-bussproofs >= %{texlive_version}
#!BuildIgnore: texlive-bussproofs
Requires:       texlive-bussproofs-extra >= %{texlive_version}
#!BuildIgnore: texlive-bussproofs-extra
Requires:       texlive-bytefield >= %{texlive_version}
#!BuildIgnore: texlive-bytefield
Requires:       texlive-calculation >= %{texlive_version}
#!BuildIgnore: texlive-calculation
Requires:       texlive-cartonaugh >= %{texlive_version}
#!BuildIgnore: texlive-cartonaugh
Requires:       texlive-cascade >= %{texlive_version}
#!BuildIgnore: texlive-cascade
Requires:       texlive-causets >= %{texlive_version}
#!BuildIgnore: texlive-causets
Requires:       texlive-ccfonts >= %{texlive_version}
#!BuildIgnore: texlive-ccfonts
Requires:       texlive-ccool >= %{texlive_version}
#!BuildIgnore: texlive-ccool
Requires:       texlive-chemarrow >= %{texlive_version}
#!BuildIgnore: texlive-chemarrow
Requires:       texlive-chemcompounds >= %{texlive_version}
#!BuildIgnore: texlive-chemcompounds
Requires:       texlive-chemcono >= %{texlive_version}
#!BuildIgnore: texlive-chemcono
Requires:       texlive-chemexec >= %{texlive_version}
#!BuildIgnore: texlive-chemexec
Requires:       texlive-chemformula >= %{texlive_version}
#!BuildIgnore: texlive-chemformula
Requires:       texlive-chemgreek >= %{texlive_version}
#!BuildIgnore: texlive-chemgreek
Requires:       texlive-chemmacros >= %{texlive_version}
#!BuildIgnore: texlive-chemmacros
Requires:       texlive-chemnum >= %{texlive_version}
#!BuildIgnore: texlive-chemnum
Requires:       texlive-chemobabel >= %{texlive_version}
#!BuildIgnore: texlive-chemobabel
Requires:       texlive-chemplants >= %{texlive_version}
#!BuildIgnore: texlive-chemplants
Requires:       texlive-chemschemex >= %{texlive_version}
#!BuildIgnore: texlive-chemschemex
Requires:       texlive-chemsec >= %{texlive_version}
#!BuildIgnore: texlive-chemsec
Requires:       texlive-chemstyle >= %{texlive_version}
#!BuildIgnore: texlive-chemstyle
Requires:       texlive-clrscode >= %{texlive_version}
#!BuildIgnore: texlive-clrscode
Requires:       texlive-clrscode3e >= %{texlive_version}
#!BuildIgnore: texlive-clrscode3e
Requires:       texlive-codeanatomy >= %{texlive_version}
#!BuildIgnore: texlive-codeanatomy
Requires:       texlive-collection-fontsrecommended >= %{texlive_version}
#!BuildIgnore: texlive-collection-fontsrecommended
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-commath >= %{texlive_version}
#!BuildIgnore: texlive-commath
Requires:       texlive-commutative-diagrams >= %{texlive_version}
#!BuildIgnore: texlive-commutative-diagrams
Requires:       texlive-complexity >= %{texlive_version}
#!BuildIgnore: texlive-complexity
Requires:       texlive-computational-complexity >= %{texlive_version}
#!BuildIgnore: texlive-computational-complexity
Requires:       texlive-concmath >= %{texlive_version}
#!BuildIgnore: texlive-concmath
Requires:       texlive-concrete >= %{texlive_version}
#!BuildIgnore: texlive-concrete
Requires:       texlive-conteq >= %{texlive_version}
#!BuildIgnore: texlive-conteq
Requires:       texlive-correctmathalign >= %{texlive_version}
#!BuildIgnore: texlive-correctmathalign
Requires:       texlive-cryptocode >= %{texlive_version}
#!BuildIgnore: texlive-cryptocode
Requires:       texlive-csassignments >= %{texlive_version}
#!BuildIgnore: texlive-csassignments
Requires:       texlive-cvss >= %{texlive_version}
#!BuildIgnore: texlive-cvss
Requires:       texlive-decision-table >= %{texlive_version}
#!BuildIgnore: texlive-decision-table
Requires:       texlive-delim >= %{texlive_version}
#!BuildIgnore: texlive-delim
Requires:       texlive-delimseasy >= %{texlive_version}
#!BuildIgnore: texlive-delimseasy
Requires:       texlive-delimset >= %{texlive_version}
#!BuildIgnore: texlive-delimset
Requires:       texlive-derivative >= %{texlive_version}
#!BuildIgnore: texlive-derivative
Requires:       texlive-diffcoeff >= %{texlive_version}
#!BuildIgnore: texlive-diffcoeff
Requires:       texlive-digiconfigs >= %{texlive_version}
#!BuildIgnore: texlive-digiconfigs
Requires:       texlive-dijkstra >= %{texlive_version}
#!BuildIgnore: texlive-dijkstra
Requires:       texlive-drawmatrix >= %{texlive_version}
#!BuildIgnore: texlive-drawmatrix
Requires:       texlive-drawstack >= %{texlive_version}
#!BuildIgnore: texlive-drawstack
Requires:       texlive-dyntree >= %{texlive_version}
#!BuildIgnore: texlive-dyntree
Requires:       texlive-easing >= %{texlive_version}
#!BuildIgnore: texlive-easing
Requires:       texlive-ebproof >= %{texlive_version}
#!BuildIgnore: texlive-ebproof
Requires:       texlive-econometrics >= %{texlive_version}
#!BuildIgnore: texlive-econometrics
Requires:       texlive-eltex >= %{texlive_version}
#!BuildIgnore: texlive-eltex
Requires:       texlive-emf >= %{texlive_version}
#!BuildIgnore: texlive-emf
Requires:       texlive-endiagram >= %{texlive_version}
#!BuildIgnore: texlive-endiagram
Requires:       texlive-engtlc >= %{texlive_version}
#!BuildIgnore: texlive-engtlc
Requires:       texlive-eolang >= %{texlive_version}
#!BuildIgnore: texlive-eolang
Requires:       texlive-eqexpl >= %{texlive_version}
#!BuildIgnore: texlive-eqexpl
Requires:       texlive-eqnarray >= %{texlive_version}
#!BuildIgnore: texlive-eqnarray
Requires:       texlive-eqnnumwarn >= %{texlive_version}
#!BuildIgnore: texlive-eqnnumwarn
Requires:       texlive-euclideangeometry >= %{texlive_version}
#!BuildIgnore: texlive-euclideangeometry
Requires:       texlive-extarrows >= %{texlive_version}
#!BuildIgnore: texlive-extarrows
Requires:       texlive-extpfeil >= %{texlive_version}
#!BuildIgnore: texlive-extpfeil
Requires:       texlive-faktor >= %{texlive_version}
#!BuildIgnore: texlive-faktor
Requires:       texlive-fascicules >= %{texlive_version}
#!BuildIgnore: texlive-fascicules
Requires:       texlive-fixdif >= %{texlive_version}
#!BuildIgnore: texlive-fixdif
Requires:       texlive-fixmath >= %{texlive_version}
#!BuildIgnore: texlive-fixmath
Requires:       texlive-fnspe >= %{texlive_version}
#!BuildIgnore: texlive-fnspe
Requires:       texlive-formal-grammar >= %{texlive_version}
#!BuildIgnore: texlive-formal-grammar
Requires:       texlive-fouridx >= %{texlive_version}
#!BuildIgnore: texlive-fouridx
Requires:       texlive-functan >= %{texlive_version}
#!BuildIgnore: texlive-functan
Requires:       texlive-galois >= %{texlive_version}
#!BuildIgnore: texlive-galois
Requires:       texlive-gastex >= %{texlive_version}
#!BuildIgnore: texlive-gastex
Requires:       texlive-gene-logic >= %{texlive_version}
#!BuildIgnore: texlive-gene-logic
Requires:       texlive-ghsystem >= %{texlive_version}
#!BuildIgnore: texlive-ghsystem
Requires:       texlive-glosmathtools >= %{texlive_version}
#!BuildIgnore: texlive-glosmathtools
Requires:       texlive-gotoh >= %{texlive_version}
#!BuildIgnore: texlive-gotoh
Requires:       texlive-grundgesetze >= %{texlive_version}
#!BuildIgnore: texlive-grundgesetze
Requires:       texlive-gu >= %{texlive_version}
#!BuildIgnore: texlive-gu
Requires:       texlive-helmholtz-ellis-ji-notation >= %{texlive_version}
#!BuildIgnore: texlive-helmholtz-ellis-ji-notation
Requires:       texlive-hep >= %{texlive_version}
#!BuildIgnore: texlive-hep
Requires:       texlive-hep-reference >= %{texlive_version}
#!BuildIgnore: texlive-hep-reference
Requires:       texlive-hepnames >= %{texlive_version}
#!BuildIgnore: texlive-hepnames
Requires:       texlive-hepparticles >= %{texlive_version}
#!BuildIgnore: texlive-hepparticles
Requires:       texlive-hepthesis >= %{texlive_version}
#!BuildIgnore: texlive-hepthesis
Requires:       texlive-hepunits >= %{texlive_version}
#!BuildIgnore: texlive-hepunits
Requires:       texlive-ibrackets >= %{texlive_version}
#!BuildIgnore: texlive-ibrackets
Requires:       texlive-includernw >= %{texlive_version}
#!BuildIgnore: texlive-includernw
Requires:       texlive-interval >= %{texlive_version}
#!BuildIgnore: texlive-interval
Requires:       texlive-ionumbers >= %{texlive_version}
#!BuildIgnore: texlive-ionumbers
Requires:       texlive-isomath >= %{texlive_version}
#!BuildIgnore: texlive-isomath
Requires:       texlive-jkmath >= %{texlive_version}
#!BuildIgnore: texlive-jkmath
Requires:       texlive-jupynotex >= %{texlive_version}
#!BuildIgnore: texlive-jupynotex
Requires:       texlive-karnaugh >= %{texlive_version}
#!BuildIgnore: texlive-karnaugh
Requires:       texlive-karnaugh-map >= %{texlive_version}
#!BuildIgnore: texlive-karnaugh-map
Requires:       texlive-karnaughmap >= %{texlive_version}
#!BuildIgnore: texlive-karnaughmap
Requires:       texlive-kvmap >= %{texlive_version}
#!BuildIgnore: texlive-kvmap
Requires:       texlive-letterswitharrows >= %{texlive_version}
#!BuildIgnore: texlive-letterswitharrows
Requires:       texlive-lie-hasse >= %{texlive_version}
#!BuildIgnore: texlive-lie-hasse
Requires:       texlive-logicproof >= %{texlive_version}
#!BuildIgnore: texlive-logicproof
Requires:       texlive-longdivision >= %{texlive_version}
#!BuildIgnore: texlive-longdivision
Requires:       texlive-lpform >= %{texlive_version}
#!BuildIgnore: texlive-lpform
Requires:       texlive-lplfitch >= %{texlive_version}
#!BuildIgnore: texlive-lplfitch
Requires:       texlive-lstbayes >= %{texlive_version}
#!BuildIgnore: texlive-lstbayes
Requires:       texlive-mathcommand >= %{texlive_version}
#!BuildIgnore: texlive-mathcommand
Requires:       texlive-mathcomp >= %{texlive_version}
#!BuildIgnore: texlive-mathcomp
Requires:       texlive-mathfixs >= %{texlive_version}
#!BuildIgnore: texlive-mathfixs
Requires:       texlive-mathlig >= %{texlive_version}
#!BuildIgnore: texlive-mathlig
Requires:       texlive-mathpartir >= %{texlive_version}
#!BuildIgnore: texlive-mathpartir
Requires:       texlive-mathpunctspace >= %{texlive_version}
#!BuildIgnore: texlive-mathpunctspace
Requires:       texlive-mathsemantics >= %{texlive_version}
#!BuildIgnore: texlive-mathsemantics
Requires:       texlive-matlab-prettifier >= %{texlive_version}
#!BuildIgnore: texlive-matlab-prettifier
Requires:       texlive-matrix-skeleton >= %{texlive_version}
#!BuildIgnore: texlive-matrix-skeleton
Requires:       texlive-mattens >= %{texlive_version}
#!BuildIgnore: texlive-mattens
Requires:       texlive-mecaso >= %{texlive_version}
#!BuildIgnore: texlive-mecaso
Requires:       texlive-membranecomputing >= %{texlive_version}
#!BuildIgnore: texlive-membranecomputing
Requires:       texlive-memorygraphs >= %{texlive_version}
#!BuildIgnore: texlive-memorygraphs
Requires:       texlive-messagepassing >= %{texlive_version}
#!BuildIgnore: texlive-messagepassing
Requires:       texlive-mgltex >= %{texlive_version}
#!BuildIgnore: texlive-mgltex
Requires:       texlive-mhchem >= %{texlive_version}
#!BuildIgnore: texlive-mhchem
Requires:       texlive-mhequ >= %{texlive_version}
#!BuildIgnore: texlive-mhequ
Requires:       texlive-miller >= %{texlive_version}
#!BuildIgnore: texlive-miller
Requires:       texlive-mismath >= %{texlive_version}
#!BuildIgnore: texlive-mismath
Requires:       texlive-multiobjective >= %{texlive_version}
#!BuildIgnore: texlive-multiobjective
Requires:       texlive-naive-ebnf >= %{texlive_version}
#!BuildIgnore: texlive-naive-ebnf
Requires:       texlive-namedtensor >= %{texlive_version}
#!BuildIgnore: texlive-namedtensor
Requires:       texlive-natded >= %{texlive_version}
#!BuildIgnore: texlive-natded
Requires:       texlive-nath >= %{texlive_version}
#!BuildIgnore: texlive-nath
Requires:       texlive-nchairx >= %{texlive_version}
#!BuildIgnore: texlive-nchairx
Requires:       texlive-nicematrix >= %{texlive_version}
#!BuildIgnore: texlive-nicematrix
Requires:       texlive-nuc >= %{texlive_version}
#!BuildIgnore: texlive-nuc
Requires:       texlive-nucleardata >= %{texlive_version}
#!BuildIgnore: texlive-nucleardata
Requires:       texlive-numerica >= %{texlive_version}
#!BuildIgnore: texlive-numerica
Requires:       texlive-numerica-plus >= %{texlive_version}
#!BuildIgnore: texlive-numerica-plus
Requires:       texlive-numerica-tables >= %{texlive_version}
#!BuildIgnore: texlive-numerica-tables
Requires:       texlive-objectz >= %{texlive_version}
#!BuildIgnore: texlive-objectz
Requires:       texlive-oplotsymbl >= %{texlive_version}
#!BuildIgnore: texlive-oplotsymbl
Requires:       texlive-ot-tableau >= %{texlive_version}
#!BuildIgnore: texlive-ot-tableau
Requires:       texlive-oubraces >= %{texlive_version}
#!BuildIgnore: texlive-oubraces
Requires:       texlive-overarrows >= %{texlive_version}
#!BuildIgnore: texlive-overarrows
Requires:       texlive-pascaltriangle >= %{texlive_version}
#!BuildIgnore: texlive-pascaltriangle
Requires:       texlive-perfectcut >= %{texlive_version}
#!BuildIgnore: texlive-perfectcut
Requires:       texlive-pfdicons >= %{texlive_version}
#!BuildIgnore: texlive-pfdicons
Requires:       texlive-physconst >= %{texlive_version}
#!BuildIgnore: texlive-physconst
Requires:       texlive-physics >= %{texlive_version}
#!BuildIgnore: texlive-physics
Requires:       texlive-physics2 >= %{texlive_version}
#!BuildIgnore: texlive-physics2
Requires:       texlive-physunits >= %{texlive_version}
#!BuildIgnore: texlive-physunits
Requires:       texlive-pinoutikz >= %{texlive_version}
#!BuildIgnore: texlive-pinoutikz
Requires:       texlive-pm-isomath >= %{texlive_version}
#!BuildIgnore: texlive-pm-isomath
Requires:       texlive-polexpr >= %{texlive_version}
#!BuildIgnore: texlive-polexpr
Requires:       texlive-prftree >= %{texlive_version}
#!BuildIgnore: texlive-prftree
Requires:       texlive-principia >= %{texlive_version}
#!BuildIgnore: texlive-principia
Requires:       texlive-proba >= %{texlive_version}
#!BuildIgnore: texlive-proba
Requires:       texlive-proof-at-the-end >= %{texlive_version}
#!BuildIgnore: texlive-proof-at-the-end
Requires:       texlive-prooftrees >= %{texlive_version}
#!BuildIgnore: texlive-prooftrees
Requires:       texlive-pseudo >= %{texlive_version}
#!BuildIgnore: texlive-pseudo
Requires:       texlive-pseudocode >= %{texlive_version}
#!BuildIgnore: texlive-pseudocode
Requires:       texlive-pythonhighlight >= %{texlive_version}
#!BuildIgnore: texlive-pythonhighlight
Requires:       texlive-qsharp >= %{texlive_version}
#!BuildIgnore: texlive-qsharp
Requires:       texlive-rank-2-roots >= %{texlive_version}
#!BuildIgnore: texlive-rank-2-roots
Requires:       texlive-rbt-mathnotes >= %{texlive_version}
#!BuildIgnore: texlive-rbt-mathnotes
Requires:       texlive-rec-thy >= %{texlive_version}
#!BuildIgnore: texlive-rec-thy
Requires:       texlive-resolsysteme >= %{texlive_version}
#!BuildIgnore: texlive-resolsysteme
Requires:       texlive-rest-api >= %{texlive_version}
#!BuildIgnore: texlive-rest-api
Requires:       texlive-revquantum >= %{texlive_version}
#!BuildIgnore: texlive-revquantum
Requires:       texlive-ribbonproofs >= %{texlive_version}
#!BuildIgnore: texlive-ribbonproofs
Requires:       texlive-rmathbr >= %{texlive_version}
#!BuildIgnore: texlive-rmathbr
Requires:       texlive-sankey >= %{texlive_version}
#!BuildIgnore: texlive-sankey
Requires:       texlive-sasnrdisplay >= %{texlive_version}
#!BuildIgnore: texlive-sasnrdisplay
Requires:       texlive-sciposter >= %{texlive_version}
#!BuildIgnore: texlive-sciposter
Requires:       texlive-sclang-prettifier >= %{texlive_version}
#!BuildIgnore: texlive-sclang-prettifier
Requires:       texlive-scratchx >= %{texlive_version}
#!BuildIgnore: texlive-scratchx
Requires:       texlive-sesamanuel >= %{texlive_version}
#!BuildIgnore: texlive-sesamanuel
Requires:       texlive-sfg >= %{texlive_version}
#!BuildIgnore: texlive-sfg
Requires:       texlive-shuffle >= %{texlive_version}
#!BuildIgnore: texlive-shuffle
Requires:       texlive-simplebnf >= %{texlive_version}
#!BuildIgnore: texlive-simplebnf
Requires:       texlive-simpler-wick >= %{texlive_version}
#!BuildIgnore: texlive-simpler-wick
Requires:       texlive-simples-matrices >= %{texlive_version}
#!BuildIgnore: texlive-simples-matrices
Requires:       texlive-simplewick >= %{texlive_version}
#!BuildIgnore: texlive-simplewick
Requires:       texlive-sistyle >= %{texlive_version}
#!BuildIgnore: texlive-sistyle
Requires:       texlive-siunits >= %{texlive_version}
#!BuildIgnore: texlive-siunits
Requires:       texlive-siunitx >= %{texlive_version}
#!BuildIgnore: texlive-siunitx
Requires:       texlive-skmath >= %{texlive_version}
#!BuildIgnore: texlive-skmath
Requires:       texlive-spalign >= %{texlive_version}
#!BuildIgnore: texlive-spalign
Requires:       texlive-spbmark >= %{texlive_version}
#!BuildIgnore: texlive-spbmark
Requires:       texlive-stanli >= %{texlive_version}
#!BuildIgnore: texlive-stanli
Requires:       texlive-statex >= %{texlive_version}
#!BuildIgnore: texlive-statex
Requires:       texlive-statex2 >= %{texlive_version}
#!BuildIgnore: texlive-statex2
Requires:       texlive-statistics >= %{texlive_version}
#!BuildIgnore: texlive-statistics
Requires:       texlive-statistik >= %{texlive_version}
#!BuildIgnore: texlive-statistik
Requires:       texlive-statmath >= %{texlive_version}
#!BuildIgnore: texlive-statmath
Requires:       texlive-steinmetz >= %{texlive_version}
#!BuildIgnore: texlive-steinmetz
Requires:       texlive-stmaryrd >= %{texlive_version}
#!BuildIgnore: texlive-stmaryrd
Requires:       texlive-structmech >= %{texlive_version}
#!BuildIgnore: texlive-structmech
Requires:       texlive-struktex >= %{texlive_version}
#!BuildIgnore: texlive-struktex
Requires:       texlive-substances >= %{texlive_version}
#!BuildIgnore: texlive-substances
Requires:       texlive-subsupscripts >= %{texlive_version}
#!BuildIgnore: texlive-subsupscripts
Requires:       texlive-subtext >= %{texlive_version}
#!BuildIgnore: texlive-subtext
Requires:       texlive-susy >= %{texlive_version}
#!BuildIgnore: texlive-susy
Requires:       texlive-syllogism >= %{texlive_version}
#!BuildIgnore: texlive-syllogism
Requires:       texlive-synproof >= %{texlive_version}
#!BuildIgnore: texlive-synproof
Requires:       texlive-t-angles >= %{texlive_version}
#!BuildIgnore: texlive-t-angles
Requires:       texlive-tablor >= %{texlive_version}
#!BuildIgnore: texlive-tablor
Requires:       texlive-tensind >= %{texlive_version}
#!BuildIgnore: texlive-tensind
Requires:       texlive-tensor >= %{texlive_version}
#!BuildIgnore: texlive-tensor
Requires:       texlive-tex-ewd >= %{texlive_version}
#!BuildIgnore: texlive-tex-ewd
Requires:       texlive-textgreek >= %{texlive_version}
#!BuildIgnore: texlive-textgreek
Requires:       texlive-textopo >= %{texlive_version}
#!BuildIgnore: texlive-textopo
Requires:       texlive-thermodynamics >= %{texlive_version}
#!BuildIgnore: texlive-thermodynamics
Requires:       texlive-thmbox >= %{texlive_version}
#!BuildIgnore: texlive-thmbox
Requires:       texlive-tiscreen >= %{texlive_version}
#!BuildIgnore: texlive-tiscreen
Requires:       texlive-turnstile >= %{texlive_version}
#!BuildIgnore: texlive-turnstile
Requires:       texlive-ulqda >= %{texlive_version}
#!BuildIgnore: texlive-ulqda
Requires:       texlive-unitsdef >= %{texlive_version}
#!BuildIgnore: texlive-unitsdef
Requires:       texlive-venn >= %{texlive_version}
#!BuildIgnore: texlive-venn
Requires:       texlive-witharrows >= %{texlive_version}
#!BuildIgnore: texlive-witharrows
Requires:       texlive-xymtex >= %{texlive_version}
#!BuildIgnore: texlive-xymtex
Requires:       texlive-yhmath >= %{texlive_version}
#!BuildIgnore: texlive-yhmath
Requires:       texlive-youngtab >= %{texlive_version}
#!BuildIgnore: texlive-youngtab
Requires:       texlive-yquant >= %{texlive_version}
#!BuildIgnore: texlive-yquant
Requires:       texlive-ytableau >= %{texlive_version}
#!BuildIgnore: texlive-ytableau
Requires:       texlive-zx-calculus >= %{texlive_version}
#!BuildIgnore: texlive-zx-calculus
BuildArch:      noarch

%description -n texlive-collection-mathscience
The collection-mathscience package

%package -n texlive-collection-metapost
Version:        %{texlive_version}.%{texlive_noarch}.svn64878
Release:        60.1
License:        LPPL-1.0
Summary:        MetaPost and Metafont packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-metapost <= %{texlive_previous}
Requires:       texlive-automata >= %{texlive_version}
#!BuildIgnore: texlive-automata
Requires:       texlive-bbcard >= %{texlive_version}
#!BuildIgnore: texlive-bbcard
Requires:       texlive-blockdraw_mp >= %{texlive_version}
#!BuildIgnore: texlive-blockdraw_mp
Requires:       texlive-bpolynomial >= %{texlive_version}
#!BuildIgnore: texlive-bpolynomial
Requires:       texlive-cmarrows >= %{texlive_version}
#!BuildIgnore: texlive-cmarrows
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-drv >= %{texlive_version}
#!BuildIgnore: texlive-drv
Requires:       texlive-dviincl >= %{texlive_version}
#!BuildIgnore: texlive-dviincl
Requires:       texlive-emp >= %{texlive_version}
#!BuildIgnore: texlive-emp
Requires:       texlive-epsincl >= %{texlive_version}
#!BuildIgnore: texlive-epsincl
Requires:       texlive-expressg >= %{texlive_version}
#!BuildIgnore: texlive-expressg
Requires:       texlive-exteps >= %{texlive_version}
#!BuildIgnore: texlive-exteps
Requires:       texlive-featpost >= %{texlive_version}
#!BuildIgnore: texlive-featpost
Requires:       texlive-feynmf >= %{texlive_version}
#!BuildIgnore: texlive-feynmf
Requires:       texlive-feynmp-auto >= %{texlive_version}
#!BuildIgnore: texlive-feynmp-auto
Requires:       texlive-fiziko >= %{texlive_version}
#!BuildIgnore: texlive-fiziko
Requires:       texlive-garrigues >= %{texlive_version}
#!BuildIgnore: texlive-garrigues
Requires:       texlive-gmp >= %{texlive_version}
#!BuildIgnore: texlive-gmp
Requires:       texlive-hatching >= %{texlive_version}
#!BuildIgnore: texlive-hatching
Requires:       texlive-hershey-mp >= %{texlive_version}
#!BuildIgnore: texlive-hershey-mp
Requires:       texlive-latexmp >= %{texlive_version}
#!BuildIgnore: texlive-latexmp
Requires:       texlive-mcf2graph >= %{texlive_version}
#!BuildIgnore: texlive-mcf2graph
Requires:       texlive-metago >= %{texlive_version}
#!BuildIgnore: texlive-metago
Requires:       texlive-metaobj >= %{texlive_version}
#!BuildIgnore: texlive-metaobj
Requires:       texlive-metaplot >= %{texlive_version}
#!BuildIgnore: texlive-metaplot
Requires:       texlive-metapost >= %{texlive_version}
#!BuildIgnore: texlive-metapost
Requires:       texlive-metapost-colorbrewer >= %{texlive_version}
#!BuildIgnore: texlive-metapost-colorbrewer
Requires:       texlive-metauml >= %{texlive_version}
#!BuildIgnore: texlive-metauml
Requires:       texlive-mfpic >= %{texlive_version}
#!BuildIgnore: texlive-mfpic
Requires:       texlive-mfpic4ode >= %{texlive_version}
#!BuildIgnore: texlive-mfpic4ode
Requires:       texlive-minim-hatching >= %{texlive_version}
#!BuildIgnore: texlive-minim-hatching
Requires:       texlive-mp3d >= %{texlive_version}
#!BuildIgnore: texlive-mp3d
Requires:       texlive-mparrows >= %{texlive_version}
#!BuildIgnore: texlive-mparrows
Requires:       texlive-mpattern >= %{texlive_version}
#!BuildIgnore: texlive-mpattern
Requires:       texlive-mpcolornames >= %{texlive_version}
#!BuildIgnore: texlive-mpcolornames
Requires:       texlive-mpgraphics >= %{texlive_version}
#!BuildIgnore: texlive-mpgraphics
Requires:       texlive-mptrees >= %{texlive_version}
#!BuildIgnore: texlive-mptrees
Requires:       texlive-piechartmp >= %{texlive_version}
#!BuildIgnore: texlive-piechartmp
Requires:       texlive-repere >= %{texlive_version}
#!BuildIgnore: texlive-repere
Requires:       texlive-roex >= %{texlive_version}
#!BuildIgnore: texlive-roex
Requires:       texlive-roundrect >= %{texlive_version}
#!BuildIgnore: texlive-roundrect
Requires:       texlive-shapes >= %{texlive_version}
#!BuildIgnore: texlive-shapes
Requires:       texlive-slideshow >= %{texlive_version}
#!BuildIgnore: texlive-slideshow
Requires:       texlive-splines >= %{texlive_version}
#!BuildIgnore: texlive-splines
Requires:       texlive-suanpan >= %{texlive_version}
#!BuildIgnore: texlive-suanpan
Requires:       texlive-textpath >= %{texlive_version}
#!BuildIgnore: texlive-textpath
Requires:       texlive-threeddice >= %{texlive_version}
#!BuildIgnore: texlive-threeddice
Provides:       tex(metapost)
BuildArch:      noarch

%description -n texlive-collection-metapost
The collection-metapost package

%package -n texlive-collection-music
Version:        %{texlive_version}.%{texlive_noarch}.svn65862
Release:        60.1
License:        LPPL-1.0
Summary:        Music packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-musictex <= %{texlive_previous}
Requires:       texlive-abc >= %{texlive_version}
#!BuildIgnore: texlive-abc
Requires:       texlive-autosp >= %{texlive_version}
#!BuildIgnore: texlive-autosp
Requires:       texlive-bagpipe >= %{texlive_version}
#!BuildIgnore: texlive-bagpipe
Requires:       texlive-chordbars >= %{texlive_version}
#!BuildIgnore: texlive-chordbars
Requires:       texlive-chordbox >= %{texlive_version}
#!BuildIgnore: texlive-chordbox
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-ddphonism >= %{texlive_version}
#!BuildIgnore: texlive-ddphonism
Requires:       texlive-figbas >= %{texlive_version}
#!BuildIgnore: texlive-figbas
Requires:       texlive-gchords >= %{texlive_version}
#!BuildIgnore: texlive-gchords
Requires:       texlive-gregoriotex >= %{texlive_version}
#!BuildIgnore: texlive-gregoriotex
Requires:       texlive-gtrcrd >= %{texlive_version}
#!BuildIgnore: texlive-gtrcrd
Requires:       texlive-guitar >= %{texlive_version}
#!BuildIgnore: texlive-guitar
Requires:       texlive-guitarchordschemes >= %{texlive_version}
#!BuildIgnore: texlive-guitarchordschemes
Requires:       texlive-guitartabs >= %{texlive_version}
#!BuildIgnore: texlive-guitartabs
Requires:       texlive-harmony >= %{texlive_version}
#!BuildIgnore: texlive-harmony
Requires:       texlive-latex4musicians >= %{texlive_version}
#!BuildIgnore: texlive-latex4musicians
Requires:       texlive-leadsheets >= %{texlive_version}
#!BuildIgnore: texlive-leadsheets
Requires:       texlive-lilyglyphs >= %{texlive_version}
#!BuildIgnore: texlive-lilyglyphs
Requires:       texlive-lyluatex >= %{texlive_version}
#!BuildIgnore: texlive-lyluatex
Requires:       texlive-m-tx >= %{texlive_version}
#!BuildIgnore: texlive-m-tx
Requires:       texlive-musical >= %{texlive_version}
#!BuildIgnore: texlive-musical
Requires:       texlive-musicography >= %{texlive_version}
#!BuildIgnore: texlive-musicography
Requires:       texlive-musixguit >= %{texlive_version}
#!BuildIgnore: texlive-musixguit
Requires:       texlive-musixtex >= %{texlive_version}
#!BuildIgnore: texlive-musixtex
Requires:       texlive-musixtex-fonts >= %{texlive_version}
#!BuildIgnore: texlive-musixtex-fonts
Requires:       texlive-musixtnt >= %{texlive_version}
#!BuildIgnore: texlive-musixtnt
Requires:       texlive-octave >= %{texlive_version}
#!BuildIgnore: texlive-octave
Requires:       texlive-piano >= %{texlive_version}
#!BuildIgnore: texlive-piano
Requires:       texlive-pmx >= %{texlive_version}
#!BuildIgnore: texlive-pmx
Requires:       texlive-pmxchords >= %{texlive_version}
#!BuildIgnore: texlive-pmxchords
Requires:       texlive-recorder-fingering >= %{texlive_version}
#!BuildIgnore: texlive-recorder-fingering
Requires:       texlive-songbook >= %{texlive_version}
#!BuildIgnore: texlive-songbook
Requires:       texlive-songproj >= %{texlive_version}
#!BuildIgnore: texlive-songproj
Requires:       texlive-songs >= %{texlive_version}
#!BuildIgnore: texlive-songs
Requires:       texlive-xml2pmx >= %{texlive_version}
#!BuildIgnore: texlive-xml2pmx
Requires:       texlive-xpiano >= %{texlive_version}
#!BuildIgnore: texlive-xpiano
Provides:       tex(music)
BuildArch:      noarch

%description -n texlive-collection-music
Music-related fonts and packages.

%package -n texlive-collection-pictures
Version:        %{texlive_version}.%{texlive_noarch}.svn66360
Release:        60.1
License:        LPPL-1.0
Summary:        Graphics, pictures, diagrams
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-adigraph >= %{texlive_version}
#!BuildIgnore: texlive-adigraph
Requires:       texlive-aobs-tikz >= %{texlive_version}
#!BuildIgnore: texlive-aobs-tikz
Requires:       texlive-askmaps >= %{texlive_version}
#!BuildIgnore: texlive-askmaps
Requires:       texlive-asyfig >= %{texlive_version}
#!BuildIgnore: texlive-asyfig
Requires:       texlive-asypictureb >= %{texlive_version}
#!BuildIgnore: texlive-asypictureb
Requires:       texlive-autoarea >= %{texlive_version}
#!BuildIgnore: texlive-autoarea
Requires:       texlive-bardiag >= %{texlive_version}
#!BuildIgnore: texlive-bardiag
Requires:       texlive-beamerswitch >= %{texlive_version}
#!BuildIgnore: texlive-beamerswitch
Requires:       texlive-binarytree >= %{texlive_version}
#!BuildIgnore: texlive-binarytree
Requires:       texlive-blochsphere >= %{texlive_version}
#!BuildIgnore: texlive-blochsphere
Requires:       texlive-bloques >= %{texlive_version}
#!BuildIgnore: texlive-bloques
Requires:       texlive-blox >= %{texlive_version}
#!BuildIgnore: texlive-blox
Requires:       texlive-bodegraph >= %{texlive_version}
#!BuildIgnore: texlive-bodegraph
Requires:       texlive-bondgraph >= %{texlive_version}
#!BuildIgnore: texlive-bondgraph
Requires:       texlive-bondgraphs >= %{texlive_version}
#!BuildIgnore: texlive-bondgraphs
Requires:       texlive-braids >= %{texlive_version}
#!BuildIgnore: texlive-braids
Requires:       texlive-bxeepic >= %{texlive_version}
#!BuildIgnore: texlive-bxeepic
Requires:       texlive-byo-twemojis >= %{texlive_version}
#!BuildIgnore: texlive-byo-twemojis
Requires:       texlive-byrne >= %{texlive_version}
#!BuildIgnore: texlive-byrne
Requires:       texlive-cachepic >= %{texlive_version}
#!BuildIgnore: texlive-cachepic
Requires:       texlive-callouts >= %{texlive_version}
#!BuildIgnore: texlive-callouts
Requires:       texlive-celtic >= %{texlive_version}
#!BuildIgnore: texlive-celtic
Requires:       texlive-chemfig >= %{texlive_version}
#!BuildIgnore: texlive-chemfig
Requires:       texlive-circuit-macros >= %{texlive_version}
#!BuildIgnore: texlive-circuit-macros
Requires:       texlive-circuitikz >= %{texlive_version}
#!BuildIgnore: texlive-circuitikz
Requires:       texlive-coffeestains >= %{texlive_version}
#!BuildIgnore: texlive-coffeestains
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-combinedgraphics >= %{texlive_version}
#!BuildIgnore: texlive-combinedgraphics
Requires:       texlive-curve >= %{texlive_version}
#!BuildIgnore: texlive-curve
Requires:       texlive-curve2e >= %{texlive_version}
#!BuildIgnore: texlive-curve2e
Requires:       texlive-curves >= %{texlive_version}
#!BuildIgnore: texlive-curves
Requires:       texlive-dcpic >= %{texlive_version}
#!BuildIgnore: texlive-dcpic
Requires:       texlive-diagmac2 >= %{texlive_version}
#!BuildIgnore: texlive-diagmac2
Requires:       texlive-ditaa >= %{texlive_version}
#!BuildIgnore: texlive-ditaa
Requires:       texlive-doc-pictex >= %{texlive_version}
#!BuildIgnore: texlive-doc-pictex
Requires:       texlive-dot2texi >= %{texlive_version}
#!BuildIgnore: texlive-dot2texi
Requires:       texlive-dottex >= %{texlive_version}
#!BuildIgnore: texlive-dottex
Requires:       texlive-dpcircling >= %{texlive_version}
#!BuildIgnore: texlive-dpcircling
Requires:       texlive-dratex >= %{texlive_version}
#!BuildIgnore: texlive-dratex
Requires:       texlive-drs >= %{texlive_version}
#!BuildIgnore: texlive-drs
Requires:       texlive-duotenzor >= %{texlive_version}
#!BuildIgnore: texlive-duotenzor
Requires:       texlive-dynkin-diagrams >= %{texlive_version}
#!BuildIgnore: texlive-dynkin-diagrams
Requires:       texlive-ecgdraw >= %{texlive_version}
#!BuildIgnore: texlive-ecgdraw
Requires:       texlive-eepic >= %{texlive_version}
#!BuildIgnore: texlive-eepic
Requires:       texlive-ellipse >= %{texlive_version}
#!BuildIgnore: texlive-ellipse
Requires:       texlive-endofproofwd >= %{texlive_version}
#!BuildIgnore: texlive-endofproofwd
Requires:       texlive-epspdf >= %{texlive_version}
#!BuildIgnore: texlive-epspdf
Requires:       texlive-epspdfconversion >= %{texlive_version}
#!BuildIgnore: texlive-epspdfconversion
Requires:       texlive-esk >= %{texlive_version}
#!BuildIgnore: texlive-esk
Requires:       texlive-euflag >= %{texlive_version}
#!BuildIgnore: texlive-euflag
Requires:       texlive-fast-diagram >= %{texlive_version}
#!BuildIgnore: texlive-fast-diagram
Requires:       texlive-fig4latex >= %{texlive_version}
#!BuildIgnore: texlive-fig4latex
Requires:       texlive-figchild >= %{texlive_version}
#!BuildIgnore: texlive-figchild
Requires:       texlive-figput >= %{texlive_version}
#!BuildIgnore: texlive-figput
Requires:       texlive-fitbox >= %{texlive_version}
#!BuildIgnore: texlive-fitbox
Requires:       texlive-flowchart >= %{texlive_version}
#!BuildIgnore: texlive-flowchart
Requires:       texlive-forest >= %{texlive_version}
#!BuildIgnore: texlive-forest
Requires:       texlive-genealogytree >= %{texlive_version}
#!BuildIgnore: texlive-genealogytree
Requires:       texlive-getmap >= %{texlive_version}
#!BuildIgnore: texlive-getmap
Requires:       texlive-gincltex >= %{texlive_version}
#!BuildIgnore: texlive-gincltex
Requires:       texlive-gnuplottex >= %{texlive_version}
#!BuildIgnore: texlive-gnuplottex
Requires:       texlive-gradientframe >= %{texlive_version}
#!BuildIgnore: texlive-gradientframe
Requires:       texlive-grafcet >= %{texlive_version}
#!BuildIgnore: texlive-grafcet
Requires:       texlive-graph35 >= %{texlive_version}
#!BuildIgnore: texlive-graph35
Requires:       texlive-graphicxpsd >= %{texlive_version}
#!BuildIgnore: texlive-graphicxpsd
Requires:       texlive-graphviz >= %{texlive_version}
#!BuildIgnore: texlive-graphviz
Requires:       texlive-gtrlib-largetrees >= %{texlive_version}
#!BuildIgnore: texlive-gtrlib-largetrees
Requires:       texlive-harveyballs >= %{texlive_version}
#!BuildIgnore: texlive-harveyballs
Requires:       texlive-here >= %{texlive_version}
#!BuildIgnore: texlive-here
Requires:       texlive-hf-tikz >= %{texlive_version}
#!BuildIgnore: texlive-hf-tikz
Requires:       texlive-hobby >= %{texlive_version}
#!BuildIgnore: texlive-hobby
Requires:       texlive-hvfloat >= %{texlive_version}
#!BuildIgnore: texlive-hvfloat
Requires:       texlive-istgame >= %{texlive_version}
#!BuildIgnore: texlive-istgame
Requires:       texlive-kblocks >= %{texlive_version}
#!BuildIgnore: texlive-kblocks
Requires:       texlive-kinematikz >= %{texlive_version}
#!BuildIgnore: texlive-kinematikz
Requires:       texlive-knitting >= %{texlive_version}
#!BuildIgnore: texlive-knitting
Requires:       texlive-knittingpattern >= %{texlive_version}
#!BuildIgnore: texlive-knittingpattern
Requires:       texlive-ladder >= %{texlive_version}
#!BuildIgnore: texlive-ladder
Requires:       texlive-lapdf >= %{texlive_version}
#!BuildIgnore: texlive-lapdf
Requires:       texlive-latex-make >= %{texlive_version}
#!BuildIgnore: texlive-latex-make
Requires:       texlive-liftarm >= %{texlive_version}
#!BuildIgnore: texlive-liftarm
Requires:       texlive-lpic >= %{texlive_version}
#!BuildIgnore: texlive-lpic
Requires:       texlive-lroundrect >= %{texlive_version}
#!BuildIgnore: texlive-lroundrect
Requires:       texlive-luamesh >= %{texlive_version}
#!BuildIgnore: texlive-luamesh
Requires:       texlive-luasseq >= %{texlive_version}
#!BuildIgnore: texlive-luasseq
Requires:       texlive-maker >= %{texlive_version}
#!BuildIgnore: texlive-maker
Requires:       texlive-makeshape >= %{texlive_version}
#!BuildIgnore: texlive-makeshape
Requires:       texlive-mathspic >= %{texlive_version}
#!BuildIgnore: texlive-mathspic
Requires:       texlive-mercatormap >= %{texlive_version}
#!BuildIgnore: texlive-mercatormap
Requires:       texlive-milsymb >= %{texlive_version}
#!BuildIgnore: texlive-milsymb
Requires:       texlive-miniplot >= %{texlive_version}
#!BuildIgnore: texlive-miniplot
Requires:       texlive-mkpic >= %{texlive_version}
#!BuildIgnore: texlive-mkpic
Requires:       texlive-modiagram >= %{texlive_version}
#!BuildIgnore: texlive-modiagram
Requires:       texlive-neuralnetwork >= %{texlive_version}
#!BuildIgnore: texlive-neuralnetwork
Requires:       texlive-nl-interval >= %{texlive_version}
#!BuildIgnore: texlive-nl-interval
Requires:       texlive-nndraw >= %{texlive_version}
#!BuildIgnore: texlive-nndraw
Requires:       texlive-numericplots >= %{texlive_version}
#!BuildIgnore: texlive-numericplots
Requires:       texlive-outilsgeomtikz >= %{texlive_version}
#!BuildIgnore: texlive-outilsgeomtikz
Requires:       texlive-pb-diagram >= %{texlive_version}
#!BuildIgnore: texlive-pb-diagram
Requires:       texlive-penrose >= %{texlive_version}
#!BuildIgnore: texlive-penrose
Requires:       texlive-petri-nets >= %{texlive_version}
#!BuildIgnore: texlive-petri-nets
Requires:       texlive-pgf >= %{texlive_version}
#!BuildIgnore: texlive-pgf
Requires:       texlive-pgf-blur >= %{texlive_version}
#!BuildIgnore: texlive-pgf-blur
Requires:       texlive-pgf-interference >= %{texlive_version}
#!BuildIgnore: texlive-pgf-interference
Requires:       texlive-pgf-periodictable >= %{texlive_version}
#!BuildIgnore: texlive-pgf-periodictable
Requires:       texlive-pgf-pie >= %{texlive_version}
#!BuildIgnore: texlive-pgf-pie
Requires:       texlive-pgf-soroban >= %{texlive_version}
#!BuildIgnore: texlive-pgf-soroban
Requires:       texlive-pgf-spectra >= %{texlive_version}
#!BuildIgnore: texlive-pgf-spectra
Requires:       texlive-pgf-umlcd >= %{texlive_version}
#!BuildIgnore: texlive-pgf-umlcd
Requires:       texlive-pgf-umlsd >= %{texlive_version}
#!BuildIgnore: texlive-pgf-umlsd
Requires:       texlive-pgfgantt >= %{texlive_version}
#!BuildIgnore: texlive-pgfgantt
Requires:       texlive-pgfkeyx >= %{texlive_version}
#!BuildIgnore: texlive-pgfkeyx
Requires:       texlive-pgfmolbio >= %{texlive_version}
#!BuildIgnore: texlive-pgfmolbio
Requires:       texlive-pgfmorepages >= %{texlive_version}
#!BuildIgnore: texlive-pgfmorepages
Requires:       texlive-pgfopts >= %{texlive_version}
#!BuildIgnore: texlive-pgfopts
Requires:       texlive-pgfornament >= %{texlive_version}
#!BuildIgnore: texlive-pgfornament
Requires:       texlive-pgfplots >= %{texlive_version}
#!BuildIgnore: texlive-pgfplots
Requires:       texlive-picinpar >= %{texlive_version}
#!BuildIgnore: texlive-picinpar
Requires:       texlive-pict2e >= %{texlive_version}
#!BuildIgnore: texlive-pict2e
Requires:       texlive-pictex >= %{texlive_version}
#!BuildIgnore: texlive-pictex
Requires:       texlive-pictex2 >= %{texlive_version}
#!BuildIgnore: texlive-pictex2
Requires:       texlive-pinlabel >= %{texlive_version}
#!BuildIgnore: texlive-pinlabel
Requires:       texlive-pixelart >= %{texlive_version}
#!BuildIgnore: texlive-pixelart
Requires:       texlive-pixelarttikz >= %{texlive_version}
#!BuildIgnore: texlive-pixelarttikz
Requires:       texlive-pmgraph >= %{texlive_version}
#!BuildIgnore: texlive-pmgraph
Requires:       texlive-postage >= %{texlive_version}
#!BuildIgnore: texlive-postage
Requires:       texlive-prerex >= %{texlive_version}
#!BuildIgnore: texlive-prerex
Requires:       texlive-productbox >= %{texlive_version}
#!BuildIgnore: texlive-productbox
Requires:       texlive-ptolemaicastronomy >= %{texlive_version}
#!BuildIgnore: texlive-ptolemaicastronomy
Requires:       texlive-puyotikz >= %{texlive_version}
#!BuildIgnore: texlive-puyotikz
Requires:       texlive-pxpgfmark >= %{texlive_version}
#!BuildIgnore: texlive-pxpgfmark
Requires:       texlive-pxpic >= %{texlive_version}
#!BuildIgnore: texlive-pxpic
Requires:       texlive-qcircuit >= %{texlive_version}
#!BuildIgnore: texlive-qcircuit
Requires:       texlive-qrcode >= %{texlive_version}
#!BuildIgnore: texlive-qrcode
Requires:       texlive-quantikz >= %{texlive_version}
#!BuildIgnore: texlive-quantikz
Requires:       texlive-randbild >= %{texlive_version}
#!BuildIgnore: texlive-randbild
Requires:       texlive-randomwalk >= %{texlive_version}
#!BuildIgnore: texlive-randomwalk
Requires:       texlive-realhats >= %{texlive_version}
#!BuildIgnore: texlive-realhats
Requires:       texlive-reotex >= %{texlive_version}
#!BuildIgnore: texlive-reotex
Requires:       texlive-robotarm >= %{texlive_version}
#!BuildIgnore: texlive-robotarm
Requires:       texlive-rviewport >= %{texlive_version}
#!BuildIgnore: texlive-rviewport
Requires:       texlive-sa-tikz >= %{texlive_version}
#!BuildIgnore: texlive-sa-tikz
Requires:       texlive-sacsymb >= %{texlive_version}
#!BuildIgnore: texlive-sacsymb
Requires:       texlive-schemabloc >= %{texlive_version}
#!BuildIgnore: texlive-schemabloc
Requires:       texlive-scratch >= %{texlive_version}
#!BuildIgnore: texlive-scratch
Requires:       texlive-scratch3 >= %{texlive_version}
#!BuildIgnore: texlive-scratch3
Requires:       texlive-scsnowman >= %{texlive_version}
#!BuildIgnore: texlive-scsnowman
Requires:       texlive-setdeck >= %{texlive_version}
#!BuildIgnore: texlive-setdeck
Requires:       texlive-signchart >= %{texlive_version}
#!BuildIgnore: texlive-signchart
Requires:       texlive-simplenodes >= %{texlive_version}
#!BuildIgnore: texlive-simplenodes
Requires:       texlive-simpleoptics >= %{texlive_version}
#!BuildIgnore: texlive-simpleoptics
Requires:       texlive-smartdiagram >= %{texlive_version}
#!BuildIgnore: texlive-smartdiagram
Requires:       texlive-spath3 >= %{texlive_version}
#!BuildIgnore: texlive-spath3
Requires:       texlive-spectralsequences >= %{texlive_version}
#!BuildIgnore: texlive-spectralsequences
Requires:       texlive-strands >= %{texlive_version}
#!BuildIgnore: texlive-strands
Requires:       texlive-swimgraf >= %{texlive_version}
#!BuildIgnore: texlive-swimgraf
Requires:       texlive-syntaxdi >= %{texlive_version}
#!BuildIgnore: texlive-syntaxdi
Requires:       texlive-table-fct >= %{texlive_version}
#!BuildIgnore: texlive-table-fct
Requires:       texlive-texdraw >= %{texlive_version}
#!BuildIgnore: texlive-texdraw
Requires:       texlive-ticollege >= %{texlive_version}
#!BuildIgnore: texlive-ticollege
Requires:       texlive-tikz-3dplot >= %{texlive_version}
#!BuildIgnore: texlive-tikz-3dplot
Requires:       texlive-tikz-among-us >= %{texlive_version}
#!BuildIgnore: texlive-tikz-among-us
Requires:       texlive-tikz-bagua >= %{texlive_version}
#!BuildIgnore: texlive-tikz-bagua
Requires:       texlive-tikz-bayesnet >= %{texlive_version}
#!BuildIgnore: texlive-tikz-bayesnet
Requires:       texlive-tikz-bbox >= %{texlive_version}
#!BuildIgnore: texlive-tikz-bbox
Requires:       texlive-tikz-cd >= %{texlive_version}
#!BuildIgnore: texlive-tikz-cd
Requires:       texlive-tikz-dependency >= %{texlive_version}
#!BuildIgnore: texlive-tikz-dependency
Requires:       texlive-tikz-dimline >= %{texlive_version}
#!BuildIgnore: texlive-tikz-dimline
Requires:       texlive-tikz-ext >= %{texlive_version}
#!BuildIgnore: texlive-tikz-ext
Requires:       texlive-tikz-feynhand >= %{texlive_version}
#!BuildIgnore: texlive-tikz-feynhand
Requires:       texlive-tikz-feynman >= %{texlive_version}
#!BuildIgnore: texlive-tikz-feynman
Requires:       texlive-tikz-imagelabels >= %{texlive_version}
#!BuildIgnore: texlive-tikz-imagelabels
Requires:       texlive-tikz-inet >= %{texlive_version}
#!BuildIgnore: texlive-tikz-inet
Requires:       texlive-tikz-kalender >= %{texlive_version}
#!BuildIgnore: texlive-tikz-kalender
Requires:       texlive-tikz-karnaugh >= %{texlive_version}
#!BuildIgnore: texlive-tikz-karnaugh
Requires:       texlive-tikz-ladder >= %{texlive_version}
#!BuildIgnore: texlive-tikz-ladder
Requires:       texlive-tikz-lake-fig >= %{texlive_version}
#!BuildIgnore: texlive-tikz-lake-fig
Requires:       texlive-tikz-layers >= %{texlive_version}
#!BuildIgnore: texlive-tikz-layers
Requires:       texlive-tikz-mirror-lens >= %{texlive_version}
#!BuildIgnore: texlive-tikz-mirror-lens
Requires:       texlive-tikz-nef >= %{texlive_version}
#!BuildIgnore: texlive-tikz-nef
Requires:       texlive-tikz-network >= %{texlive_version}
#!BuildIgnore: texlive-tikz-network
Requires:       texlive-tikz-opm >= %{texlive_version}
#!BuildIgnore: texlive-tikz-opm
Requires:       texlive-tikz-optics >= %{texlive_version}
#!BuildIgnore: texlive-tikz-optics
Requires:       texlive-tikz-page >= %{texlive_version}
#!BuildIgnore: texlive-tikz-page
Requires:       texlive-tikz-palattice >= %{texlive_version}
#!BuildIgnore: texlive-tikz-palattice
Requires:       texlive-tikz-planets >= %{texlive_version}
#!BuildIgnore: texlive-tikz-planets
Requires:       texlive-tikz-qtree >= %{texlive_version}
#!BuildIgnore: texlive-tikz-qtree
Requires:       texlive-tikz-relay >= %{texlive_version}
#!BuildIgnore: texlive-tikz-relay
Requires:       texlive-tikz-sfc >= %{texlive_version}
#!BuildIgnore: texlive-tikz-sfc
Requires:       texlive-tikz-swigs >= %{texlive_version}
#!BuildIgnore: texlive-tikz-swigs
Requires:       texlive-tikz-timing >= %{texlive_version}
#!BuildIgnore: texlive-tikz-timing
Requires:       texlive-tikz-trackschematic >= %{texlive_version}
#!BuildIgnore: texlive-tikz-trackschematic
Requires:       texlive-tikz-truchet >= %{texlive_version}
#!BuildIgnore: texlive-tikz-truchet
Requires:       texlive-tikzbricks >= %{texlive_version}
#!BuildIgnore: texlive-tikzbricks
Requires:       texlive-tikzcodeblocks >= %{texlive_version}
#!BuildIgnore: texlive-tikzcodeblocks
Requires:       texlive-tikzducks >= %{texlive_version}
#!BuildIgnore: texlive-tikzducks
Requires:       texlive-tikzfill >= %{texlive_version}
#!BuildIgnore: texlive-tikzfill
Requires:       texlive-tikzinclude >= %{texlive_version}
#!BuildIgnore: texlive-tikzinclude
Requires:       texlive-tikzlings >= %{texlive_version}
#!BuildIgnore: texlive-tikzlings
Requires:       texlive-tikzmark >= %{texlive_version}
#!BuildIgnore: texlive-tikzmark
Requires:       texlive-tikzmarmots >= %{texlive_version}
#!BuildIgnore: texlive-tikzmarmots
Requires:       texlive-tikzorbital >= %{texlive_version}
#!BuildIgnore: texlive-tikzorbital
Requires:       texlive-tikzpackets >= %{texlive_version}
#!BuildIgnore: texlive-tikzpackets
Requires:       texlive-tikzpagenodes >= %{texlive_version}
#!BuildIgnore: texlive-tikzpagenodes
Requires:       texlive-tikzpeople >= %{texlive_version}
#!BuildIgnore: texlive-tikzpeople
Requires:       texlive-tikzpfeile >= %{texlive_version}
#!BuildIgnore: texlive-tikzpfeile
Requires:       texlive-tikzpingus >= %{texlive_version}
#!BuildIgnore: texlive-tikzpingus
Requires:       texlive-tikzposter >= %{texlive_version}
#!BuildIgnore: texlive-tikzposter
Requires:       texlive-tikzscale >= %{texlive_version}
#!BuildIgnore: texlive-tikzscale
Requires:       texlive-tikzsymbols >= %{texlive_version}
#!BuildIgnore: texlive-tikzsymbols
Requires:       texlive-tikztosvg >= %{texlive_version}
#!BuildIgnore: texlive-tikztosvg
Requires:       texlive-tikzviolinplots >= %{texlive_version}
#!BuildIgnore: texlive-tikzviolinplots
Requires:       texlive-tile-graphic >= %{texlive_version}
#!BuildIgnore: texlive-tile-graphic
Requires:       texlive-timing-diagrams >= %{texlive_version}
#!BuildIgnore: texlive-timing-diagrams
Requires:       texlive-tipfr >= %{texlive_version}
#!BuildIgnore: texlive-tipfr
Requires:       texlive-tkz-base >= %{texlive_version}
#!BuildIgnore: texlive-tkz-base
Requires:       texlive-tkz-berge >= %{texlive_version}
#!BuildIgnore: texlive-tkz-berge
Requires:       texlive-tkz-doc >= %{texlive_version}
#!BuildIgnore: texlive-tkz-doc
Requires:       texlive-tkz-euclide >= %{texlive_version}
#!BuildIgnore: texlive-tkz-euclide
Requires:       texlive-tkz-fct >= %{texlive_version}
#!BuildIgnore: texlive-tkz-fct
Requires:       texlive-tkz-graph >= %{texlive_version}
#!BuildIgnore: texlive-tkz-graph
Requires:       texlive-tkz-orm >= %{texlive_version}
#!BuildIgnore: texlive-tkz-orm
Requires:       texlive-tkz-tab >= %{texlive_version}
#!BuildIgnore: texlive-tkz-tab
Requires:       texlive-tkzexample >= %{texlive_version}
#!BuildIgnore: texlive-tkzexample
Requires:       texlive-tonevalue >= %{texlive_version}
#!BuildIgnore: texlive-tonevalue
Requires:       texlive-tqft >= %{texlive_version}
#!BuildIgnore: texlive-tqft
Requires:       texlive-tsemlines >= %{texlive_version}
#!BuildIgnore: texlive-tsemlines
Requires:       texlive-tufte-latex >= %{texlive_version}
#!BuildIgnore: texlive-tufte-latex
Requires:       texlive-twemojis >= %{texlive_version}
#!BuildIgnore: texlive-twemojis
Requires:       texlive-tzplot >= %{texlive_version}
#!BuildIgnore: texlive-tzplot
Requires:       texlive-utfsym >= %{texlive_version}
#!BuildIgnore: texlive-utfsym
Requires:       texlive-venndiagram >= %{texlive_version}
#!BuildIgnore: texlive-venndiagram
Requires:       texlive-visualpstricks >= %{texlive_version}
#!BuildIgnore: texlive-visualpstricks
Requires:       texlive-wheelchart >= %{texlive_version}
#!BuildIgnore: texlive-wheelchart
Requires:       texlive-worldflags >= %{texlive_version}
#!BuildIgnore: texlive-worldflags
Requires:       texlive-xistercian >= %{texlive_version}
#!BuildIgnore: texlive-xistercian
Requires:       texlive-xpicture >= %{texlive_version}
#!BuildIgnore: texlive-xpicture
Requires:       texlive-xypic >= %{texlive_version}
#!BuildIgnore: texlive-xypic
Provides:       tex(pictures)
BuildArch:      noarch

%description -n texlive-collection-pictures
Including TikZ, pict, etc., but MetaPost and PStricks are
separate.

%package -n texlive-collection-plaingeneric
Version:        %{texlive_version}.%{texlive_noarch}.svn65622
Release:        60.1
License:        LPPL-1.0
Summary:        Plain (La)TeX packages
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-abbr >= %{texlive_version}
#!BuildIgnore: texlive-abbr
Requires:       texlive-abstyles >= %{texlive_version}
#!BuildIgnore: texlive-abstyles
Requires:       texlive-apnum >= %{texlive_version}
#!BuildIgnore: texlive-apnum
Requires:       texlive-autoaligne >= %{texlive_version}
#!BuildIgnore: texlive-autoaligne
Requires:       texlive-barr >= %{texlive_version}
#!BuildIgnore: texlive-barr
Requires:       texlive-bitelist >= %{texlive_version}
#!BuildIgnore: texlive-bitelist
Requires:       texlive-borceux >= %{texlive_version}
#!BuildIgnore: texlive-borceux
Requires:       texlive-c-pascal >= %{texlive_version}
#!BuildIgnore: texlive-c-pascal
Requires:       texlive-catcodes >= %{texlive_version}
#!BuildIgnore: texlive-catcodes
Requires:       texlive-chronosys >= %{texlive_version}
#!BuildIgnore: texlive-chronosys
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-colorsep >= %{texlive_version}
#!BuildIgnore: texlive-colorsep
Requires:       texlive-compare >= %{texlive_version}
#!BuildIgnore: texlive-compare
Requires:       texlive-crossrefenum >= %{texlive_version}
#!BuildIgnore: texlive-crossrefenum
Requires:       texlive-cweb-old >= %{texlive_version}
#!BuildIgnore: texlive-cweb-old
Requires:       texlive-dinat >= %{texlive_version}
#!BuildIgnore: texlive-dinat
Requires:       texlive-dirtree >= %{texlive_version}
#!BuildIgnore: texlive-dirtree
Requires:       texlive-docbytex >= %{texlive_version}
#!BuildIgnore: texlive-docbytex
Requires:       texlive-dowith >= %{texlive_version}
#!BuildIgnore: texlive-dowith
Requires:       texlive-eijkhout >= %{texlive_version}
#!BuildIgnore: texlive-eijkhout
Requires:       texlive-encxvlna >= %{texlive_version}
#!BuildIgnore: texlive-encxvlna
Requires:       texlive-epigram >= %{texlive_version}
#!BuildIgnore: texlive-epigram
Requires:       texlive-epsf >= %{texlive_version}
#!BuildIgnore: texlive-epsf
Requires:       texlive-epsf-dvipdfmx >= %{texlive_version}
#!BuildIgnore: texlive-epsf-dvipdfmx
Requires:       texlive-expex-acro >= %{texlive_version}
#!BuildIgnore: texlive-expex-acro
Requires:       texlive-expkv-bundle >= %{texlive_version}
#!BuildIgnore: texlive-expkv-bundle
Requires:       texlive-fenixpar >= %{texlive_version}
#!BuildIgnore: texlive-fenixpar
Requires:       texlive-figflow >= %{texlive_version}
#!BuildIgnore: texlive-figflow
Requires:       texlive-fixpdfmag >= %{texlive_version}
#!BuildIgnore: texlive-fixpdfmag
Requires:       texlive-fltpoint >= %{texlive_version}
#!BuildIgnore: texlive-fltpoint
Requires:       texlive-fntproof >= %{texlive_version}
#!BuildIgnore: texlive-fntproof
Requires:       texlive-font-change >= %{texlive_version}
#!BuildIgnore: texlive-font-change
Requires:       texlive-fontch >= %{texlive_version}
#!BuildIgnore: texlive-fontch
Requires:       texlive-fontname >= %{texlive_version}
#!BuildIgnore: texlive-fontname
Requires:       texlive-gates >= %{texlive_version}
#!BuildIgnore: texlive-gates
Requires:       texlive-getoptk >= %{texlive_version}
#!BuildIgnore: texlive-getoptk
Requires:       texlive-gfnotation >= %{texlive_version}
#!BuildIgnore: texlive-gfnotation
Requires:       texlive-gobble >= %{texlive_version}
#!BuildIgnore: texlive-gobble
Requires:       texlive-graphics-pln >= %{texlive_version}
#!BuildIgnore: texlive-graphics-pln
Requires:       texlive-gtl >= %{texlive_version}
#!BuildIgnore: texlive-gtl
Requires:       texlive-hlist >= %{texlive_version}
#!BuildIgnore: texlive-hlist
Requires:       texlive-hyplain >= %{texlive_version}
#!BuildIgnore: texlive-hyplain
Requires:       texlive-inputnormalization >= %{texlive_version}
#!BuildIgnore: texlive-inputnormalization
Requires:       texlive-insbox >= %{texlive_version}
#!BuildIgnore: texlive-insbox
Requires:       texlive-js-misc >= %{texlive_version}
#!BuildIgnore: texlive-js-misc
Requires:       texlive-kastrup >= %{texlive_version}
#!BuildIgnore: texlive-kastrup
Requires:       texlive-lambda-lists >= %{texlive_version}
#!BuildIgnore: texlive-lambda-lists
Requires:       texlive-langcode >= %{texlive_version}
#!BuildIgnore: texlive-langcode
Requires:       texlive-lecturer >= %{texlive_version}
#!BuildIgnore: texlive-lecturer
Requires:       texlive-letterspacing >= %{texlive_version}
#!BuildIgnore: texlive-letterspacing
Requires:       texlive-librarian >= %{texlive_version}
#!BuildIgnore: texlive-librarian
Requires:       texlive-listofitems >= %{texlive_version}
#!BuildIgnore: texlive-listofitems
Requires:       texlive-localloc >= %{texlive_version}
#!BuildIgnore: texlive-localloc
Requires:       texlive-mathdots >= %{texlive_version}
#!BuildIgnore: texlive-mathdots
Requires:       texlive-metatex >= %{texlive_version}
#!BuildIgnore: texlive-metatex
Requires:       texlive-midnight >= %{texlive_version}
#!BuildIgnore: texlive-midnight
Requires:       texlive-mkpattern >= %{texlive_version}
#!BuildIgnore: texlive-mkpattern
Requires:       texlive-modulus >= %{texlive_version}
#!BuildIgnore: texlive-modulus
Requires:       texlive-multido >= %{texlive_version}
#!BuildIgnore: texlive-multido
Requires:       texlive-namedef >= %{texlive_version}
#!BuildIgnore: texlive-namedef
Requires:       texlive-navigator >= %{texlive_version}
#!BuildIgnore: texlive-navigator
Requires:       texlive-newsletr >= %{texlive_version}
#!BuildIgnore: texlive-newsletr
Requires:       texlive-nth >= %{texlive_version}
#!BuildIgnore: texlive-nth
Requires:       texlive-ofs >= %{texlive_version}
#!BuildIgnore: texlive-ofs
Requires:       texlive-olsak-misc >= %{texlive_version}
#!BuildIgnore: texlive-olsak-misc
Requires:       texlive-outerhbox >= %{texlive_version}
#!BuildIgnore: texlive-outerhbox
Requires:       texlive-path >= %{texlive_version}
#!BuildIgnore: texlive-path
Requires:       texlive-pdf-trans >= %{texlive_version}
#!BuildIgnore: texlive-pdf-trans
Requires:       texlive-pdfmsym >= %{texlive_version}
#!BuildIgnore: texlive-pdfmsym
Requires:       texlive-pitex >= %{texlive_version}
#!BuildIgnore: texlive-pitex
Requires:       texlive-placeins-plain >= %{texlive_version}
#!BuildIgnore: texlive-placeins-plain
Requires:       texlive-plainpkg >= %{texlive_version}
#!BuildIgnore: texlive-plainpkg
Requires:       texlive-plipsum >= %{texlive_version}
#!BuildIgnore: texlive-plipsum
Requires:       texlive-plnfss >= %{texlive_version}
#!BuildIgnore: texlive-plnfss
Requires:       texlive-plstmary >= %{texlive_version}
#!BuildIgnore: texlive-plstmary
Requires:       texlive-poormanlog >= %{texlive_version}
#!BuildIgnore: texlive-poormanlog
Requires:       texlive-present >= %{texlive_version}
#!BuildIgnore: texlive-present
Requires:       texlive-pwebmac >= %{texlive_version}
#!BuildIgnore: texlive-pwebmac
Requires:       texlive-random >= %{texlive_version}
#!BuildIgnore: texlive-random
Requires:       texlive-randomlist >= %{texlive_version}
#!BuildIgnore: texlive-randomlist
Requires:       texlive-resumemac >= %{texlive_version}
#!BuildIgnore: texlive-resumemac
Requires:       texlive-ruler >= %{texlive_version}
#!BuildIgnore: texlive-ruler
Requires:       texlive-schemata >= %{texlive_version}
#!BuildIgnore: texlive-schemata
Requires:       texlive-shade >= %{texlive_version}
#!BuildIgnore: texlive-shade
Requires:       texlive-simplekv >= %{texlive_version}
#!BuildIgnore: texlive-simplekv
Requires:       texlive-soul >= %{texlive_version}
#!BuildIgnore: texlive-soul
Requires:       texlive-swrule >= %{texlive_version}
#!BuildIgnore: texlive-swrule
Requires:       texlive-systeme >= %{texlive_version}
#!BuildIgnore: texlive-systeme
Requires:       texlive-tabto-generic >= %{texlive_version}
#!BuildIgnore: texlive-tabto-generic
Requires:       texlive-termmenu >= %{texlive_version}
#!BuildIgnore: texlive-termmenu
Requires:       texlive-tex-ps >= %{texlive_version}
#!BuildIgnore: texlive-tex-ps
Requires:       texlive-tex4ht >= %{texlive_version}
#!BuildIgnore: texlive-tex4ht
Requires:       texlive-texapi >= %{texlive_version}
#!BuildIgnore: texlive-texapi
Requires:       texlive-texdate >= %{texlive_version}
#!BuildIgnore: texlive-texdate
Requires:       texlive-texdimens >= %{texlive_version}
#!BuildIgnore: texlive-texdimens
Requires:       texlive-texinfo >= %{texlive_version}
#!BuildIgnore: texlive-texinfo
Requires:       texlive-timetable >= %{texlive_version}
#!BuildIgnore: texlive-timetable
Requires:       texlive-tracklang >= %{texlive_version}
#!BuildIgnore: texlive-tracklang
Requires:       texlive-transparent-io >= %{texlive_version}
#!BuildIgnore: texlive-transparent-io
Requires:       texlive-treetex >= %{texlive_version}
#!BuildIgnore: texlive-treetex
Requires:       texlive-trigonometry >= %{texlive_version}
#!BuildIgnore: texlive-trigonometry
Requires:       texlive-ulem >= %{texlive_version}
#!BuildIgnore: texlive-ulem
Requires:       texlive-upca >= %{texlive_version}
#!BuildIgnore: texlive-upca
Requires:       texlive-varisize >= %{texlive_version}
#!BuildIgnore: texlive-varisize
Requires:       texlive-xii >= %{texlive_version}
#!BuildIgnore: texlive-xii
Requires:       texlive-xii-lat >= %{texlive_version}
#!BuildIgnore: texlive-xii-lat
Requires:       texlive-xintsession >= %{texlive_version}
#!BuildIgnore: texlive-xintsession
Requires:       texlive-xlop >= %{texlive_version}
#!BuildIgnore: texlive-xlop
Requires:       texlive-yax >= %{texlive_version}
#!BuildIgnore: texlive-yax
Requires:       texlive-zztex >= %{texlive_version}
#!BuildIgnore: texlive-zztex
BuildArch:      noarch

%description -n texlive-collection-plaingeneric
Add-on packages and macros that work with plain TeX, often
LaTeX, and occasionally other formats.

%package -n texlive-collection-pstricks
Version:        %{texlive_version}.%{texlive_noarch}.svn65367
Release:        60.1
License:        LPPL-1.0
Summary:        PSTricks
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-auto-pst-pdf >= %{texlive_version}
#!BuildIgnore: texlive-auto-pst-pdf
Requires:       texlive-bclogo >= %{texlive_version}
#!BuildIgnore: texlive-bclogo
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-collection-plaingeneric >= %{texlive_version}
#!BuildIgnore: texlive-collection-plaingeneric
Requires:       texlive-dsptricks >= %{texlive_version}
#!BuildIgnore: texlive-dsptricks
Requires:       texlive-luapstricks >= %{texlive_version}
#!BuildIgnore: texlive-luapstricks
Requires:       texlive-makeplot >= %{texlive_version}
#!BuildIgnore: texlive-makeplot
Requires:       texlive-pdftricks >= %{texlive_version}
#!BuildIgnore: texlive-pdftricks
Requires:       texlive-pdftricks2 >= %{texlive_version}
#!BuildIgnore: texlive-pdftricks2
Requires:       texlive-pedigree-perl >= %{texlive_version}
#!BuildIgnore: texlive-pedigree-perl
Requires:       texlive-psbao >= %{texlive_version}
#!BuildIgnore: texlive-psbao
Requires:       texlive-pst-2dplot >= %{texlive_version}
#!BuildIgnore: texlive-pst-2dplot
Requires:       texlive-pst-3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-3d
Requires:       texlive-pst-3dplot >= %{texlive_version}
#!BuildIgnore: texlive-pst-3dplot
Requires:       texlive-pst-abspos >= %{texlive_version}
#!BuildIgnore: texlive-pst-abspos
Requires:       texlive-pst-am >= %{texlive_version}
#!BuildIgnore: texlive-pst-am
Requires:       texlive-pst-antiprism >= %{texlive_version}
#!BuildIgnore: texlive-pst-antiprism
Requires:       texlive-pst-arrow >= %{texlive_version}
#!BuildIgnore: texlive-pst-arrow
Requires:       texlive-pst-asr >= %{texlive_version}
#!BuildIgnore: texlive-pst-asr
Requires:       texlive-pst-bar >= %{texlive_version}
#!BuildIgnore: texlive-pst-bar
Requires:       texlive-pst-barcode >= %{texlive_version}
#!BuildIgnore: texlive-pst-barcode
Requires:       texlive-pst-bezier >= %{texlive_version}
#!BuildIgnore: texlive-pst-bezier
Requires:       texlive-pst-blur >= %{texlive_version}
#!BuildIgnore: texlive-pst-blur
Requires:       texlive-pst-bspline >= %{texlive_version}
#!BuildIgnore: texlive-pst-bspline
Requires:       texlive-pst-calculate >= %{texlive_version}
#!BuildIgnore: texlive-pst-calculate
Requires:       texlive-pst-calendar >= %{texlive_version}
#!BuildIgnore: texlive-pst-calendar
Requires:       texlive-pst-cie >= %{texlive_version}
#!BuildIgnore: texlive-pst-cie
Requires:       texlive-pst-circ >= %{texlive_version}
#!BuildIgnore: texlive-pst-circ
Requires:       texlive-pst-coil >= %{texlive_version}
#!BuildIgnore: texlive-pst-coil
Requires:       texlive-pst-contourplot >= %{texlive_version}
#!BuildIgnore: texlive-pst-contourplot
Requires:       texlive-pst-cox >= %{texlive_version}
#!BuildIgnore: texlive-pst-cox
Requires:       texlive-pst-dart >= %{texlive_version}
#!BuildIgnore: texlive-pst-dart
Requires:       texlive-pst-dbicons >= %{texlive_version}
#!BuildIgnore: texlive-pst-dbicons
Requires:       texlive-pst-diffraction >= %{texlive_version}
#!BuildIgnore: texlive-pst-diffraction
Requires:       texlive-pst-electricfield >= %{texlive_version}
#!BuildIgnore: texlive-pst-electricfield
Requires:       texlive-pst-eps >= %{texlive_version}
#!BuildIgnore: texlive-pst-eps
Requires:       texlive-pst-eucl >= %{texlive_version}
#!BuildIgnore: texlive-pst-eucl
Requires:       texlive-pst-exa >= %{texlive_version}
#!BuildIgnore: texlive-pst-exa
Requires:       texlive-pst-feyn >= %{texlive_version}
#!BuildIgnore: texlive-pst-feyn
Requires:       texlive-pst-fill >= %{texlive_version}
#!BuildIgnore: texlive-pst-fill
Requires:       texlive-pst-fit >= %{texlive_version}
#!BuildIgnore: texlive-pst-fit
Requires:       texlive-pst-flags >= %{texlive_version}
#!BuildIgnore: texlive-pst-flags
Requires:       texlive-pst-fr3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-fr3d
Requires:       texlive-pst-fractal >= %{texlive_version}
#!BuildIgnore: texlive-pst-fractal
Requires:       texlive-pst-fun >= %{texlive_version}
#!BuildIgnore: texlive-pst-fun
Requires:       texlive-pst-func >= %{texlive_version}
#!BuildIgnore: texlive-pst-func
Requires:       texlive-pst-gantt >= %{texlive_version}
#!BuildIgnore: texlive-pst-gantt
Requires:       texlive-pst-geo >= %{texlive_version}
#!BuildIgnore: texlive-pst-geo
Requires:       texlive-pst-geometrictools >= %{texlive_version}
#!BuildIgnore: texlive-pst-geometrictools
Requires:       texlive-pst-gr3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-gr3d
Requires:       texlive-pst-grad >= %{texlive_version}
#!BuildIgnore: texlive-pst-grad
Requires:       texlive-pst-graphicx >= %{texlive_version}
#!BuildIgnore: texlive-pst-graphicx
Requires:       texlive-pst-hsb >= %{texlive_version}
#!BuildIgnore: texlive-pst-hsb
Requires:       texlive-pst-infixplot >= %{texlive_version}
#!BuildIgnore: texlive-pst-infixplot
Requires:       texlive-pst-intersect >= %{texlive_version}
#!BuildIgnore: texlive-pst-intersect
Requires:       texlive-pst-jtree >= %{texlive_version}
#!BuildIgnore: texlive-pst-jtree
Requires:       texlive-pst-knot >= %{texlive_version}
#!BuildIgnore: texlive-pst-knot
Requires:       texlive-pst-labo >= %{texlive_version}
#!BuildIgnore: texlive-pst-labo
Requires:       texlive-pst-layout >= %{texlive_version}
#!BuildIgnore: texlive-pst-layout
Requires:       texlive-pst-lens >= %{texlive_version}
#!BuildIgnore: texlive-pst-lens
Requires:       texlive-pst-light3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-light3d
Requires:       texlive-pst-lsystem >= %{texlive_version}
#!BuildIgnore: texlive-pst-lsystem
Requires:       texlive-pst-magneticfield >= %{texlive_version}
#!BuildIgnore: texlive-pst-magneticfield
Requires:       texlive-pst-marble >= %{texlive_version}
#!BuildIgnore: texlive-pst-marble
Requires:       texlive-pst-math >= %{texlive_version}
#!BuildIgnore: texlive-pst-math
Requires:       texlive-pst-mirror >= %{texlive_version}
#!BuildIgnore: texlive-pst-mirror
Requires:       texlive-pst-moire >= %{texlive_version}
#!BuildIgnore: texlive-pst-moire
Requires:       texlive-pst-node >= %{texlive_version}
#!BuildIgnore: texlive-pst-node
Requires:       texlive-pst-ob3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-ob3d
Requires:       texlive-pst-ode >= %{texlive_version}
#!BuildIgnore: texlive-pst-ode
Requires:       texlive-pst-optexp >= %{texlive_version}
#!BuildIgnore: texlive-pst-optexp
Requires:       texlive-pst-optic >= %{texlive_version}
#!BuildIgnore: texlive-pst-optic
Requires:       texlive-pst-osci >= %{texlive_version}
#!BuildIgnore: texlive-pst-osci
Requires:       texlive-pst-ovl >= %{texlive_version}
#!BuildIgnore: texlive-pst-ovl
Requires:       texlive-pst-pad >= %{texlive_version}
#!BuildIgnore: texlive-pst-pad
Requires:       texlive-pst-pdf >= %{texlive_version}
#!BuildIgnore: texlive-pst-pdf
Requires:       texlive-pst-pdgr >= %{texlive_version}
#!BuildIgnore: texlive-pst-pdgr
Requires:       texlive-pst-perspective >= %{texlive_version}
#!BuildIgnore: texlive-pst-perspective
Requires:       texlive-pst-platon >= %{texlive_version}
#!BuildIgnore: texlive-pst-platon
Requires:       texlive-pst-plot >= %{texlive_version}
#!BuildIgnore: texlive-pst-plot
Requires:       texlive-pst-poker >= %{texlive_version}
#!BuildIgnore: texlive-pst-poker
Requires:       texlive-pst-poly >= %{texlive_version}
#!BuildIgnore: texlive-pst-poly
Requires:       texlive-pst-pulley >= %{texlive_version}
#!BuildIgnore: texlive-pst-pulley
Requires:       texlive-pst-qtree >= %{texlive_version}
#!BuildIgnore: texlive-pst-qtree
Requires:       texlive-pst-rputover >= %{texlive_version}
#!BuildIgnore: texlive-pst-rputover
Requires:       texlive-pst-rubans >= %{texlive_version}
#!BuildIgnore: texlive-pst-rubans
Requires:       texlive-pst-shell >= %{texlive_version}
#!BuildIgnore: texlive-pst-shell
Requires:       texlive-pst-sigsys >= %{texlive_version}
#!BuildIgnore: texlive-pst-sigsys
Requires:       texlive-pst-slpe >= %{texlive_version}
#!BuildIgnore: texlive-pst-slpe
Requires:       texlive-pst-solarsystem >= %{texlive_version}
#!BuildIgnore: texlive-pst-solarsystem
Requires:       texlive-pst-solides3d >= %{texlive_version}
#!BuildIgnore: texlive-pst-solides3d
Requires:       texlive-pst-soroban >= %{texlive_version}
#!BuildIgnore: texlive-pst-soroban
Requires:       texlive-pst-spectra >= %{texlive_version}
#!BuildIgnore: texlive-pst-spectra
Requires:       texlive-pst-spinner >= %{texlive_version}
#!BuildIgnore: texlive-pst-spinner
Requires:       texlive-pst-stru >= %{texlive_version}
#!BuildIgnore: texlive-pst-stru
Requires:       texlive-pst-support >= %{texlive_version}
#!BuildIgnore: texlive-pst-support
Requires:       texlive-pst-text >= %{texlive_version}
#!BuildIgnore: texlive-pst-text
Requires:       texlive-pst-thick >= %{texlive_version}
#!BuildIgnore: texlive-pst-thick
Requires:       texlive-pst-tools >= %{texlive_version}
#!BuildIgnore: texlive-pst-tools
Requires:       texlive-pst-tree >= %{texlive_version}
#!BuildIgnore: texlive-pst-tree
Requires:       texlive-pst-turtle >= %{texlive_version}
#!BuildIgnore: texlive-pst-turtle
Requires:       texlive-pst-tvz >= %{texlive_version}
#!BuildIgnore: texlive-pst-tvz
Requires:       texlive-pst-uml >= %{texlive_version}
#!BuildIgnore: texlive-pst-uml
Requires:       texlive-pst-vectorian >= %{texlive_version}
#!BuildIgnore: texlive-pst-vectorian
Requires:       texlive-pst-vehicle >= %{texlive_version}
#!BuildIgnore: texlive-pst-vehicle
Requires:       texlive-pst-venn >= %{texlive_version}
#!BuildIgnore: texlive-pst-venn
Requires:       texlive-pst-vowel >= %{texlive_version}
#!BuildIgnore: texlive-pst-vowel
Requires:       texlive-pst2pdf >= %{texlive_version}
#!BuildIgnore: texlive-pst2pdf
Requires:       texlive-pstricks >= %{texlive_version}
#!BuildIgnore: texlive-pstricks
Requires:       texlive-pstricks-add >= %{texlive_version}
#!BuildIgnore: texlive-pstricks-add
Requires:       texlive-pstricks_calcnotes >= %{texlive_version}
#!BuildIgnore: texlive-pstricks_calcnotes
Requires:       texlive-uml >= %{texlive_version}
#!BuildIgnore: texlive-uml
Requires:       texlive-vaucanson-g >= %{texlive_version}
#!BuildIgnore: texlive-vaucanson-g
Requires:       texlive-vocaltract >= %{texlive_version}
#!BuildIgnore: texlive-vocaltract
Provides:       tex(pstricks)
BuildArch:      noarch

%description -n texlive-collection-pstricks
PSTricks core and all add-on packages.

%package -n texlive-collection-publishers
Version:        %{texlive_version}.%{texlive_noarch}.svn66330
Release:        60.1
License:        LPPL-1.0
Summary:        Publisher styles, theses, etcetera
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires:       texlive-aastex >= %{texlive_version}
#!BuildIgnore: texlive-aastex
Requires:       texlive-abnt >= %{texlive_version}
#!BuildIgnore: texlive-abnt
Requires:       texlive-abntex2 >= %{texlive_version}
#!BuildIgnore: texlive-abntex2
Requires:       texlive-abntexto >= %{texlive_version}
#!BuildIgnore: texlive-abntexto
Requires:       texlive-acmart >= %{texlive_version}
#!BuildIgnore: texlive-acmart
Requires:       texlive-acmconf >= %{texlive_version}
#!BuildIgnore: texlive-acmconf
Requires:       texlive-active-conf >= %{texlive_version}
#!BuildIgnore: texlive-active-conf
Requires:       texlive-adfathesis >= %{texlive_version}
#!BuildIgnore: texlive-adfathesis
Requires:       texlive-afparticle >= %{texlive_version}
#!BuildIgnore: texlive-afparticle
Requires:       texlive-afthesis >= %{texlive_version}
#!BuildIgnore: texlive-afthesis
Requires:       texlive-aguplus >= %{texlive_version}
#!BuildIgnore: texlive-aguplus
Requires:       texlive-aiaa >= %{texlive_version}
#!BuildIgnore: texlive-aiaa
Requires:       texlive-anonymous-acm >= %{texlive_version}
#!BuildIgnore: texlive-anonymous-acm
Requires:       texlive-anufinalexam >= %{texlive_version}
#!BuildIgnore: texlive-anufinalexam
Requires:       texlive-aomart >= %{texlive_version}
#!BuildIgnore: texlive-aomart
Requires:       texlive-apa >= %{texlive_version}
#!BuildIgnore: texlive-apa
Requires:       texlive-apa6 >= %{texlive_version}
#!BuildIgnore: texlive-apa6
Requires:       texlive-apa6e >= %{texlive_version}
#!BuildIgnore: texlive-apa6e
Requires:       texlive-apa7 >= %{texlive_version}
#!BuildIgnore: texlive-apa7
Requires:       texlive-arsclassica >= %{texlive_version}
#!BuildIgnore: texlive-arsclassica
Requires:       texlive-articleingud >= %{texlive_version}
#!BuildIgnore: texlive-articleingud
Requires:       texlive-asaetr >= %{texlive_version}
#!BuildIgnore: texlive-asaetr
Requires:       texlive-ascelike >= %{texlive_version}
#!BuildIgnore: texlive-ascelike
Requires:       texlive-asmeconf >= %{texlive_version}
#!BuildIgnore: texlive-asmeconf
Requires:       texlive-asmejour >= %{texlive_version}
#!BuildIgnore: texlive-asmejour
Requires:       texlive-aucklandthesis >= %{texlive_version}
#!BuildIgnore: texlive-aucklandthesis
Requires:       texlive-bangorcsthesis >= %{texlive_version}
#!BuildIgnore: texlive-bangorcsthesis
Requires:       texlive-bangorexam >= %{texlive_version}
#!BuildIgnore: texlive-bangorexam
Requires:       texlive-bath-bst >= %{texlive_version}
#!BuildIgnore: texlive-bath-bst
Requires:       texlive-beamer-fuberlin >= %{texlive_version}
#!BuildIgnore: texlive-beamer-fuberlin
Requires:       texlive-beamer-verona >= %{texlive_version}
#!BuildIgnore: texlive-beamer-verona
Requires:       texlive-beilstein >= %{texlive_version}
#!BuildIgnore: texlive-beilstein
Requires:       texlive-bfh-ci >= %{texlive_version}
#!BuildIgnore: texlive-bfh-ci
Requires:       texlive-bgteubner >= %{texlive_version}
#!BuildIgnore: texlive-bgteubner
Requires:       texlive-bjfuthesis >= %{texlive_version}
#!BuildIgnore: texlive-bjfuthesis
Requires:       texlive-bmstu >= %{texlive_version}
#!BuildIgnore: texlive-bmstu
Requires:       texlive-bmstu-iu8 >= %{texlive_version}
#!BuildIgnore: texlive-bmstu-iu8
Requires:       texlive-br-lex >= %{texlive_version}
#!BuildIgnore: texlive-br-lex
Requires:       texlive-brandeis-dissertation >= %{texlive_version}
#!BuildIgnore: texlive-brandeis-dissertation
Requires:       texlive-brandeis-problemset >= %{texlive_version}
#!BuildIgnore: texlive-brandeis-problemset
Requires:       texlive-brandeis-thesis >= %{texlive_version}
#!BuildIgnore: texlive-brandeis-thesis
Requires:       texlive-buctthesis >= %{texlive_version}
#!BuildIgnore: texlive-buctthesis
Requires:       texlive-cascadilla >= %{texlive_version}
#!BuildIgnore: texlive-cascadilla
Requires:       texlive-cesenaexam >= %{texlive_version}
#!BuildIgnore: texlive-cesenaexam
Requires:       texlive-chem-journal >= %{texlive_version}
#!BuildIgnore: texlive-chem-journal
Requires:       texlive-chifoot >= %{texlive_version}
#!BuildIgnore: texlive-chifoot
Requires:       texlive-chs-physics-report >= %{texlive_version}
#!BuildIgnore: texlive-chs-physics-report
Requires:       texlive-cje >= %{texlive_version}
#!BuildIgnore: texlive-cje
Requires:       texlive-classicthesis >= %{texlive_version}
#!BuildIgnore: texlive-classicthesis
Requires:       texlive-cleanthesis >= %{texlive_version}
#!BuildIgnore: texlive-cleanthesis
Requires:       texlive-cmpj >= %{texlive_version}
#!BuildIgnore: texlive-cmpj
Requires:       texlive-collection-latex >= %{texlive_version}
#!BuildIgnore: texlive-collection-latex
Requires:       texlive-confproc >= %{texlive_version}
#!BuildIgnore: texlive-confproc
Requires:       texlive-cquthesis >= %{texlive_version}
#!BuildIgnore: texlive-cquthesis
Requires:       texlive-dccpaper >= %{texlive_version}
#!BuildIgnore: texlive-dccpaper
Requires:       texlive-dithesis >= %{texlive_version}
#!BuildIgnore: texlive-dithesis
Requires:       texlive-ebook >= %{texlive_version}
#!BuildIgnore: texlive-ebook
Requires:       texlive-ebsthesis >= %{texlive_version}
#!BuildIgnore: texlive-ebsthesis
Requires:       texlive-ecothesis >= %{texlive_version}
#!BuildIgnore: texlive-ecothesis
Requires:       texlive-ejpecp >= %{texlive_version}
#!BuildIgnore: texlive-ejpecp
Requires:       texlive-ekaia >= %{texlive_version}
#!BuildIgnore: texlive-ekaia
Requires:       texlive-elbioimp >= %{texlive_version}
#!BuildIgnore: texlive-elbioimp
Requires:       texlive-els-cas-templates >= %{texlive_version}
#!BuildIgnore: texlive-els-cas-templates
Requires:       texlive-elsarticle >= %{texlive_version}
#!BuildIgnore: texlive-elsarticle
Requires:       texlive-elteikthesis >= %{texlive_version}
#!BuildIgnore: texlive-elteikthesis
Requires:       texlive-emisa >= %{texlive_version}
#!BuildIgnore: texlive-emisa
Requires:       texlive-erdc >= %{texlive_version}
#!BuildIgnore: texlive-erdc
Requires:       texlive-estcpmm >= %{texlive_version}
#!BuildIgnore: texlive-estcpmm
Requires:       texlive-etsvthor >= %{texlive_version}
#!BuildIgnore: texlive-etsvthor
Requires:       texlive-facture-belge-simple-sans-tva >= %{texlive_version}
#!BuildIgnore: texlive-facture-belge-simple-sans-tva
Requires:       texlive-fbithesis >= %{texlive_version}
#!BuildIgnore: texlive-fbithesis
Requires:       texlive-fcavtex >= %{texlive_version}
#!BuildIgnore: texlive-fcavtex
Requires:       texlive-fcltxdoc >= %{texlive_version}
#!BuildIgnore: texlive-fcltxdoc
Requires:       texlive-fei >= %{texlive_version}
#!BuildIgnore: texlive-fei
Requires:       texlive-ftc-notebook >= %{texlive_version}
#!BuildIgnore: texlive-ftc-notebook
Requires:       texlive-gaceta >= %{texlive_version}
#!BuildIgnore: texlive-gaceta
Requires:       texlive-gammas >= %{texlive_version}
#!BuildIgnore: texlive-gammas
Requires:       texlive-geradwp >= %{texlive_version}
#!BuildIgnore: texlive-geradwp
Requires:       texlive-gfdl >= %{texlive_version}
#!BuildIgnore: texlive-gfdl
Requires:       texlive-gradstudentresume >= %{texlive_version}
#!BuildIgnore: texlive-gradstudentresume
Requires:       texlive-grant >= %{texlive_version}
#!BuildIgnore: texlive-grant
Requires:       texlive-gsemthesis >= %{texlive_version}
#!BuildIgnore: texlive-gsemthesis
Requires:       texlive-gzt >= %{texlive_version}
#!BuildIgnore: texlive-gzt
Requires:       texlive-h2020proposal >= %{texlive_version}
#!BuildIgnore: texlive-h2020proposal
Requires:       texlive-hagenberg-thesis >= %{texlive_version}
#!BuildIgnore: texlive-hagenberg-thesis
Requires:       texlive-har2nat >= %{texlive_version}
#!BuildIgnore: texlive-har2nat
Requires:       texlive-hecthese >= %{texlive_version}
#!BuildIgnore: texlive-hecthese
Requires:       texlive-hep-paper >= %{texlive_version}
#!BuildIgnore: texlive-hep-paper
Requires:       texlive-hfutexam >= %{texlive_version}
#!BuildIgnore: texlive-hfutexam
Requires:       texlive-hfutthesis >= %{texlive_version}
#!BuildIgnore: texlive-hfutthesis
Requires:       texlive-hithesis >= %{texlive_version}
#!BuildIgnore: texlive-hithesis
Requires:       texlive-hitszbeamer >= %{texlive_version}
#!BuildIgnore: texlive-hitszbeamer
Requires:       texlive-hitszthesis >= %{texlive_version}
#!BuildIgnore: texlive-hitszthesis
Requires:       texlive-hobete >= %{texlive_version}
#!BuildIgnore: texlive-hobete
Requires:       texlive-hu-berlin-bundle >= %{texlive_version}
#!BuildIgnore: texlive-hu-berlin-bundle
Requires:       texlive-hustthesis >= %{texlive_version}
#!BuildIgnore: texlive-hustthesis
Requires:       texlive-icsv >= %{texlive_version}
#!BuildIgnore: texlive-icsv
Requires:       texlive-ieeeconf >= %{texlive_version}
#!BuildIgnore: texlive-ieeeconf
Requires:       texlive-ieeepes >= %{texlive_version}
#!BuildIgnore: texlive-ieeepes
Requires:       texlive-ieeetran >= %{texlive_version}
#!BuildIgnore: texlive-ieeetran
Requires:       texlive-ijmart >= %{texlive_version}
#!BuildIgnore: texlive-ijmart
Requires:       texlive-ijsra >= %{texlive_version}
#!BuildIgnore: texlive-ijsra
Requires:       texlive-imac >= %{texlive_version}
#!BuildIgnore: texlive-imac
Requires:       texlive-imtekda >= %{texlive_version}
#!BuildIgnore: texlive-imtekda
Requires:       texlive-inkpaper >= %{texlive_version}
#!BuildIgnore: texlive-inkpaper
Requires:       texlive-iodhbwm >= %{texlive_version}
#!BuildIgnore: texlive-iodhbwm
Requires:       texlive-iscram >= %{texlive_version}
#!BuildIgnore: texlive-iscram
Requires:       texlive-jacow >= %{texlive_version}
#!BuildIgnore: texlive-jacow
Requires:       texlive-jmlr >= %{texlive_version}
#!BuildIgnore: texlive-jmlr
Requires:       texlive-jnuexam >= %{texlive_version}
#!BuildIgnore: texlive-jnuexam
Requires:       texlive-jourcl >= %{texlive_version}
#!BuildIgnore: texlive-jourcl
Requires:       texlive-jpsj >= %{texlive_version}
#!BuildIgnore: texlive-jpsj
Requires:       texlive-jwjournal >= %{texlive_version}
#!BuildIgnore: texlive-jwjournal
Requires:       texlive-kdgdocs >= %{texlive_version}
#!BuildIgnore: texlive-kdgdocs
Requires:       texlive-kdpcover >= %{texlive_version}
#!BuildIgnore: texlive-kdpcover
Requires:       texlive-kfupm-math-exam >= %{texlive_version}
#!BuildIgnore: texlive-kfupm-math-exam
Requires:       texlive-kluwer >= %{texlive_version}
#!BuildIgnore: texlive-kluwer
Requires:       texlive-ksp-thesis >= %{texlive_version}
#!BuildIgnore: texlive-ksp-thesis
Requires:       texlive-ku-template >= %{texlive_version}
#!BuildIgnore: texlive-ku-template
Requires:       texlive-langsci >= %{texlive_version}
#!BuildIgnore: texlive-langsci
Requires:       texlive-langsci-avm >= %{texlive_version}
#!BuildIgnore: texlive-langsci-avm
Requires:       texlive-limecv >= %{texlive_version}
#!BuildIgnore: texlive-limecv
Requires:       texlive-lion-msc >= %{texlive_version}
#!BuildIgnore: texlive-lion-msc
Requires:       texlive-llncs >= %{texlive_version}
#!BuildIgnore: texlive-llncs
Requires:       texlive-llncsconf >= %{texlive_version}
#!BuildIgnore: texlive-llncsconf
Requires:       texlive-lni >= %{texlive_version}
#!BuildIgnore: texlive-lni
Requires:       texlive-lps >= %{texlive_version}
#!BuildIgnore: texlive-lps
Requires:       texlive-matc3 >= %{texlive_version}
#!BuildIgnore: texlive-matc3
Requires:       texlive-matc3mem >= %{texlive_version}
#!BuildIgnore: texlive-matc3mem
Requires:       texlive-mcmthesis >= %{texlive_version}
#!BuildIgnore: texlive-mcmthesis
Requires:       texlive-mentis >= %{texlive_version}
#!BuildIgnore: texlive-mentis
Requires:       texlive-mlacls >= %{texlive_version}
#!BuildIgnore: texlive-mlacls
Requires:       texlive-mluexercise >= %{texlive_version}
#!BuildIgnore: texlive-mluexercise
Requires:       texlive-mnras >= %{texlive_version}
#!BuildIgnore: texlive-mnras
Requires:       texlive-modeles-factures-belges-assocs >= %{texlive_version}
#!BuildIgnore: texlive-modeles-factures-belges-assocs
Requires:       texlive-msu-thesis >= %{texlive_version}
#!BuildIgnore: texlive-msu-thesis
Requires:       texlive-mucproc >= %{texlive_version}
#!BuildIgnore: texlive-mucproc
Requires:       texlive-mugsthesis >= %{texlive_version}
#!BuildIgnore: texlive-mugsthesis
Requires:       texlive-muling >= %{texlive_version}
#!BuildIgnore: texlive-muling
Requires:       texlive-musuos >= %{texlive_version}
#!BuildIgnore: texlive-musuos
Requires:       texlive-muthesis >= %{texlive_version}
#!BuildIgnore: texlive-muthesis
Requires:       texlive-mynsfc >= %{texlive_version}
#!BuildIgnore: texlive-mynsfc
Requires:       texlive-nature >= %{texlive_version}
#!BuildIgnore: texlive-nature
Requires:       texlive-navydocs >= %{texlive_version}
#!BuildIgnore: texlive-navydocs
Requires:       texlive-nddiss >= %{texlive_version}
#!BuildIgnore: texlive-nddiss
Requires:       texlive-ndsu-thesis >= %{texlive_version}
#!BuildIgnore: texlive-ndsu-thesis
Requires:       texlive-ndsu-thesis-2022 >= %{texlive_version}
#!BuildIgnore: texlive-ndsu-thesis-2022
Requires:       texlive-nih >= %{texlive_version}
#!BuildIgnore: texlive-nih
Requires:       texlive-nihbiosketch >= %{texlive_version}
#!BuildIgnore: texlive-nihbiosketch
Requires:       texlive-njustthesis >= %{texlive_version}
#!BuildIgnore: texlive-njustthesis
Requires:       texlive-njuthesis >= %{texlive_version}
#!BuildIgnore: texlive-njuthesis
Requires:       texlive-njuvisual >= %{texlive_version}
#!BuildIgnore: texlive-njuvisual
Requires:       texlive-nostarch >= %{texlive_version}
#!BuildIgnore: texlive-nostarch
Requires:       texlive-novel >= %{texlive_version}
#!BuildIgnore: texlive-novel
Requires:       texlive-nrc >= %{texlive_version}
#!BuildIgnore: texlive-nrc
Requires:       texlive-nwafuthesis >= %{texlive_version}
#!BuildIgnore: texlive-nwafuthesis
Requires:       texlive-nwejm >= %{texlive_version}
#!BuildIgnore: texlive-nwejm
Requires:       texlive-onrannual >= %{texlive_version}
#!BuildIgnore: texlive-onrannual
Requires:       texlive-opteng >= %{texlive_version}
#!BuildIgnore: texlive-opteng
Requires:       texlive-oup-authoring-template >= %{texlive_version}
#!BuildIgnore: texlive-oup-authoring-template
Requires:       texlive-philosophersimprint >= %{texlive_version}
#!BuildIgnore: texlive-philosophersimprint
Requires:       texlive-pittetd >= %{texlive_version}
#!BuildIgnore: texlive-pittetd
Requires:       texlive-pkuthss >= %{texlive_version}
#!BuildIgnore: texlive-pkuthss
Requires:       texlive-powerdot-fuberlin >= %{texlive_version}
#!BuildIgnore: texlive-powerdot-fuberlin
Requires:       texlive-powerdot-tuliplab >= %{texlive_version}
#!BuildIgnore: texlive-powerdot-tuliplab
Requires:       texlive-pracjourn >= %{texlive_version}
#!BuildIgnore: texlive-pracjourn
Requires:       texlive-prociagssymp >= %{texlive_version}
#!BuildIgnore: texlive-prociagssymp
Requires:       texlive-proposal >= %{texlive_version}
#!BuildIgnore: texlive-proposal
Requires:       texlive-prtec >= %{texlive_version}
#!BuildIgnore: texlive-prtec
Requires:       texlive-ptptex >= %{texlive_version}
#!BuildIgnore: texlive-ptptex
Requires:       texlive-qrbill >= %{texlive_version}
#!BuildIgnore: texlive-qrbill
Requires:       texlive-quantumarticle >= %{texlive_version}
#!BuildIgnore: texlive-quantumarticle
Requires:       texlive-resphilosophica >= %{texlive_version}
#!BuildIgnore: texlive-resphilosophica
Requires:       texlive-resumecls >= %{texlive_version}
#!BuildIgnore: texlive-resumecls
Requires:       texlive-revtex >= %{texlive_version}
#!BuildIgnore: texlive-revtex
Requires:       texlive-revtex4 >= %{texlive_version}
#!BuildIgnore: texlive-revtex4
Requires:       texlive-revtex4-1 >= %{texlive_version}
#!BuildIgnore: texlive-revtex4-1
Requires:       texlive-rutitlepage >= %{texlive_version}
#!BuildIgnore: texlive-rutitlepage
Requires:       texlive-ryersonsgsthesis >= %{texlive_version}
#!BuildIgnore: texlive-ryersonsgsthesis
Requires:       texlive-ryethesis >= %{texlive_version}
#!BuildIgnore: texlive-ryethesis
Requires:       texlive-sageep >= %{texlive_version}
#!BuildIgnore: texlive-sageep
Requires:       texlive-sapthesis >= %{texlive_version}
#!BuildIgnore: texlive-sapthesis
Requires:       texlive-schule >= %{texlive_version}
#!BuildIgnore: texlive-schule
Requires:       texlive-scientific-thesis-cover >= %{texlive_version}
#!BuildIgnore: texlive-scientific-thesis-cover
Requires:       texlive-scripture >= %{texlive_version}
#!BuildIgnore: texlive-scripture
Requires:       texlive-scrjrnl >= %{texlive_version}
#!BuildIgnore: texlive-scrjrnl
Requires:       texlive-sduthesis >= %{texlive_version}
#!BuildIgnore: texlive-sduthesis
Requires:       texlive-se2thesis >= %{texlive_version}
#!BuildIgnore: texlive-se2thesis
Requires:       texlive-seu-ml-assign >= %{texlive_version}
#!BuildIgnore: texlive-seu-ml-assign
Requires:       texlive-seuthesis >= %{texlive_version}
#!BuildIgnore: texlive-seuthesis
Requires:       texlive-seuthesix >= %{texlive_version}
#!BuildIgnore: texlive-seuthesix
Requires:       texlive-shortmathj >= %{texlive_version}
#!BuildIgnore: texlive-shortmathj
Requires:       texlive-shtthesis >= %{texlive_version}
#!BuildIgnore: texlive-shtthesis
Requires:       texlive-smflatex >= %{texlive_version}
#!BuildIgnore: texlive-smflatex
Requires:       texlive-soton >= %{texlive_version}
#!BuildIgnore: texlive-soton
Requires:       texlive-sphdthesis >= %{texlive_version}
#!BuildIgnore: texlive-sphdthesis
Requires:       texlive-spie >= %{texlive_version}
#!BuildIgnore: texlive-spie
Requires:       texlive-sr-vorl >= %{texlive_version}
#!BuildIgnore: texlive-sr-vorl
Requires:       texlive-srdp-mathematik >= %{texlive_version}
#!BuildIgnore: texlive-srdp-mathematik
Requires:       texlive-stellenbosch >= %{texlive_version}
#!BuildIgnore: texlive-stellenbosch
Requires:       texlive-suftesi >= %{texlive_version}
#!BuildIgnore: texlive-suftesi
Requires:       texlive-sugconf >= %{texlive_version}
#!BuildIgnore: texlive-sugconf
Requires:       texlive-tabriz-thesis >= %{texlive_version}
#!BuildIgnore: texlive-tabriz-thesis
Requires:       texlive-technion-thesis-template >= %{texlive_version}
#!BuildIgnore: texlive-technion-thesis-template
Requires:       texlive-texilikechaps >= %{texlive_version}
#!BuildIgnore: texlive-texilikechaps
Requires:       texlive-texilikecover >= %{texlive_version}
#!BuildIgnore: texlive-texilikecover
Requires:       texlive-thesis-ekf >= %{texlive_version}
#!BuildIgnore: texlive-thesis-ekf
Requires:       texlive-thesis-gwu >= %{texlive_version}
#!BuildIgnore: texlive-thesis-gwu
Requires:       texlive-thesis-qom >= %{texlive_version}
#!BuildIgnore: texlive-thesis-qom
Requires:       texlive-thesis-titlepage-fhac >= %{texlive_version}
#!BuildIgnore: texlive-thesis-titlepage-fhac
Requires:       texlive-thuaslogos >= %{texlive_version}
#!BuildIgnore: texlive-thuaslogos
Requires:       texlive-thubeamer >= %{texlive_version}
#!BuildIgnore: texlive-thubeamer
Requires:       texlive-thucoursework >= %{texlive_version}
#!BuildIgnore: texlive-thucoursework
Requires:       texlive-thuthesis >= %{texlive_version}
#!BuildIgnore: texlive-thuthesis
Requires:       texlive-tidyres >= %{texlive_version}
#!BuildIgnore: texlive-tidyres
Requires:       texlive-timbreicmc >= %{texlive_version}
#!BuildIgnore: texlive-timbreicmc
Requires:       texlive-tlc-article >= %{texlive_version}
#!BuildIgnore: texlive-tlc-article
Requires:       texlive-topletter >= %{texlive_version}
#!BuildIgnore: texlive-topletter
Requires:       texlive-toptesi >= %{texlive_version}
#!BuildIgnore: texlive-toptesi
Requires:       texlive-tuda-ci >= %{texlive_version}
#!BuildIgnore: texlive-tuda-ci
Requires:       texlive-tudscr >= %{texlive_version}
#!BuildIgnore: texlive-tudscr
Requires:       texlive-tugboat >= %{texlive_version}
#!BuildIgnore: texlive-tugboat
Requires:       texlive-tugboat-plain >= %{texlive_version}
#!BuildIgnore: texlive-tugboat-plain
Requires:       texlive-tui >= %{texlive_version}
#!BuildIgnore: texlive-tui
Requires:       texlive-turabian >= %{texlive_version}
#!BuildIgnore: texlive-turabian
Requires:       texlive-uaclasses >= %{texlive_version}
#!BuildIgnore: texlive-uaclasses
Requires:       texlive-uafthesis >= %{texlive_version}
#!BuildIgnore: texlive-uafthesis
Requires:       texlive-uantwerpendocs >= %{texlive_version}
#!BuildIgnore: texlive-uantwerpendocs
Requires:       texlive-ucalgmthesis >= %{texlive_version}
#!BuildIgnore: texlive-ucalgmthesis
Requires:       texlive-ucbthesis >= %{texlive_version}
#!BuildIgnore: texlive-ucbthesis
Requires:       texlive-ucdavisthesis >= %{texlive_version}
#!BuildIgnore: texlive-ucdavisthesis
Requires:       texlive-ucsmonograph >= %{texlive_version}
#!BuildIgnore: texlive-ucsmonograph
Requires:       texlive-ucthesis >= %{texlive_version}
#!BuildIgnore: texlive-ucthesis
Requires:       texlive-udes-genie-these >= %{texlive_version}
#!BuildIgnore: texlive-udes-genie-these
Requires:       texlive-uestcthesis >= %{texlive_version}
#!BuildIgnore: texlive-uestcthesis
Requires:       texlive-ufrgscca >= %{texlive_version}
#!BuildIgnore: texlive-ufrgscca
Requires:       texlive-uhhassignment >= %{texlive_version}
#!BuildIgnore: texlive-uhhassignment
Requires:       texlive-uiucredborder >= %{texlive_version}
#!BuildIgnore: texlive-uiucredborder
Requires:       texlive-uiucthesis >= %{texlive_version}
#!BuildIgnore: texlive-uiucthesis
Requires:       texlive-ukbill >= %{texlive_version}
#!BuildIgnore: texlive-ukbill
Requires:       texlive-ulthese >= %{texlive_version}
#!BuildIgnore: texlive-ulthese
Requires:       texlive-umbclegislation >= %{texlive_version}
#!BuildIgnore: texlive-umbclegislation
Requires:       texlive-umich-thesis >= %{texlive_version}
#!BuildIgnore: texlive-umich-thesis
Requires:       texlive-umthesis >= %{texlive_version}
#!BuildIgnore: texlive-umthesis
Requires:       texlive-unam-thesis >= %{texlive_version}
#!BuildIgnore: texlive-unam-thesis
Requires:       texlive-unamth-template >= %{texlive_version}
#!BuildIgnore: texlive-unamth-template
Requires:       texlive-unamthesis >= %{texlive_version}
#!BuildIgnore: texlive-unamthesis
Requires:       texlive-unbtex >= %{texlive_version}
#!BuildIgnore: texlive-unbtex
Requires:       texlive-unifith >= %{texlive_version}
#!BuildIgnore: texlive-unifith
Requires:       texlive-unigrazpub >= %{texlive_version}
#!BuildIgnore: texlive-unigrazpub
Requires:       texlive-unitn-bimrep >= %{texlive_version}
#!BuildIgnore: texlive-unitn-bimrep
Requires:       texlive-univie-ling >= %{texlive_version}
#!BuildIgnore: texlive-univie-ling
Requires:       texlive-unizgklasa >= %{texlive_version}
#!BuildIgnore: texlive-unizgklasa
Requires:       texlive-unswcover >= %{texlive_version}
#!BuildIgnore: texlive-unswcover
Requires:       texlive-uol-physics-report >= %{texlive_version}
#!BuildIgnore: texlive-uol-physics-report
Requires:       texlive-uothesis >= %{texlive_version}
#!BuildIgnore: texlive-uothesis
Requires:       texlive-uowthesis >= %{texlive_version}
#!BuildIgnore: texlive-uowthesis
Requires:       texlive-uowthesistitlepage >= %{texlive_version}
#!BuildIgnore: texlive-uowthesistitlepage
Requires:       texlive-urcls >= %{texlive_version}
#!BuildIgnore: texlive-urcls
Requires:       texlive-uspatent >= %{texlive_version}
#!BuildIgnore: texlive-uspatent
Requires:       texlive-ut-thesis >= %{texlive_version}
#!BuildIgnore: texlive-ut-thesis
Requires:       texlive-utexasthesis >= %{texlive_version}
#!BuildIgnore: texlive-utexasthesis
Requires:       texlive-uvaletter >= %{texlive_version}
#!BuildIgnore: texlive-uvaletter
Requires:       texlive-uwa-colours >= %{texlive_version}
#!BuildIgnore: texlive-uwa-colours
Requires:       texlive-uwa-letterhead >= %{texlive_version}
#!BuildIgnore: texlive-uwa-letterhead
Requires:       texlive-uwa-pcf >= %{texlive_version}
#!BuildIgnore: texlive-uwa-pcf
Requires:       texlive-uwa-pif >= %{texlive_version}
#!BuildIgnore: texlive-uwa-pif
Requires:       texlive-uwthesis >= %{texlive_version}
#!BuildIgnore: texlive-uwthesis
Requires:       texlive-vancouver >= %{texlive_version}
#!BuildIgnore: texlive-vancouver
Requires:       texlive-wsemclassic >= %{texlive_version}
#!BuildIgnore: texlive-wsemclassic
Requires:       texlive-xduthesis >= %{texlive_version}
#!BuildIgnore: texlive-xduthesis
Requires:       texlive-xduts >= %{texlive_version}
#!BuildIgnore: texlive-xduts
Requires:       texlive-xmuthesis >= %{texlive_version}
#!BuildIgnore: texlive-xmuthesis
Requires:       texlive-yathesis >= %{texlive_version}
#!BuildIgnore: texlive-yathesis
Requires:       texlive-yazd-thesis >= %{texlive_version}
#!BuildIgnore: texlive-yazd-thesis
Requires:       texlive-yb-book >= %{texlive_version}
#!BuildIgnore: texlive-yb-book
Requires:       texlive-york-thesis >= %{texlive_version}
#!BuildIgnore: texlive-york-thesis
BuildArch:      noarch

%description -n texlive-collection-publishers
The collection-publishers package

%package -n texlive-collection-xetex
Version:        %{texlive_version}.%{texlive_noarch}.svn64951
Release:        60.1
License:        LPPL-1.0
Summary:        XeTeX and packages
Group:          Productivity/Publishing/TeX/Frontends
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-xetex <= %{texlive_previous}
Requires:       texlive-arabxetex >= %{texlive_version}
#!BuildIgnore: texlive-arabxetex
Requires:       texlive-awesomebox >= %{texlive_version}
#!BuildIgnore: texlive-awesomebox
Requires:       texlive-bidi-atbegshi >= %{texlive_version}
#!BuildIgnore: texlive-bidi-atbegshi
Requires:       texlive-bidicontour >= %{texlive_version}
#!BuildIgnore: texlive-bidicontour
Requires:       texlive-bidipagegrid >= %{texlive_version}
#!BuildIgnore: texlive-bidipagegrid
Requires:       texlive-bidipresentation >= %{texlive_version}
#!BuildIgnore: texlive-bidipresentation
Requires:       texlive-bidishadowtext >= %{texlive_version}
#!BuildIgnore: texlive-bidishadowtext
Requires:       texlive-businesscard-qrcode >= %{texlive_version}
#!BuildIgnore: texlive-businesscard-qrcode
Requires:       texlive-collection-basic >= %{texlive_version}
#!BuildIgnore: texlive-collection-basic
Requires:       texlive-cqubeamer >= %{texlive_version}
#!BuildIgnore: texlive-cqubeamer
Requires:       texlive-fixlatvian >= %{texlive_version}
#!BuildIgnore: texlive-fixlatvian
Requires:       texlive-font-change-xetex >= %{texlive_version}
#!BuildIgnore: texlive-font-change-xetex
Requires:       texlive-fontbook >= %{texlive_version}
#!BuildIgnore: texlive-fontbook
Requires:       texlive-fontwrap >= %{texlive_version}
#!BuildIgnore: texlive-fontwrap
Requires:       texlive-interchar >= %{texlive_version}
#!BuildIgnore: texlive-interchar
Requires:       texlive-na-position >= %{texlive_version}
#!BuildIgnore: texlive-na-position
Requires:       texlive-philokalia >= %{texlive_version}
#!BuildIgnore: texlive-philokalia
Requires:       texlive-ptext >= %{texlive_version}
#!BuildIgnore: texlive-ptext
Requires:       texlive-realscripts >= %{texlive_version}
#!BuildIgnore: texlive-realscripts
Requires:       texlive-simple-resume-cv >= %{texlive_version}
#!BuildIgnore: texlive-simple-resume-cv
Requires:       texlive-simple-thesis-dissertation >= %{texlive_version}
#!BuildIgnore: texlive-simple-thesis-dissertation
Requires:       texlive-tetragonos >= %{texlive_version}
#!BuildIgnore: texlive-tetragonos
Requires:       texlive-ucharclasses >= %{texlive_version}
#!BuildIgnore: texlive-ucharclasses
Requires:       texlive-unicode-bidi >= %{texlive_version}
#!BuildIgnore: texlive-unicode-bidi
Requires:       texlive-unimath-plain-xetex >= %{texlive_version}
#!BuildIgnore: texlive-unimath-plain-xetex
Requires:       texlive-unisugar >= %{texlive_version}
#!BuildIgnore: texlive-unisugar
Requires:       texlive-xebaposter >= %{texlive_version}
#!BuildIgnore: texlive-xebaposter
Requires:       texlive-xechangebar >= %{texlive_version}
#!BuildIgnore: texlive-xechangebar
Requires:       texlive-xecolor >= %{texlive_version}
#!BuildIgnore: texlive-xecolor
Requires:       texlive-xecyr >= %{texlive_version}
#!BuildIgnore: texlive-xecyr
Requires:       texlive-xeindex >= %{texlive_version}
#!BuildIgnore: texlive-xeindex
Requires:       texlive-xelatex-dev >= %{texlive_version}
#!BuildIgnore: texlive-xelatex-dev
Requires:       texlive-xesearch >= %{texlive_version}
#!BuildIgnore: texlive-xesearch
Requires:       texlive-xespotcolor >= %{texlive_version}
#!BuildIgnore: texlive-xespotcolor
Requires:       texlive-xetex >= %{texlive_version}
#!BuildIgnore: texlive-xetex
Requires:       texlive-xetex-itrans >= %{texlive_version}
#!BuildIgnore: texlive-xetex-itrans
Requires:       texlive-xetex-pstricks >= %{texlive_version}
#!BuildIgnore: texlive-xetex-pstricks
Requires:       texlive-xetex-tibetan >= %{texlive_version}
#!BuildIgnore: texlive-xetex-tibetan
Requires:       texlive-xetexconfig >= %{texlive_version}
#!BuildIgnore: texlive-xetexconfig
Requires:       texlive-xetexfontinfo >= %{texlive_version}
#!BuildIgnore: texlive-xetexfontinfo
Requires:       texlive-xetexko >= %{texlive_version}
#!BuildIgnore: texlive-xetexko
Requires:       texlive-xevlna >= %{texlive_version}
#!BuildIgnore: texlive-xevlna
Requires:       texlive-zbmath-review-template >= %{texlive_version}
#!BuildIgnore: texlive-zbmath-review-template
Provides:       tex(xetex)
BuildArch:      noarch

%description -n texlive-collection-xetex
Packages for XeTeX, the Unicode/OpenType-enabled TeX by
Jonathan Kew, http://tug.org/xetex.

%package -n texlive-updmap-map
Version:        %{texlive_version}.%{texlive_noarch}.svn54495
Release:        60.1
Summary:        Auto-generated font map files
License:        LPPL-1.0
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Requires(pre):  texlive-filesystem >= %{texlive_version}
Requires(post): coreutils
Requires(postun):coreutils
Requires(postun):texlive >= %{texlive_version}
Requires(postun):texlive-filesystem >= %{texlive_version}
Requires(postun):texlive-kpathsea-bin >= %{texlive_version}
Requires(postun):texlive-kpathsea >= %{texlive_version}
Requires(postun):texlive-scripts-bin >= %{texlive_version}
Requires(postun):texlive-scripts >= %{texlive_version}
Requires(posttrans):coreutils
Requires(posttrans):ed
Requires(posttrans):findutils
Requires(posttrans):grep
Requires(posttrans):sed
Requires(posttrans):texlive >= %{texlive_version}
Requires(posttrans):texlive-filesystem >= %{texlive_version}
Requires(posttrans):texlive-kpathsea-bin >= %{texlive_version}
Requires(posttrans):texlive-kpathsea >= %{texlive_version}
Requires(posttrans):texlive-scripts-bin >= %{texlive_version}
Requires(posttrans):texlive-scripts >= %{texlive_version}
Provides:       tex(builtin35.map)
Provides:       tex(download35.map)
Provides:       tex(kanjix.map)
Provides:       tex(pdftex.map)
Provides:       tex(pdftex_dl14.map)
Provides:       tex(pdftex_ndl14.map)
Provides:       tex(ps2pk.map)
Provides:       tex(psfonts.map)
Provides:       tex(psfonts_pk.map)
Provides:       tex(psfonts_t1.map)

%description -n texlive-updmap-map
These map files are regenerated every time a new font is added.
There is no need to rebuild formats or update binaries because
of such updates, hence this separate package.

%post -n texlive-updmap-map
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update

%postun -n texlive-updmap-map
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
if test $1 = 0; then
    exit 0
fi

%package -n texlive-devel
Version:        %{texlive_version}.%{texlive_noarch}
Release:        60.1
Summary:        Basic development packages for TeXLive
License:        BSD-3-Clause AND LGPL-2.1-or-later AND SUSE-TeX
Group:          Development/Languages/Other
URL:            https://www.tug.org/texlive/
Requires:       texlive-kpathsea-devel = 6.3.5
Requires:       texlive-ptexenc-devel = 1.4.3
Requires:       texlive-synctex-devel = 1.21
Requires:       texlive-texlua-devel = 5.3.6
%if %{with LuaJIT}
Requires:       texlive-texluajit-devel = 2.1.0beta3
%endif
Requires:       texlive-bin-devel >= %{texlive_version}
Requires:       texlive-cweb >= %{texlive_version}
Requires:       texlive-web >= %{texlive_version}

%description -n texlive-devel
This package will cause the installation of several
development packages for TeXLive.

%package -n texlive-alldocumentation
Version:        %{texlive_version}.%{texlive_noarch}
Release:        60.1
Summary:        Attract all documentations of installed TeXLive packages
License:        BSD-3-Clause AND LGPL-2.1-or-later AND SUSE-TeX
Group:          Documentation/Other
URL:            https://www.tug.org/texlive/

%description -n texlive-alldocumentation
This package will attract all the documentation packages of any
already installed TeXLive package.

%package -n texlive-extratools
Version:        %{texlive_version}.%{texlive_noarch}
Release:        60.1
Summary:        Utilities like DviToDvi, PSToPS, and LaCheck
License:        GPL-2.0-or-later AND LPPL-1.0 AND LGPL-2.1-or-later
Group:          Productivity/Publishing/TeX/Base
URL:            https://www.tug.org/texlive/
Obsoletes:      texlive-tools <= %{texlive_previous}
Requires:       psutils
Requires:       texlive-dviasm >= %{texlive_version}
Requires:       texlive-dvidvi >= %{texlive_version}
Requires:       texlive-dvipng >= %{texlive_version}
Requires:       texlive-dvisvgm >= %{texlive_version}
Requires:       texlive-lacheck >= %{texlive_version}
Requires:       texlive-seetexk >= %{texlive_version}

%description -n texlive-extratools
The LaCheck utility is a syntax checker for LaTeX documents.

The DviToDvi utilities are

dvibook       rearranges pages into book signatures, adds blank pages
              as needed
dviselect     selects pages and page ranges
dvitodvi      performs general page rearrangement of selected pages
dviconcat     concatenation of DVI files

Three simple scripts for scaling DIN A4 pages and rearranging two by
two onto a DIN A4 page (a4toa5) are included. The number of pages must
be even (which can be done by odd2even or dvibook).

%prep
pushd %_sourcedir
    chmod g-w *.tar.xz
popd
%setup -c -q -n %name -T

%build

%install
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/updmap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/updmap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/pdftex/updmap
    mkdir -p %{buildroot}%{_bindir}
    mkdir -p %{buildroot}%{_libdir}
    mkdir -p %{buildroot}%{_includedir}
    mkdir -p %{buildroot}%{_infodir}
    mkdir -p %{buildroot}%{_libexecdir}/mktex
    mkdir -p %{buildroot}%{_mandir}
    mkdir -p %{buildroot}%{_mandir}/man1
    mkdir -p %{buildroot}%{_mandir}/man5
    mkdir -p %{buildroot}%{_mandir}/man8
    mkdir -p %{buildroot}%{_texmfmaindir}/tlpkg/TeXLive
    mkdir -p %{buildroot}%{_texmfdistdir}/tlpkg/TeXLive
    mkdir -p %{buildroot}%{_texmfmaindir}/tlpkg/tlpostcode
    mkdir -p %{buildroot}%{_texmfconfdir}/dvipdfm/config
    mkdir -p %{buildroot}%{_texmfconfdir}/dvipdfmx
    mkdir -p %{buildroot}%{_texmfconfdir}/dvips/config
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/urlbst
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/match_parens
    mkdir -p %{buildroot}%{_texmfconfdir}/scripts/mf2pt1
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/amstex/base
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/generic/config
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/generic/tex-ini-files
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/lambda/config
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/mex/base
    mkdir -p %{buildroot}%{_texmfconfdir}/tex/plain/cyrplain
    mkdir -p %{buildroot}%{_texmfconfdir}/web2c
    mkdir -p %{buildroot}%{_texmfconfdir}/xdvi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/config/language.splits
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/m-tx
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pmx
    mkdir -p %{buildroot}%{_texmfmaindir}/scripts/texlive
    mkdir -p %{buildroot}%{_texmfvardir}
    mkdir -p %{buildroot}%{_texmfvardir}/dist
    mkdir -p %{buildroot}%{_texmfvardir}/fonts
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/dvipdfm
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/dvips
    mkdir -p %{buildroot}%{_texmfvardir}/fonts/pdftex
    mkdir -p %{buildroot}%{_texmfvardir}/main
    mkdir -p %{buildroot}%{_texmfvardir}/md5
    mkdir -p %{buildroot}%{_texmfvardir}/web2c
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/aleph
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/eptex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/luatex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/metafont
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/pdftex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/ptex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/tex
    mkdir -p %{buildroot}%{_texmfvardir}/web2c/xetex
    mkdir -p %{buildroot}%{_texmfcache}
    mkdir -p %{buildroot}%{_fontcache}
    mkdir -p %{buildroot}%{_fontcache}/pk
    mkdir -p %{buildroot}%{_fontcache}/source
    mkdir -p %{buildroot}%{_fontcache}/tfm
    mkdir -p %{buildroot}%{_appdefdir}
    mkdir -p %{buildroot}%{_sysconfdir}/permissions.d
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/GUI
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/GUI/configs
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/GUI/pyUIClass
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/GUI/res/icons
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/shaders
    mkdir -p %{buildroot}%{_texmfdistdir}/asymptote/webgl
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/abntex2
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/abstyles
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/amsrefs
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/archaeologie
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/attachfile
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/base
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/beebe
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/biblatex-ms/biblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/biblatex/biblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/cnltx
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/directory
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/dk-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/dtk-bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/frankenstein
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/gloss
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/glossaries-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/gustlib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/harvard
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/ieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/jurabib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/lsc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/nostarch
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/oberdiek
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/spie
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bib/testidx
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aaai-named
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aastex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/abntex2
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/abstyles
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/achemso
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/acmart
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/adfathesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/adrconv
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/afthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aguplus
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aiaa
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aichej
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ajl
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/alpha-persian
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/amscls
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/amsrefs
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/annotate
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/aomart
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/apacite
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/apalike-ejor
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/apalike-german
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/apalike2
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/asaetr
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ascelike
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/asmeconf
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/asmejour
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/authordate
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/babelbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/base
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bath-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/beilstein
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/besjournals
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bestpapers
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bgteubner
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bib-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bibexport
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bibhtml
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/biblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/biblatex-ms
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/biolett-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/bookdb
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cascadilla
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cell
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chem-journal
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chembst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chet
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chicago
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chicago-annote
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chicagoa
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/chscite
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cje
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cmpj
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cnbwp
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/computational-complexity
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/confproc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/context/mkii
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/cquthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/datatool
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/din1505
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/dinat
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/directory
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/dk-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/dlfltxb
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/dvdcoll
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/econ-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/economic
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/els-cas-templates
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/elsarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/fbs
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/fcavtex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/figbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/finbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/francais-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/frankenstein
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/gammas
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/gbt7714
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/germbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/gloss
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/gost
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/gustlib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/harvard
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/hc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/hithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/hitszbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/hitszthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/hustthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ieeepes
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ieejtran
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ijmart
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ijqc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/imac
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/index
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/inlinebib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/iopart-num
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/is-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jbact
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jmb
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jneurosci
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jurabib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/jurarsp
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/kluwer
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/ksfh_nat
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/lion-msc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/listbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/llncs
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/lni
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/mciteplus
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/mnras
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/mslapa
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/multibib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/multibibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/munich
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/nar
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/natbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/nature
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/nddiss
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/newcastle-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/nmbib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/notex-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/opcit
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/perception
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/persian-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/phfnote
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/plainyr
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/pnas2009
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/prtec
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/przechlewski-book
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/quantumarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/resphilosophica
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/revtex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/revtex4
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/revtex4-1
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/rsc
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/sageep
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/sapthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/savetrees
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/seuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/seuthesix
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/shipunov
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/smflatex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/sort-by-letters
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/spie
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/stellenbosch
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/swebib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/texsis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/thubeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/thuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/tufte-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/tugboat
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/udesoftec
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/uestcthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/unamthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/unifith
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/upmethodology
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/urlbst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/vak
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/vancouver
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/bst/zootaxa-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/csf/base
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/csf/dk-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/csf/gost
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/csf/persian-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/bibtex/csf/polish-csf
    mkdir -p %{buildroot}%{_texmfdistdir}/chktex
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/scite/context
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/scite/context/documents
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/scite/context/lexers/data
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/scite/context/lexers/themes
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/texworks
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/texworks/TUG
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/texworks/completion
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/texworks/configuration
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context/keybindings
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context/settings
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context/syntaxes
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context/tasks
    mkdir -p %{buildroot}%{_texmfdistdir}/context/data/vscode/extensions/context/themes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/aleph/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/amstex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/asymptote/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/asymptote/examples/animations
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/abstyles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/alpha-persian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/alpha-persian/image
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/apacite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/apalike-ejor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/apalike-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/authordate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/babelbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bath-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/besjournals
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bestpapers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bib-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bibcop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/biber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/biber-ms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bibexport
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bibhtml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/biolett-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/bookdb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/chicago-annote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/dinat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/dtk-bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/econ-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/econ-bst/customization
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/economic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/francais-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gbt7714
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/germbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gost
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gost/examples/cp1251
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gost/examples/cp1251/bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gost/examples/utf8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/gost/examples/utf8/bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/ieejtran
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/ietfbibs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/ijqc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/inlinebib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/iopart-num
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/is-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/jieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/newcastle-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/perception
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/sort-by-letters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/tamethebeast
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/urlbst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/vak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/vancouver
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex/zootaxa-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtex8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/bibtexu/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/chktex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/documents/general/leaflets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/documents/general/magazines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/documents/general/manuals
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/documents/general/qrcs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/examples/calculator
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/examples/clock
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2005
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2009
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2010
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2011
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2012
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2013
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2014
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2015
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2016
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2017
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2018
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/bachotex/2019
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2007
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2010
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2011
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2012
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2013
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2015
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2016
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2017
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2019
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2020
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/context/2021
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/tug/2001
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/presentations/tug/2007
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/scripts/mkii
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/scripts/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/leaflets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/magazines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/about
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/bidi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/canbedone
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/charts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/cld
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/colors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/columnsets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/details
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/epub
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/evenmore
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/followingup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/hybrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/interaction
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/languages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/libraries
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/lowlevel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/lua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/luametafun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/luametatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/luatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/mathml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/metafun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/mk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/musings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/nodes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/notnow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/onandon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/ontarget
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/pagecolumns
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/primitives
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/publications
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/readme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/rules
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/spacing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/spreadsheets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/sql
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/start
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/start/en
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/start/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/steps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/still
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/svg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/swiglib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/texit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/tiptrick
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/units
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/workflows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/xml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/sources/general/manuals/xtables
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/account
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/algorithmic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/animation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/annotation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/bnf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/chromato
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/cmscbf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/cmttbf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/construction-plan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/cyrillicnumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/degrade
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/enigma/enigma/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/fancybreak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/filter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/fullpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/gantt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/gantt/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/gnuplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/handlecsv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/layout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/letter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/lettrine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/markdown/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/mathsets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/rst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/ruby
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/simplefonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/simpleslides/solutions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/simpleslides/styles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/title
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/transliterator
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/typearea
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/typescripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/vim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/context/third/visualcounter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/cstex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/cstex/cspsfonts-gen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/dvipdfm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/dvipdfmx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/dvipng
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/eplain
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/eplain/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/eplain/util
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/etex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/aboensis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/aboensis/doc/pics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/academicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/accfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/alchemist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/alkalami
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/allrunes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/almfixed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/amiri
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/amsfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arphic-ttf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arphic/bkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arphic/bsmiu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arphic/gbsnu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arphic/gkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/asana-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/asapsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ascii-font
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/astro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/baekmuk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bartel-chess-fonts/other-sources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bbm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bbold-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/belleek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bengali
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/blacklettert1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/boisik/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/auncial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/carolmin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/egothic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/humanist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/huncial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/inslrmaj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/inslrmin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/pgothic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/rotunda
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/rustic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/sqrcaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/tgothic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/bookhands/uncial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/burmese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/calligra-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/carolmin-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cbfonts-fd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cjk-gs-integrate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmbright
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6i
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6k
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6w
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmexb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-6
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-7
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cns/cns40-b5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/concmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/concmath-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/concmath-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/concrete
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/courier-scaled
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cuprum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dejavu-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dingbat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/doulossil
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/droid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/duerer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ebgaramond-maths
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ecc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eco
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eczar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eiad
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ektype-tanka
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/elvish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/enc/c90
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/erewhon-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/esint-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/euler-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eulerpx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/euro-ce
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eurosym/c
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/eurosym/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fandol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/figbas
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/firamath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/firamath-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/encspecs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/examples/basic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/examples/eurofont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/examples/mathptm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/examples/mathptmx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/talks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinst/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontinstallationguide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontmfizz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fontname
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fonts-churchslavonic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fonts-tlwg/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fouriernc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/fpl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/frederika2016
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/garamond-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/genealogy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/assets/css
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/assets/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/pandocfilters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/pdftemp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/productsite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gentium-tug/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsdidotclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsneohellenicmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/notes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/generate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/report
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/report/OpenType
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/script-menu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test/MES-Conformance
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test/ranges/Arabic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/utility/metafont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gnu-freefont/tools/utility/special-purpose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/go
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gothic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/greektex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/greenpoint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hamnosys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/haranoaji
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/haranoaji-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/helmholtz-ellis-ji-notation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hep-font
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hep-math-font
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/heros-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hfbright
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hfoldsty
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ifsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ipaex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/jablantile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/japanese-otf/doc/TeXLive-maps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/jfmutil
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/kixfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/kpfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/latex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/levy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lexend
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lfb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lh/beresta
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lh/fonttest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lh/lhfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lh/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinegc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinus-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinus-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lm-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/logix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mathabx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mathabx-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/memdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/metafont-beginners
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mflogo-font
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/missaali
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mlmodern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/modes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/musixtex-fonts/MuseJazzText
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/musixtex-fonts/frenchtab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/newcomputermodern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/niceframe-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/nkarta
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/noto-emoji
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/obnov
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ocr-b
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ocr-b-outline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ogham
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/oldlatin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/orkhun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/pacioli
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/padauk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/pagella-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/paratype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/phonetic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/phonetic/209
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/plex-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/plex-otf/Examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ptex-fontmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ptex-fontmaps/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/ptex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/punk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/punknova/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/punknova/documentation/documentation-sources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/punknova/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/punknova/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/pxtxalfa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/qpxqtx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/qualitype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/rojud
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/rsfso
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/sanskrit-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/sansmathaccent
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/schola-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/schulschriften
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/shobhika
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/spark-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/staves
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/step
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stix2-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/symbats3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/talos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tapir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/termes-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tex-gyre-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/twemoji-colr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/txuprcal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/typicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/uhc/umj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/umtypewriter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/unfonts-core
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/unfonts-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/universa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/uppunctlm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/uptex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/urwchancal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/variablelm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/venturisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/dgj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/dmj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/mc2j
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/mcj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/mr2j
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wadalab/mrj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wasy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wasy-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wnri/old
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wsuipa/latex209
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wsuipa/latex2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/wsuipa/text1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/xcharter-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/xits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/xq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/yannisgr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/yfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/yfonts-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/yinit-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/zhmetrics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/zhmetrics-uptex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/zhmetrics-uptex/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/fonts/zlmtt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/2up
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/abbr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/apnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/armenian/examples/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/armenian/examples/plain
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/around-the-bend
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/arrayjobx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/autoaligne
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/autosp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-albanian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-azerbaijani
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-basque
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-belarusian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-bosnian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-breton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-bulgarian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-catalan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-croatian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-czech
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-esperanto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-friulan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-galician
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-georgian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-greek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-hungarian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-icelandic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-indonesian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-interlingua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-japanese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-kurmanji
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-latin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-latvian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-macedonian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-malay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-norsk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-occitan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-piedmontese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-romanian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-romansh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-russian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-samin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-scottish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-serbianc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-slovak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-slovenian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-sorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-swedish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-thai
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-turkish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-ukrainian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-vietnamese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/babel-welsh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/bagpipe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/barr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/bitelist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/borceux/compatibility
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/c-pascal/prog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/catcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/chemfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/chronosys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/colorprofiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/colortab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/commado
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/commutative-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/components
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/crossrefenum/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/crossrefenum/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/dcpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/dehyph-exptl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/dirtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/doc-pictex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/docbytex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/dowith
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/dratex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/bin/linux
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/bin/windows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/install
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/manuels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/test/XeLaTeX
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/e-french/test/tests-formats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ean
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/elhyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/enctex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/encxvlna
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/epsf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/epsf/okay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/es-tex-faq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/expex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/expex-acro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/fenixpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/fixjfm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/fltpoint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/fntproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/formlett
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/frame
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/gates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/german/betatest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/gobble
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/gtl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hologo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/huhyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hyph-utf8/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hyph-utf8/languages/es
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hyph-utf8/languages/hu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/hyph-utf8/languages/sa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ifptex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/iftex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ifxptex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/insbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/kastrup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-errata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/ctie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/cweb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/errata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/etc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/mf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/mfware
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/other
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/texware
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/tie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/web
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-hint/xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/ctie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/cweb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/errata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/etc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/mf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/mfware
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/other
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/texware
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/tie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/web
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/knuth-pdf/xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/langcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/lecturer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/librarian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/listofitems
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/localloc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/lpform
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/lt3luabridge
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ltxcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/luatex85
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/m-tx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/mathdots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/mfpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/mfpic/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/midnight
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/minifp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/mkjobtexmf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/modulus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/multido
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/multiexpand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/musixcrd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/musixdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/musixftab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/musixlyr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/musixlyr/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/notationMistakes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/psslurs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/reference
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtex/scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/musixtnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/namedef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/navigator
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ofs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/olsak-misc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/path
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pdf-trans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pdfmsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pdftexcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/petri-nets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pgf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pgfplots/license_prepcontour
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pictex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/plainpkg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pmx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pmx/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/polexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/poormanlog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/poster-mac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-2dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-abspos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-am
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-antiprism
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-arrow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-asr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-bar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-barcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-barcode/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-bezier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-bspline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-calculate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-cie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-circ
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-coil
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-contourplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-contourplot/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-cox/pst-coxcoor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-cox/pst-coxeterp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-dart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-dbicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-diffraction
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-electricfield
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-eps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-eucl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-feyn/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-fill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-fit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-fr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-fractal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-fun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-func
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-gantt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-geo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-geo/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-geometrictools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-gr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-grad
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-graphicx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-hsb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-infixplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-jtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-knot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-labo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-lens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-light3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-lsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-magneticfield
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-marble
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-marble/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-mirror
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-mirror/createEPS
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-mirror/createEPS/scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-moire
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-moire/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-node
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-ob3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-ode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-ode/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-optic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-osci
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-ovl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-pad
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-pdgr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-perspective
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-platon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-plot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-plot/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-poly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-pulley
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-rputover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-rubans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-shell/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-shell/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-sigsys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-slpe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-solarsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-solides3d/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-solides3d/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-solides3d/text
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-soroban
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-spinner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-spinner/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-stru
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-support
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-text
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-thick
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-tree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-turtle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-tvz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-uml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-vehicle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pst-venn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pstricks-add
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pstricks-add/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/pstricks/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/random
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/randomlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/reverxii
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/rlepsf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/schemata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/shade
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/shapepar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/simplekv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/soul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/systeme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/t2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/t2/etc/rubibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/t2/etc/rumkidx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/t2/etc/utf-8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/t2/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tap/tapcv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tap/tapcv/sampdos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/termmenu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-ewd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-ini-files
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-locale
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-locale/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-ps/cmyk-hax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-ps/poligraf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-refs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/context
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/fonty
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/gify
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/idx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/kuchnia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/listy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/macro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/spisy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/tytuly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/poczatki
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/podstawy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/prog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/prog/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tex4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/texapi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/texdate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/texdimens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/textmerg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/thumbpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tikzducks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tokcycle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tracklang
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tracklang/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tracklang/samples/animals
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/tracklang/samples/regions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/trigonometry
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ukrhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/ulem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/unicode-data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/upca
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/upzhkinsoku
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/variations
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/vaucanson-g
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/vaucanson-g/VCManual-src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/witharrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xcomment
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xlop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xstring
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xypic-tut-pt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/xypic/support
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/yax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/youngtab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/generic/zhspacing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/hitex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/kpathsea
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/amsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/firstaid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/latex-lab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex-dev/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/12many
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/a0poster
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/a4wide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/a5comb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aalok
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aastex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abntex2/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abntexto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abraces
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abspos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/abstract
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/accents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/accessibility
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/accsupp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/achemso
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/acmart/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/acmconf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/acro/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/acronym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/acroterm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/active-conf/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/actuarialangle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/actuarialsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/addfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/addlines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adfathesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adigraph/img_examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adjmulticol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adjustbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adrconv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages/Contents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages/QuickLook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/adtrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/advdate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aeguill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/afparticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/afthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aguplus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aiaa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/paper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/refs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/subfigs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/talk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/akktex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/akletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/akshar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alertmessage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algobox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algorithm2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algorithmicx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algorithms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algpseudocodex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/algxpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aligned-overset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alnumsec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alphalph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alterqcm/examples/iut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alterqcm/examples/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/alterqcm/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/altfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/altsubsup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amiweb2c-guide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsaddr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amscdx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amscls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amscls-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amslatex-primer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsldoc-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsldoc-vn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsmath-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsrefs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/amsthdoc-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/animate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/annee-scolaire
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/annotate-equations
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/anonchap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/anonymous-acm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/answers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/antanilipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/anufinalexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/anyfontsize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/anysize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aobs-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aomart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apa6/pseudoTeX
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apa6/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apa6e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apa7/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/appendixnumberbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apprends-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apprends-latex/exemples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apptools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/apxproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arabi-add
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arabicfront
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/archaeologie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arcs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arraycols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arraysort
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arsclassica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arsclassica/Chapters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arsclassica/FrontBackMatter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arsclassica/Graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/articleingud
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/arydshln
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asaetr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ascelike
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asciilist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/askinclude
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/askmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asmeconf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asmeconf/examples/asmeconf-wide-equation-example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asmejour
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asmejour/asmewide_example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/assignment
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/assoccnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/association-matrix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asternote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asyfig/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/asypictureb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/atbegshi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/atenddvi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/atendofenv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/attachfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/attachfile2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/atveryend
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aucklandthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/augie/other
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/augie/vtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/aurl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/authoraftertitle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/authorarchive/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/authorarchive/examples/bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/authorindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/auto-pst-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/auto-pst-pdf-lua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/autoarea/autodemo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/autobreak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/autofancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/autonum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/autopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/auxhook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/avremu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/awesomebox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/axessibility
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/axodraw2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/b1encoding
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/babel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/background
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/backnaur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bangla
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bangorcsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bangorexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bangtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bankstatement
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/barcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bardiag/example/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bardiag/figs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bardiag/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bashful
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/basicarith
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/basque-book
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/basque-date
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bbding
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bbm-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bbold
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bchart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bclogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer-fuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer-tut-pt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer-verona
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/emulation-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/examples/a-conference-talk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/examples/a-lecture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/licenses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/solutions/conference-talks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/solutions/generic-talks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer/solutions/short-talks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamer2thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerappendixnote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beameraudience
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerauxtheme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Hannover-dark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Hannover-light
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Pittsburgh-dark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Pittsburgh-light
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/metropolis-dark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/metropolis-light
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerdarkthemes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerposter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamersubframe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerswitch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-arguelles/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-cuerna
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-cuerna/pictures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-detlevcm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-epyt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-focus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-focus/focus-demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-light
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-metropolis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-npbt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-npbt/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-phnompenh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-pure-minimalistic/logos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-saintpetersburg/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-simpledarkblue
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-simpleplus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-tcolorbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-trigon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamertheme-upenn-bc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerthemeamurmaple
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerthemelalic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerthemenirma
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beamerthemenord/screenshots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bearwear
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beaulivre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/begingreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/begriff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beilstein
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/betababel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/beton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bewerbung
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bez123
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bfh-ci
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bgteubner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibarts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-abnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-abnt/tests
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ajc2020unofficial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-anonymous
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-apa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-apa6
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-archaeology/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-arthistory-bonn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bookinarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bookinarticle/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bookinother
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bookinother/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-bwl/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-caspervector
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-cheatsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-chem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-chicago
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-claves
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-claves/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-dw/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-enc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-fiwi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-gb7714-2015
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-german-legal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-gost
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-historian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ieee
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ijsra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-iso690
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-jura2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-juradiss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-license
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-lncs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-lni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-luh-ipw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-manuscripts-philology
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-manuscripts-philology/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-mla/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-morenames
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-morenames/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ms/biber/bltxml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-ms/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-multiple-dm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-musuos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-nature
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-nejm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-nottsclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-opcit-booktitle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-opcit-booktitle/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-oxref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-philosophy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-phys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-publist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-readbbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-realauthor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-realauthor/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-sbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-science
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-shortfields
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-shortfields/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-socialscienceshuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-software
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-source-division
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-spbasic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-subseries
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-subseries/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-swiss-legal/doc_source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-trad
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-true-citepages-omit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-unified
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex-vancouver
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex/biber/bltxml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblatex2bibitem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref-lds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref-mouth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref-parse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibleref/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibletext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biblist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibtopic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibtopicprefix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bibunits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bigfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bigintcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bigints
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bilingualpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/binarytree/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/binomexp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biochemistry-colors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/biocon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bitpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bitset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bizcard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bjfuthesis/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bjfuthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bjfuthesis/example/contents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bjfuthesis/example/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/blindtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/blkarray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/blochsphere
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/block
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bloques
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/blowup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/blox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bmstu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bmstu-iu8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bmstu/examples/inc/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bmstu/examples/inc/lst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bnumexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bodegraph/gnuplot/bodegraph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bodeplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bohr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/boites
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bold-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/boldtensors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bondgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bondgraphs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/book-of-common-prayer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bookcover/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bookest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/booklet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bookmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bookshelf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/booktabs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/booktabs-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/booktabs-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/boolexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bophook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bosisio
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/boxedminipage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/boxhandler
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bpchem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/br-lex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bracketkey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/braids
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/braille
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/braket
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/brandeis-dissertation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/brandeis-problemset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/brandeis-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/breakcites
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/breakurl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bredzenie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/breqn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bropd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bubblesort
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bullcntr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bussproofs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bussproofs-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxbase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxcjkjatype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxdpx-beamer/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxdvidriver
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxeepic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxenclose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxghost
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxjaholiday
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxjalipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxjaprnind
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxjatoucs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxjscls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxnewfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxorigcapt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxpapersize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxpdfver
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxtexlogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bxwareki
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/byo-twemojis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/bytefield
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cachepic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calcage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calctab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calculation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calculator
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calligra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/callouts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calrsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/cell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/colsep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/decoration
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/llt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/regression
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/rowsep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/span
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/support
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/table
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cals/test/visual_tables
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/calxxxx-yyyy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cancel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/canoniclayout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/capt-of
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/captcont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/captdef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/caption
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/carbohydrates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/carlisle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cartonaugh/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cascade
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cascadilla
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cases
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/casyl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/catchfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/catchfilebetweentags
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/catechis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/catoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/causets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cbcoptic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ccaption
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ccfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cclicenses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ccool
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cd-cover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cdcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cdpbundl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cellprops
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cellspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/celtic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/censor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/centeredline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/centerlastline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cesenaexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cfr-initials
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changebar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changelog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changes/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changes/regression
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/changes/userdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chappg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chapterfolder
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chbibref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cheatsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/checkend
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/checklistings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chembst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemcompounds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemcono
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemexec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemformula
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemmacros
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemobabel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemplants
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemschemex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemsec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chemstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chess-problem-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chessboard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chessfss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chextras
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chhaya
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chifoot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/childdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chinesechess
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chkfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chngcntr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chordbars
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chordbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chronology
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chs-physics-report
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/chscite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/churchslavonic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circ
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circledsteps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circledtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/dpv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/extras
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/mf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/mpost
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/psfrag
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuit-macros/examples/xfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/citation-style-language
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/citeall
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/citeref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cje
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk-ko
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/chinese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/cjk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/japanese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/Bg5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/GB
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/JIS
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/SJIS
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/examples/cjk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/examples/pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/texlive
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjk/utils/pyhyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjkpunct/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cjkpunct/setpunct
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/classics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/classicthesis/Chapters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/classicthesis/Examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/classicthesis/FrontBackmatter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/classicthesis/gfx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cleanthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cleanthesis/content
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cleanthesis/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cleanthesis/gfx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clefval
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cleveref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clicks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clipboard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clistmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clock
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clrdblpg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clrscode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clrscode3e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/clrstrip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmbright
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmdstring
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmdtrack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmpica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmpj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmsd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cmtiup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cnbwp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cnltx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cntformats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cntperchap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codeanatomy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codebox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codedoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codehigh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codesection
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/codicefiscaleitaliano
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coffeestains
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/collcell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/collectbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/collref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colophon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/color-edits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colordoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorframed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coloring
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colortbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorwav
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colorweb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/colourchange
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/combelow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/combine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/combinedgraphics/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/comma
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/commath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/commedit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/comment
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/commonunicode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/competences
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/complexity
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/comprehensive
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/comprehensive/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/computational-complexity
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/concepts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/concprog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/conditext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/conditext/conditext-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_001
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_003
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_005
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_007
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/papers/sources_tex/p_009
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/pictures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_001
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_003
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_005
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_007
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/confproc/example/sources_tex/p_009
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/constants
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/conteq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/continue
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/contour
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/contracard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/conv-xkv/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/conv-xkv/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cooking
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cooking-units
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cookingsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cool
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coolfn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coollist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coolstr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coolthms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cooltooltips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coop-writing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coordsys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/copyedit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/copyedit/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/copyrightbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/correctmathalign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coseoul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/counttexruns
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/courseoutline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coursepaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/coverpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/covington
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cprotect
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cprotectinside
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cquthesis/contents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cquthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cquthesis/ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/create-theorem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crefthe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crossreference
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crossreftools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crossword
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crosswrd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/crumbs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cryptocode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cryst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csassignments
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csbulletin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csquotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csquotes-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/css-colors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csvmerge
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/csvsimple
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ctable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ctanify
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ctex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ctex-faq/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ctib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cuisine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/currency
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/currfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/currvita
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cursolatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/curve
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/curve/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/curve2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/curves
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/custom-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/customdice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cutwin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cv4tw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cvss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/contrib/cweb-hy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/contrib/wagner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/examples/compare
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/src/style
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cweb-latex/src/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cyber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cybercic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/darkmode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dashbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dashrule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dashundergaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dataref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datatool/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dateiliste
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datenumber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-bahasai
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-basque
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-breton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-bulgarian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-catalan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-croatian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-czech
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-en-fulltext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-esperanto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-galician
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-greek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-icelandic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-it-fulltext/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-italian/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-latin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-lsorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-magyar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-norsk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-romanian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-russian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-samin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-scottish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-slovak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-slovene
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-swedish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-turkish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-ukrainian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-usorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2-welsh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/datetime2/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dblfloatfix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dbshow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dccpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ddphonism
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/debate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/decimal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/decision-table
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/decorule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/delim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/delimseasy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/delimset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/delimtxt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/democodetools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/denisbdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/derivative
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dhua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diabetes-logbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diabetes-logbook/QQ/TEST
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diadia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diagbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diagmac2/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diagnose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dialogl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dichokey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/minexample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/novices/pictures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/novices/term-defs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/thesis/imgsource
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/thesis/listing-samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dickimaw/src/thesis/pictures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/diffcoeff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/digiconfigs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dijkstra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dimnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/din1505
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dinbrief
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/directory
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dirtytalk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/include
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/bachelor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/bachelor/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/candidate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/candidate/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/doctor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/doctor/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/master
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/master/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/specialist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates-utf8/specialist/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/bachelor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/bachelor/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/candidate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/candidate/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/doctor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/doctor/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/master
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/master/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/specialist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/disser/templates/specialist/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ditaa/resources/ditaa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dk-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dlfltxb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dnaseq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/doclicense
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/docmfp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/docmute
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/docshots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/docsurvey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/doctools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/docutils
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/doi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/doipubmed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dot2texi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dot2texi/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dotarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dotlessi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dotseqn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dottex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/download
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dpcircling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dpfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dprogress
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/drac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/draftcopy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/draftfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/draftwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dramatist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/drawmatrix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/drawstack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/droit-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/droit-fr/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/drs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dsptricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dtk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dtk/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dtxdescribe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dtxgallery
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dtxtut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ducksay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/duckuments
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/duerer-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/duotenzor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dvdcoll
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dvgloss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dviasm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dviinfox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dynamicnumber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dynblocks/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dynkin-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/dyntree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ean13isbn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easy-todo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easy/for-latex2html
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easybook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyfloats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyfloats/content
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyfloats/lexer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyfloats/preamble
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyformat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easylist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/easyreview/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ebezier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ebook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ebproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ebsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecclesiastic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecgdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecltree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecobiblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/econlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/econometrics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecothesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap01
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap02
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap03
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecothesis/preambulo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ecv/template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/edfnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/edichokey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/edmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/edmargin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eemeir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eepic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eepic/fig2eepic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/efbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/egameps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/egplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ehhline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eiad-ltx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/einfart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ejpecp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ekaia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elbioimp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eledform
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eledform/include
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eledmac/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elements
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ellipse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ellipsis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elocalloc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elpres
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/els-cas-templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/els-cas-templates/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elsarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elteikthesis/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elteikthesis/samples_en
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elteikthesis/samples_hu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/elzcards
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emarks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/embedall
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/embedfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/embrac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emisa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emoji
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emptypage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/emulateapj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endheads
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endnotes-hy/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endnotes-hy/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endnotesj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/endofproofwd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/engpron
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/engrec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/engtlc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/enotez
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/enumitem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/enumitem-zref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/envbig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/environ
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/envlab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eolang
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epigraph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epigraph-keys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epiolmec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epsdice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epslatex-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epspdfconversion/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/epstopdf-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eq-pin2corr/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eq-pin2corr/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqexpl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqnalign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqnarray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqnnumwarn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eqparbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/erdc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/errata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/erw-l3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esami
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esami/doc/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esieecv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eskd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eskdx/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eskdx/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eskdx/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eso-pic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/estcpmm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etaremune
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etdipa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etdipa/Data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etdipa/Help
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etdipa/Images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etdipa/Textparts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etex-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etexcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etextools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ethiop-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etoolbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etoolbox-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/etsvthor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/euclideangeometry
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/euenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/euflag
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eukdate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/eulervm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/euro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/europasscv/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/europecv/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/europecv/templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/everyhook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/everypage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/everysel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/everyshi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam-lite/imgs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam-n
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam-n/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam-n/sample/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exam-randomizechoices
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/examdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/examplep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exceltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/excludeonly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exercise
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exercisebank
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exercisepoints
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exercises
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exesheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exframe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exp-testopt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expdlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expkv-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/export
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/bibliographie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/codes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/extensions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/glosaires
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exsheets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/exsol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/extarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/extpfeil
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/extract
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/extsizes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/facsimile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/factura
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/faktor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/familytree/doc-ja
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/familytree/doc-ja/figs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/familytree/figs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/familytree/samples/Asai
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/familytree/samples/Tokugawa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancybox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyhandout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyhdr-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancylabel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancynum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancypar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyqr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyslides/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancytabs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancytooltips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancytooltips/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancytooltips/examples/pics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fancyvrb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fascicules/guide/ch4_mon_chapitre/content
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fascicules/guide/ch4_mon_chapitre/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fascicules/guide/content/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fascicules/guide/solutions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fast-diagram/sources_help
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fast-diagram/sources_help/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fbithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fcavtex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fcavtex/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fcltxdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fcolumn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fei
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fetchcls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/feupphdteses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/feupphdteses/Figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fewerfloatpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/feynmf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/feynmp-auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ffcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ffslides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fgruler
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fifinddo-info/variants
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fifo-stack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figchild
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figput/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figput/figput-manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figput/javascript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figput/javascript/development
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figput/javascript/release
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/figsize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/filecontents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/filecontentsdef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/filedate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/filehook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/filemod
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fink
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/finstrut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/first-latex-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/firstaid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fistrum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fitbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fix2col
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixcmex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixdif
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixltxhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fixmetodonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fjodor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flabels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flacards
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flagderiv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flashcards
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flashmovie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flashmovie/flv-player-license
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flexipage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flipbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an1b
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flipbook/Images/Anims/anASCII
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flippdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/float
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/floatrow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flowchart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/flowfram/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fmp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fmtcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fn2end
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fnbreak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fncychap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fncylab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fnpara
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fnpct
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fnspe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fnumprint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/foekfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/foilhtml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/foliono/pics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fontaxes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fontsetup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fontsize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fontspec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fonttable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footmisc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footmisx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footnotebackref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footnotehyper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footnoterange
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/footnpag/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forarray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/foreign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forest-quickstart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forloop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/formal-grammar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/formation-latex-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forms16be/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/forms16be/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/formular
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fouridx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fragments
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/framed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frankenstein/unsupported
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frege
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frenchmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frontespizio
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/froufrou
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/frpseudocode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftc-notebook/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftc-notebook/src/aug19
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftc-notebook/src/bio
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftc-notebook/src/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftcap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ftnxtra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fullblck
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fullminipage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fullwidth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/functan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/functional
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fundus-calligra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fundus-sueterlin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fvextra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/fwlw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/g-brief
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gaceta
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/galois
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gamebook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gamebooklib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gammas
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gastex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gatherenum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gauss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gb4e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gcard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gchords
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gcite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gckanbun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gender
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gene-logic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/genealogytree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/genmpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gensymb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gentombow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/geometry
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/geradwp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/germkorr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/geschichtsfrkl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/getfiledate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/getitems
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/getmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gettitlestring
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gfdl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ghab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ghsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gillcm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gincltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ginpenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gitinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gitinfo2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gitlog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gitstatus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gitver
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/globalvals
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glosmathtools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gloss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gloss-occitan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-extra/glossaries-extra-manual-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-extra/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-magyar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-nynorsk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-slovene
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries/glossaries-user-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/glossaries/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmdoc-enhance
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmdoc/basedrivers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmiflink
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmutils
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmverb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gmverse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gnuplottex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gotoh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grabbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gradient-text
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gradientframe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grading-scheme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gradstudentresume
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grafcet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grant
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graph35
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphics-cfg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphics-def
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicscache
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicx-psmin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicxbox/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicxbox/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicxbox/examples/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphicxpsd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/graphviz/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grayhints/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grayhints/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/greek-fontenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/greek-inputenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/greekdates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/greektonoi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grfext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grffile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grfpaste
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grfpaste/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grid-system
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gridpapers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gridpapers/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gridset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gridslides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gridslides/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/grundgesetze
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gs1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gsemthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gtrcrd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gtrlib-largetrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap10
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap11
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap15
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap6
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap7
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guitar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guitarchordschemes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guitartabs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/guitlogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gzt/english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/gzt/french/sections
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/h2020proposal/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/h2020proposal/template-fet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/h2020proposal/template-ict
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ha-prosper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hackthefootline/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hagenberg-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/halloweenmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/handin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/handout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/handout/examples/txt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/handoutwithnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hang
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hanging
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/har2nat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hardwrap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/harmony
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/harnon-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/harpoon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/harvard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/harveyballs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hausarbeit-jura
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/havannah
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/he-she
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hecthese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-acronym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-float
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-paper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-reference
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-text
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hep-title
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hepnames
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hepparticles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hepthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hepthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hepunits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/here
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hereapplies
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hereapplies/lyx-module
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hexboard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hexgame
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hf-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hfutexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hhtensor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hideanswer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/highlightlatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hindawi-latex-template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/histogr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/historische-zeitschrift
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitreport/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitreport/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitreport/photo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitreport/ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszbeamer/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszthesis/back
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszthesis/body
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hitszthesis/front
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hobby
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hobete
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hobsub
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hopatch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/horoscop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hpsdiss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/href-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hrefhide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hrlatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/huawei
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/huaz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hulipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hustthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvarabic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvextern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvlogos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvpygmentex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hvqrurl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hwemoji
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hycolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hypdestopt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hypdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hypdvips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hypdvips/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyper/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyper/scontrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyperbar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hypernat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyperref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyperxmp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/hyphenat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ibrackets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ibycus-babel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/icite/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/icsv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/identkey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/idxcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/idxlayout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ieeeconf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ieeepes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ieeetran/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ieeetran/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iexec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifallfalse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iffont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifmslide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifmtarg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifnextok
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifoddpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifplatform
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ifthenx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iitem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ijmart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ijsra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/imac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/image-gallery
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/imakeidx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/impnattypo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/import
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/imtekda/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/incgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/includernw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/index
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/indextools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/infwarerr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inkpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inline-images/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inline-images/screenshots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inlinedef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inlinelabel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inputenx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inputnormalization
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inputtrc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn/chapter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/intcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/interactiveworkbook/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/interactiveworkbook/epsfiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/interactiveworkbook/samplefiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/interfaces
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/interval
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/intopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/intro-scientific
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/inversepath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/invoice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/invoice-class/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/invoice2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/abstract
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/acronyms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/customizing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/how-to-use-iodhbwm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/listings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/references
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/titlepages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/examples/titlepages/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/i18n/english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iodhbwm/i18n/ngerman
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ionumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iscram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iso
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iso10303
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isodate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isodoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isomath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isonums
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isopt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isorot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/isotope
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/issuulinks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/istgame
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/itnumpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/iwhdp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jacow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jamtimes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jeuxcartes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jigsaw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jkmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jknapltx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jlabels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jlreq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jmlr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jmsdelim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jneurosci
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jnuexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jobname-suffix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jourcl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jourcl/imgs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jpneduenumerate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jpnedumathsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jpsj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jslectureplanner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jslectureplanner/examples/English
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jslectureplanner/examples/German
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jumplines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jupynotex/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jupynotex/tests
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jura
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/juraabbrev
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jurabib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jurabib/docs/english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jurabib/docs/german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/juramisc/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/juramisc/doc/jbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jurarsp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jvlisting
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/jwjournal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kalendarium
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kanbun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kantlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/karnaugh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/karnaugh-map
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/karnaughmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kaytannollista-latexia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kblocks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kdgdocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kdpcover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kerntest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keycommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyfloat/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyparse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyreader
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keystroke
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyval2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/keyvaltable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kfupm-math-exam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kinematikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kluwer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/knittingpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/knowledge
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-moderncvclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script-sfs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/koma-script/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/komacv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/komacv-rg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/komacv/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kotex-oblivoir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kotex-utf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kotex-utf/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kotex-utils
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/preamble
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ksp-thesis/demo/minimal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ktv-texdata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ku-template/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kvdefinekeys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kvmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kvoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/kvsetkeys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2picfaq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2tabu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2tabu-english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2tabu-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2tabu-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l2tabu-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3backend
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3build
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3benchmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3bitset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3draw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3opacity
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3str
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/l3sys-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/xcoffins
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3experimental/xgalley
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3kernel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3packages/l3keys2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3packages/xfp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3packages/xfrac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3packages/xparse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/l3packages/xtemplate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/labbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/labels/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/labels4easylist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/labelschanged
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/labyrinth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ladder
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lambdax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/langnames
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/langsci-avm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lapdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lastpackage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lastpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-brochure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-course
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-course/Graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-doc-ptr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-for-undergraduates/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-graphics-companion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-lab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-mr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-refsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-uni8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-veryshortguide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-via-exemplos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/apa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/apb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/apc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch6
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch7
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex-web-companion/ch7/SGMLS
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex2e-help-texinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex2e-help-texinfo-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex2e-help-texinfo-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex2e-help-texinfo/graphics/asy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex2e-help-texinfo/latex2e-figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex4musicians
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex4musicians/Figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex4wp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latex4wp-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexbangla
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexbug
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcheat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcheat-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcheat-esmx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcheat-ptbr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcolors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexcourse-rug
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexdemo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexfileinfo-pkgs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latexgit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/latino-sine-flexione
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/layaureo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/layouts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lazylist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lccaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lcd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lcg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lcyw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leading
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leadsheets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leaflet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lebhart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lectures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lectureslides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leftidx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leftindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/leipzig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lengthconvert
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/letltxmacro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/letterswitharrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lettre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lettrine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lewis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lexikon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lexref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lgrmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lhelp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/libgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lie-hasse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/liftarm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lilyglyphs/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lilyglyphs/documentation/lilyglyphs_logo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lilyglyphs/documentation/resources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lilyglyphs/license
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/limap/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/limecv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/limecv/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/linegoal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lineno
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ling-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/linguex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/linop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lion-msc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lisp-on-tex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listings-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listingsutf8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listlbls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listliketab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/listofsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/liturg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lkproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/llncs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/llncsconf/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lmake
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/locality
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logical-markup-utils
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logicproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logicpuzzle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logpap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/logreq/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/longdivision
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/longfbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/longfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/longnamefilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/loops
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lplfitch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lroundrect
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lsc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-bulgarian/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-chinese/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-chinese/src/chap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-czech/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-estonian/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-finnish/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-german
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-japanese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-korean
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-mongol/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-persian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-portuguese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-russian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-slovak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-slovenian/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-spanish/fuente/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-thai
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-turkish
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-ukr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lshort-vietnamese/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lstaddons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lstbayes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lstfiracode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lt3graph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lt3rawobjects
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltablex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltabptch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltb2bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltxdockit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltxguidex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltxkeys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltxnew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ltxtools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/luacolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lualatex-doc-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/lwarp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/macrolist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/macros2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/macroswap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mafr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/magaz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/magicnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/magicwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mahjong
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mailing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mailmerge
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makebarcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makebase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makebox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makecell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makecmds
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makeglos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makelabels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makeplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/maker
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makerobust
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/makeshape
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mandi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/manfnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/manuscript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/manyind
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/marathi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/margbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/marginfit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/marginfix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/marginnote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/markdown/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matapli
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matapli/auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matapli/examples/couverture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matapli/examples/modeleauteur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matc3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matc3mem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/math-into-latex-4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathalpha
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathastext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathcomp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathfam256
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathfixs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathpartir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathpazo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathpunctspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/maths-symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathsemantics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathspic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mathtools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matlab-prettifier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/matrix-skeleton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mattens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/maybemath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/maze
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcaption
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mceinleger
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mciteplus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcmthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcmthesis/code
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mcmthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mdframed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mdputu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mdwtools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mecaso
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/media4svg/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/media9
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/medstarbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/meetingmins/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/membranecomputing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/memexsupp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/memoir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/memoirchapterstyles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/memory
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/memorygraphs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mensa-tex/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mentis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/menu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/menucard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/menukeys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mercatormap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/messagepassing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metalogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metalogox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metanorma
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metaplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metaplot/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metastr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/method
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/metrix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mfirstuc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mflogo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mfnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mfpic4ode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mfpic4ode/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mftinc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mgltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mhchem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mhequ
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mi-solns/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mi-solns/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/microtype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/microtype-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/midpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/miller
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/milog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/milsymb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/milsymb/manual_examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/milsymb/manual_scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mindflow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minibox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minidocument
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minim-hatching
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minimalist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minipage-marginpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/miniplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minitoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minitoc/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minitoc/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minorrevision
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minted
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/minutes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mismath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mla-paper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mlacls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mleftright
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mluexercise
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mnras
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mnras/legacy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modeles-factures-belges-assocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moderncv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moderncv/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modernposter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moderntimeline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modroman
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modular
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/modular/doc/example/octopus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mongolian-babel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/monofill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/montex/mfinput/bithe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moodle/test/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moodle/test/latin1ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moodle/test/utf8ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moreenum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/morefloats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/morehype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/morehype/blogdemo/hellowor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/morehype/blogdemo/writings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moresize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/moreverb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/morewrites
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/movie15
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/movie15/files
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/movie15/javascript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mparhack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mpgraphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mpostinl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/msc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/msg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mslapa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/msu-thesis/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/msu-thesis/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mtgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mucproc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mugsthesis/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/muling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multenum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multiaudience
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multibbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multibib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multibibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multicap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multicolrule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multidef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multienv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multifootnote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multilang
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multiobjective
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multiple-choice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/multirow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/munich
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/musical
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/musicography
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/musikui
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/musixguit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/musuos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/muthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mversion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mwcls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mwe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mweights
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mycv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mycv/Doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mycv/Doc/Images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mycv/Examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mylatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/mylatexformat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nag
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/naive-ebnf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nameauth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/namedtensor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/namespc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/natbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/natded
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nature
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/navydocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/navydocs/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ncclatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ncctools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nchairx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nddiss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ndsu-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ndsu-thesis-2022
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ndsu-thesis-2022/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/needspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/neuralnetwork/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nevelok
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newenviron
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newlfm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newpax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newspaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newunicodechar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newvbtm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/newverbs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nfssext-cfr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nicefilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/niceframe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nicematrix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nicetext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nicetext/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nidanfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nih
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nihbiosketch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nimsticks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ninecolors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/njurepo/ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/njustthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/njuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/njuvisual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nl-interval
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nlctdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nmbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nndraw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nnext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/noconflict
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/noindentafter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/noitcrul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nolbreaks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nomencl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nomentbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nonfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nonumonpart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nopageno
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/normalcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nostarch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/notes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/notes2bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/notespages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/notestex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/notoccite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nowidow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nrc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ntgclass
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ntheorem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ntheorem-vn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ntheorem-vn/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nuc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nucleardata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numberedblock
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numberpt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numerica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numerica-plus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numerica-tables
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numericplots/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numericplots/src/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numname
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numnameru
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numprint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/numspell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwafuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwafuthesis/logo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwejm/addons/completion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwejm/english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwejm/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/nwejm/french
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oberdiek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oberdiek/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/objectz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ocg-p
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ocg-p/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ocgx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ocgx2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ocr-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/octave
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/octavo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/onedown
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/onedown/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/onlyamsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/onrannual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/opcit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/opencolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oplotsymbl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/opteng
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/optidef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/optional
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/options
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/orcidlink
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ordinalpt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/orientation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oscola
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ot-tableau
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/othello
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/othelloboard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oubraces
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oup-authoring-template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/oup-authoring-template/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/outilsgeomtikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/outline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/outliner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/outlines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/outlining
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/overarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/overlays
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/overpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/padcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagecolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagecont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagegrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagenote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagerange
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pagesel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pageslts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/palette
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pangram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/paper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/papercdcase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/papermas
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/papertex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/papertex/example/img/weather
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/paracol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parades
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parades/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/paralist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parallel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/paresse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parrun
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parselines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/parskip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pas-cours
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pas-crosswords
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pas-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pas-cv/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pas-tableur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pascaltriangle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/patchcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pauldoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pawpict
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pb-diagram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbalance
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbibtex-manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbsheet/xpl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbsheet/xpl/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pbsheet/xpl/pgm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdf14
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfcol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfcolfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfcolmk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfcomment
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfcprot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfescape
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdflscape
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfmanagement-testphase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfmarginpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfoverlay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpagediff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpagediff/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpagediff/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfpc-movie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfprivacy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfreview
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfscreen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfslide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfsync
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdftricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdftricks2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfwin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pdfx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pecha
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/penrose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/perfectcut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/perltex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/permute
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/petiteannonce
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pfarrei
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pfdicons
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-interference
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-periodictable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-periodictable/manualfiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-pie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-pie/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-soroban
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-umlcd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-umlcd/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-umlsd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgf-umlsd/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfgantt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfkeyx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfmath-xfp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfmorepages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfopts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfornament
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfornament-han
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfcc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfextendedabstract
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phffullpagefigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfnote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfparen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfqit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfquotetext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfsvnwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phfthm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/philex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/philosophersimprint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phonenumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/phonrule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/photo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/photobook/scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/physconst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/physics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/physics2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/physunits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/piano
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/picinpar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pict2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pictexsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/picture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/piff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pinlabel/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pinoutikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pittetd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pixelart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pixelarttikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pkgloader
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pkuthss/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pkuthss/example/chap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pkuthss/readme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pkuthss/readme/chap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/placeins
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plantslabels/doc/pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plantslabels/doc/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plantslabels/example/pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plantslabels/example/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plari
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/platex-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/platexcheat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plautopatch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/play
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/plweb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pm-isomath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pmboxdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pmgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pmhanguljamo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/poemscol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/poetry
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/poetrytex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/polski
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/polyglossia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/polynom
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/polynomial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/polytable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/postage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/postcards
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/postnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/powerdot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/powerdot-fuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/powerdot-tuliplab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ppr-prv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ppt-slides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pracjourn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/practicalreports
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/precattl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prelim2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/preprint
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prerex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pressrelease/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prettyref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prettytok
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/preview
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prftree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/principia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/printlen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proba
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/probsoln/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prociagssymp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/productbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/profcollege
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proflabo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proflycee
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proflycee/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/program
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/progress
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/progressbar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/projlib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proof-at-the-end
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proofread
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prooftrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/properties
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proposal/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proposal/dfg/proposal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proposal/dfg/report
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/proposal/eu/strep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prosper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/protex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/protocol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/prtec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/przechlewski-book
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psbao
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pseudo/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pseudo/doc/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pseudo/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pseudocode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psfrag
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psfrag-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psfragx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psgo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/psnfss/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pspicture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-calendar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-eucl-translation-bg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-eucl-translation-bg/Exemples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-exa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-flags
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-intersect
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-layout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-optexp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-poker
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-vectorian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pst-vowel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstool
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstricks_calcnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstricks_calcnotes/Convert_PstricksCode_To_Pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstricks_calcnotes/For_Pdf_Output
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstricks_calcnotes/For_Ps_Output
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pstring
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ptex2pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ptolemaicastronomy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ptptex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/punk-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/puyotikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxcjkcat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxgreeks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxjodel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxpgfmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxtatescale
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pxufont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pygmentex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/python
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pythonhighlight
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pythonimmediate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/pythontex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qcircuit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qcm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qobitree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qrbill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qrcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qsharp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qstest
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quantikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quantumarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quicktype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quiz2socrative
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quotchap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quoting
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quotmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quran
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quran-bn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/quran-ur
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qyxf-book
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/qyxf-book/figure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/r_und_s
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ragged2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ran_toks/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ran_toks/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/randbild
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/randomwalk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/randtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rank-2-roots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rbt-mathnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rbt-mathnotes/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rccol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rcs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rcs-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rcsinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/readablecv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/readarray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/realboxes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/realhats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/realhats/readme_images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/realscripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/realtranspose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rec-thy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/recipe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/recipebook/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/recipecard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/recorder-fingering
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rectopma
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/refcheck
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/refcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/refenums/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reflectgraphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/refman
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/refstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/regcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/regexpatch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/register
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/regstats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reledmac/doc-include
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reledmac/doc-more
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reledmac/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/relenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/relsize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/reotex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/repeatindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/repltext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rerunfilecheck
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rescansync
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/resmes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/resolsysteme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/resphilosophica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rest-api
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/returntogrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revquantum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/aip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/aps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/auguide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/sample/aapm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/sample/aip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/sample/aps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex/sample/sor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/aip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/aps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/auguide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/sample/aip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/sample/aps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/revtex4-1/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rgltxdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ribbonproofs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rjlparshap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rmathbr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rmpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/robotarm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/robustcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/robustindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/romanbar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/romanbarpagenumber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/romanneg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/romannum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rotfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rotpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rotpages/Documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rotpages/Examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/roundbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rrgtrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rsc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rterface
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rtkinenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rtklage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rubik
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rulerbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rulercompass
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/runcode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/runcode/generated
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/russ
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rutitlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rviewport
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/rvwrite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ryersonsgsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ryethesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sa-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sacsymb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sageep
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sanitize-umlaut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sankey
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sanskrit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sansmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sapthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sasnrdisplay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sauerj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sauterfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/saveenv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/savefnmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/savetrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scale
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scalebar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scalerel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scanpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schedule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schemabloc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schooldocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schule
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schule/Abbildungen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schule/Beispiele
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schule/source/Module/GENord
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schule/source/Module/GENordLogbuch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schulmathematik
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/schwalbe-chess
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scientific-thesis-cover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sciposter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sciposter/sciposterexample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sciposter/sciposterexample/auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sclang-prettifier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scontents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scrabble
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scrambledenvs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scratch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scratch3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scratchx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/screenplay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/screenplay-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scripture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scrjrnl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scrlayer-fancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scrlttr2copy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/scsnowman
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps/html
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps/html/_images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps/html/_sources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps/html/_static
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdaps/html/_static/css
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sdrt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/se2thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/secdot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/secnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/section
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sectionbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sectionbox/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sectionbreak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sectsty
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seealso
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/selectp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/selinput
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semantex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semantic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semantic-markup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seminar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semioneside
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semproc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/semtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sepfootnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sepnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seqsplit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/serbian-apostrophe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/serbian-date-lat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/serbian-def-cyr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/serbian-lig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sesamanuel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sesstime
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/setdeck
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/setspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seu-ml-assign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seuthesis/a3cover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seuthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seuthesis/zharticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seuthesix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/seuthesix/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sf298
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sffms
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sfg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sgame
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shadethm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shadow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shadowtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shipunov
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shipunov/scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/short-math-guide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shortmathj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shorttoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/show2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/showcharinbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/showdim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/showexpl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/showlabels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/showtags
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shtthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/shuffle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sidecap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sidenotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sidenotesplus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/signchart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/silence
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sillypage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplebnf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplecd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplecv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simpleinvoice/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simpleinvoice/doc/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplenodes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simpleoptics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simpler-wick
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simples-matrices
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplewick
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplified-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/simplivre
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sistyle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sitem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/siunits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/siunitx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/database/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/figures/dirtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/figures/multiexample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository/exa-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository/getting-started
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository/separate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/repository/story
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skb/user-guide/slides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skeldoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skeycommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skeyval
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skills
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/skrapport
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/slantsc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smalltableof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smart-eqn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smartdiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smartref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smartunits
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/smflatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/snapshot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/snaptodo/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/snotez
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songbook/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songbook/contrib/CarolBook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songbook/contrib/crd2sb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songproj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songproj/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songs/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/songs/songidx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/soton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/soulpos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/soup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spacingtricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spalign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sparklines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spath3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spbmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spectralsequences/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spectralsequences/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spectralsequences/manual/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sphdthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/splitbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/splitindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spotcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spreadtab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/spverbatim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sr-vorl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/srbook-mem
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/srcltx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/srdp-mathematik
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sseq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sslides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stackengine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/standalone
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stanli
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/statex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/statex2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/statistics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/statistik
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/statmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stdclsdv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stdpage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stealcaps/testfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/steinmetz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stellenbosch/templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stex/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stex/packages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/storebox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/storecmd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/strands
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stringenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stringstrings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/structmech
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/struktex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sttools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/stubs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/studenthandouts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/studenthandouts/samplecode/worksheets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/styledcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subdepth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subdocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subeqn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subeqnarray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subfigmat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subfiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/substances
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/substitutefont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/substr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subsupscripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/subtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sudoku
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sudokubundle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/suftesi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/sugconf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/supertabular
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/suppose
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/susy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svg-inkscape
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svgcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svn-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svn-prov
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/svninfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/swebib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/swfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/swimgraf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/swungdash
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/syllogism
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/synproof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/syntax
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/syntaxdi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/syntrace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/synttree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/t-angles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabbing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabfigures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/table-fct
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tableaux
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablefootnote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tableof
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablists
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablor/Figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablor/auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tablvar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabriz-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabstackengine
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabto-ltx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabularborder
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabularcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabularew
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabularray
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabulary
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tagging
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tagpair
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tagpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/talk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tamefloats
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tangramtikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tasks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tcldoc/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tcldoc/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tcolorbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tdclock
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tdsfrmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/technics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ted
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/templates-fenn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/templates-sommer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/templatetools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tensind
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tensor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/termcal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/termcal-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/termlist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/termsim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/testhyphens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/testidx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/testidx/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/teubner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tex-font-errors-cheatsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tex-label
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tex-overview
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tex-vpat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texmate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texments
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texnegar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texpower
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texpower/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texpower/tpslifonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texproposal
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texproposal/contents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texproposal/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texproposal/ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texproposal/scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texshade
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texsurgery
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textcase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textcsc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textfit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textglos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textopo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textpos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textpos/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/textualicomma
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/texvc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thaienum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thaispec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thalie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/theatre/doc/help_source/util
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/theatre/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/theoremref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thermodynamics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thesis-ekf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thesis-gwu
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thesis-gwu/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thesis-gwu/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thesis-titlepage-fhac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thinsp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thmbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thmtools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/threadcol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/threeparttable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/threeparttablex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thuaslogos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thubeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thucoursework
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thumb
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thumbs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thumby
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thuthesis/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/thuthesis/ref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ticket
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ticollege
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tidyres
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-among-us
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-bagua
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-bayesnet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-bbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-cd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-dependency
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-dimline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-feynhand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-feynman
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-imagelabels
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-inet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-kalender
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-karnaugh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-ladder
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-lake-fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-layers
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-mirror-lens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-nef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-network
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-network/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-opm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-optics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-page
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-palattice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-planets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-relay
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-sfc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-swigs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-timing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-trackschematic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-trackschematic/tikz-trackschematic-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-trackschematic/tikz-trackschematic-snippets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikz-truchet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzbricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzcodeblocks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzcodeblocks/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzfill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzinclude
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzlings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzmark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzmarmots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzorbital
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzpackets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzpagenodes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzpeople
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzpfeile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzpingus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzposter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzscale
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tikzviolinplots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tile-graphic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tile-graphic/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tile-graphic/examples/choo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tile-graphic/examples/postscript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/timbreicmc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/timing-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tipa-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tipauni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tipfr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tiscreen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titlecaps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titlepages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titlepic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titleref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titlesec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/titling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/doc/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/examples/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/doc/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-berge/examples/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-doc/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-doc/doc/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-doc/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-euclide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-fct
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-graph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-graph/doc/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-orm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkz-tab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tkzexample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc-article
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc-article/bin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc-article/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc-article/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc-article/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tlc3-examples/example-sources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/to-be-determined
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tocbibind
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tocdata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tocloft
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tocvsec2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/todo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/todonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/todonotes/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/todonotes/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tokenizer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tonevalue
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/toolbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/topfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/topiclongtable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/topletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/toptesi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/totalcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/totcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/totpages
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tpslifonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tqft
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tramlines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-array-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-arsclassica-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-biblatex-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-chemsym-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-dcolumn-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-ecv-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-enumitem-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-europecv-de/Beispiele
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-europecv-de/templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-filecontents-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-moreverb-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-natbib-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translation-tabbing-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translations
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/translator
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/transparent
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tree-dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/trfsigns
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/trimspaces
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/trivfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/trsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/truncate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tucv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tuda-ci
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tudscr/tutorials
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tufte-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tufte-latex/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tugboat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tui/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tui/template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/turabian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/turabian-formatting
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/turkmen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/turnstile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/turnthepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/twemojis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/twoinone
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/twoup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/txgreeks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/type1cm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/typed-checklist
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/typeface
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/typehtml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/typoaid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/typogrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/tzplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uaclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uafthesis/bib_styles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uafthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uafthesis/example/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uantwerpendocs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uassign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucalgmthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucbthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucbthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucdavisthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucdavisthesis/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucharcat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucs/config
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucs/unsupported
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucs/utils
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucsmonograph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ucthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/udes-genie-these
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/udes-genie-these/Exemple
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/udesoftec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uebungsblatt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uestcthesis/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uestcthesis/doc/chapters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uestcthesis/doc/contents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uestcthesis/doc/pics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uestcthesis/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ufrgscca
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uhhassignment
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uhrzeit
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uiucredborder
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uiucthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ukbill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ulqda
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ulthese
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/umbclegislation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/umich-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/umlaute
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/umoline
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/umthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unam-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Agradecimientos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Apendice1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Bibliografia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Capitulo1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Capitulo2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Capitulo3/figs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Capitulo4
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Capitulo5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Declaracion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Latex/Classes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Latex/Classes/Escudos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Latex/Macros
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamth-template/Resumen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unamthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unbtex/unbtex-example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unbtex/unbtex-example/codigos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unbtex/unbtex-example/figuras
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/undergradmath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/underlin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/underoverlap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/underscore
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/undolabl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uni-titlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uni-wtal-ger
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uni-wtal-lin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unicode-alphabets
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unicode-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unicodefonttable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unifith
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unifith/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unigrazpub
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unigrazpub/examples/monografie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unigrazpub/examples/sammelband
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uniquecounter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unisc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unitn-bimrep/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/units
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unitsdef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/univie-ling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/univie-ling/templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unizgklasa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unravel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/unswcover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uol-physics-report
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uothesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uowthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uowthesistitlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/upmethodology
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/upquote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/urcls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uri
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/url
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/usebib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ushort
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uspace
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uspatent
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ut-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/utexasthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/utf8add
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/utfsym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uvaletter/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwa-colours
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwa-letterhead
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwa-pcf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwa-pif
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwmslide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/uwthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/varindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/varsfromjobname
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/varwidth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vcell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vdmlisting
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/venndiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/venndiagram/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verbasef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verbatimbox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verbatimcopy
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verbdef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verbments
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verifica
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verifiche
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/verse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/version
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/versions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/versonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vertbars
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vgrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vhistory
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualfaq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualfaq-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualfaq-fr/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualfaq-fr/source/latex-books
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualfaq/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualpstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualpstricks/Source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualtikz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/visualtikz/Source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vmargin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vocaltract
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/volumes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/voss-mathcol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vpe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vruler
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vtable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/vwcol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wallpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wallpaper/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wallpaper/example/auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wargame
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wargame/tutorial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/warning
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/warpcol
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/was
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wasysym
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/webguide
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/webquiz/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/webquiz/www/css
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/webquiz/www/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/webquiz/www/js
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wheelchart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/widetable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/widows-and-orphans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/williams
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/willowtreebook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/windycity
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/withargs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wnri-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wordcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wordlike
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/worksheet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/worldflags
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wrapfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wrapfig2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wrapstuff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/writeongrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wsemclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/wtref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xargs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xassoccnt
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xbmks/docs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xbmks/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcjk2uni
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcntperchap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcolor-material
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcolor-solarized
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcookybooky
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcookybooky/example/pic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcookybooky/example/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xcpdftips
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xduthesis/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xebaposter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xebaposter/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xecyrmongolian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xellipsis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xfakebold
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xfor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xhfill
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xifthen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xistercian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xkcdcolors
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xkeyval
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xltabular
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xmpincl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xmuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xnewcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xoptarg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpatch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpeek
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpiano
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpicture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpinyin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xprintlen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xpunctuate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xsavebox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xsim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xsim/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xskak
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtab
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtuthesis/body
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtuthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtuthesis/preface
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xtuthesis/reference
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xurl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xyling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xymtex/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xymtex/readme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xymtex/readme/oldreadme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/xytree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yafoot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yagusylo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yaletter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/addons/completion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/english
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/code
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/annexes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/configuration
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/corps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/extraits-these
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/glossaries
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/liminaires
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/documentation/tableaux
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yathesis/french/exemples/specimen/a-plat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yb-book
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ycbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ydoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yet-another-guide-latex2e
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/york-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yplan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/yquant
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ytableau
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zebra-goodies
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zed-csp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zennote
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zhlineskip
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zhlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zhnumber
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/ziffer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zref-check
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zref-clever
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zref-vario
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zwgetfdate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zwpagelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zx-calculus
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zxjafbfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zxjafont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/latex/zxjatype/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/addliga
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/arabluatex/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/autopuncitems
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/beamer-rl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/bezierplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/combofont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/cstypo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/datestamp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/ekdosis/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/emojicite
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/hmtrump/nkd04_playing_cards_index
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/hu-berlin-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/hu-berlin-bundle/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/innerscript
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/japanese-mathformulas
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/letgut
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/ligtype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/linebreaker
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lua-check-hyphen/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lua-physical/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lua-typo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lua-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luabibentry
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luabidi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/intro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_algebra/ref_algebra_classes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_algebra/ref_algebra_methods
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_calculus/ref_calculus_classes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_calculus/ref_calculus_methods
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_core/ref_core_classes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/reference/ref_core/ref_core_methods
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut3
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacensor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luacomplex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luagcd
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luahyphenrules
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaimageembed
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luainputenc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lualatex-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lualatex-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lualatex-truncate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/lualinalg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luamathalign
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luamaths
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luamesh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luamodulartables
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaprogtable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luapstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaquotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luarandom
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luaset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luasseq
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luatextra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luatodonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/luatruthtable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/makecookbook/mycookbook/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/makecookbook/mycookbook/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/novel
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/novel/extras
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/novel/html-resources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/odsfile
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/pdfarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/pgfmolbio
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/piton
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/placeat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/plantuml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/pyluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/pyluatex/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/scikgtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/selnolig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/semesterplanner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/showhyphenation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/showkerning
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/simurgh
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/spacekern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/stricttex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/truthtable
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/truthtable/res
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/typewriter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/uninormalize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/unitconv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar/doc/auto
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/cal-burst
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/data
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/photos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/xindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/xindex/tests
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/lualatex/yamlvars
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/doc/ga-graphic-asm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/doc/manual/image
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-barracuda-package
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-code128
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-code39
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-ean
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-ga-pdfliteral
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-ga-svg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-i2of5
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-libgeo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/barracuda/test/test-upc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/base/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/blopentype
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/chickenize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/chinese-jfm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/cloze
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/ctablestack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/evangelion-jfm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/gregoriotex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/hyph-utf8
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/interpreter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/kanaparser
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lparse
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lua-uni-algos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lua-visual-debug
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lua-widow-control
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luaaddplot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luaintro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luakeys
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lualibs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luamplib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luaotfload
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luapackageloader
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luatexbase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luatexja
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luatexko
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luavlna
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/luaxml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/lutabulartools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/minim
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/minim-math
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/minim-mp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/minim-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/minim-xmp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/nodetree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/penlight
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/spelling
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/luatex/tsvtemplate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/automata
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/base/source-manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/base/source-tutorial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/bbcard
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/blockdraw_mp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/bpolynomial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/byrne
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/cmarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/drv/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/drv/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/drv/template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/dviincl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/epsincl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/expressg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/exteps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/featpost/bash
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/featpost/doc/metapostpropagandafiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/featpost/doc/otherinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/featpost/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/featpost/png
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/fiziko
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/garrigues
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/hatching
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/hershey-mp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/latexmp
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/makecirc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mcf2graph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metago
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metaobj
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metapost-colorbrewer
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metapost-examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metauml
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metauml/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/metauml/manual/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mp3d
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mparrows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mpcolornames
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mpman-ru
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/mptrees
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/piechartmp/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/repere
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/roundrect
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/shapes
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/slideshow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/splines
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/suanpan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/textpath
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/threeddice
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/metapost/venn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/mex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/mex/utf8mex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/mex/utf8mex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/omega/antomega
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/omega/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/omega/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/optex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/optex/pdfextra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/optex/pdfextra/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/jadetex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/lollipop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/lollipop/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/psizzl/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/startex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/texsis/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/otherformats/xmltex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/samplepdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/01-fake-interword-space
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/02-pdfmatch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/03-deterministic-output
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/04-pdfsuppressptexinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/05-mediabox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/06-pkmap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/07-mapwarn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/08-pdfprimitive
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/09-fontobjnum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/10-moddate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/11-omitcharset
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pdftex/tests/12-pdf2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/cover
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/output
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/source
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/epsf-dvipdfmx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/figflow
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/font-change
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/fontch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/gentle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/getoptk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/gfnotation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/graphics-pln
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/gustlib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/happy4th
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/harvmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/hyplain
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/impatient
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/impatient-cn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/impatient-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/impatient/diffs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/js-misc/xfig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/kotex-plain
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/lambda-lists
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/metatex/mtpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/mkpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/newsletr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/pitex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/plain-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/plipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/plnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/plstmary
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/present
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/pwebmac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/resumemac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/tex-nutshell
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/texbytopic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/texonly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/transparent-io
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/treetex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/tugboat-plain
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/varisize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/xii
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/xii-lat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/xintsession
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/plain/zztex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/jlreq-deluxe
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/jsclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/pxbase
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/pxchfon
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/pxjahyper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/platex/pxrubrica/sample
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pmxchords
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pmxchords/examples/jazz/misty
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pmxchords/examples/jazz/schema
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pmxchords/examples/noel/aj_co_to_hlasaju
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/pmxchords/examples/noel/pasli_ovce_valasi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/ptex/pbibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/ptex/ptex-base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/ptex/ptex-manual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/a2ping
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/adhocfilelist/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/albatross
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/arara/resources
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ascii-chart
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/asymptote-by-example-zh-cn/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/asymptote-by-example-zh-cn/src/figure-src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/asymptote-faq-zh-cn/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/asymptote-faq-zh-cn/src/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/asymptote-manual-zh-cn/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/bib2gls/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/bundledoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/checkcites
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/chklref
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/classpack
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/clojure-pamphlet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/bin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/biblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/empty
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/epstopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/epstopdf/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/include
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/include/path/to
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/makeindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/minted
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/simple
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/example/simple-ja
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/cluttex/src/texrunner
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/convbkmk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/crossrefware
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ctan-o-mat
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ctan-o-mat/lib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ctan_chk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ctanbib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ctanupload
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/de-macro
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/digestif/bin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/dosepsbin
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/dtxgen
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/epspdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/epspdf/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/epstopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/fig4latex/figs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/findhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/fontools
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/fragmaster
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/fragmaster/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/git-latexdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/gitfile-info
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/gustprog
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/hook-pre-commit-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forLinux
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forMac
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forMac/Forsettingmanually
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/forWindows/Forsettingmanually
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/ketmanual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s01figure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s02graph
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s03table
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s06animation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/figwall
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s08R
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s11asir
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s13objview
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/config/META-INF/services
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/lib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/src
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/cdy-templates
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/howtoinstall
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/readme
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ketcindy/source/spacekc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex-git-log/po
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex-make
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex-papersize
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2man
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2nemeth
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2nemeth/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2nemeth/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2nemeth/encodings
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latex2nemeth/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexdiff/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexdiff/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexdiff/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexfileversion
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexindent
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexmk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexmk/example_rcfiles
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexmk/extra-scripts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/latexpand
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/light-latex-make
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ltxfileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/ltximg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/lua-alt-getopt/tests
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/lua-uca
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/luafindfont
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/lyluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/lyluatex/ly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/make4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/makedtx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/makeindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/match_parens
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/mendex-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/mf2pt1
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/mkgrkindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/mkpic
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/optexcount
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/patgen2-tutorial
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdfbook2
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdfcrop
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdfjam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdflatexpicscale
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdftex-quiet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pdfxup
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pedigree-perl/Pedigree
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pedigree-perl/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pedigree-perl/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pkfix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pkfix-helper
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/pst2pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/purifyeps
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/spix
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/srcredact
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/sty2dtx
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/svn-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tex4ebook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texaccents
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texcount/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdef
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdirflatten
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdraw/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texdraw/test
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texfot
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texliveonfly
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texloganalyser
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texlogfilter
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texlogsieve
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texosquery
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/texplate
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tikztosvg
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn/body
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn/fig
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/tlmgrbasics
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/typeoutfileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/upmendex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/upmendex/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/upmendex/samples/alphabet
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/upmendex/samples/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/support/upmendex/samples/option
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-common
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-common/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-cz
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-en
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-en/archive
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2017
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2018
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2019
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2020
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2021
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-es/archive/2022-march-2022-dec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-it
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-ja
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-ja/img
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-ru
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-sr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-sr/images
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/texlive-zh-cn
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/texlive/tlbuild
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/tpic2pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/ttf2pk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/uplatex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/uptex/uptex-base/samples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/vlna
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/web2c
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/arabic-book
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/arabxetex/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bhcexam/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidi-atbegshi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidicontour
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidihl
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidipagegrid
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidipresentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/bidishadowtext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/buctthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/businesscard-qrcode/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/businesscard-qrcode/screenshots
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/cqubeamer/demo_code
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/cqubeamer/figure
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/cqubeamer/logo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/exam-zh/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/exam-zh/doc/back
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/exam-zh/doc/body
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/exam-zh/doc/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/exam-zh/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/facture
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/facture-belge-simple-sans-tva
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/fixlatvian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/fontbook
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/fontwrap
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hanzibox
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hfutthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-chapters
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hithesis/back
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hithesis/body
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hithesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/hithesis/front
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/imsproc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/interchar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/kurdishlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/langsci/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/langsci/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/mathspec
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/mynsfc
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/na-box
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/na-position
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/nanicolle
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/parsa
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/persian-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/philokalia
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/ptext
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/quran-de
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/resumecls
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/resumecls/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/sexam
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/simple-resume-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/simple-thesis-dissertation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/simple-thesis-dissertation/Figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/tabriz-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/technion-thesis-template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/technion-thesis-template/Example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/tetragonos
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/thesis-qom
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/ucharclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/unicode-bidi
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/unisugar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xduts
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xechangebar
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecjk
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecjk/example
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecyr
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecyr/combined_hyphenation
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecyr/inputs
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xecyr/old
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xeindex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xepersian
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xepersian-hm
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xepersian/img/weather
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xespotcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xetex-itrans
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xevlna
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xltxtra
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/xunicode
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/yazd-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/yazd-thesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/zbmath-review-template
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/zbmath-review-template/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xelatex/zitie
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/font-change-xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/unimath-plain-xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xesearch
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetex-devanagari
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetex-pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetex-tibetan
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetexfontinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetexko
    mkdir -p %{buildroot}%{_texmfdistdir}/doc/xetex/xetexref
    mkdir -p %{buildroot}%{_texmfdistdir}/dvipdfmx
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/arphic
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/base
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/colorsep
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/config
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/dvipsconfig
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/esint-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/garuda-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/gastex
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/gsftopk
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/l3backend
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/musixtex
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/norasi-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/psfrag
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pspicture
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-3d
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-antiprism
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-bar
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-barcode
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-bezier
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-bspline
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-cie
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-circ
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-coil
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-cox
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-electricfield
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-eucl
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-fractal
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-fun
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-func
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-geo
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-grad
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-intersect
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-knot
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-light3d
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-lsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-magneticfield
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-marble
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-math
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-mirror
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-moire
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-node
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-ode
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-optexp
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-ovl
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-slpe
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-solarsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-solides3d
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-spinner
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-text
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-turtle
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pst-vectorian
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/pstricks-add
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/tetex
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/tex-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/times
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/tree-dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/uhc
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/xcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/xdvi
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/yfonts-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/dvips/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/adobe/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arabi/arabeyes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arkandis/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arphic/bkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arphic/bsmiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arphic/gbsnu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/arphic/gkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/gust/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/hoekwater/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/hoekwater/manfnt-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/hoekwater/mflogo-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/jmn/hans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/nowacki/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/nowacki/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/paratype/ptmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/paratype/ptsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/paratype/ptserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/latxfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/amsfonts/symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/bbold-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/calligra-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/carolmin-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cryst
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/figbas
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fouriernc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/fpl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/hfbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/mathpazo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/niceframe-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/wasy-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/public/yfonts-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/uhc/umj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/urw/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/vntex/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/vntex/grotesqvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/vntex/urwvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/vntex/vntopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/dgj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/dmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/mc2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/mcj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/mr2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/afm/wadalab/mrj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cid/fontforge
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-CNS1-7
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-CNS1-7/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-GB1-5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-GB1-5/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Identity-0/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Japan1-7
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Japan1-7/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-KR-9
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-KR-9/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Korea1-2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Korea1-2/CMap
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/mapping-resources-pdf/pdf2other
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/adobemapping/mapping-resources-pdf/pdf2unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/dvipdfmx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/ptex-fontmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/cmap/uptex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/afm2pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/b1encoding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/base
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/c90
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/chessfss
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/droid
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ebgaramond-maths
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fontools
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/hfbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/jmn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/libertinegc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/paratype
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/tetex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/ucs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/venturisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/dvips/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/pdftex/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/t2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/enc/ttf2pk/base
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/lig/afm2pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfm/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/adobe
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/apple
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/arphic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/baekmuk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/bizud
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/canon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts-ttf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/dynacomware
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/fandol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/founder
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/haranoaji
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/hiragino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/hiragino-pron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ipaex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6n
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo-ex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/morisawa-pr6n
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms-osx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms-win10
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noEmbed
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noto-otc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/solaris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/sourcehan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/sourcehan-otc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ume
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/unfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-osx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-win
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-win10
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/allrunes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/amsfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arphic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ascii-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bbold-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/belleek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/burmese
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/calligra-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/carolmin-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmexb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cuprum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/droid
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dummy-space
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ebgaramond-maths
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/epiolmec
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/esint-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ethiop-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/figbas
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/foekfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/garuda-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gillcm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/greektonoi
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/hfbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/jamtimes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/jmn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/libertinegc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/manfnt-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mathabx-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mflogo-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mlmodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/niceframe-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/norasi-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/ocr-b-outline
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/paratype
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/pslatex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/psnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/rojud
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/rsfso
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sanskrit-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sansmathaccent
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/scanpages
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/staves
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tetex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/txuprcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/uhc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/wadalab
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/wasy-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/yfonts-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/dvips/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/fontname
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/glyphlist
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/luatex/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/pdftex/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/pdftex/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/vtex/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/vtex/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/map/vtex/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/cjk-gs-integrate
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/cns
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/ptex-fontmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/arabxetex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/base
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/polyglossia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/unimath-plain-xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/xecjk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/xepersian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-devanagari
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-itrans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-tibetan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/japanese-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ofm/public/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/adobe/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/adobe/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/adobe/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/arkandis/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/arkandis/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/arkandis/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/arkandis/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/arkandis/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/gnome/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/google/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/gust/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/huerta/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/ibm/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/iginomarini/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/impallari/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/kosch/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/novel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/nowacki/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/nowacki/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/omnibus-type/asapsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/aboensis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/almfixed
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/asana-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/concmath-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/eczar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/erewhon-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/euler-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fandol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/firamath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fonts-churchslavonic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/frederika2016
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/garamond-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsdidotclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsneohellenicmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/gnu-freefont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/haranoaji
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/haranoaji-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/helmholtz-ellis-ji-notation
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/kpfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/libertinus-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/lilyglyphs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/lm-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/logix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/luapstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/missaali
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/newcomputermodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/ocr-b-outline
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/philokalia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/punknova
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/qualitype
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/shobhika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/spark-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/stix2-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/talos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/tex-gyre-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/umtypewriter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/xcharter-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/xits
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/yfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/public/yinit-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/rozynski/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/sorkin/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/opentype/tipo/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovf/public/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovp/public/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovp/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovp/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/ovp/public/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/pk/ljfour/public/cm/dpi600
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/sfd/dnp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/sfd/pxchfon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/sfd/ttf2pk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/jknappen/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/jknappen/fc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/base
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-XSlav
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-conc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-lcy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-ot2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-t2b
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-t2c
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-t2d
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/lh-x2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/nont2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/lh/specific
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/ptex-fonts/jis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/ptex-fonts/nmin-ngoth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/ptex-fonts/standard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/allrunes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/amsfonts/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/amsfonts/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/amsfonts/dummy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/amsfonts/symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/astro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bangtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/barcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bartel-chess-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bbding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bbm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bbold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bengali
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/boisik
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/calligra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/casyl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cbcoptic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/circ
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/clock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cm-mf-extra-bold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmpica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmtiup
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/concmath-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/concrete
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cookingsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cryst
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ctib
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/dancers
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/dice
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/dingbat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/duerer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ecc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/eiad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/eiad-ltx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/elvish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/esint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/etex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/euro-ce
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/euxm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/genealogy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ghab
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/go
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/gothic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/greenpoint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/hands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ifsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/jablantile
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/kixfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/knuth-lib
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/knuth-local
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/latex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/levy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/lfb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/mathabx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/mflogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/modes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/niceframe
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/nkarta
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/obnov
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ocr-b
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/ogham
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/oldlatin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/orkhun
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/othello
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/pacioli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/phonetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/punk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/sanskrit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/sauter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/schulschriften
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/semaphor/metafont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/shade
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/shuffle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/skak
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/skull
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/tapir
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/tram
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/trsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/universa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/wasy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/wnri
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/wsuipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/xq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/yannisgr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/public/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/uptex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/source/vntex/vnr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/SIL/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/SIL/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/aajohan/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/adobe/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arabi/arabeyes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arabi/farsiweb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arkandis/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/bkaimp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/bkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/bsmilp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/bsmiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/gbsnlp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/gbsnu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/gkaimp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/arphic/gkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ascender/droid/droidsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ascender/droid/droidsansmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ascender/droid/droidserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ascender/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/bh/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/catharsis/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c0so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c1so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c2so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c3so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c4so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c5so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c6so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cns/c7so12
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cs/cs-a35
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/cs/cs-charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/gnome/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/google/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/google/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/google/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/google/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/google/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/gust/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/hoekwater/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/huerta/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/huerta/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/huerta/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ibm/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/iginomarini/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/impallari/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/intel/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/jknappen/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/jknappen/fc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/jmn/hans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/kosch/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/monotype/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/monotype/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ndiscovered/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/nowacki/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/nowacki/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/paratype/ptmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/paratype/ptsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/paratype/ptserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/production/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ptex-fonts/dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ptex-fonts/jis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ptex-fonts/nmin-ngoth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/ptex-fonts/standard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/amsfonts/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/amsfonts/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/amsfonts/dummy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/amsfonts/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/amsfonts/symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ascii-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/astro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bangtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/barcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bartel-chess-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bbding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bbm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bbold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bengali
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/blacklettert1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/boisik
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/burmese
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/bxjatoucs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/calligra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/casyl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cbcoptic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/circ
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/clock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cm-mf-extra-bold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmexb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmpica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmtiup
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/concmath-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/concrete
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cookingsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cryst
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ctib
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cuprum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dancers
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dice
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dingbat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/duerer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ebgaramond-maths
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ecc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/eco
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/eiad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/elvish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/epiolmec
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/esint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/etex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/eulervm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/euro-ce
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/euxm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/figbas
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/foekfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/fouriernc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/garuda-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/genealogy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gillcm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/go
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gothic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/greenpoint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/hands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/hfoldsty
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ifsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/jamtimes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/japanese-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/jlreq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/kixfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/knuth-lib
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/knuth-local
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/latex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/levy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/lfb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/libertinegc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathabx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdbch
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdici
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdpgd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdpus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdput
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathdesign/mdugm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mathpazo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mdputu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mflogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mlmodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/niceframe
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/nkarta
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/norasi-c90
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/obnov
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ocr-b
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/ogham
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/oldlatin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/orkhun
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/othello
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pacioli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/phonetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pslatex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/punk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pxchfon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pxjodel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pxtxalfa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/pxufont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/qpxqtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/relenc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/rojud
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/rsfso
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/sanskrit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/sansmathaccent
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/scanpages
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/schulschriften
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/shuffle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/skak
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/skull
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/staves
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/trsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/txuprcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/universa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/uppunctlm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/wasy
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/wnri
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/wsuipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/xq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/yannisgr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/public/zhmetrics-uptex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/rozynski/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/sorkin/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/tipo/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/typoland/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/uhc/umj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/uhc/uwmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/uhc/wmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/uptex-fonts/jis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/uptex-fonts/min
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw/urwchancal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/urw35vf/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/arevvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/cmbrightvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/concretevn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/grotesqvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/txttvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/urwvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/vnr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/vntex/vntopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/dgj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/dmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/mc2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/mcj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/mr2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/mrj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/udgj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/udmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/umcj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/wadalab/umrj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/cyberb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbkfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbkhei
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbkkai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbkli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbksong
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/gbkyou
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/unifs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/unihei
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/unikai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/unili
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/unisong
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/tfm/zhmetrics/uniyou
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/SIL/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/SIL/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/aajohan/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/ascender/droid/droidsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/ascender/droid/droidsansmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/ascender/droid/droidserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/ascender/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/bh/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/catharsis/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/google/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/google/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/google/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/google/noto-emoji
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/google/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/huerta/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/huerta/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/impallari/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/impallari/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/intel/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/ndiscovered/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/paratype/ptmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/paratype/ptsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/paratype/ptserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/production/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/academicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/alkalami
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/almfixed
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/amiri
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/arphic-ttf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/asana-math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/baekmuk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/bangla
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/belleek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/cuprum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/doulossil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/ektype-tanka
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/fontmfizz
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/gnu-freefont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/hamnosys
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/hmtrump
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/ipaex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/lexend
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/logix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/padauk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/twemoji-colr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/typicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/unfonts-core
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/public/unfonts-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/truetype/typoland/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/SIL/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/SIL/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/aajohan/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/adobe/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/adobe/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/adobe/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/adobe/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arabi/arabeyes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arabi/farsiweb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arkandis/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arphic/bkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arphic/bsmiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arphic/gbsnu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/arphic/gkaiu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ascender/droid/droidsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ascender/droid/droidsansmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ascender/droid/droidserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ascender/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/bh/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/catharsis/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/gnome/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/google/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/google/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/google/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/google/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/google/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/gust/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/hoekwater/context
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/hoekwater/manfnt-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/hoekwater/mflogo-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/huerta/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/huerta/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/huerta/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ibm/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/iginomarini/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/impallari/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/intel/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/jmn/hans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/kosch/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/ndiscovered/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/nowacki/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/nowacki/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/paratype/ptmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/paratype/ptsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/paratype/ptserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/production/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/allrunes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/cmextra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/latxfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/amsfonts/symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ascii-font
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/bbold-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/belleek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/burmese
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/calligra-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/carolmin-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cbcoptic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cbfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cm-unicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmexb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cryst
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/epiolmec
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/esint-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ethiop-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/figbas
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/foekfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/fpl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/hfbright
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathabx-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdbch
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdici
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdpgd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdpus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdput
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathdesign/mdugm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mathpazo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mlmodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/musixtex-fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/niceframe-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/ocr-b-outline
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/rojud
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/sanskrit-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/scanpages
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/skaknew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/staves
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tapir
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/txuprcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/wasy-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/yfonts-t1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/public/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/rozynski/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/sorkin/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/tipo/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/typoland/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/uhc/umj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/urw/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/arevvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/cmbrightvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/concretevn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/grotesqvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/txttvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/urwvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/vnr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/vntex/vntopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/dgj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/dmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/mc2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/mcj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/mr2j
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type1/wadalab/mrj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/type3/mpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/SIL/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/SIL/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/aajohan/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/adobe/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arkandis/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arphic/bkaimp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arphic/bsmilp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arphic/gbsnlp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/arphic/gkaimp
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ascender/droid/droidsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ascender/droid/droidsansmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ascender/droid/droidserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ascender/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/bh/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/catharsis/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/cs/cs-a35
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/cs/cs-charter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/gnome/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/google/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/google/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/google/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/google/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/google/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/huerta/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/huerta/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/huerta/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ibm/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/iginomarini/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/impallari/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/intel/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/kosch/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/monotype/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ndiscovered/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/paratype/ptmono
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/paratype/ptsans
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/paratype/ptserif
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/production/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ptex-fonts/jis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ptex-fonts/nmin-ngoth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/ptex-fonts/standard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/blacklettert1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cmtiup
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/eco
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/eulervm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/fouriernc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gillcm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/hfoldsty
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/jamtimes
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/japanese-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/jlreq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/jlreq-deluxe
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdbch
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdici
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdpgd
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdpus
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdput
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathdesign/mdugm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mathpazo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/mdputu
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pslatex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pxchfon
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pxjodel
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pxtxalfa
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/pxufont
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/qpxqtx
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/relenc
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/rsfso
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/sansmathaccent
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/step
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/uppunctlm
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/public/zhmetrics-uptex
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/rozynski/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/sorkin/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/tipo/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/typoland/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/uhc/uwmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/uhc/wmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/uptex-fonts/jis
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/uptex-fonts/min
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw/urwchancal
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/times
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/urw35vf/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/vntex/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/vntex/urwvn
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/vntex/vntopia
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/wadalab/udgj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/wadalab/udmj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/wadalab/umcj
    mkdir -p %{buildroot}%{_texmfdistdir}/fonts/vf/wadalab/umrj
    mkdir -p %{buildroot}%{_texmfdistdir}/hbf2gf
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/babel
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/bgteubner
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/biblatex-sbl
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/cnbwp
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/cnltx
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/confproc
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/disser
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/e-french
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/fixlatvian
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/forest
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/gindex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/gmdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/hitex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/hithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/hitszthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/index
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/iso
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/juraabbrev
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/kotex-utils
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/leipzig
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/memoir
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/mendex-doc
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/mkgrkindex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/multibib
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/nomencl
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/nomentbl
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/nostarch
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/oscola
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/plain
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/pst-optexp
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/repeatindex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/songbook
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/startex
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/tikzpingus
    mkdir -p %{buildroot}%{_texmfdistdir}/makeindex/xdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/base
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/config
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/feynmf
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/mflua
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/mfpic
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/metafont/roex
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/automata
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/base
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/bbcard
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/bclogo
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/blockdraw_mp
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/bpolynomial
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/byrne
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/cmarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/config
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/context/base/common
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/context/base/mpiv
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/context/base/mpxl
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/context/fonts/mpiv
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/context/third/gnuplot
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/drv
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/dviincl
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/epsincl
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/expressg
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/exteps
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/featpost
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/feynmf
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/fiziko
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/garrigues
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/hatching
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/hershey-mp
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/latexmp
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/luamesh
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/makecirc
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/metago
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/metaobj
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/metaplot
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/metapost-colorbrewer
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/metauml
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mf2pt1
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mfpic
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/minim-hatching
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/minim-mp
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mp3d
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mparrows
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mpcolornames
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/mptrees
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/nkarta
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/piechartmp
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/profcollege
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/repere
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/roundrect
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/shapes
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/slideshow
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/splines
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/suanpan
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/support
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/support/charlib
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/textpath
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/threeddice
    mkdir -p %{buildroot}%{_texmfdistdir}/metapost/venn
    mkdir -p %{buildroot}%{_texmfdistdir}/mft/base
    mkdir -p %{buildroot}%{_texmfdistdir}/mft/knuth-local
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/antomega
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/antomega/latin
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/char2uni
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/ocp/uni2char
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/antomega
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/antomega/latin
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/char2uni
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/omega/otp/uni2char
    mkdir -p %{buildroot}%{_texmfdistdir}/pbibtex/bib
    mkdir -p %{buildroot}%{_texmfdistdir}/pbibtex/bst
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/a2ping
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/accfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/adhocfilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/albatross
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/arara/rules
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/attachfile2
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/authorindex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/barracuda/lib-barcode
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/barracuda/lib-driver
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/barracuda/lib-geo
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bib2gls
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bib2gls/resources
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bibcop
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bibexport
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bibtexperllibs/BibTeX/Parser
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bibtexperllibs/LaTeX/ToUnicode
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/bundledoc
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/cachepic
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/changes
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/checkcites
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/checklistings
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/chklref
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/chktex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/citation-style-language
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/cjk-gs-integrate
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/clojure-pamphlet
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/cloze
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/cluttex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/context/lua/third/enigma/mtx-t-enigma.lua
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/context/lua/third/rst
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/context/lua/third/simpleslides
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/context/lua/third/transliterator
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/context/perl
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/convbkmk
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/crossrefware
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ctan-o-mat
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ctanbib
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ctanify
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ctanupload
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/de-macro
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/diadia
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/digestif
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/dosepsbin
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/dtxgen
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/dviasm
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/dviinfox
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/epspdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/epstopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/exceltex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/fig4latex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/findhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/flowfram
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/fmtcount
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/fontools
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/fragmaster
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/getmap
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/git-latexdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/glossaries
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/hyperxmp
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/jfmutil
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/data/fontF
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/ketjava
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/ketlib/ketpicR
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/ketlib/oshima
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ketcindy/ketlibC
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/kotex-utils
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/l3build
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latex-git-log
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latex-make
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latex-papersize
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latex2man
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latex2nemeth
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexfileversion
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexindent
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexindent/LatexIndent
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexmk
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/latexpand
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/light-latex-make
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lilyglyphs
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/listbib
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/listings-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/logicpuzzle
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ltxfileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ltximg
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lua-alt-getopt
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lua-physical
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lua-uca
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/luafindfont
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/luaindex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/luamesh
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/luaotfload
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/luasseq
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lwarp
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/lyluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/m-tx
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/magicnum
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/make4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/make4ht/domfilters
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/make4ht/extensions
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/make4ht/filters
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/make4ht/formats
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/makedtx
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/match_parens
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mathspic
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mf2pt1
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mfirstuc
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mflua
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mkgrkindex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mkjobtexmf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mkpic
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/multibibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/musixtex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/mycv
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/optexcount
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pagelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pax
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdfbook2
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdfcrop
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdfjam
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdflatexpicscale
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdftex-quiet
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pdfxup
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pedigree-perl
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pedigree-perl/Pedigree
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/perltex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/petri-nets
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pfarrei
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pgfmolbio
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pkfix
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pkfix-helper
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/placeat
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pmxchords
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ps2eps
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pst-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pst2pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ptex-fontmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ptex2pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/purifyeps
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/puyotikz
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pygmentex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/pythontex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/qrbill
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/rubik
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/simpdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/spelling
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/spix
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/splitindex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/srcredact
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/sty2dtx
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/svn-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/tex4ebook
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/tex4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texaccents
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texcount
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texdef
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texdirflatten
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texdoctk
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texfot
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texlive
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texlive-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texliveonfly
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texloganalyser
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texlogfilter
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texlogsieve
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texosquery
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/texplate
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/thumbpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/tikztosvg
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/typeoutfileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/ulqda
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/urlbst
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/vpe
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/webquiz
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/wordcount
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/xindex
    mkdir -p %{buildroot}%{_texmfdistdir}/scripts/yplan
    mkdir -p %{buildroot}%{_texmfdistdir}/source/bibtex/biber-ms
    mkdir -p %{buildroot}%{_texmfdistdir}/source/generic/patch
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/fifinddo-info/makeelse
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/fifinddo-info/makeone
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/fifinddo-info/makevars
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/formation-latex-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/formation-latex-ul/auxdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/formation-latex-ul/images
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/formation-latex-ul/listings
    mkdir -p %{buildroot}%{_texmfdistdir}/source/latex/gloss-occitan
    mkdir -p %{buildroot}%{_texmfdistdir}/source/metapost/metatype1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/amstex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/amstex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/base/mkii
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/base/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/base/mkxl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/bib/common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/colors/icc/context
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/colors/icc/profiles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/fonts/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/fonts/mkxl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/interface/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/interface/third
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/modules/common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/modules/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/modules/mkxl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/patterns/common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/patterns/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/patterns/mkxl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/sample/common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/sample/third
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/test/mkiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/account
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/algorithmic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/animation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/annotation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/asymptote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/bnf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/chromato
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/cmscbf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/cmttbf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/commutative-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/construction-plan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/cyrillicnumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/degrade
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/enigma/t-enigma.mkv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/expkv-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/fancybreak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/filter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/fullpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/gantt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/gnuplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/handlecsv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/layout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/letter/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/letter/style
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/lettrine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/lua-widow-control
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/mathsets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgf/basiclayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgf/frontendlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgf/math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgf/systemlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgf/utilities
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/rst
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/ruby
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/scontents
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/simplefonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/simpleslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/title
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/transliterator
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/typearea
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/typescripts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/vim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/visualcounter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/context/third/zhspacing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/cslatex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/cslatex/cspsfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/csplain/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/csplain/fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/csplain/opmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/eplain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/afm2pl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/latinetx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/latinmtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/mathetx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/mathmtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/smbletx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/fontinst/smblmtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/2up
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/abbr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/abstyles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/alphalph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/apnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/arrayjobx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/asapsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/atbegshi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/autoaligne
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-albanian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-azerbaijani
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-basque
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-belarusian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-bosnian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-breton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-bulgarian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-catalan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-croatian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-czech
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-english
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-esperanto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-friulan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-galician
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-georgian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-german
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-greek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-hungarian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-icelandic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-indonesian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-interlingua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-japanese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-kurmanji
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-latin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-latvian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-macedonian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-malay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-norsk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-occitan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-piedmontese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-romanian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-romansh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-russian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-samin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-scottish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-serbianc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-slovak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-slovenian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-sorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-swedish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-thai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-turkish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-ukrainian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-vietnamese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel-welsh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/af
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/agq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/am
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/as
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/asa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ast
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/az
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/be
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bez
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/br
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/brx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/bs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ca
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ce
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/cgg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/chr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ckb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/cop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/cu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/cy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/da
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dav
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/de
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dje
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dsb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dyo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/dz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ebu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/el
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/en
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/eo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/es
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/et
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/eu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ewo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/fy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ga
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/gd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/gl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/grc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/gsw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/gu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/guz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/gv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ha
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/haw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/he
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/hi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/hr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/hsb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/hu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/hy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/id
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ii
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/is
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/it
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ja
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/jgo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/jmc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ka
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kde
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kea
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kgp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/khq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ki
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kkj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kln
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/km
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kmr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ko
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kok
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ksb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ksf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ksh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/kw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ky
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/la
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lkt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ln
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lrc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/luo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/luy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/lv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mfe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mgh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mgo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/my
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/mzn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/naq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ne
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nmg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nnh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/no
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/nyn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/oc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/om
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/or
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/os
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/pa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/pms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/pt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/qu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/rm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/rn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/rof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ru
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/rw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/rwk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sah
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/saq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sbp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/se
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/seh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/shi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/si
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/smn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/so
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/sw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/syr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ta
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/te
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/teo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/th
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ti
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/tk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/to
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/tr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/twq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/tzm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ug
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/uk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/ur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/uz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/vai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/vi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/vun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/wae
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/xog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/yav
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/yi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/yo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/yrl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/yue
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/zgh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/zh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/babel/locale/zu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/bagpipe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/barr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/beebe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/bibtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/bigintcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/bitelist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/bitset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/borceux
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/c-pascal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/catchfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/catcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/chemfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/chronosys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/colorprofiles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/colortab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/commado
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/commutative-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/compare
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/context/luatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/context/mptopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/crossrefenum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ctex/zhmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dcpic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dehyph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dehyph-exptl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dirtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/docbytex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dowith
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dratex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/e-french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ean
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/edmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/eijkhout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/embedfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/encodings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/enctex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/enigma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/epigram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/epsf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/etexcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/expex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/expex-acro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/expkv-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/fenixpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/filemod
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/fixjfm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/fltpoint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/fntproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/formlett
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/frame
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/gates
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/german
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/gettitlestring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/gobble
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/gtl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hologo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/conversions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/loadhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/patterns/ptex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/patterns/quote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/patterns/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/patterns/tex-8bit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyph-utf8/patterns/txt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/hyphenex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ifptex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/iftex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ifxptex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/infwarerr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/insbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/intcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/kastrup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/knuth-lib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/kvdefinekeys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/langcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/lecturer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/letterspacing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/levy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/librarian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/listofitems
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/localloc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/lpform
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/lt3luabridge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ltxcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/luatex85
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/m-tx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/magicnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/mathabx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/mathdots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/mathlig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/metapost
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/mfpic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/midnight
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/minifp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/mleftright
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/modulus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/multido
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/multiexpand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/musixtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/musixtnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/namedef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/navigator
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/nth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/oberdiek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ofs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/olsak-misc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/omegahyph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/outerhbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/path
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pdf-trans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pdfescape
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pdfmsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pdftex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pdftexcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/petri-nets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/basiclayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/circuits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/datavisualization
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/graphs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/bindings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/circular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/control
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/deprecated
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/energybased/multilevelmixer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/layered
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/misclayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/module
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/planarity
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/examples
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/experimental/evolving
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/algorithms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/forcetypes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/initialpositioning
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/interface
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/layered
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/lib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/model
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/ogdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/pedigrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/phylogenetics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/planar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/routing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/trees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/tex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/graphdrawing/tex/experimental
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/datavisualization
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/decorations
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/luamath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/luamath/pgf/luamath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/shapes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/libraries/shapes/circuits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/lua/pgf/manual
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/modules
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/systemlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgf/utilities
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfornament/am
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfornament/pgfhan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfornament/vectorian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/libs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/liststructure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/lua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/lua/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/lua/pgfplotsoldpgfsupp/luamath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/numtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/oldpgfcompatib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/oldpgfplotscompatib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/pgfcontrib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/sys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/test
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pgfplots/util
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pictex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/plainpkg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pmx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pmxchords
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/polexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/poormanlog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/poster-mac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-abspos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-antiprism
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-arrow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-asr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-bar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-barcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-bezier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-bspline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-cie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-circ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-coil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-contourplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-cox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-dart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-diffraction
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-electricfield
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-eps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-eucl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-fill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-fit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-fr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-fractal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-fun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-func
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-gantt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-geo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-geo/data
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-geometrictools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-gr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-grad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-graphicx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-hsb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-infixplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-intersect
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-jtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-knot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-labo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-lens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-light3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-lsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-magneticfield
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-marble
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-mirror
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-moire
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-node
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-ob3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-ode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-optic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-osci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-ovl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-pad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-pdgr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-perspective
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-plot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-poly
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-pulley
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-rputover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-rubans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-sigsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-slpe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-solarsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-solides3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-spinner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-stru
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-text
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-thick
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-tree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-turtle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-tvz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pst-vehicle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pstricks-add
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/pstricks/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/qpxqtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/random
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/randomlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/reverxii
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/rlepsf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ruhyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ruler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/schemata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/scontents
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/shade
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/shapepar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/simplekv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/soul
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/splitindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/stringenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/swrule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/systeme
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/t2/cyrfinst
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/t2/cyrfinst/derivatives
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/t2/cyrfinst/etc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tabto-generic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/termmenu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tex-ewd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tex-ini-files
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tex-locale
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tex-ps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tex4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/texapi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/texdate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/texdimens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/texdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/textmerg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/thumbpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tikz-cd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tikz-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tikzducks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tokcycle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/tracklang
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/trigonometry
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ukrhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ulem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/unicode-data
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/uniquecounter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/upca
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/upzhkinsoku
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/variations
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/vaucanson-g
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/witharrows
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xcomment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xkeyval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xlop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xstring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/yax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/ydoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/youngtab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/zhmetrics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/generic/zhspacing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/hitex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/jadetex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lambda/antomega
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lambda/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lambda/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lambda/ocherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lambda/oinuit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/amsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/firstaid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/latex-lab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex-dev/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/12many
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/a0poster
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/a4wide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/a5comb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aalok
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aastex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abntex2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abntexto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aboensis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abraces
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abspos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/abstract
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/academicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/accanthis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/accents
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/accessibility
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/accfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/accsupp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/achemso
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/acmart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/acmconf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/acro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/acronym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/acroterm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/active-conf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/actuarialangle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/actuarialsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/addfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/addlines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adfathesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adforn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adfsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adigraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adjmulticol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adjustbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adrconv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/adtrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/advdate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aeguill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aesupp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/afparticle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/afthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aguplus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aiaa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/akktex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/akletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/akshar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alchemist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alegreya
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alertmessage/img
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alfaslabone
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algobox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algolrevived
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algorithm2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algorithmicx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algorithms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algpseudocodex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/algxpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aligned-overset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/allrunes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/almendra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alnumsec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/alterqcm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/altfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/altsubsup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amsaddr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amscdx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amscls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amsfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/amsrefs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/andika
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/animate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/annee-scolaire
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/annotate-equations
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/anonchap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/anonymous-acm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/anonymouspro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/answers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/antanilipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/antiqua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/anyfontsize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/anysize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aobs-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aomart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apa6/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apa6e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apa7/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apacite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/appendix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/appendixnumberbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apptools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/apxproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arabi-add
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arabicfront
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arabtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aramaic-serto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/archaeologie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/archaic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/archivo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arcs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arimo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arraycols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arraysort
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arsclassica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/articleingud
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arvo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/arydshln
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asaetr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asapsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ascelike
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ascii-font
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asciilist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ascmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/askinclude
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/askmaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asmeconf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asmejour
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aspectratio
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/assignment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/assoccnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/association-matrix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asternote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asyfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asymptote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/asypictureb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/atenddvi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/atendofenv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/atkinson
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/attachfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/attachfile2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/atveryend
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aucklandthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/augie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/auncial-new
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aurical
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/aurl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/authoraftertitle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/authorarchive
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/authordate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/authorindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/auto-pst-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/auto-pst-pdf-lua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/autoarea
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/autobreak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/autofancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/autonum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/autopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/auxhook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/avremu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/awesomebox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/axessibility
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/axodraw2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/b1encoding
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/babelbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/background
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/backnaur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bangla
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bangorcsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bangorexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bangtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bankstatement
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/barcodes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bardiag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bashful
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/basicarith
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/baskervald
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/baskervillef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/basque-book
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/basque-date
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bbding
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bbm-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bbold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bboldx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bchart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bclogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamer-fuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamer-verona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamer2thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerappendixnote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beameraudience
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerauxtheme
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamercolorthemeowl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerdarkthemes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerposter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamersubframe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerswitch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-arguelles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-cuerna
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-detlevcm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-epyt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-focus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-metropolis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-npbt/images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-phnompenh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-pure-minimalistic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-saintpetersburg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-simpledarkblue
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-simpleplus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-tcolorbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-trigon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamertheme-upenn-bc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerthemeamurmaple
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerthemejltree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerthemelalic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerthemenirma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beamerthemenord
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bearwear
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beaulivre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/begingreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/begriff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beilstein
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bengali
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/berenisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/betababel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/beuron
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bewerbung
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bez123
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bfh-ci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bgteubner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bguq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibarts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibcop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-abnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ajc2020unofficial
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-anonymous
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-apa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-apa6
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-archaeology
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-arthistory-bonn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-bath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-bookinarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-bookinother
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-bwl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-caspervector
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-chem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-chicago
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-claves
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-dw/bbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-dw/cbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-dw/lbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-enc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-fiwi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-gb7714-2015
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-german-legal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-gost
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-historian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ieee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ijsra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-iso690
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-jura2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-juradiss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-license
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-lncs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-lni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-luh-ipw/bbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-luh-ipw/cbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-luh-ipw/lbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-manuscripts-philology
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-mla
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-morenames
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ms/bbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ms/cbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-ms/lbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-multiple-dm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-musuos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-nature
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-nejm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-nottsclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-opcit-booktitle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-oxref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-philosophy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-phys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-publist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-readbbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-realauthor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-sbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-science
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-shortfields
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-socialscienceshuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-software
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-source-division
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-spbasic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-subseries
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-swiss-legal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-trad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-true-citepages-omit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-unified
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex-vancouver
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex/bbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex/cbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex/lbx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblatex2bibitem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref-french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref-german
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref-lds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref-mouth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibleref-parse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibletext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biblist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibtopic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibtopicprefix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bibunits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bigfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bigints
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bilingualpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/binarytree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/binomexp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biochemistry-colors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/biocon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bitpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bitter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bizcard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bjfuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blacklettert1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blindtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blkarray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blochsphere
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/block
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bloques
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blowup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/blox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bmstu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bmstu-iu8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bnumexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bodegraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bodeplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bohr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boisik
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boites
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bold-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boldtensors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bondgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bondgraphs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/book-of-common-prayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookcover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookest
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookhands
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/booklet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bookshelf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/booktabs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boolexpr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boondox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bophook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bosisio
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boxedminipage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/boxhandler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bpchem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/br-lex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bracketkey
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/braids
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/braille
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/braket
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/brandeis-dissertation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/brandeis-problemset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/brandeis-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/breakcites
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/breakurl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bredzenie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/breqn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bropd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/brushscr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bubblesort
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bullcntr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bundledoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/burmese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bussproofs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bussproofs-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxbase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxcjkjatype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxdpx-beamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxdvidriver
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxeepic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxenclose
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxghost
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxjaholiday
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxjalipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxjaprnind
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxjatoucs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxjscls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxnewfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxorigcapt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxpapersize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxpdfver
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxtexlogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bxwareki
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/byo-twemojis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/byrne
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/bytefield
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cabin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cachepic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/caladea
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calcage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calctab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calculation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calculator
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/callouts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calrsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cals
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/calxxxx-yyyy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cancel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/canoniclayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cantarell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/capt-of
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/captcont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/captdef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/caption
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/carbohydrates
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/carlisle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/carlito
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cartonaugh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cascade
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cascadia-code
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cascadilla
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cases
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/casyl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/catchfilebetweentags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/catechis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/catoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/causets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cbcoptic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cbfonts-fd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ccaption
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ccfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ccicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cclicenses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ccool
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cd-cover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cdcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cdpbundl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cellprops
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cellspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/celtic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/censor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/centeredline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/centerlastline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cesenaexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cfr-initials
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cfr-lm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/changebar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/changelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/changelog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/changepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/changes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chappg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chapterfolder
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/charissil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chbibref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cheatsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/checkend
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/checklistings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemcompounds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemcono
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemexec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemformula
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemmacros
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemobabel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemplants
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemschemex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemsec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chemstyle/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cherokee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chess-problem-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chessboard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chessfss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chextras
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chhaya
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chicago
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chifoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/childdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chinesechess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chivo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chkfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chklref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chngcntr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chordbars
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chordbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chronology
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chs-physics-report
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/chscite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/churchslavonic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cinzel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/circ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/circledsteps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/circledtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/circuit-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/circuitikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/citation-style-language/locales
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/citation-style-language/styles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/citeall
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/citeref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cje
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjhebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk-ko
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/contrib/wadalab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/Bg5
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/CEF
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/CNS
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/GB
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/JIS
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/KS
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/KS/HLaTeX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/SJIS
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/UTF8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/mule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/texinput/thai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjk/utils/pyhyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cjkpunct
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clara
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/classics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/classicthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/classpack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cleanthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clearsans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clefval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cleveref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clicks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clipboard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clistmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clock
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clojure-pamphlet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clrdblpg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clrscode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clrscode3e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/clrstrip
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cm-lgc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cm-super
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmathbb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmbright
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmdstring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmdtrack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmll
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmpj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmsd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmsrb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmtiup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cmupint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cnbwp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cnltx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cntformats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cntperchap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cochineal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codeanatomy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codebox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codedoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codehigh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codesection
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/codicefiscaleitaliano
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coelacanth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coffeestains
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/collcell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/collectbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/collref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colophon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/color-edits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colordoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorframed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coloring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colortbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorwav
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colorweb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/colourchange
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/combelow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/combine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/combinedgraphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/comfortaa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/comicneue
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/comma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/commath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/commedit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/comment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/commonunicode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/commutative-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/compactbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/competences
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/complexity
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/computational-complexity
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/concepts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/concmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/concmath-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/concprog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/conditext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/confproc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/constants
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/conteq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/context/ppchtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/continue
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/contour
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/contracard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/conv-xkv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cooking
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cooking-units
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cookingsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cool
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coolfn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coollist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coolstr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coolthms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cooltooltips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coop-writing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cooperhewitt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coordsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/copyedit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/copyrightbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cormorantgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/correctmathalign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coseoul
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/countriesofeurope
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/counttexruns
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/courier-scaled
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/courierten
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/courseoutline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coursepaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/coverpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/covington
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cprotect
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cprotectinside
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cquthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/create-theorem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crefthe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crimson
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crimsonpro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crossreference
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crossreftools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crossrefware
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crossword
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crosswrd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/crumbs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cryptocode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/csassignments
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/csbulletin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/csquotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/css-colors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/csvmerge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/csvsimple
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/dictionary
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/engine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/fd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/fontset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/heading
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctex/scheme
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ctib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cuisine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cuprum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/currency
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/currfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/currvita
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/curve
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/curve2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/curves
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/custom-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/customdice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cutwin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cv4tw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cvss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cweb-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cyber
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cybercic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dantelogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/darkmode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dashbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dashrule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dashundergaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dataref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datatool
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dateiliste
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datenumber
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-bahasai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-basque
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-breton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-bulgarian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-catalan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-croatian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-czech
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-en-fulltext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-english
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-esperanto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-galician
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-german
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-greek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-icelandic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-it-fulltext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-latin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-lsorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-magyar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-norsk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-romanian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-russian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-samin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-scottish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-slovak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-slovene
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-swedish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-turkish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-ukrainian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-usorbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/datetime2-welsh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dblfloatfix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dbshow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dccpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ddphonism
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/debate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/decimal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/decision-table
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/decorule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dejavu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dejavu-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/delim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/delimseasy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/delimset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/delimtxt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/democodetools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/denisbdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/derivative
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dhua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diabetes-logbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diadia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diagbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diagmac2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diagnose
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dialogl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dichokey
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dictsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/diffcoeff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/digiconfigs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dijkstra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dimnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dinbrief
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dingbat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/directory
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dirtytalk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/disser
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ditaa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dk-bib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dlfltxb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dnaseq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doclicense/images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doclicense/license-texts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/docmfp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/docmute
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/docshots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doctools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/documentation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/docutils
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doipubmed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/domitian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dot2texi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dotarrow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dotlessi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dotseqn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dottex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/doublestroke
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/download
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dozenal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dpcircling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dpfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dprogress
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/drac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/draftcopy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/draftfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/draftwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dramatist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/drawmatrix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/drawstack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/drm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/droid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/droit-fr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/drs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dsptricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dsserif
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dtk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dtk-bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dtxdescribe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ducksay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/duckuments
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/duerer-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/duotenzor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dutchcal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dvdcoll
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dvdcoll/dcl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dvgloss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dynamicnumber
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dynblocks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dynkin-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/dyntree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ean13isbn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easy-todo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easybook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easyfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easyfloats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easyformat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easylist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/easyreview
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebezier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebgaramond
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebgaramond-maths
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ebsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ecclesiastic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ecgdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ecltree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eco
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ecobiblatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/econlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/econometrics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/economic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/edfnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/edichokey
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/edmargin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eemeir
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eepic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/efbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/egameps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/egplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ehhline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eiad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eiad-ltx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/einfart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ejpecp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ekaia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elbioimp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/electrum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eledform
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elements
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ellipse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ellipsis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elocalloc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elpres
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/els-cas-templates/thumbnails
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elsarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elteikthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/elzcards
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emarks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/embedall
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/embedfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/embrac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emisa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emoji
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emptypage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/emulateapj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/encxvlna
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endheads
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endnotes-hy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endnotesj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endofproofwd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/endofproofwd/common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/engpron
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/engrec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/engtlc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/enigma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/enotez
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/enumitem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/enumitem-zref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/envbig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/environ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/envlab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eolang
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epigrafica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epigraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epigraph-keys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epiolmec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epsdice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epspdfconversion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/epstopdf-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eq-pin2corr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqexpl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqnalign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqname
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqnarray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqnnumwarn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eqparbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/erdc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/erewhon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/erewhon-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/errata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/erw-l3
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esami
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esdiff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esieecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eskd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eskdx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eso-pic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esrelation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esstix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/estcpmm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/esvect
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etaremune
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etbb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etex-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etextools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ethiop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etoolbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/etsvthor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euclideangeometry
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euflag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eukdate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euler-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eulerpx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eulervm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/euro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/europasscv/def
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/europasscv/icons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/europecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/eurosym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/everyhook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/everypage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/everysel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/everyshi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exam-lite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exam-n
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exam-randomizechoices
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exam-zh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/examdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/example
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/examplep
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exceltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/excludeonly
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exercise
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exercisebank
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exercisepoints
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exercises
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exesheet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exframe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exp-testopt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/expdlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/expkv-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/export
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exsheets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/exsol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/extarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/extpfeil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/extract
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/extsizes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/facsimile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/factura
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/faktor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/familytree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancybox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyhandout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancylabel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancynum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancypar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyqr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancytabs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancytooltips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fancyvrb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fascicules
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fast-diagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fbb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fbithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fcavtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fcltxdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fcolumn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fei
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fetamont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fetchcls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/feupphdteses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fewerfloatpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/feynmf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/feynmp-auto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ffcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ffslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fgruler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fifo-stack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/figbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/figchild
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/figput
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/figsize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/filecontents
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/filecontentsdef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/filedate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/filehook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fileinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/filemod
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fink
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/finstrut
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fira
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/firamath-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/firstaid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fistrum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fitbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/econ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/fi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/fsps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/fss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/law
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/med
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/ped
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/pharm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/phil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/locale/mu/sci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/logo/mu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fithesis/style/mu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fix2col
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixcmex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixdif
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixltxhyph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixme/layouts/env
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixme/layouts/target
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixme/themes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fixmetodonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fjodor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flacards
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flagderiv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flashcards
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flashmovie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flexipage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flipbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flippdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/float
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/floatrow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flowchart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/flowfram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fmp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fmtcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fn2end
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fnbreak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fncychap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fncylab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fnpara
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fnpct
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fnspe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fnumprint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/foekfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/foilhtml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/foliono
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fonetika
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontawesome5
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontaxes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontinst
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontmfizz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fonts-tlwg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontsetup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontsize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fontspec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fonttable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footmisc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footmisx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footnotebackref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footnotehyper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footnoterange
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/footnpag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/forarray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/foreign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/forest
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/forloop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/formal-grammar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/forms16be
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/formular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/forum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fouridx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fourier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fouriernc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fragments
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/framed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/francais-bst
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frankenstein
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frcursive
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frege
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frenchmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frimurer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frontespizio
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/froufrou
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/frpseudocode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ftc-notebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ftcap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ftnxtra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fullblck
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fullminipage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fullwidth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/functan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/functional
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fundus-calligra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fundus-cyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fundus-sueterlin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fvextra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/fwlw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/g-brief
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gaceta
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/galois
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gamebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gamebooklib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gammas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/garamond-libre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gastex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gatherenum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gauss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gb4e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gbt7714
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gcard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gchords
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gcite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gckanbun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gender
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gene-logic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/genealogytree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/genmpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gensymb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gentium-tug
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gentombow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/geometry
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/geradwp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/germbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/germkorr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/geschichtsfrkl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/getfiledate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/getitems
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/getmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfdl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsartemisia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsbaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsbodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfscomplutum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsdidot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsneohellenic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsneohellenicmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfsporson
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gfssolomos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ghab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ghsystem/language
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ghsystem/pictures
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gillcm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gillius
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gincltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ginpenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitfile-info
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitinfo2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitlog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitstatus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gitver
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/globalvals
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glosmathtools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gloss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-danish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-dutch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-english
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-estonian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-extra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-finnish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-french
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-german
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-irish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-italian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-magyar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-nynorsk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-polish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-portuges
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-serbian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-slovene
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries-spanish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries/expl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries/rollback
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries/styles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/glossaries/test-entries
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmdoc-enhance
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmiflink
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmutils
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmverb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gmverse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gnuplottex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/go
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gofonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gotoh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grabbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gradient-text
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gradientframe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grading-scheme
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gradstudentresume
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grafcet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grant
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graph35
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphics-cfg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphics-def
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphicscache
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphicx-psmin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphicxbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphicxpsd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/graphviz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grayhints
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/greek-fontenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/greek-inputenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/greekdates
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/greektex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/greektonoi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grfext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grffile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grfpaste
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grid-system
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gridpapers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gridset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gridslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grotesq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/grundgesetze
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gs1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gsemthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gtrcrd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gtrlib-largetrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gudea
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/guitar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/guitarchordschemes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/guitartabs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/guitlogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/gzt/images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/h2020proposal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Aggie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Capsules
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Ciment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Fyma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/HA
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Lakar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Simple
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/TCS
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ha-prosper/Styles/Tycja
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hackthefootline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hacm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hagenberg-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/halloweenmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hamnosys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/handin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/handout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/handoutwithnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hang
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hanging
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/har2nat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hardwrap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/harmony
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/harnon-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/harpoon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/harvard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/harveyballs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hausarbeit-jura
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/havannah
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/he-she
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hecthese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/helmholtz-ellis-ji-notation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-acronym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-bibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-float
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-font
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-math-font
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-paper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-reference
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-text
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hep-title
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hepnames
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hepparticles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hepthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hepunits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/here
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hereapplies
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/heros-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/heuristica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hexboard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hexgame
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hf-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hfoldsty
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hfutexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hhtensor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hideanswer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/highlightlatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hindmadurai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/histogr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/historische-zeitschrift
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hitec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hitreport
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hitszbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hitszthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hobby
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hobete
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hobsub
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hopatch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/horoscop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hpsdiss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/href-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hrefhide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hrlatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/huawei
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/huaz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hulipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hustthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvarabic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvextern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvlogos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvpygmentex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hvqrurl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hwemoji
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hycolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hypdestopt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hypdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hypdvips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hyper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hyperbar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hypernat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hyperref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hyperxmp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/hyphenat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ibarra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ibrackets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ibycus-babel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/icite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/icsv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/identkey
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/idxcmds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/idxlayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ieeeconf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ieeepes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ieeetran
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iexec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifallfalse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iffont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifmslide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifmtarg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifnextok
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifoddpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifplatform
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ifthenx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iitem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ijmart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ijsra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/imac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/image-gallery
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/imakeidx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/imfellenglish
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/impnattypo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/import
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/imtekda
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/incgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/includernw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inconsolata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/index
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/indextools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/initials
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inkpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inline-images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inlinebib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inlinedef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inlinelabel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inputenx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inputnormalization
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inputtrc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inriafonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/interactiveworkbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/interfaces
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/interval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/intopdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/inversepath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/invoice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/invoice-class
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/invoice2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iodhbwm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ionumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ipaex-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iscram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iso
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iso10303
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isodate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isodoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isomath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isonums
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isopt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isorot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/isotope
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/issuulinks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/istgame
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/itnumpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iwhdp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jacow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jamtimes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jeuxcartes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jigsaw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jkmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jknapltx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jlabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jlreq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jmb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jmlr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jmsdelim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jneurosci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jnuexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jobname-suffix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/josefin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jourcl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jpneduenumerate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jpnedumathsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jpsj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jslectureplanner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jumplines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/junicode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jupynotex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jura
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/juraabbrev
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jurabib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/juramisc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jurarsp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jvlisting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/jwjournal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kalendarium
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kanbun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kantlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/karnaugh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/karnaugh-map
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/karnaughmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kblocks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kdgdocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kdpcover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kerkis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kerntest
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ketcindy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keycommand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyparse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyreader
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keystroke
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyval2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/keyvaltable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kfupm-math-exam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kinematikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kluwer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/knittingpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/knowledge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/koma-moderncvclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/koma-script
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/koma-script-sfs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/komacv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/komacv-rg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-oblivoir
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-utf/contrib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kotex-utf/tex4ht
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kpfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kpfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ksp-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ktv-texdata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ku-template
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kvmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kvoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/kvsetkeys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3backend
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3build
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3benchmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3bitset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3draw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3graphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3opacity
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3str
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/l3sys-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/xcoffins
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3experimental/xgalley
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3kernel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3packages/l3keys2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3packages/xfp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3packages/xfrac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3packages/xparse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/l3packages/xtemplate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/labbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/labels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/labels4easylist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/labelschanged
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/labyrinth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ladder
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lambdax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/langnames
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/langsci-avm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lapdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lastpackage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lastpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latex-lab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latex-make
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latex-uni8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latex2man
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexbangla
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexbug
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexcolors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexconfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexdemo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexfileinfo-pkgs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latexgit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/latino-sine-flexione
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lato
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/layaureo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/layouts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lazylist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lccaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lcd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lcg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lcyw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leading
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leadsheets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leaflet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lebhart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lectures
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lectureslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leftidx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leftindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/leipzig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lengthconvert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/letltxmacro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/letterswitharrows
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lettre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lettrine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lewis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lexend
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lexikon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lexref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lgrmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lhcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lhcyr/lhcyralt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lhcyr/lhcyrkoi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lhcyr/lhcyrwin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lhelp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertinegc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertinus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertinus-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertinus-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libertinust1math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/librebaskerville
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/librebodoni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/librecaslon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/librefranklin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/libris
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lie-hasse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/liftarm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lilyglyphs/commands
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lilyglyphs/core
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lilyglyphs/pdfs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/limap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/limecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lineara
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/linegoal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lineno
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ling-macros
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/linguex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/linguisticspro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/linop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lion-msc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lisp-on-tex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listings-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listingsutf8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listlbls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listliketab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/listofsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lithuanian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/liturg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lkproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/llncs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/llncsconf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lmake
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lobster2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/locality
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logical-markup-utils
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logicproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logicpuzzle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logpap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/logreq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/longdivision
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/longfbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/longfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/longnamefilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/loops
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lpic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lplfitch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lroundrect
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lstaddons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lstbayes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lstfiracode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lt3graph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lt3rawobjects
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltablex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltabptch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltb2bib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxdockit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxguidex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxkeys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxmisc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxnew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ltxtools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/luacolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lwarp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/lxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/m-tx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/macrolist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/macros2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/macroswap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mafr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/magaz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/magicwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/magra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mahjong/tiles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mailing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mailmerge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makebarcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makebase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makebox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makecell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makecmds
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makedtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makeglos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makelabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makeplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/maker
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makerobust
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/makeshape
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mandi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/manfnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/manuscript
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/manyind
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marathi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marcellus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/margbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marginfit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marginfix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marginnote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/matapli
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/matc3
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/matc3mem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathalpha
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathastext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathcomp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdbch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdici
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdpgd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdpus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdput
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathdesign/mdugm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathfam256
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathfixs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathpartir
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathpunctspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathsemantics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathspic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mathtools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/matlab-prettifier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/matrix-skeleton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mattens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/maybemath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/maze
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mcaption
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mceinleger
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mcexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mcite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mciteplus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mcmthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mdframed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mdputu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mdsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mdwtools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mecaso
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/media4svg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/media9/javascript
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/media9/players
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/medstarbeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/meetingmins
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/membranecomputing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/memexsupp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/memoir
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/memory
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/memorygraphs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mensa-tex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mentis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/menu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/menucard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/menukeys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mercatormap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/merriweather
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/messagepassing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metalogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metalogox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metanorma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metastr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/method
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/metrix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mfirstuc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mflogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mfnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mfpic4ode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mftinc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mgltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mhchem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mhchem/hpstatement.inc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mhequ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mi-solns
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/miama
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/microtype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/midpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/miller
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/milog
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/milsymb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mindflow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minibox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minidocument
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minimalist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minipage-marginpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/miniplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minitoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minorrevision
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minted
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mintspirit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/minutes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mismath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/missaali
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mla-paper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mlacls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mlmodern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mluexercise
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mnras
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mnsymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modeles-factures-belges-assocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moderncv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modernposter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moderntimeline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modroman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/modular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mongolian-babel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/monofill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/montex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/montserrat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moodle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moreenum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/morefloats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/morehype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moresize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/moreverb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/morewrites
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/morisawa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/movie15
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mparhack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mpgraphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mpostinl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/msc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/msg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mslapa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/msu-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mtgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mucproc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mugsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/muling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multenum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multiaudience
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multibbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multibib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multibibliography
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multicap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multicolrule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multidef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multido
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multienv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multifootnote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multilang
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multiobjective
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multiple-choice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/multirow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musical
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musicography
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musikui
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musixguit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musixtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/musuos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/muthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mversion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mwcls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mwe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mweights
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mxedruli
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mycv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mylatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/mylatexformat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/naive-ebnf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nameauth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/namedtensor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/namespc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nanumtype1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/natbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/natded
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nature
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/navydocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ncclatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ncctools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nchairx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nddiss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ndsu-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ndsu-thesis-2022
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/needspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nestquot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/neuralnetwork
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nevelok
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newcomputermodern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newenviron
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newlfm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newpax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newpx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newspaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newtx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newtxsf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newtxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newunicodechar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newvbtm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/newverbs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nextpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nfssext-cfr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nicefilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/niceframe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nicematrix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nicetext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nicetext/run
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nidanfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nih
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nihbiosketch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nimbus15
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nimsticks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ninecolors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/njurepo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/njustthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/njuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/njuvisual
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nl-interval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nlctdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nmbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nndraw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nnext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/noconflict
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/noindentafter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/noitcrul
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nolbreaks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nomencl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nomentbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nonfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nonumonpart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nopageno
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/normalcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nostarch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notes2bib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notespages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notestex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/noto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notoccite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/notomath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nowidow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nrc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ntgclass
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ntheorem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nuc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nucleardata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numberedblock
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numberpt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numerica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numerica-plus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numerica-tables
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numericplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numname
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numnameru
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numprint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/numspell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nunito
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nwafuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nwejm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/nwejm/images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oberdiek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/objectz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/obnov
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ocg-p
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ocgx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ocgx2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ocr-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/octave
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/octavo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/old-arrows
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oldstandard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/onedown
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/onlyamsmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/onrannual
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/opcit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/opencolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/opensans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oplotsymbl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/opteng
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/optidef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/optional
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/options
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/orcidlink
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ordinalpt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/orientation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oscola
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oswald
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ot-tableau
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/othello
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/othelloboard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/otibet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oubraces
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/oup-authoring-template
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/outilsgeomtikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/outline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/outliner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/outlines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/outlining
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/overarrows
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/overlays
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/overlock
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/overpic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pacioli
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/padcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagecolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagecont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagegrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagella-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagenote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagerange
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pagesel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pageslts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/palette
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pangram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/paper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/papercdcase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/papermas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/papertex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/paracol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parades
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/paralist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parallel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/paratype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/paresse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parrun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parselines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/parskip
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pas-cours
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pas-crosswords
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pas-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pas-tableur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pascaltriangle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/patchcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pauldoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pawpict
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pb-diagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pbalance
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pbsheet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdf14
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfcol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfcolfoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfcolmk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfcomment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfcprot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdflscape
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfmanagement-testphase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfmarginpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfoverlay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfpagediff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfpc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfpc-movie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfprivacy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfreview
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfscreen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfslide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfsync
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdftricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdftricks2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfwin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pdfxup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pecha
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/penrose
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/perfectcut
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/perltex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/permute
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/petiteannonce
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pfarrei
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pfdicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-interference
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-periodictable/flags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-periodictable/lattice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-periodictable/spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-pie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-soroban
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-umlcd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf-umlsd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/basiclayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/compatibility
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/doc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/frontendlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/frontendlayer/libraries
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/systemlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgf/utilities
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfgantt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfkeyx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfmath-xfp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfmorepages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfopts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfornament
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfornament-han
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfornament-han/han
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pgfplots/libs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phaistos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfcc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfextendedabstract
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phffullpagefigure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfnote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfparen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfqit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfquotetext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfsvnwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phfthm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/philex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/philosophersimprint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phonenumbers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phonetic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/phonrule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/photo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/photobook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/physconst
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/physics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/physics2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/physunits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/piano
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/picinpar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pict2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pictex2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/picture
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/piff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pigpen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pinlabel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pinoutikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pittetd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pixelart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pixelarttikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pkgloader
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pkuthss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/placeins
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plantslabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plari
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plates
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/platex-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plautopatch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/play
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/playfair
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plex-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plimsoll
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/plweb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pm-isomath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pmboxdraw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pmgraph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pmhanguljamo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/poemscol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/poetry
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/poetrytex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/poiretone
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/polski
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/poltawski
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/polyglossia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/polynom
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/polynomial
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/polytable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/postage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/postcards
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/postnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/powerdot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/powerdot-fuberlin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/powerdot-tuliplab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/powerdot-tuliplab/logos/tulip
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ppr-prv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ppt-slides/ppt-schemes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ppt-slides/ppt-templates
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pracjourn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/practicalreports
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/precattl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prelim2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/preprint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prerex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pressrelease
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prettyref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prettytok
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/preview
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prftree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/principia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/printlen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proba
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/probsoln
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prociagssymp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prodint
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/productbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/profcollege
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proflabo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proflycee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/program
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/progress
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/progressbar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/projlib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proof-at-the-end
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proofread
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prooftrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/properties
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proposal/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proposal/dfg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/proposal/eu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prosper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/protex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/protocol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/prtec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/przechlewski-book
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/psbao
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pseudo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pseudocode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/psfrag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/psfragx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/psgo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pslatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/psnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pspicture
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-2dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-abspos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-am
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-antiprism
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-arrow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-asr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-bar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-barcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-bezier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-blur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-bspline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-calculate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-calendar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-cie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-circ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-coil
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-contourplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-cox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-dart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-dbicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-diffraction
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-electricfield
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-eps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-eucl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-exa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-feyn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-fill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-fit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-flags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-flags/Flags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-fr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-fractal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-fun
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-func
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-gantt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-geo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-geometrictools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-gr3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-grad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-hsb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-infixplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-intersect
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-jtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-knot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-labo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-layout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-lens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-light3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-lsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-magneticfield
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-marble
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-mirror
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-moire
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-node
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-ob3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-ode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-optexp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-optic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-osci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-ovl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-pad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-pdgr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-perspective
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-platon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-plot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-poker
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-poly
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-pulley
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-rputover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-rubans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-shell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-sigsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-slpe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-solarsystem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-solides3d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-soroban
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-spectra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-spinner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-stru
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-text
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-thick
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-tree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-turtle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-tvz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-uml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-vectorian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-vehicle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-venn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pst-vowel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pstool
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pstricks-add
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pstring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ptolemaicastronomy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ptptex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/punk-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/puyotikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxcjkcat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxgreeks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxjodel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxpgfmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxpic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxtatescale
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxtxalfa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pxufont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pygmentex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/python
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pythonhighlight
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pythonimmediate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/pythontex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qcircuit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qcm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qobitree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qrbill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qrcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qsharp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qstest
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quantikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quantumarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quattrocento
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quicktype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quiz2socrative
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quotchap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quoting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quotmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quran
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quran-bn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/quran-ur
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/qyxf-book
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/r_und_s
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ragged2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/raleway
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ran_toks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/randbild
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/randomwalk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/randtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rank-2-roots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rbt-mathnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rccol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rcs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rcs-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rcsinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/readablecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/readarray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/realboxes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/realhats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/realhats/hats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/realscripts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/realtranspose
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rec-thy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/recipe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/recipebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/recipecard
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/recorder-fingering
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rectopma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/recycle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/refcheck
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/refcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/refenums
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/reflectgraphics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/refman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/refstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/regcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/regexpatch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/register
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/regstats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/reledmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/relenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/relsize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/reotex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/repeatindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/repltext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rerunfilecheck
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rescansync
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/resmes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/resolsysteme
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/resphilosophica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rest-api
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/returntogrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/revquantum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/revtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/revtex4
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/revtex4-1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rgltxdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ribbonproofs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rjlparshap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rmathbr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rmpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/robotarm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/roboto
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/robustcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/robustindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rojud
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/romanbar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/romanbarpagenumber
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/romande
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/romanneg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/romannum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rosario
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rotfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rotpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/roundbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rrgtrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rsfso
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rterface
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rtkinenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rtklage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rubik
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rulerbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rulercompass
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/runcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/russ
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rutitlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rviewport
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/rvwrite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ryersonsgsthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ryethesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sa-tikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sacsymb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sageep
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sanitize-umlaut
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sankey
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sanskrit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sansmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sansmathaccent
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sansmathfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sapthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sasnrdisplay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sauerj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sauterfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/saveenv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/savefnmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/savesym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/savetrees
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scale
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scalebar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scalerel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scanpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schedule
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schemabloc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schola-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scholax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schooldocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schule/xsim-style
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schulmathematik
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schulschriften
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/schwalbe-chess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scientific-thesis-cover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sciposter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sclang-prettifier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scontents
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scrabble
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scrambledenvs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scratch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scratch3
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scratchx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/screenplay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/screenplay-pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scripture
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scrjrnl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scrlayer-fancyhdr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scrlttr2copy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/scsnowman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sdaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sdrt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sduthesis/figures
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/se2thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/secdot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/secnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/section
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sectionbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sectionbreak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sectsty
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/seealso
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/selectp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/selinput
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semantex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semantic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semantic-markup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/seminar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semioneside
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semproc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/semtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sepfootnotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sepnum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/seqsplit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/serbian-apostrophe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/serbian-date-lat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/serbian-def-cyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/serbian-lig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sesamanuel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sesstime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/setdeck
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/setspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/seu-ml-assign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/seuthesix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sf298
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sffms
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sfg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sfmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sgame
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shadethm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shadow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shadowtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shipunov
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shortmathj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shorttoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/show2e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/showcharinbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/showdim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/showexpl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/showlabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/showtags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shtthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/shuffle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sidecap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sidenotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sidenotesplus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/signchart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/silence
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sillypage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplebnf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplecd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplecv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simpleicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simpleinvoice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplenodes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simpleoptics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simpler-wick
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simples-matrices
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplewick
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/simplivre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sistyle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sitem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/siunits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/siunitx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skeldoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skeycommand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skeyval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skills
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skrapport
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/skull
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/slantsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smalltableof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smart-eqn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smartdiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smartref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smartunits
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/smflatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/snapshot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/snaptodo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/snotez
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/songbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/songproj
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/songs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/soton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/soulpos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/soup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sourcecodepro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sourcesanspro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sourceserifpro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spacingtricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spalign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spark-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sparklines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spath3
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spbmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spectralsequences
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sphdthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/splitbib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/splitindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spotcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spreadtab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/spverbatim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sr-vorl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/srbook-mem
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/srbtiks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/srcltx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/srdp-mathematik
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sseq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sslides
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stackengine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/standalone
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stanli
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/starfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/statex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/statex2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/statistics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/statistik
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/statmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/staves
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stdclsdv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stdpage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stealcaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/steinmetz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stellenbosch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stellenbosch/logos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/step
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stepgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stex/etc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stex/img
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stex/ldf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stickstoo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stix2-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/storebox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/storecmd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/strands
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stringstrings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/structmech
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/struktex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sttools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/stubs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/studenthandouts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/styledcmd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subdepth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subdocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subeqn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subeqnarray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subfigmat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subfiles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/substances
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/substitutefont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/substr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subsupscripts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/subtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sudoku
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sudokubundle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/suftesi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/sugconf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/superiors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/supertabular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/suppose
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/susy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svgcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svn-multi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svn-prov
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svninfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/svrsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/swfigure
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/swimgraf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/swungdash
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/syllogism
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/symbats3
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/synproof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/syntax
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/syntaxdi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/syntrace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/synttree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/t-angles
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/t2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabbing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabfigures
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/table-fct
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tableaux
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tablefootnote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tableof
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tablists
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tablor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tablvar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabriz-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabstackengine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabto-ltx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabularborder
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabularcalc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabularew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabularray
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabulary
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tabvar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tagging
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tagpair
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tagpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/talk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tamefloats
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tangramtikz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tasks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tcldoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tcolorbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tdclock
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tdsfrmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/technics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ted
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/templatetools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tempora
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tengwarscript
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tensind
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tensor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/termcal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/termcal-de
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/termes-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/termlist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/termsim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/testhyphens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/testidx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/teubner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tex-gyre
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tex-label
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tex-locale
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tex4ebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texilikechaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texilikecover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texlogos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texmate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texments
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texnegar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texosquery
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texpower
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texshade
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texsurgery
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textcase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textcsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textfit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textglos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textopo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textpath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textpos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/textualicomma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/texvc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tfrupee
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thaienum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thaispec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thalie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/theanodidot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/theanomodern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/theanooldstyle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/theoremref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thermodynamics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thesis-ekf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thesis-gwu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thesis-titlepage-fhac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thinsp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thmbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thmtools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/threadcol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/threeparttable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/threeparttablex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thuaslogos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thubeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thucoursework
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thumb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thumbs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thumby
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/thuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ticket
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ticollege
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tidyres
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-3dplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-among-us
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-bagua
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-bayesnet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-bbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-cd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-dependency
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-dimline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-feynhand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-feynman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-imagelabels
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-inet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-kalender
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-karnaugh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-ladder
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-lake-fig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-layers
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-mirror-lens
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-nef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-network
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-opm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-optics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-page
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-palattice
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-planets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-qtree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-relay
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-sfc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-swigs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-timing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-trackschematic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikz-truchet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzbricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzcodeblocks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzfill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzinclude
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzlings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzmark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzmarmots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzorbital
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzpackets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzpagenodes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzpeople
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzpfeile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzpingus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzposter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzscale
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzsymbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tikzviolinplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tile-graphic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/timbreicmc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/times
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/timing-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tinos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tipauni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tipfr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tiscreen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titlecaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titlefoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titlepic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titleref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titlesec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/titling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-berge
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-euclide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-fct
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-graph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-orm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkz-tab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tkzexample
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tlc-article
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/to-be-determined
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tocbibind
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tocdata
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tocloft
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tocvsec2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/todo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/todonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tokenizer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tonevalue
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/toolbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/topfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/topiclongtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/topletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/toptesi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/totalcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/totcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/totpages
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tpslifonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tqft
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tracklang
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/trajan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tramlines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/translations
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/translator
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/transparent
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tree-dvips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/trfsigns
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/trimspaces
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/trivfloat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/trsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/truncate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tsemlines
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tucv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tuda-ci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tudscr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tudscr/logo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tufte-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tugboat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tui
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/turabian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/turabian-formatting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/turkmen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/turnstile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/turnthepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/twemojis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/twoinone
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/twoup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/txfontsb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/txgreeks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/txuprcal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/type1cm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typed-checklist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typeface
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typehtml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typicons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typoaid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/typogrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/tzplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uaclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uafthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uantwerpendocs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uantwerpendocs/Images
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uantwerpendocs/Logos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uassign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucalgmthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucbthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucdavisthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucharcat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucs/data
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucsmonograph
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ucthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/udes-genie-these
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/udesoftec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uebungsblatt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uestcthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ufrgscca
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uhhassignment
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uhrzeit
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uiucredborder
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uiucthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ukbill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ulqda
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ulthese
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/umbclegislation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/umich-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/umlaute
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/umoline
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/umthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unam-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unamthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unbtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/underlin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/underoverlap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/underscore
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/undolabl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uni-titlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uni-wtal-ger
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uni-wtal-lin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unicode-alphabets
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unicode-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unicodefonttable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unifith
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unigrazpub
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unisc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unitn-bimrep
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/units
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unitsdef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/universa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/universalis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/univie-ling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unizgklasa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unravel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/unswcover
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uol-physics-report
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uothesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uowthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uowthesistitlepage
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/upmethodology
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uppunctlm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/upquote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/urcls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uri
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/url
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/urwchancal
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/usebib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ushort
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uspace
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uspatent
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ut-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/utexasthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/utf8add
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/utfsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uvaletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwa-colours
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwa-letterhead
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwa-pcf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwa-pif
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwmslide
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/uwthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/variablelm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/varindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/varsfromjobname
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/varwidth
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vcell
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vdmlisting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venndiagram
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturis2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturisadf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturisold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturissans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/venturissans2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verbasef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verbatimbox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verbatimcopy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verbdef
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verbments
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verifica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verifiche
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/verse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/version
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/versions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/versonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vertbars
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vgrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vhistory
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vmargin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vocaltract
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/volumes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vpe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vruler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/vwcol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wallpaper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wargame
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/warning
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/warpcol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/was
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wasysym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/webquiz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wheelchart
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/widetable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/widows-and-orphans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/williams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/willowtreebook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/windycity
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/withargs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wnri-latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wordcount
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wordlike
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/worksheet
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/worldflags
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wrapfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wrapfig2
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wrapstuff
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/writeongrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wsemclassic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wsuipa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/wtref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xargs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xassoccnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xbmks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcharter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcharter-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcjk2uni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcjk2uni/cmap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcntperchap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcolor-material
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcolor-solarized
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcookybooky
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xcpdftips
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xduthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xebaposter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xecyrmongolian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xellipsis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xfakebold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xfor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xhfill
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xifthen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xistercian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xkcdcolors
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xkeyval
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xltabular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xmpincl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xmuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xnewcommand
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xoptarg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpatch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpeek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpiano
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpicture
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpinyin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xprintlen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xpunctuate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xsavebox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xsim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xskak
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xtab
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xtuthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xurl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xwatermark
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xyling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xymtex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xymtex/chemist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xymtex/xymtxpdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xymtex/xymtxps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/xytree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yafoot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yagusylo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yaletter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yathesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yb-book
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ycbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ydoc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yfonts-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yhmath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/york-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yplan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/yquant
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ytableau
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zebra-goodies
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zed-csp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zennote
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zhlineskip
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zhlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zhmetrics
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zhnumber
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/ziffer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zlmtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zref
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zref-check
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zref-clever
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zref-vario
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zwgetfdate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zwpagelayout
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zx-calculus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zxjafbfont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zxjafont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/latex/zxjatype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lollipop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/addliga
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/arabluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/autopuncitems
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/beamer-rl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/bezierplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/combofont
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/cstypo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/dad
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/datestamp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/ekdosis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/emojicite
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/hmtrump
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/hu-berlin-bundle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/innerscript
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/japanese-mathformulas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/letgut
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/ligtype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/linebreaker
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lua-check-hyphen
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lua-typo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lua-ul
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lua-widow-control
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luabibentry
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luabidi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/_lib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/algebra/polynomialring
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/calculus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/core
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/core/binaryoperation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/test/calculus
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/test/expressions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/test/polynomials
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacas/test/rings
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacensor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luacomplex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luagcd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luahyphenrules
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaimageembed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luainputenc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lualatex-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lualatex-truncate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/lualinalg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luamathalign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luamaths
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luamesh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luamodulartables
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaoptions
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaprogtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luapstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaquotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luarandom
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luaset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luasseq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luatextra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luatodonotes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/luatruthtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/novel
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/odsfile
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/pdfarticle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/pgfmolbio
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/piton
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/placeat
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/plantuml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/pyluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/scikgtex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/selnolig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/semesterplanner
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/showhyphenation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/showkerning
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/simurgh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/spacekern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/stricttex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/truthtable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/typewriter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/uninormalize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/unitconv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/wallcalendar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/wallcalendar/i18n
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/xindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/lualatex/yamlvars
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/barracuda
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/blopentype
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/chickenize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/chinese-jfm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/cloze
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/cstypo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/ctablestack
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/ctex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/evangelion-jfm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/gregoriotex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/hyph-utf8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/interpreter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/jlreq
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/kanaparser
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lparse
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lua-uni-algos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lua-visual-debug
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lua-widow-control
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luaaddplot
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luakeys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lualibs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luamplib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luaotfload
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luapackageloader
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luatexbase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luatexja/addons
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luatexja/patches
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luatexko
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luavlna
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/luaxml
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lutabulartools
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/lyluatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/markdown
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/minim
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/minim-math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/minim-mp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/minim-pdf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/minim-xmp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/nodetree
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/pdfextra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/penlight
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/spelling
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/luatex/tsvtemplate
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/mex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/mex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/mex/utf8mex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/mltex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/optex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/optex/demo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/optex/lua-widow-control
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/optex/pdfextra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/optex/pkg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/amsfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/armenian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/asapsym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/commutative-diagrams
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/cweb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/cweb-old
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/cweb/cwebbin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/cyrplain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/encxvlna
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/enigma
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/epsf-dvipdfmx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/esint-type1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/etex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/figflow
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/fixpdfmag
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/font-change
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/fontch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/fp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/getoptk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gfnotation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/graphics-pln
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib/biblotex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib/licz
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib/map
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib/plbtx993
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/gustlib/plmac218
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/hanoi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/harvmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/hyplain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/js-misc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/knitting
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/knuth-lib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/knuth-local
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/kotex-plain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/kurier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/lambda-lists
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/lh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/ly1
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/makeindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/metatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/mkpattern
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/newsletr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/omega
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgf/basiclayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgf/frontendlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgf/math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgf/systemlayer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgf/utilities
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pgfplots
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pitex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/placeins-plain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/plipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/plnfss
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/plstmary
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/present
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/pwebmac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/resumemac
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/rsfs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/semaphor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/tikz-ext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/timetable
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/treetex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/tugboat-plain
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/varisize
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/vntex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/wasy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/xintsession
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/plain/zztex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/japanese-otf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/jlreq-deluxe
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/jsclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/pxbase
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/pxchfon
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/pxjahyper
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/platex/pxrubrica
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/psizzl/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/psizzl/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/ptex/ptex-base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/startex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/support/adhocfilelist
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/texinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/texsis/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/texsis/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/uplatex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/uplatex/config
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/uptex/uptex-base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/arabic-book
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/arabxetex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bhcexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidi-atbegshi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidicontour
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidihl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidipagegrid
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidipresentation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/bidishadowtext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/buctthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/businesscard-qrcode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/cqubeamer
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/facture
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/facture-belge-simple-sans-tva
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/fixlatvian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/fontbook
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/fontwrap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/hanzibox
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/hfutthesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/hithesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/imsproc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/interchar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/kurdishlipsum
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/langsci
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/mathspec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/mynsfc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/na-box
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/na-position
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/nanicolle
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/parsa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/philokalia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/ptext
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/quran-de
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/resumecls
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/sexam
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/simple-resume-cv
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/simple-thesis-dissertation
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/tabriz-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/technion-thesis-template
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/tetragonos
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/thesis-qom
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/ucharclasses
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/unicode-bidi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/unisugar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/velthuis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xduts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xechangebar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xecjk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xecolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xecyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xeindex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xepersian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xepersian-hm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xespotcolor
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xetex-pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xetexconfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xevlna
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xltxtra
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/xunicode
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/yazd-thesis
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/zbmath-review-template
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/zhspacing
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xelatex/zitie
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/font-change-xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/unimath-plain-xetex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/xesearch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/xetex-pstricks
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/xetexfontinfo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xetex/xetexko
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xmltex/base
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xmltex/passivetex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex/xmltex/xmltexconfig
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/base/unix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/base/win32
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/bin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Century_Schoolbook_L
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Bold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Bold_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_ExtraBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_ExtraBold_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Initials
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Medium
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Medium_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Regular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_SemiBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_SemiBold_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Fourier-Math-Letters
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Ex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Exa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Sy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Sya
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Companion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-Companion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Ex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Exa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Sy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-SC-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-SmallCaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-SC-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-SmallCaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/LibertineMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Biolinum_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Display_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Initials_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Mono_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Mono_T_
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/MnSymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/NewTXMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Condensed
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Condensed_Light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_ExtraBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_SemiBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/STIX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/STIX_Two
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Comp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Companion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Exp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Sc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Sc-Exp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_ExtraBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_ExtraLight
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_Light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_Medium
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_SemiBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/TeXGyreTermes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/TeXGyreTermesX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp-Comp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp-Exp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/Utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/XCharterMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/avantgar
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/bookman
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/mathppl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/mathptmx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/ncntrsbk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/ppalatino
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/pslatex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/times
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/zapfchan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/ams/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/arphic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/bera
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cc-pl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cjk/b5ka
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cm/sauter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/coch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/concrete
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/currency
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/cyrillic/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/erew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/eulervm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/euro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/fourier-orns
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futb-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futbi-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futc-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9c
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futrc9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futrci9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futrci9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futri-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futs-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9c
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsc9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsc9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsci9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsci9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9c
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9c
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9e
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkcy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkfs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkhei
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkkai
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkli
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkshu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbksu
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxh
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkyao
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkyou
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/greek/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/cs-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/ec-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/qx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/t5-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/texnansi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/jknappen/tc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/cs-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/cs-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/ex-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/exp-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/greek-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/mi-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/qx-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/qx-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/rm-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/sy-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2a-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2b-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2c-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t5-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t5-iwonacap
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/texnansi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/wncy-iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-ec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-qx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmrm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-csin
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-csrm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cstt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-plrm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-t5psn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/pre2005
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/mathpple
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/mathtime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/mlm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/musix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/ntxsups
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/ntxtm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/pazo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/qfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/sw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/t1fonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xbtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xbttsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xttsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/tcxbtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/times
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbexas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbmiaX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsyb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsyc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txbttsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txmiaX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/txttsc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/arevvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/chartervn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/classicovn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/cmbrightvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/comicsansvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/concretevn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/garamondvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/grotesqvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/mscorevn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/urwvn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/utopiavn
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/vnr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/aliase/mathtime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/ascii/manfnt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/cp1256/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/css/emacspeak/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/dbcs/cjk/b5ka
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/gb2312/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/gbk/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/html-speech/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/charset/uni
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/devanagari
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/euro
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/go
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/html/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/ipa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/mathtime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/mongolian
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/ps2mf
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/sw
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/tibetan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/xypic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2/html/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cm/sauter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cyrillic/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/html/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6/html/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/7/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/iso8859/8/hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/jsml/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/koi/8r/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/koi/8r/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset/mnemonic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset/native
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/ooffice/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/share/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/symbol/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/symbol/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/symbol/hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/symbol/mathtime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Baskervaldx
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Century_Schoolbook_L
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Initials
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Italic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Regular
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Extension
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Letters
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Ex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Exa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Sy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Sya
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Companion
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Ex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Sy
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-SmallCaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-SC-Expert
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-SmallCaps
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/LibertineMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Biolinum_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Display_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Initials_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Mono_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_T
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/MinLib
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/MnSymbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/NCXFourierMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/NewTXMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Nimbus_Roman_No9_L
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Open_Sans_ExtraBold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Open_Sans_Light
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/STIX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/STIX_Two
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Sf-Kp-Sc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Spectral
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/TeXGyreTermes
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/TeXGyreTermesX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Tt-Kp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Tt-Kp-Exp
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/URW_Chancery_L
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/Utopia
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/courier
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/helvetic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/mathptm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/palatino
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/symbol
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/times
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/zapfding
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ae
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/euler
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/symbols
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/antt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/arabi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/arev
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/arphic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/bbold
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/bitstrea/charter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cbgreek
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/chess
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/b5ka
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/gbksong/long
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/utf8
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/coch
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/concrete
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/currency
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cyklop
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/cyrillic/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/dstroke
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ebg
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ec
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/erewMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/fontawesome
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/fourier-orns
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/futr-sup
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/futrc9d
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/futrd8t
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/greek/ibygrk
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/hebrew
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/html/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/iwona
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/jknappen/tc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/latex
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/libertine
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/lm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/lm/pre2005
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/marvosym
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/math
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathdesign
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathkerncmssi
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathtime
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/mflogo
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/misc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/musix
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ntxsups
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/ntxtm
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/pl
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/public
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/pxfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/stickstooMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/stmaryrd
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/stxickstooMath
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/t1xtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/tcxtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/tibetan
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/tipa
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbexs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbmiaX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txexas
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txexs
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txfonts
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txmiaX
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsyb
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsyc
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsys
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/unicode/txtt
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/utf8/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/viqr/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/viscii/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/win/1251/charset
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cm/sauter
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cyrillic
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cyrillic/cmcyr
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/ht-fonts/win/1251/lh/lh-t2a
    mkdir -p %{buildroot}%{_texmfdistdir}/tex4ht/xtpipes
    mkdir -p %{buildroot}%{_texmfdistdir}/texconfig
    mkdir -p %{buildroot}%{_texmfdistdir}/texdoc
    mkdir -p %{buildroot}%{_texmfdistdir}/texdoctk
    mkdir -p %{buildroot}%{_texmfdistdir}/ttf2pk
    mkdir -p %{buildroot}%{_texmfdistdir}/web2c
    mkdir -p %{buildroot}%{_texmfdistdir}/xdvi/pixmap
    mkdir -p %{buildroot}%{_texmfmaindir}/readme-html.dir
    mkdir -p %{buildroot}%{_texmfmaindir}/readme-txt.dir
    mkdir -p %{buildroot}%{_texmfmaindir}/tlpkg/TeXLive
    mkdir -p %{buildroot}%{_texmfmaindir}/tlpkg/gpg
    mkdir -p %{buildroot}%{_datadir}/texlive
    ln -sf ../../share/texmf %{buildroot}%{_datadir}/texlive/texmf-dist
    ln -sf ../../lib/texmf   %{buildroot}%{_datadir}/texlive/texmf
    tar --use-compress-program=xz -xf %{S:1000} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1001} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1002} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1003} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1004} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1005} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1006} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1007} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1008} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1009} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1010} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1011} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1012} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1013} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1014} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1015} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1016} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1017} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1018} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1019} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1020} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1021} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1022} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1023} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1024} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1025} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1026} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1027} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1028} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1029} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1030} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1031} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1032} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1033} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1034} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1035} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1036} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1037} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1038} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1039} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1040} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1041} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1042} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1043} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1044} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1045} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1046} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1047} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    tar --use-compress-program=xz -xf %{S:1048} -C %{buildroot}%{_datadir}/texlive/texmf-dist
    rm -v  %{buildroot}%{_datadir}/texlive/texmf
    rm -v  %{buildroot}%{_datadir}/texlive/texmf-dist
    rm -vr %{buildroot}%{_datadir}/texlive

    # clear out all file below texmf tree as this will delivered by texlive tar balls
    find %{buildroot}%{_texmfdirs} -type f | xargs -r rm -vf

    # the ls-R file (empty at package time)
    for dir in	%{_texmfconfdir}	\
		%{_fontcache}		\
		%{_texmfvardir}		\
		%{_texmfvardir}/dist	\
		%{_texmfvardir}/main
    do
	echo '%% ls-R -- filename database for kpathsea; do not change this line.' > \
	%{buildroot}${dir}/ls-R
	chmod 0664 %{buildroot}${dir}/ls-R
    done
    ln -sf %{_texmfvardir}/dist/ls-R %{buildroot}%{_texmfdistdir}/
    ln -sf %{_texmfvardir}/main/ls-R %{buildroot}%{_texmfmaindir}/
    pushd %{buildroot}%{_texmfdistdir}/
	ls -RLA ./ 2>/dev/null >> %{buildroot}%{_texmfvardir}/dist/ls-R || true
    popd
    pushd %{buildroot}%{_texmfmaindir}/
	ls -RLA ./ 2>/dev/null >> %{buildroot}%{_texmfvardir}/main/ls-R || true
    popd

    (cat > %{buildroot}%{_texmfdistdir}/fonts/map/dvipdfmx/updmap/kanjix.map) <<-'EOF'
	% maintained by updmap[-sys] (multi).
	% Don't change this file directly. Use updmap[-sys] instead.
	% See the updmap documentation.
	% A log of the run that created this file is available here:
	% /tmp/umap-var/web2c/updmap.log
	EOF
    for cfg in builtin35 download35 ps2pk psfonts psfonts_pk psfonts_t1
    do
	(cat > %{buildroot}%{_texmfdistdir}/fonts/map/dvips/updmap/${cfg}.map) <<-'EOF'
	% maintained by updmap[-sys] (multi).
	% Don't change this file directly. Use updmap[-sys] instead.
	% See the updmap documentation.
	% A log of the run that created this file is available here:
	% /tmp/umap-var/web2c/updmap.log
	EOF
    done
    for cfg in pdftex pdftex_dl14 pdftex_ndl14
    do
	(cat > %{buildroot}%{_texmfdistdir}/fonts/map/pdftex/updmap/${cfg}.map) <<-'EOF'
	% maintained by updmap[-sys] (multi).
	% Don't change this file directly. Use updmap[-sys] instead.
	% See the updmap documentation.
	% A log of the run that created this file is available here:
	% /tmp/umap-var/web2c/updmap.log
	EOF
    done

    # the permission files, any change is also required within do.mklists
    # Note: the entry for the public program is set to
    #   %{_libexecdir}/mktex/publici    root:%{texgrp}  2755
    # in the standard global permission files
    mkdir -p %{buildroot}%{_sysconfdir}/permissions.d
    (cat > %{buildroot}%{_sysconfdir}/permissions.d/texlive.texlive) <<-EOF
	%{_texmfconfdir}/ls-R		root:%{texgrp}	0664
	%{_fontcache}/ls-R	   %{texusr}:%{texgrp}	0664
	%{_texmfvardir}/ls-R		root:%{texgrp}	0664
	%{_texmfvardir}/dist/ls-R	root:%{texgrp}	0664
	%{_texmfvardir}/main/ls-R	root:%{texgrp}	0664
	%{_texmfvardir}/		root:root	1755
	%{_texmfvardir}/dist/		root:root	1755
	%{_texmfvardir}/main/		root:root	1755
	%{_texmfvardir}/fonts/		root:root	1755
	%{_texmfvardir}/fonts/dvipdfm/	root:root	1755
	%{_texmfvardir}/fonts/dvips/	root:root	1755
	%{_texmfvardir}/fonts/pdftex/	root:root	1755
	%{_texmfcache}/			root:root	1755
	%{_fontcache}/		   %{texusr}:%{texgrp}	3775
	%{_fontcache}/pk/	   %{texusr}:%{texgrp}	3775
	%{_fontcache}/source/	   %{texusr}:%{texgrp}	3775
	%{_fontcache}/tfm/	   %{texusr}:%{texgrp}	3775
	EOF
    (cat > %{buildroot}%{_sysconfdir}/permissions.d/texlive) <<-EOF
	%{_texmfconfdir}/ls-R		root:%{texgrp}	0664
	%{_fontcache}/ls-R	   %{texusr}:%{texgrp}	0664
	%{_texmfvardir}/ls-R		root:%{texgrp}	0664
	%{_texmfvardir}/dist/ls-R	root:%{texgrp}	0664
	%{_texmfvardir}/main/ls-R	root:%{texgrp}	0664
	%{_texmfvardir}/		root:root	1755
	%{_texmfvardir}/dist/		root:root	1755
	%{_texmfvardir}/main/		root:root	1755
	%{_texmfvardir}/fonts/		root:root	1755
	%{_texmfvardir}/fonts/dvipdfm/	root:root	1755
	%{_texmfvardir}/fonts/dvips/	root:root	1755
	%{_texmfvardir}/fonts/pdftex/	root:root	1755
	%{_texmfcache}/			root:root	1755
	%{_fontcache}/		   %{texusr}:%{texgrp}	3775
	%{_fontcache}/pk/	   %{texusr}:%{texgrp}	3775
	%{_fontcache}/source/	   %{texusr}:%{texgrp}	3775
	%{_fontcache}/tfm/	   %{texusr}:%{texgrp}	3775
	EOF

%if %{with zypper_posttrans}
    sed -r 's@%%\{_texmfdistdir\}@%{_texmfdistdir}@' < %{S:42} > %{buildroot}%{_texmfdistdir}/texconfig/zypper.py
    mkdir -p %{buildroot}/var/adm/update-scripts
    ln -sf %{_texmfdistdir}/texconfig/zypper.py \
        %{buildroot}/var/adm/update-scripts/%{name}-%{version}-%{release}-zypper
%endif

    # enviroment
    mkdir -p %{buildroot}%{_sysconfdir}/profile.d
    install -m 0644 %{S:13} %{buildroot}%{_sysconfdir}/profile.d/
    install -m 0644 %{S:14} %{buildroot}%{_sysconfdir}/profile.d/

    mkdir -p %{buildroot}%{_datadir}/fontconfig/conf.avail

    install -m 0644 %{S:15} %{buildroot}%{_datadir}/fontconfig/conf.avail/09-texlive.conf
    install -m 0644 %{S:16} %{buildroot}%{_datadir}/fontconfig/conf.avail/09-texlive-type1.conf
    install -m 0644 %{S:17} %{buildroot}%{_datadir}/fontconfig/conf.avail/09-texlive-truetype.conf

    mkdir -p %{buildroot}%{_sysconfdir}/skel
    install -m 0644 %{S:31} %{buildroot}%{_sysconfdir}/skel/.dvipsrc

    # install config stuff
    mkdir -p %{buildroot}%{_fillupdir}
    install -m 0644 %{S:10} %{buildroot}%{_fillupdir}/sysconfig.texlive

    install -m 0755 %{S:11} %{buildroot}%{_texmfdistdir}/texconfig/update
%if 0%{?suse_version} > 1550
    install -m 0755 %{S:12} %{buildroot}%{_texmfdistdir}/texconfig/daily
    mkdir -p %{buildroot}%{_unitdir}
    install -m 0644 %{S:18} %{buildroot}%{_unitdir}/texlive.timer
    install -m 0644 %{S:19} %{buildroot}%{_unitdir}/texlive.service
    install -m 0644 %{S:20} %{buildroot}%{_unitdir}/texlive-initial.service
%else
    mkdir -p %{buildroot}%{_sysconfdir}/cron.daily
    install -m 0755 %{S:12} %{buildroot}%{_sysconfdir}/cron.daily/suse-texlive
%endif

%if %{defined verify_permissions}
%verifyscript
%verify_permissions -e %{_texmfconfdir}/ls-R
%verify_permissions -e %{_texmfvardir}/
%verify_permissions -e %{_texmfvardir}/fonts/
%verify_permissions -e %{_texmfvardir}/fonts/dvipdfm/
%verify_permissions -e %{_texmfvardir}/fonts/dvips/
%verify_permissions -e %{_texmfvardir}/fonts/ls-R
%verify_permissions -e %{_texmfvardir}/fonts/pdftex/
%verify_permissions -e %{_texmfvardir}/dist/
%verify_permissions -e %{_texmfvardir}/dist/ls-R
%verify_permissions -e %{_texmfvardir}/ls-R
%verify_permissions -e %{_texmfvardir}/main/
%verify_permissions -e %{_texmfvardir}/main/ls-R
%verify_permissions -e %{_texmfcache}/
%verify_permissions -e %{_fontcache}/
%verify_permissions -e %{_fontcache}/ls-R
%verify_permissions -e %{_fontcache}/pk/
%verify_permissions -e %{_fontcache}/source/
%verify_permissions -e %{_fontcache}/tfm/
%endif

%pre
# the ls-R file on update
for dir in	%{_texmfconfdir}	\
		%{_fontcache}		\
		%{_texmfvardir}		\
		%{_texmfvardir}/dist	\
		%{_texmfvardir}/main
do
    rm -f ${dir}/ls-R
done
%if 0%{?suse_version} > 1550
%service_add_pre texlive.timer texlive.service texlive-initial.service
%endif

%post
%fillup_only -n texlive
# the ls-R file (empty at package time)
error=0
user=
for dir in	%{_texmfconfdir}	\
		%{_fontcache}		\
		%{_texmfvardir}		\
		%{_texmfvardir}/dist	\
		%{_texmfvardir}/main
do
    test "$dir" = %{_fontcache} && user=%{texusr} || user=root
    setpriv --reuid $user --regid %{texgrp} --init-groups /bin/sh -ec "
	tmp=\$(mktemp ${dir}/ls-R.XXXXXX)
	chmod 0664 \${tmp}
	echo '%% ls-R -- filename database for kpathsea; do not change this line.' > \${tmp}
	mv \${tmp} ${dir}/ls-R" || error=1
done
%if %{defined set_permissions}
%set_permissions %{_texmfconfdir}/ls-R
%set_permissions %{_texmfvardir}/
%set_permissions %{_texmfvardir}/fonts/
%set_permissions %{_texmfvardir}/fonts/dvipdfm/
%set_permissions %{_texmfvardir}/fonts/dvips/
%set_permissions %{_texmfvardir}/fonts/ls-R
%set_permissions %{_texmfvardir}/fonts/pdftex/
%set_permissions %{_texmfvardir}/dist/
%set_permissions %{_texmfvardir}/dist/ls-R
%set_permissions %{_texmfvardir}/ls-R
%set_permissions %{_texmfvardir}/main/
%set_permissions %{_texmfvardir}/main/ls-R
%set_permissions %{_texmfcache}/
%set_permissions %{_fontcache}/
%set_permissions %{_fontcache}/ls-R
%set_permissions %{_fontcache}/pk/
%set_permissions %{_fontcache}/source/
%set_permissions %{_fontcache}/tfm/
%endif
%if 0%{?suse_version} > 1550
%service_add_post texlive.timer texlive.service texlive-initial.service
%endif
mkdir -p /var/run/texlive
> /var/run/texlive/run-mktexlsr
> /var/run/texlive/run-update
test $error = 0 || exit 1

%preun
%if 0%{?suse_version} > 1550
%service_del_preun texlive.timer texlive.service texlive-initial.service
%endif

%postun
%if 0%{?suse_version} > 1550
%service_del_postun texlive.timer texlive.service texlive-initial.service
%endif
if test $1 = 1; then
    mkdir -p /var/run/texlive
    > /var/run/texlive/run-mktexlsr
    > /var/run/texlive/run-update
fi

%posttrans
%if %{with zypper_posttrans}
test -z "$ZYPP_IS_RUNNING" || exit 0
%endif
test -d /var/run/texlive || exit 0
VERBOSE=false %{_texmfdistdir}/texconfig/update || :

%files
%defattr(-,root,root,755)
%if 0%{?suse_version} <= 1550
%config %{_sysconfdir}/cron.daily/suse-texlive
%endif
%config %{_sysconfdir}/permissions.d/texlive*
%config %{_sysconfdir}/profile.d/texlive*
%config %{_sysconfdir}/skel/.dvipsrc
%{_datadir}/fontconfig/conf.avail/09-texlive*.conf
%dir %{_libexecdir}/mktex
%dir %{_texmfconfdir}
%dir %{_texmfconfdir}/dvipdfm
%dir %{_texmfconfdir}/dvipdfm/config
%dir %{_texmfconfdir}/dvipdfmx
%dir %{_texmfconfdir}/dvips
%dir %{_texmfconfdir}/dvips/config
%dir %{_texmfconfdir}/scripts
%dir %{_texmfconfdir}/scripts/urlbst
%dir %{_texmfconfdir}/scripts/match_parens
%dir %{_texmfconfdir}/scripts/mf2pt1
%dir %{_texmfconfdir}/tex
%dir %{_texmfconfdir}/tex/amstex
%dir %{_texmfconfdir}/tex/amstex/base
%dir %{_texmfconfdir}/tex/generic
%dir %{_texmfconfdir}/tex/generic/config
%dir %{_texmfconfdir}/tex/generic/tex-ini-files
%dir %{_texmfconfdir}/tex/lambda
%dir %{_texmfconfdir}/tex/lambda/config
%dir %{_texmfconfdir}/tex/mex
%dir %{_texmfconfdir}/tex/mex/base
%dir %{_texmfconfdir}/tex/plain
%dir %{_texmfconfdir}/tex/plain/cyrplain
%dir %{_texmfconfdir}/web2c
%dir %{_texmfconfdir}/xdvi
%dir %{_texmfmaindir}
%dir %{_texmfdistdir}/web2c
%dir %{_texmfdistdir}/chktex
%dir %{_texmfdistdir}/doc
%dir %{_texmfdistdir}/doc/chktex
%dir %{_texmfdistdir}/doc/bibtex8
%dir %{_texmfdistdir}/tex/generic/config/language.splits
%dir %{_texmfdistdir}/scripts
%dir %{_texmfdistdir}/scripts/chktex
%dir %{_texmfdistdir}/scripts/ps2eps
%dir %{_texmfdistdir}/scripts/simpdftex
%dir %{_texmfdistdir}/scripts/a2ping
%dir %{_texmfdistdir}/scripts/texdoc
%dir %{_texmfdistdir}/scripts/texlive
%dir %{_texmfdistdir}/hbf2gf
%dir %{_texmfdistdir}/fonts
%dir %{_texmfdistdir}/fonts/cmap
%dir %{_texmfdistdir}/fonts/cmap/dvipdfmx
%dir %{_texmfdistdir}/fonts/map
%dir %{_texmfdistdir}/fonts/map/dvipdfmx
%dir %{_texmfdistdir}/dvipdfmx
%dir %{_texmfdistdir}/dvips
%dir %{_texmfdistdir}/dvips/base
%dir %{_texmfdistdir}/dvips/gsftopk
%dir %{_texmfdistdir}/xdvi
%dir %{_texmfdistdir}/xdvi/pixmap
%dir %{_texmfdistdir}/texconfig
%attr(0755,root,root) %{_texmfdistdir}/texconfig/update
%if 0%{?suse_version} > 1550
%attr(0755,root,root) %{_texmfdistdir}/texconfig/daily
%{_unitdir}/texlive.timer
%{_unitdir}/texlive.service
%{_unitdir}/texlive-initial.service
%endif
%if %{with zypper_posttrans}
%attr(0755,root,root) %{_texmfdistdir}/texconfig/zypper.py
%endif
%dir %{_texmfdistdir}/asymptote
%dir %{_texmfdistdir}/asymptote/GUI
%dir %{_texmfdistdir}
%dir %{_texmfdistdir}/tlpkg
%dir %{_texmfdistdir}/tlpkg/TeXLive
%dir %{_texmfdistdir}/tlpkg/tlpostcode
%dir %{_texmfdistdir}/bibtex
%dir %{_texmfdistdir}/bibtex/csf
%dir %{_texmfdistdir}/bibtex/csf/base
%dir %{_texmfdistdir}/fonts
%dir %{_texmfdistdir}/fonts/map
%dir %{_texmfdistdir}/fonts/map/glyphlist
%dir %{_texmfdistdir}/scripts
%dir %{_texmfdistdir}/scripts/tex4ht
%dir %{_texmfdistdir}/scripts/bibexport
%dir %{_texmfdistdir}/scripts/listings-ext
%dir %{_texmfdistdir}/scripts/pdfjam
%dir %{_texmfdistdir}/scripts/pst-pdf
%dir %{_texmfdistdir}/scripts/accfonts
%dir %{_texmfdistdir}/scripts/authorindex
%dir %{_texmfdistdir}/scripts/bundledoc
%dir %{_texmfdistdir}/scripts/cachepic
%dir %{_texmfdistdir}/scripts/context
%dir %{_texmfdistdir}/scripts/context/perl
%dir %{_texmfdistdir}/scripts/de-macro
%dir %{_texmfdistdir}/scripts/dviasm
## %dir %{_texmfdistdir}/scripts/ebong
%dir %{_texmfdistdir}/scripts/epspdf
%dir %{_texmfdistdir}/scripts/epstopdf
%dir %{_texmfdistdir}/scripts/fig4latex
%dir %{_texmfdistdir}/scripts/findhyph
%dir %{_texmfdistdir}/scripts/fontools
%dir %{_texmfdistdir}/scripts/fragmaster
%dir %{_texmfdistdir}/scripts/glossaries
%dir %{_texmfdistdir}/scripts/latex2man
%dir %{_texmfdistdir}/scripts/latexdiff
%dir %{_texmfdistdir}/scripts/latexmk
%dir %{_texmfdistdir}/scripts/luaotfload
%dir %{_texmfdistdir}/scripts/mathspic
%dir %{_texmfdistdir}/scripts/mkjobtexmf
%dir %{_texmfdistdir}/scripts/mkgrkindex
%dir %{_texmfdistdir}/scripts/m-tx
%dir %{_texmfdistdir}/scripts/musixtex
%dir %{_texmfdistdir}/scripts/pax
%dir %{_texmfdistdir}/scripts/pdfcrop
%dir %{_texmfdistdir}/scripts/perltex
%dir %{_texmfdistdir}/scripts/pkfix
%dir %{_texmfdistdir}/scripts/pkfix-helper
%dir %{_texmfdistdir}/scripts/pmx
%dir %{_texmfdistdir}/scripts/pst2pdf
%dir %{_texmfdistdir}/scripts/purifyeps
%dir %{_texmfdistdir}/scripts/splitindex
%dir %{_texmfdistdir}/scripts/sty2dtx
%dir %{_texmfdistdir}/scripts/svn-multi
%dir %{_texmfdistdir}/scripts/texcount
%dir %{_texmfdistdir}/scripts/texdef
%dir %{_texmfdistdir}/scripts/texdiff
%dir %{_texmfdistdir}/scripts/texdirflatten
%dir %{_texmfdistdir}/scripts/texloganalyser
%dir %{_texmfdistdir}/scripts/thumbpdf
%dir %{_texmfdistdir}/scripts/ulqda
%dir %{_texmfdistdir}/scripts/vpe
%dir %{_x11data}
%dir %{_x11data}/app-defaults
%dir %{_texmfdistdir}/asymptote
%dir %{_texmfdistdir}/asymptote/GUI
%dir %{_texmfdistdir}/asymptote/GUI/configs
%dir %{_texmfdistdir}/asymptote/GUI/pyUIClass
%dir %{_texmfdistdir}/asymptote/GUI/res
%dir %{_texmfdistdir}/asymptote/GUI/res/icons
%dir %{_texmfdistdir}/asymptote/shaders
%dir %{_texmfdistdir}/asymptote/webgl
%dir %{_texmfdistdir}/bibtex
%dir %{_texmfdistdir}/bibtex/bib
%dir %{_texmfdistdir}/bibtex/bib/abntex2
%dir %{_texmfdistdir}/bibtex/bib/abstyles
%dir %{_texmfdistdir}/bibtex/bib/amsrefs
%dir %{_texmfdistdir}/bibtex/bib/archaeologie
%dir %{_texmfdistdir}/bibtex/bib/attachfile
%dir %{_texmfdistdir}/bibtex/bib/base
%dir %{_texmfdistdir}/bibtex/bib/beebe
%dir %{_texmfdistdir}/bibtex/bib/biblatex
%dir %{_texmfdistdir}/bibtex/bib/biblatex-ms
%dir %{_texmfdistdir}/bibtex/bib/biblatex-ms/biblatex
%dir %{_texmfdistdir}/bibtex/bib/biblatex/biblatex
%dir %{_texmfdistdir}/bibtex/bib/cnltx
%dir %{_texmfdistdir}/bibtex/bib/directory
%dir %{_texmfdistdir}/bibtex/bib/dk-bib
%dir %{_texmfdistdir}/bibtex/bib/dtk-bibliography
%dir %{_texmfdistdir}/bibtex/bib/frankenstein
%dir %{_texmfdistdir}/bibtex/bib/gloss
%dir %{_texmfdistdir}/bibtex/bib/glossaries-extra
%dir %{_texmfdistdir}/bibtex/bib/gustlib
%dir %{_texmfdistdir}/bibtex/bib/harvard
%dir %{_texmfdistdir}/bibtex/bib/ieeetran
%dir %{_texmfdistdir}/bibtex/bib/jurabib
%dir %{_texmfdistdir}/bibtex/bib/lsc
%dir %{_texmfdistdir}/bibtex/bib/nostarch
%dir %{_texmfdistdir}/bibtex/bib/oberdiek
%dir %{_texmfdistdir}/bibtex/bib/spie
%dir %{_texmfdistdir}/bibtex/bib/testidx
%dir %{_texmfdistdir}/bibtex/bst
%dir %{_texmfdistdir}/bibtex/bst/aaai-named
%dir %{_texmfdistdir}/bibtex/bst/aastex
%dir %{_texmfdistdir}/bibtex/bst/abntex2
%dir %{_texmfdistdir}/bibtex/bst/abstyles
%dir %{_texmfdistdir}/bibtex/bst/achemso
%dir %{_texmfdistdir}/bibtex/bst/acmart
%dir %{_texmfdistdir}/bibtex/bst/adfathesis
%dir %{_texmfdistdir}/bibtex/bst/adrconv
%dir %{_texmfdistdir}/bibtex/bst/afthesis
%dir %{_texmfdistdir}/bibtex/bst/aguplus
%dir %{_texmfdistdir}/bibtex/bst/aiaa
%dir %{_texmfdistdir}/bibtex/bst/aichej
%dir %{_texmfdistdir}/bibtex/bst/ajl
%dir %{_texmfdistdir}/bibtex/bst/alpha-persian
%dir %{_texmfdistdir}/bibtex/bst/amscls
%dir %{_texmfdistdir}/bibtex/bst/amsrefs
%dir %{_texmfdistdir}/bibtex/bst/annotate
%dir %{_texmfdistdir}/bibtex/bst/aomart
%dir %{_texmfdistdir}/bibtex/bst/apacite
%dir %{_texmfdistdir}/bibtex/bst/apalike-ejor
%dir %{_texmfdistdir}/bibtex/bst/apalike-german
%dir %{_texmfdistdir}/bibtex/bst/apalike2
%dir %{_texmfdistdir}/bibtex/bst/asaetr
%dir %{_texmfdistdir}/bibtex/bst/ascelike
%dir %{_texmfdistdir}/bibtex/bst/asmeconf
%dir %{_texmfdistdir}/bibtex/bst/asmejour
%dir %{_texmfdistdir}/bibtex/bst/authordate
%dir %{_texmfdistdir}/bibtex/bst/babelbib
%dir %{_texmfdistdir}/bibtex/bst/base
%dir %{_texmfdistdir}/bibtex/bst/bath-bst
%dir %{_texmfdistdir}/bibtex/bst/beilstein
%dir %{_texmfdistdir}/bibtex/bst/besjournals
%dir %{_texmfdistdir}/bibtex/bst/bestpapers
%dir %{_texmfdistdir}/bibtex/bst/bgteubner
%dir %{_texmfdistdir}/bibtex/bst/bib-fr
%dir %{_texmfdistdir}/bibtex/bst/bibexport
%dir %{_texmfdistdir}/bibtex/bst/bibhtml
%dir %{_texmfdistdir}/bibtex/bst/biblatex
%dir %{_texmfdistdir}/bibtex/bst/biblatex-ms
%dir %{_texmfdistdir}/bibtex/bst/biolett-bst
%dir %{_texmfdistdir}/bibtex/bst/bookdb
%dir %{_texmfdistdir}/bibtex/bst/cascadilla
%dir %{_texmfdistdir}/bibtex/bst/cell
%dir %{_texmfdistdir}/bibtex/bst/chem-journal
%dir %{_texmfdistdir}/bibtex/bst/chembst
%dir %{_texmfdistdir}/bibtex/bst/chet
%dir %{_texmfdistdir}/bibtex/bst/chicago
%dir %{_texmfdistdir}/bibtex/bst/chicago-annote
%dir %{_texmfdistdir}/bibtex/bst/chicagoa
%dir %{_texmfdistdir}/bibtex/bst/chscite
%dir %{_texmfdistdir}/bibtex/bst/cje
%dir %{_texmfdistdir}/bibtex/bst/cmpj
%dir %{_texmfdistdir}/bibtex/bst/cnbwp
%dir %{_texmfdistdir}/bibtex/bst/computational-complexity
%dir %{_texmfdistdir}/bibtex/bst/confproc
%dir %{_texmfdistdir}/bibtex/bst/context
%dir %{_texmfdistdir}/bibtex/bst/context/mkii
%dir %{_texmfdistdir}/bibtex/bst/cquthesis
%dir %{_texmfdistdir}/bibtex/bst/datatool
%dir %{_texmfdistdir}/bibtex/bst/din1505
%dir %{_texmfdistdir}/bibtex/bst/dinat
%dir %{_texmfdistdir}/bibtex/bst/directory
%dir %{_texmfdistdir}/bibtex/bst/dk-bib
%dir %{_texmfdistdir}/bibtex/bst/dlfltxb
%dir %{_texmfdistdir}/bibtex/bst/dvdcoll
%dir %{_texmfdistdir}/bibtex/bst/econ-bst
%dir %{_texmfdistdir}/bibtex/bst/economic
%dir %{_texmfdistdir}/bibtex/bst/els-cas-templates
%dir %{_texmfdistdir}/bibtex/bst/elsarticle
%dir %{_texmfdistdir}/bibtex/bst/fbs
%dir %{_texmfdistdir}/bibtex/bst/fcavtex
%dir %{_texmfdistdir}/bibtex/bst/figbib
%dir %{_texmfdistdir}/bibtex/bst/finbib
%dir %{_texmfdistdir}/bibtex/bst/francais-bst
%dir %{_texmfdistdir}/bibtex/bst/frankenstein
%dir %{_texmfdistdir}/bibtex/bst/gammas
%dir %{_texmfdistdir}/bibtex/bst/gbt7714
%dir %{_texmfdistdir}/bibtex/bst/germbib
%dir %{_texmfdistdir}/bibtex/bst/gloss
%dir %{_texmfdistdir}/bibtex/bst/gost
%dir %{_texmfdistdir}/bibtex/bst/gustlib
%dir %{_texmfdistdir}/bibtex/bst/harvard
%dir %{_texmfdistdir}/bibtex/bst/hc
%dir %{_texmfdistdir}/bibtex/bst/hithesis
%dir %{_texmfdistdir}/bibtex/bst/hitszbeamer
%dir %{_texmfdistdir}/bibtex/bst/hitszthesis
%dir %{_texmfdistdir}/bibtex/bst/hustthesis
%dir %{_texmfdistdir}/bibtex/bst/ieeepes
%dir %{_texmfdistdir}/bibtex/bst/ieeetran
%dir %{_texmfdistdir}/bibtex/bst/ieejtran
%dir %{_texmfdistdir}/bibtex/bst/ijmart
%dir %{_texmfdistdir}/bibtex/bst/ijqc
%dir %{_texmfdistdir}/bibtex/bst/imac
%dir %{_texmfdistdir}/bibtex/bst/index
%dir %{_texmfdistdir}/bibtex/bst/inlinebib
%dir %{_texmfdistdir}/bibtex/bst/iopart-num
%dir %{_texmfdistdir}/bibtex/bst/is-bst
%dir %{_texmfdistdir}/bibtex/bst/jbact
%dir %{_texmfdistdir}/bibtex/bst/jieeetran
%dir %{_texmfdistdir}/bibtex/bst/jmb
%dir %{_texmfdistdir}/bibtex/bst/jneurosci
%dir %{_texmfdistdir}/bibtex/bst/jurabib
%dir %{_texmfdistdir}/bibtex/bst/jurarsp
%dir %{_texmfdistdir}/bibtex/bst/kluwer
%dir %{_texmfdistdir}/bibtex/bst/ksfh_nat
%dir %{_texmfdistdir}/bibtex/bst/lion-msc
%dir %{_texmfdistdir}/bibtex/bst/listbib
%dir %{_texmfdistdir}/bibtex/bst/llncs
%dir %{_texmfdistdir}/bibtex/bst/lni
%dir %{_texmfdistdir}/bibtex/bst/mciteplus
%dir %{_texmfdistdir}/bibtex/bst/mnras
%dir %{_texmfdistdir}/bibtex/bst/mslapa
%dir %{_texmfdistdir}/bibtex/bst/multibib
%dir %{_texmfdistdir}/bibtex/bst/multibibliography
%dir %{_texmfdistdir}/bibtex/bst/munich
%dir %{_texmfdistdir}/bibtex/bst/nar
%dir %{_texmfdistdir}/bibtex/bst/natbib
%dir %{_texmfdistdir}/bibtex/bst/nature
%dir %{_texmfdistdir}/bibtex/bst/nddiss
%dir %{_texmfdistdir}/bibtex/bst/newcastle-bst
%dir %{_texmfdistdir}/bibtex/bst/nmbib
%dir %{_texmfdistdir}/bibtex/bst/notex-bst
%dir %{_texmfdistdir}/bibtex/bst/opcit
%dir %{_texmfdistdir}/bibtex/bst/perception
%dir %{_texmfdistdir}/bibtex/bst/persian-bib
%dir %{_texmfdistdir}/bibtex/bst/phfnote
%dir %{_texmfdistdir}/bibtex/bst/plainyr
%dir %{_texmfdistdir}/bibtex/bst/pnas2009
%dir %{_texmfdistdir}/bibtex/bst/prtec
%dir %{_texmfdistdir}/bibtex/bst/przechlewski-book
%dir %{_texmfdistdir}/bibtex/bst/quantumarticle
%dir %{_texmfdistdir}/bibtex/bst/resphilosophica
%dir %{_texmfdistdir}/bibtex/bst/revtex
%dir %{_texmfdistdir}/bibtex/bst/revtex4
%dir %{_texmfdistdir}/bibtex/bst/revtex4-1
%dir %{_texmfdistdir}/bibtex/bst/rsc
%dir %{_texmfdistdir}/bibtex/bst/sageep
%dir %{_texmfdistdir}/bibtex/bst/sapthesis
%dir %{_texmfdistdir}/bibtex/bst/savetrees
%dir %{_texmfdistdir}/bibtex/bst/seuthesis
%dir %{_texmfdistdir}/bibtex/bst/seuthesix
%dir %{_texmfdistdir}/bibtex/bst/shipunov
%dir %{_texmfdistdir}/bibtex/bst/smflatex
%dir %{_texmfdistdir}/bibtex/bst/sort-by-letters
%dir %{_texmfdistdir}/bibtex/bst/spie
%dir %{_texmfdistdir}/bibtex/bst/stellenbosch
%dir %{_texmfdistdir}/bibtex/bst/swebib
%dir %{_texmfdistdir}/bibtex/bst/texsis
%dir %{_texmfdistdir}/bibtex/bst/thubeamer
%dir %{_texmfdistdir}/bibtex/bst/thuthesis
%dir %{_texmfdistdir}/bibtex/bst/tufte-latex
%dir %{_texmfdistdir}/bibtex/bst/tugboat
%dir %{_texmfdistdir}/bibtex/bst/udesoftec
%dir %{_texmfdistdir}/bibtex/bst/uestcthesis
%dir %{_texmfdistdir}/bibtex/bst/unamthesis
%dir %{_texmfdistdir}/bibtex/bst/unifith
%dir %{_texmfdistdir}/bibtex/bst/upmethodology
%dir %{_texmfdistdir}/bibtex/bst/urlbst
%dir %{_texmfdistdir}/bibtex/bst/vak
%dir %{_texmfdistdir}/bibtex/bst/vancouver
%dir %{_texmfdistdir}/bibtex/bst/zootaxa-bst
%dir %{_texmfdistdir}/bibtex/csf
%dir %{_texmfdistdir}/bibtex/csf/base
%dir %{_texmfdistdir}/bibtex/csf/dk-bib
%dir %{_texmfdistdir}/bibtex/csf/gost
%dir %{_texmfdistdir}/bibtex/csf/persian-bib
%dir %{_texmfdistdir}/bibtex/csf/polish-csf
%dir %{_texmfdistdir}/chktex
%dir %{_texmfdistdir}/context
%dir %{_texmfdistdir}/context/data
%dir %{_texmfdistdir}/context/data/scite
%dir %{_texmfdistdir}/context/data/scite/context
%dir %{_texmfdistdir}/context/data/scite/context/documents
%dir %{_texmfdistdir}/context/data/scite/context/lexers
%dir %{_texmfdistdir}/context/data/scite/context/lexers/data
%dir %{_texmfdistdir}/context/data/scite/context/lexers/themes
%dir %{_texmfdistdir}/context/data/texworks
%dir %{_texmfdistdir}/context/data/texworks/TUG
%dir %{_texmfdistdir}/context/data/texworks/completion
%dir %{_texmfdistdir}/context/data/texworks/configuration
%dir %{_texmfdistdir}/context/data/vscode
%dir %{_texmfdistdir}/context/data/vscode/extensions
%dir %{_texmfdistdir}/context/data/vscode/extensions/context
%dir %{_texmfdistdir}/context/data/vscode/extensions/context/keybindings
%dir %{_texmfdistdir}/context/data/vscode/extensions/context/settings
%dir %{_texmfdistdir}/context/data/vscode/extensions/context/syntaxes
%dir %{_texmfdistdir}/context/data/vscode/extensions/context/tasks
%dir %{_texmfdistdir}/context/data/vscode/extensions/context/themes
%dir %{_texmfdistdir}/doc
%dir %{_texmfdistdir}/doc/aleph
%dir %{_texmfdistdir}/doc/aleph/base
%dir %{_texmfdistdir}/doc/amstex
%dir %{_texmfdistdir}/doc/amstex/base
%dir %{_texmfdistdir}/doc/asymptote
%dir %{_texmfdistdir}/doc/asymptote/examples
%dir %{_texmfdistdir}/doc/asymptote/examples/animations
%dir %{_texmfdistdir}/doc/bibtex
%dir %{_texmfdistdir}/doc/bibtex/abstyles
%dir %{_texmfdistdir}/doc/bibtex/alpha-persian
%dir %{_texmfdistdir}/doc/bibtex/alpha-persian/image
%dir %{_texmfdistdir}/doc/bibtex/apacite
%dir %{_texmfdistdir}/doc/bibtex/apalike-ejor
%dir %{_texmfdistdir}/doc/bibtex/apalike-german
%dir %{_texmfdistdir}/doc/bibtex/authordate
%dir %{_texmfdistdir}/doc/bibtex/babelbib
%dir %{_texmfdistdir}/doc/bibtex/base
%dir %{_texmfdistdir}/doc/bibtex/bath-bst
%dir %{_texmfdistdir}/doc/bibtex/besjournals
%dir %{_texmfdistdir}/doc/bibtex/bestpapers
%dir %{_texmfdistdir}/doc/bibtex/bib-fr
%dir %{_texmfdistdir}/doc/bibtex/bibcop
%dir %{_texmfdistdir}/doc/bibtex/biber
%dir %{_texmfdistdir}/doc/bibtex/biber-ms
%dir %{_texmfdistdir}/doc/bibtex/bibexport
%dir %{_texmfdistdir}/doc/bibtex/bibhtml
%dir %{_texmfdistdir}/doc/bibtex/biolett-bst
%dir %{_texmfdistdir}/doc/bibtex/bookdb
%dir %{_texmfdistdir}/doc/bibtex/chicago-annote
%dir %{_texmfdistdir}/doc/bibtex/dinat
%dir %{_texmfdistdir}/doc/bibtex/dtk-bibliography
%dir %{_texmfdistdir}/doc/bibtex/econ-bst
%dir %{_texmfdistdir}/doc/bibtex/econ-bst/customization
%dir %{_texmfdistdir}/doc/bibtex/economic
%dir %{_texmfdistdir}/doc/bibtex/francais-bst
%dir %{_texmfdistdir}/doc/bibtex/gbt7714
%dir %{_texmfdistdir}/doc/bibtex/germbib
%dir %{_texmfdistdir}/doc/bibtex/gost
%dir %{_texmfdistdir}/doc/bibtex/gost/examples
%dir %{_texmfdistdir}/doc/bibtex/gost/examples/cp1251
%dir %{_texmfdistdir}/doc/bibtex/gost/examples/cp1251/bib
%dir %{_texmfdistdir}/doc/bibtex/gost/examples/utf8
%dir %{_texmfdistdir}/doc/bibtex/gost/examples/utf8/bib
%dir %{_texmfdistdir}/doc/bibtex/ieejtran
%dir %{_texmfdistdir}/doc/bibtex/ietfbibs
%dir %{_texmfdistdir}/doc/bibtex/ijqc
%dir %{_texmfdistdir}/doc/bibtex/inlinebib
%dir %{_texmfdistdir}/doc/bibtex/iopart-num
%dir %{_texmfdistdir}/doc/bibtex/is-bst
%dir %{_texmfdistdir}/doc/bibtex/jieeetran
%dir %{_texmfdistdir}/doc/bibtex/newcastle-bst
%dir %{_texmfdistdir}/doc/bibtex/perception
%dir %{_texmfdistdir}/doc/bibtex/sort-by-letters
%dir %{_texmfdistdir}/doc/bibtex/tamethebeast
%dir %{_texmfdistdir}/doc/bibtex/urlbst
%dir %{_texmfdistdir}/doc/bibtex/vak
%dir %{_texmfdistdir}/doc/bibtex/vancouver
%dir %{_texmfdistdir}/doc/bibtex/zootaxa-bst
%dir %{_texmfdistdir}/doc/bibtex8
%dir %{_texmfdistdir}/doc/bibtexu
%dir %{_texmfdistdir}/doc/bibtexu/examples
%dir %{_texmfdistdir}/doc/chktex
%dir %{_texmfdistdir}/doc/context
%dir %{_texmfdistdir}/doc/context/documents
%dir %{_texmfdistdir}/doc/context/documents/general
%dir %{_texmfdistdir}/doc/context/documents/general/leaflets
%dir %{_texmfdistdir}/doc/context/documents/general/magazines
%dir %{_texmfdistdir}/doc/context/documents/general/manuals
%dir %{_texmfdistdir}/doc/context/documents/general/qrcs
%dir %{_texmfdistdir}/doc/context/examples
%dir %{_texmfdistdir}/doc/context/examples/calculator
%dir %{_texmfdistdir}/doc/context/examples/clock
%dir %{_texmfdistdir}/doc/context/presentations
%dir %{_texmfdistdir}/doc/context/presentations/bachotex
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2005
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2009
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2010
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2011
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2012
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2013
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2014
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2015
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2016
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2017
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2018
%dir %{_texmfdistdir}/doc/context/presentations/bachotex/2019
%dir %{_texmfdistdir}/doc/context/presentations/context
%dir %{_texmfdistdir}/doc/context/presentations/context/2007
%dir %{_texmfdistdir}/doc/context/presentations/context/2010
%dir %{_texmfdistdir}/doc/context/presentations/context/2011
%dir %{_texmfdistdir}/doc/context/presentations/context/2012
%dir %{_texmfdistdir}/doc/context/presentations/context/2013
%dir %{_texmfdistdir}/doc/context/presentations/context/2015
%dir %{_texmfdistdir}/doc/context/presentations/context/2016
%dir %{_texmfdistdir}/doc/context/presentations/context/2017
%dir %{_texmfdistdir}/doc/context/presentations/context/2019
%dir %{_texmfdistdir}/doc/context/presentations/context/2020
%dir %{_texmfdistdir}/doc/context/presentations/context/2021
%dir %{_texmfdistdir}/doc/context/presentations/examples
%dir %{_texmfdistdir}/doc/context/presentations/tug
%dir %{_texmfdistdir}/doc/context/presentations/tug/2001
%dir %{_texmfdistdir}/doc/context/presentations/tug/2007
%dir %{_texmfdistdir}/doc/context/scripts
%dir %{_texmfdistdir}/doc/context/scripts/mkii
%dir %{_texmfdistdir}/doc/context/scripts/mkiv
%dir %{_texmfdistdir}/doc/context/sources
%dir %{_texmfdistdir}/doc/context/sources/general
%dir %{_texmfdistdir}/doc/context/sources/general/leaflets
%dir %{_texmfdistdir}/doc/context/sources/general/magazines
%dir %{_texmfdistdir}/doc/context/sources/general/manuals
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/about
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/bidi
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/canbedone
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/charts
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/cld
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/colors
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/columnsets
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/details
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/epub
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/evenmore
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/followingup
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/fonts
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/graphics
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/hybrid
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/interaction
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/languages
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/libraries
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/lowlevel
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/lua
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/luametafun
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/luametatex
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/luatex
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/math
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/mathml
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/metafun
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/mk
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/musings
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/nodes
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/notnow
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/onandon
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/ontarget
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/pagecolumns
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/primitives
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/publications
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/readme
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/rules
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/spacing
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/spreadsheets
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/sql
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/start
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/start/en
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/start/graphics
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/steps
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/still
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/svg
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/swiglib
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/templates
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/texit
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/tiptrick
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/tools
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/units
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/workflows
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/xml
%dir %{_texmfdistdir}/doc/context/sources/general/manuals/xtables
%dir %{_texmfdistdir}/doc/context/third
%dir %{_texmfdistdir}/doc/context/third/account
%dir %{_texmfdistdir}/doc/context/third/algorithmic
%dir %{_texmfdistdir}/doc/context/third/animation
%dir %{_texmfdistdir}/doc/context/third/annotation
%dir %{_texmfdistdir}/doc/context/third/bnf
%dir %{_texmfdistdir}/doc/context/third/chromato
%dir %{_texmfdistdir}/doc/context/third/circuitikz
%dir %{_texmfdistdir}/doc/context/third/cmscbf
%dir %{_texmfdistdir}/doc/context/third/cmttbf
%dir %{_texmfdistdir}/doc/context/third/construction-plan
%dir %{_texmfdistdir}/doc/context/third/cyrillicnumbers
%dir %{_texmfdistdir}/doc/context/third/degrade
%dir %{_texmfdistdir}/doc/context/third/enigma
%dir %{_texmfdistdir}/doc/context/third/enigma/enigma
%dir %{_texmfdistdir}/doc/context/third/enigma/enigma/examples
%dir %{_texmfdistdir}/doc/context/third/fancybreak
%dir %{_texmfdistdir}/doc/context/third/filter
%dir %{_texmfdistdir}/doc/context/third/french
%dir %{_texmfdistdir}/doc/context/third/fullpage
%dir %{_texmfdistdir}/doc/context/third/gantt
%dir %{_texmfdistdir}/doc/context/third/gantt/examples
%dir %{_texmfdistdir}/doc/context/third/gnuplot
%dir %{_texmfdistdir}/doc/context/third/handlecsv
%dir %{_texmfdistdir}/doc/context/third/layout
%dir %{_texmfdistdir}/doc/context/third/letter
%dir %{_texmfdistdir}/doc/context/third/lettrine
%dir %{_texmfdistdir}/doc/context/third/markdown
%dir %{_texmfdistdir}/doc/context/third/markdown/examples
%dir %{_texmfdistdir}/doc/context/third/mathsets
%dir %{_texmfdistdir}/doc/context/third/pgfplots
%dir %{_texmfdistdir}/doc/context/third/rst
%dir %{_texmfdistdir}/doc/context/third/ruby
%dir %{_texmfdistdir}/doc/context/third/simplefonts
%dir %{_texmfdistdir}/doc/context/third/simpleslides
%dir %{_texmfdistdir}/doc/context/third/simpleslides/solutions
%dir %{_texmfdistdir}/doc/context/third/simpleslides/styles
%dir %{_texmfdistdir}/doc/context/third/title
%dir %{_texmfdistdir}/doc/context/third/transliterator
%dir %{_texmfdistdir}/doc/context/third/typearea
%dir %{_texmfdistdir}/doc/context/third/typescripts
%dir %{_texmfdistdir}/doc/context/third/vim
%dir %{_texmfdistdir}/doc/context/third/visualcounter
%dir %{_texmfdistdir}/doc/cstex
%dir %{_texmfdistdir}/doc/cstex/cspsfonts-gen
%dir %{_texmfdistdir}/doc/dvipdfm
%dir %{_texmfdistdir}/doc/dvipdfmx
%dir %{_texmfdistdir}/doc/dvipng
%dir %{_texmfdistdir}/doc/dvips
%dir %{_texmfdistdir}/doc/eplain
%dir %{_texmfdistdir}/doc/eplain/demo
%dir %{_texmfdistdir}/doc/eplain/util
%dir %{_texmfdistdir}/doc/etex
%dir %{_texmfdistdir}/doc/etex/base
%dir %{_texmfdistdir}/doc/fonts
%dir %{_texmfdistdir}/doc/fonts/aboensis
%dir %{_texmfdistdir}/doc/fonts/aboensis/doc
%dir %{_texmfdistdir}/doc/fonts/aboensis/doc/pics
%dir %{_texmfdistdir}/doc/fonts/academicons
%dir %{_texmfdistdir}/doc/fonts/accanthis
%dir %{_texmfdistdir}/doc/fonts/accfonts
%dir %{_texmfdistdir}/doc/fonts/adforn
%dir %{_texmfdistdir}/doc/fonts/adfsymbols
%dir %{_texmfdistdir}/doc/fonts/ae
%dir %{_texmfdistdir}/doc/fonts/aesupp
%dir %{_texmfdistdir}/doc/fonts/alchemist
%dir %{_texmfdistdir}/doc/fonts/alegreya
%dir %{_texmfdistdir}/doc/fonts/alfaslabone
%dir %{_texmfdistdir}/doc/fonts/algolrevived
%dir %{_texmfdistdir}/doc/fonts/alkalami
%dir %{_texmfdistdir}/doc/fonts/allrunes
%dir %{_texmfdistdir}/doc/fonts/almendra
%dir %{_texmfdistdir}/doc/fonts/almfixed
%dir %{_texmfdistdir}/doc/fonts/amiri
%dir %{_texmfdistdir}/doc/fonts/amsfonts
%dir %{_texmfdistdir}/doc/fonts/andika
%dir %{_texmfdistdir}/doc/fonts/anonymouspro
%dir %{_texmfdistdir}/doc/fonts/antiqua
%dir %{_texmfdistdir}/doc/fonts/antt
%dir %{_texmfdistdir}/doc/fonts/archaic
%dir %{_texmfdistdir}/doc/fonts/archivo
%dir %{_texmfdistdir}/doc/fonts/arev
%dir %{_texmfdistdir}/doc/fonts/arimo
%dir %{_texmfdistdir}/doc/fonts/arphic
%dir %{_texmfdistdir}/doc/fonts/arphic-ttf
%dir %{_texmfdistdir}/doc/fonts/arphic/bkaiu
%dir %{_texmfdistdir}/doc/fonts/arphic/bsmiu
%dir %{_texmfdistdir}/doc/fonts/arphic/gbsnu
%dir %{_texmfdistdir}/doc/fonts/arphic/gkaiu
%dir %{_texmfdistdir}/doc/fonts/arvo
%dir %{_texmfdistdir}/doc/fonts/asana-math
%dir %{_texmfdistdir}/doc/fonts/asapsym
%dir %{_texmfdistdir}/doc/fonts/ascii-font
%dir %{_texmfdistdir}/doc/fonts/astro
%dir %{_texmfdistdir}/doc/fonts/atkinson
%dir %{_texmfdistdir}/doc/fonts/auncial-new
%dir %{_texmfdistdir}/doc/fonts/baekmuk
%dir %{_texmfdistdir}/doc/fonts/bartel-chess-fonts
%dir %{_texmfdistdir}/doc/fonts/bartel-chess-fonts/other-sources
%dir %{_texmfdistdir}/doc/fonts/baskervald
%dir %{_texmfdistdir}/doc/fonts/baskervaldx
%dir %{_texmfdistdir}/doc/fonts/baskervillef
%dir %{_texmfdistdir}/doc/fonts/bbm
%dir %{_texmfdistdir}/doc/fonts/bbold-type1
%dir %{_texmfdistdir}/doc/fonts/bboldx
%dir %{_texmfdistdir}/doc/fonts/belleek
%dir %{_texmfdistdir}/doc/fonts/bengali
%dir %{_texmfdistdir}/doc/fonts/bera
%dir %{_texmfdistdir}/doc/fonts/berenisadf
%dir %{_texmfdistdir}/doc/fonts/beuron
%dir %{_texmfdistdir}/doc/fonts/bguq
%dir %{_texmfdistdir}/doc/fonts/bitter
%dir %{_texmfdistdir}/doc/fonts/blacklettert1
%dir %{_texmfdistdir}/doc/fonts/boisik
%dir %{_texmfdistdir}/doc/fonts/boisik/example
%dir %{_texmfdistdir}/doc/fonts/bookhands
%dir %{_texmfdistdir}/doc/fonts/bookhands/auncial
%dir %{_texmfdistdir}/doc/fonts/bookhands/carolmin
%dir %{_texmfdistdir}/doc/fonts/bookhands/egothic
%dir %{_texmfdistdir}/doc/fonts/bookhands/humanist
%dir %{_texmfdistdir}/doc/fonts/bookhands/huncial
%dir %{_texmfdistdir}/doc/fonts/bookhands/inslrmaj
%dir %{_texmfdistdir}/doc/fonts/bookhands/inslrmin
%dir %{_texmfdistdir}/doc/fonts/bookhands/pgothic
%dir %{_texmfdistdir}/doc/fonts/bookhands/rotunda
%dir %{_texmfdistdir}/doc/fonts/bookhands/rustic
%dir %{_texmfdistdir}/doc/fonts/bookhands/sqrcaps
%dir %{_texmfdistdir}/doc/fonts/bookhands/tgothic
%dir %{_texmfdistdir}/doc/fonts/bookhands/uncial
%dir %{_texmfdistdir}/doc/fonts/boondox
%dir %{_texmfdistdir}/doc/fonts/brushscr
%dir %{_texmfdistdir}/doc/fonts/burmese
%dir %{_texmfdistdir}/doc/fonts/cabin
%dir %{_texmfdistdir}/doc/fonts/caladea
%dir %{_texmfdistdir}/doc/fonts/calligra-type1
%dir %{_texmfdistdir}/doc/fonts/cantarell
%dir %{_texmfdistdir}/doc/fonts/carlito
%dir %{_texmfdistdir}/doc/fonts/carolmin-ps
%dir %{_texmfdistdir}/doc/fonts/cascadia-code
%dir %{_texmfdistdir}/doc/fonts/cbfonts
%dir %{_texmfdistdir}/doc/fonts/cbfonts-fd
%dir %{_texmfdistdir}/doc/fonts/cc-pl
%dir %{_texmfdistdir}/doc/fonts/ccicons
%dir %{_texmfdistdir}/doc/fonts/cfr-lm
%dir %{_texmfdistdir}/doc/fonts/charissil
%dir %{_texmfdistdir}/doc/fonts/charter
%dir %{_texmfdistdir}/doc/fonts/chemarrow
%dir %{_texmfdistdir}/doc/fonts/cherokee
%dir %{_texmfdistdir}/doc/fonts/chess
%dir %{_texmfdistdir}/doc/fonts/chivo
%dir %{_texmfdistdir}/doc/fonts/cinzel
%dir %{_texmfdistdir}/doc/fonts/cjk-gs-integrate
%dir %{_texmfdistdir}/doc/fonts/clara
%dir %{_texmfdistdir}/doc/fonts/clearsans
%dir %{_texmfdistdir}/doc/fonts/cm
%dir %{_texmfdistdir}/doc/fonts/cm-lgc
%dir %{_texmfdistdir}/doc/fonts/cm-super
%dir %{_texmfdistdir}/doc/fonts/cm-unicode
%dir %{_texmfdistdir}/doc/fonts/cmathbb
%dir %{_texmfdistdir}/doc/fonts/cmbright
%dir %{_texmfdistdir}/doc/fonts/cmcyr
%dir %{_texmfdistdir}/doc/fonts/cmcyr/vf
%dir %{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6i
%dir %{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6k
%dir %{_texmfdistdir}/doc/fonts/cmcyr/vf/cmcyr6w
%dir %{_texmfdistdir}/doc/fonts/cmexb
%dir %{_texmfdistdir}/doc/fonts/cmll
%dir %{_texmfdistdir}/doc/fonts/cmsrb
%dir %{_texmfdistdir}/doc/fonts/cmupint
%dir %{_texmfdistdir}/doc/fonts/cns
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-1
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-2
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-3
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-4
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-5
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-6
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-7
%dir %{_texmfdistdir}/doc/fonts/cns/cns40-b5
%dir %{_texmfdistdir}/doc/fonts/cochineal
%dir %{_texmfdistdir}/doc/fonts/coelacanth
%dir %{_texmfdistdir}/doc/fonts/comfortaa
%dir %{_texmfdistdir}/doc/fonts/concmath
%dir %{_texmfdistdir}/doc/fonts/concmath-fonts
%dir %{_texmfdistdir}/doc/fonts/concmath-otf
%dir %{_texmfdistdir}/doc/fonts/concrete
%dir %{_texmfdistdir}/doc/fonts/cooperhewitt
%dir %{_texmfdistdir}/doc/fonts/cormorantgaramond
%dir %{_texmfdistdir}/doc/fonts/countriesofeurope
%dir %{_texmfdistdir}/doc/fonts/courier-scaled
%dir %{_texmfdistdir}/doc/fonts/courierten
%dir %{_texmfdistdir}/doc/fonts/crimson
%dir %{_texmfdistdir}/doc/fonts/crimsonpro
%dir %{_texmfdistdir}/doc/fonts/cuprum
%dir %{_texmfdistdir}/doc/fonts/cyklop
%dir %{_texmfdistdir}/doc/fonts/dad
%dir %{_texmfdistdir}/doc/fonts/dantelogo
%dir %{_texmfdistdir}/doc/fonts/dejavu
%dir %{_texmfdistdir}/doc/fonts/dejavu-otf
%dir %{_texmfdistdir}/doc/fonts/dice
%dir %{_texmfdistdir}/doc/fonts/dictsym
%dir %{_texmfdistdir}/doc/fonts/dingbat
%dir %{_texmfdistdir}/doc/fonts/domitian
%dir %{_texmfdistdir}/doc/fonts/doublestroke
%dir %{_texmfdistdir}/doc/fonts/doulossil
%dir %{_texmfdistdir}/doc/fonts/dozenal
%dir %{_texmfdistdir}/doc/fonts/drm
%dir %{_texmfdistdir}/doc/fonts/droid
%dir %{_texmfdistdir}/doc/fonts/dsserif
%dir %{_texmfdistdir}/doc/fonts/duerer
%dir %{_texmfdistdir}/doc/fonts/dutchcal
%dir %{_texmfdistdir}/doc/fonts/ebgaramond
%dir %{_texmfdistdir}/doc/fonts/ebgaramond-maths
%dir %{_texmfdistdir}/doc/fonts/ec
%dir %{_texmfdistdir}/doc/fonts/ecc
%dir %{_texmfdistdir}/doc/fonts/eco
%dir %{_texmfdistdir}/doc/fonts/eczar
%dir %{_texmfdistdir}/doc/fonts/eiad
%dir %{_texmfdistdir}/doc/fonts/ektype-tanka
%dir %{_texmfdistdir}/doc/fonts/electrum
%dir %{_texmfdistdir}/doc/fonts/elvish
%dir %{_texmfdistdir}/doc/fonts/enc
%dir %{_texmfdistdir}/doc/fonts/enc/c90
%dir %{_texmfdistdir}/doc/fonts/epigrafica
%dir %{_texmfdistdir}/doc/fonts/erewhon
%dir %{_texmfdistdir}/doc/fonts/erewhon-math
%dir %{_texmfdistdir}/doc/fonts/esint-type1
%dir %{_texmfdistdir}/doc/fonts/esrelation
%dir %{_texmfdistdir}/doc/fonts/esstix
%dir %{_texmfdistdir}/doc/fonts/etbb
%dir %{_texmfdistdir}/doc/fonts/euler-math
%dir %{_texmfdistdir}/doc/fonts/eulerpx
%dir %{_texmfdistdir}/doc/fonts/euro-ce
%dir %{_texmfdistdir}/doc/fonts/eurosym
%dir %{_texmfdistdir}/doc/fonts/eurosym/c
%dir %{_texmfdistdir}/doc/fonts/eurosym/src
%dir %{_texmfdistdir}/doc/fonts/fandol
%dir %{_texmfdistdir}/doc/fonts/fbb
%dir %{_texmfdistdir}/doc/fonts/fc
%dir %{_texmfdistdir}/doc/fonts/fdsymbol
%dir %{_texmfdistdir}/doc/fonts/fetamont
%dir %{_texmfdistdir}/doc/fonts/feyn
%dir %{_texmfdistdir}/doc/fonts/fge
%dir %{_texmfdistdir}/doc/fonts/figbas
%dir %{_texmfdistdir}/doc/fonts/fira
%dir %{_texmfdistdir}/doc/fonts/firamath
%dir %{_texmfdistdir}/doc/fonts/firamath-otf
%dir %{_texmfdistdir}/doc/fonts/fonetika
%dir %{_texmfdistdir}/doc/fonts/fontawesome
%dir %{_texmfdistdir}/doc/fonts/fontawesome5
%dir %{_texmfdistdir}/doc/fonts/fontinst
%dir %{_texmfdistdir}/doc/fonts/fontinst/encspecs
%dir %{_texmfdistdir}/doc/fonts/fontinst/examples
%dir %{_texmfdistdir}/doc/fonts/fontinst/examples/basic
%dir %{_texmfdistdir}/doc/fonts/fontinst/examples/eurofont
%dir %{_texmfdistdir}/doc/fonts/fontinst/examples/mathptm
%dir %{_texmfdistdir}/doc/fonts/fontinst/examples/mathptmx
%dir %{_texmfdistdir}/doc/fonts/fontinst/manual
%dir %{_texmfdistdir}/doc/fonts/fontinst/talks
%dir %{_texmfdistdir}/doc/fonts/fontinst/test
%dir %{_texmfdistdir}/doc/fonts/fontinstallationguide
%dir %{_texmfdistdir}/doc/fonts/fontmfizz
%dir %{_texmfdistdir}/doc/fonts/fontname
%dir %{_texmfdistdir}/doc/fonts/fonts-churchslavonic
%dir %{_texmfdistdir}/doc/fonts/fonts-tlwg
%dir %{_texmfdistdir}/doc/fonts/fonts-tlwg/examples
%dir %{_texmfdistdir}/doc/fonts/forum
%dir %{_texmfdistdir}/doc/fonts/fourier
%dir %{_texmfdistdir}/doc/fonts/fouriernc
%dir %{_texmfdistdir}/doc/fonts/fpl
%dir %{_texmfdistdir}/doc/fonts/frcursive
%dir %{_texmfdistdir}/doc/fonts/frederika2016
%dir %{_texmfdistdir}/doc/fonts/frimurer
%dir %{_texmfdistdir}/doc/fonts/garamond-libre
%dir %{_texmfdistdir}/doc/fonts/garamond-math
%dir %{_texmfdistdir}/doc/fonts/genealogy
%dir %{_texmfdistdir}/doc/fonts/gentium-tug
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/assets
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/assets/css
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/assets/images
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/pdf
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/pandocfilters
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/pdftemp
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/GentiumPlus-6.101/documentation/source/productsite
%dir %{_texmfdistdir}/doc/fonts/gentium-tug/gentium-tug
%dir %{_texmfdistdir}/doc/fonts/gfsartemisia
%dir %{_texmfdistdir}/doc/fonts/gfsbaskerville
%dir %{_texmfdistdir}/doc/fonts/gfsbodoni
%dir %{_texmfdistdir}/doc/fonts/gfscomplutum
%dir %{_texmfdistdir}/doc/fonts/gfsdidot
%dir %{_texmfdistdir}/doc/fonts/gfsdidotclassic
%dir %{_texmfdistdir}/doc/fonts/gfsneohellenic
%dir %{_texmfdistdir}/doc/fonts/gfsneohellenicmath
%dir %{_texmfdistdir}/doc/fonts/gfsporson
%dir %{_texmfdistdir}/doc/fonts/gfssolomos
%dir %{_texmfdistdir}/doc/fonts/gillius
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/notes
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/generate
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/report
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/report/OpenType
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/script-menu
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test/MES-Conformance
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test/ranges
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/test/ranges/Arabic
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/utility
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/utility/metafont
%dir %{_texmfdistdir}/doc/fonts/gnu-freefont/tools/utility/special-purpose
%dir %{_texmfdistdir}/doc/fonts/go
%dir %{_texmfdistdir}/doc/fonts/gofonts
%dir %{_texmfdistdir}/doc/fonts/gothic
%dir %{_texmfdistdir}/doc/fonts/greektex
%dir %{_texmfdistdir}/doc/fonts/greenpoint
%dir %{_texmfdistdir}/doc/fonts/grotesq
%dir %{_texmfdistdir}/doc/fonts/gudea
%dir %{_texmfdistdir}/doc/fonts/hacm
%dir %{_texmfdistdir}/doc/fonts/hamnosys
%dir %{_texmfdistdir}/doc/fonts/haranoaji
%dir %{_texmfdistdir}/doc/fonts/haranoaji-extra
%dir %{_texmfdistdir}/doc/fonts/helmholtz-ellis-ji-notation
%dir %{_texmfdistdir}/doc/fonts/hep-font
%dir %{_texmfdistdir}/doc/fonts/hep-math-font
%dir %{_texmfdistdir}/doc/fonts/heros-otf
%dir %{_texmfdistdir}/doc/fonts/heuristica
%dir %{_texmfdistdir}/doc/fonts/hfbright
%dir %{_texmfdistdir}/doc/fonts/hfoldsty
%dir %{_texmfdistdir}/doc/fonts/hindmadurai
%dir %{_texmfdistdir}/doc/fonts/ibarra
%dir %{_texmfdistdir}/doc/fonts/ibygrk
%dir %{_texmfdistdir}/doc/fonts/ifsym
%dir %{_texmfdistdir}/doc/fonts/imfellenglish
%dir %{_texmfdistdir}/doc/fonts/inconsolata
%dir %{_texmfdistdir}/doc/fonts/initials
%dir %{_texmfdistdir}/doc/fonts/inriafonts
%dir %{_texmfdistdir}/doc/fonts/inter
%dir %{_texmfdistdir}/doc/fonts/ipaex
%dir %{_texmfdistdir}/doc/fonts/ipaex-type1
%dir %{_texmfdistdir}/doc/fonts/iwona
%dir %{_texmfdistdir}/doc/fonts/jablantile
%dir %{_texmfdistdir}/doc/fonts/japanese-otf
%dir %{_texmfdistdir}/doc/fonts/japanese-otf/doc
%dir %{_texmfdistdir}/doc/fonts/japanese-otf/doc/TeXLive-maps
%dir %{_texmfdistdir}/doc/fonts/japanese-otf/doc/test
%dir %{_texmfdistdir}/doc/fonts/japanese-otf/doc/test/uplatex
%dir %{_texmfdistdir}/doc/fonts/jfmutil
%dir %{_texmfdistdir}/doc/fonts/josefin
%dir %{_texmfdistdir}/doc/fonts/junicode
%dir %{_texmfdistdir}/doc/fonts/kerkis
%dir %{_texmfdistdir}/doc/fonts/kixfont
%dir %{_texmfdistdir}/doc/fonts/knitting
%dir %{_texmfdistdir}/doc/fonts/kpfonts
%dir %{_texmfdistdir}/doc/fonts/kpfonts-otf
%dir %{_texmfdistdir}/doc/fonts/kurier
%dir %{_texmfdistdir}/doc/fonts/latex-fonts
%dir %{_texmfdistdir}/doc/fonts/lato
%dir %{_texmfdistdir}/doc/fonts/levy
%dir %{_texmfdistdir}/doc/fonts/lexend
%dir %{_texmfdistdir}/doc/fonts/lfb
%dir %{_texmfdistdir}/doc/fonts/lh
%dir %{_texmfdistdir}/doc/fonts/lh/beresta
%dir %{_texmfdistdir}/doc/fonts/lh/fonttest
%dir %{_texmfdistdir}/doc/fonts/lh/lhfonts
%dir %{_texmfdistdir}/doc/fonts/lh/samples
%dir %{_texmfdistdir}/doc/fonts/libertine
%dir %{_texmfdistdir}/doc/fonts/libertinegc
%dir %{_texmfdistdir}/doc/fonts/libertinus
%dir %{_texmfdistdir}/doc/fonts/libertinus-fonts
%dir %{_texmfdistdir}/doc/fonts/libertinus-otf
%dir %{_texmfdistdir}/doc/fonts/libertinus-type1
%dir %{_texmfdistdir}/doc/fonts/libertinust1math
%dir %{_texmfdistdir}/doc/fonts/librebaskerville
%dir %{_texmfdistdir}/doc/fonts/librebodoni
%dir %{_texmfdistdir}/doc/fonts/librecaslon
%dir %{_texmfdistdir}/doc/fonts/librefranklin
%dir %{_texmfdistdir}/doc/fonts/libris
%dir %{_texmfdistdir}/doc/fonts/lineara
%dir %{_texmfdistdir}/doc/fonts/linguisticspro
%dir %{_texmfdistdir}/doc/fonts/lm
%dir %{_texmfdistdir}/doc/fonts/lm-math
%dir %{_texmfdistdir}/doc/fonts/lobster2
%dir %{_texmfdistdir}/doc/fonts/logix
%dir %{_texmfdistdir}/doc/fonts/lxfonts
%dir %{_texmfdistdir}/doc/fonts/magra
%dir %{_texmfdistdir}/doc/fonts/marcellus
%dir %{_texmfdistdir}/doc/fonts/marvosym
%dir %{_texmfdistdir}/doc/fonts/mathabx
%dir %{_texmfdistdir}/doc/fonts/mathabx-type1
%dir %{_texmfdistdir}/doc/fonts/mathdesign
%dir %{_texmfdistdir}/doc/fonts/mdsymbol
%dir %{_texmfdistdir}/doc/fonts/memdesign
%dir %{_texmfdistdir}/doc/fonts/merriweather
%dir %{_texmfdistdir}/doc/fonts/metafont-beginners
%dir %{_texmfdistdir}/doc/fonts/mflogo-font
%dir %{_texmfdistdir}/doc/fonts/miama
%dir %{_texmfdistdir}/doc/fonts/mintspirit
%dir %{_texmfdistdir}/doc/fonts/missaali
%dir %{_texmfdistdir}/doc/fonts/mlmodern
%dir %{_texmfdistdir}/doc/fonts/modes
%dir %{_texmfdistdir}/doc/fonts/montserrat
%dir %{_texmfdistdir}/doc/fonts/morisawa
%dir %{_texmfdistdir}/doc/fonts/mpfonts
%dir %{_texmfdistdir}/doc/fonts/musixtex-fonts
%dir %{_texmfdistdir}/doc/fonts/musixtex-fonts/MuseJazzText
%dir %{_texmfdistdir}/doc/fonts/musixtex-fonts/frenchtab
%dir %{_texmfdistdir}/doc/fonts/mxedruli
%dir %{_texmfdistdir}/doc/fonts/nanumtype1
%dir %{_texmfdistdir}/doc/fonts/newcomputermodern
%dir %{_texmfdistdir}/doc/fonts/newpx
%dir %{_texmfdistdir}/doc/fonts/newtx
%dir %{_texmfdistdir}/doc/fonts/newtxsf
%dir %{_texmfdistdir}/doc/fonts/newtxtt
%dir %{_texmfdistdir}/doc/fonts/niceframe-type1
%dir %{_texmfdistdir}/doc/fonts/nimbus15
%dir %{_texmfdistdir}/doc/fonts/nkarta
%dir %{_texmfdistdir}/doc/fonts/noto
%dir %{_texmfdistdir}/doc/fonts/noto-emoji
%dir %{_texmfdistdir}/doc/fonts/notomath
%dir %{_texmfdistdir}/doc/fonts/nunito
%dir %{_texmfdistdir}/doc/fonts/obnov
%dir %{_texmfdistdir}/doc/fonts/ocr-b
%dir %{_texmfdistdir}/doc/fonts/ocr-b-outline
%dir %{_texmfdistdir}/doc/fonts/ogham
%dir %{_texmfdistdir}/doc/fonts/oinuit
%dir %{_texmfdistdir}/doc/fonts/old-arrows
%dir %{_texmfdistdir}/doc/fonts/oldlatin
%dir %{_texmfdistdir}/doc/fonts/oldstandard
%dir %{_texmfdistdir}/doc/fonts/opensans
%dir %{_texmfdistdir}/doc/fonts/orkhun
%dir %{_texmfdistdir}/doc/fonts/oswald
%dir %{_texmfdistdir}/doc/fonts/overlock
%dir %{_texmfdistdir}/doc/fonts/pacioli
%dir %{_texmfdistdir}/doc/fonts/padauk
%dir %{_texmfdistdir}/doc/fonts/pagella-otf
%dir %{_texmfdistdir}/doc/fonts/paratype
%dir %{_texmfdistdir}/doc/fonts/phaistos
%dir %{_texmfdistdir}/doc/fonts/phonetic
%dir %{_texmfdistdir}/doc/fonts/phonetic/209
%dir %{_texmfdistdir}/doc/fonts/pl
%dir %{_texmfdistdir}/doc/fonts/playfair
%dir %{_texmfdistdir}/doc/fonts/plex
%dir %{_texmfdistdir}/doc/fonts/plex-otf
%dir %{_texmfdistdir}/doc/fonts/plex-otf/Examples
%dir %{_texmfdistdir}/doc/fonts/plimsoll
%dir %{_texmfdistdir}/doc/fonts/poiretone
%dir %{_texmfdistdir}/doc/fonts/poltawski
%dir %{_texmfdistdir}/doc/fonts/prodint
%dir %{_texmfdistdir}/doc/fonts/ptex-fontmaps
%dir %{_texmfdistdir}/doc/fonts/ptex-fontmaps/examples
%dir %{_texmfdistdir}/doc/fonts/ptex-fonts
%dir %{_texmfdistdir}/doc/fonts/punk
%dir %{_texmfdistdir}/doc/fonts/punknova
%dir %{_texmfdistdir}/doc/fonts/punknova/documentation
%dir %{_texmfdistdir}/doc/fonts/punknova/documentation/documentation-sources
%dir %{_texmfdistdir}/doc/fonts/punknova/source
%dir %{_texmfdistdir}/doc/fonts/punknova/tools
%dir %{_texmfdistdir}/doc/fonts/pxfonts
%dir %{_texmfdistdir}/doc/fonts/pxtxalfa
%dir %{_texmfdistdir}/doc/fonts/qpxqtx
%dir %{_texmfdistdir}/doc/fonts/qualitype
%dir %{_texmfdistdir}/doc/fonts/quattrocento
%dir %{_texmfdistdir}/doc/fonts/recycle
%dir %{_texmfdistdir}/doc/fonts/roboto
%dir %{_texmfdistdir}/doc/fonts/rojud
%dir %{_texmfdistdir}/doc/fonts/romande
%dir %{_texmfdistdir}/doc/fonts/rosario
%dir %{_texmfdistdir}/doc/fonts/rsfs
%dir %{_texmfdistdir}/doc/fonts/rsfso
%dir %{_texmfdistdir}/doc/fonts/sanskrit-t1
%dir %{_texmfdistdir}/doc/fonts/sansmathaccent
%dir %{_texmfdistdir}/doc/fonts/sansmathfonts
%dir %{_texmfdistdir}/doc/fonts/schola-otf
%dir %{_texmfdistdir}/doc/fonts/scholax
%dir %{_texmfdistdir}/doc/fonts/schulschriften
%dir %{_texmfdistdir}/doc/fonts/semaphor
%dir %{_texmfdistdir}/doc/fonts/shobhika
%dir %{_texmfdistdir}/doc/fonts/simpleicons
%dir %{_texmfdistdir}/doc/fonts/skaknew
%dir %{_texmfdistdir}/doc/fonts/spark-otf
%dir %{_texmfdistdir}/doc/fonts/spectral
%dir %{_texmfdistdir}/doc/fonts/srbtiks
%dir %{_texmfdistdir}/doc/fonts/starfont
%dir %{_texmfdistdir}/doc/fonts/staves
%dir %{_texmfdistdir}/doc/fonts/step
%dir %{_texmfdistdir}/doc/fonts/stepgreek
%dir %{_texmfdistdir}/doc/fonts/stickstoo
%dir %{_texmfdistdir}/doc/fonts/stix
%dir %{_texmfdistdir}/doc/fonts/stix2-otf
%dir %{_texmfdistdir}/doc/fonts/stix2-type1
%dir %{_texmfdistdir}/doc/fonts/stmaryrd
%dir %{_texmfdistdir}/doc/fonts/superiors
%dir %{_texmfdistdir}/doc/fonts/svrsymbols
%dir %{_texmfdistdir}/doc/fonts/symbats3
%dir %{_texmfdistdir}/doc/fonts/talos
%dir %{_texmfdistdir}/doc/fonts/tapir
%dir %{_texmfdistdir}/doc/fonts/tempora
%dir %{_texmfdistdir}/doc/fonts/termes-otf
%dir %{_texmfdistdir}/doc/fonts/tex-gyre
%dir %{_texmfdistdir}/doc/fonts/tex-gyre-math
%dir %{_texmfdistdir}/doc/fonts/tfrupee
%dir %{_texmfdistdir}/doc/fonts/theanodidot
%dir %{_texmfdistdir}/doc/fonts/theanomodern
%dir %{_texmfdistdir}/doc/fonts/theanooldstyle
%dir %{_texmfdistdir}/doc/fonts/tinos
%dir %{_texmfdistdir}/doc/fonts/tipa
%dir %{_texmfdistdir}/doc/fonts/twemoji-colr
%dir %{_texmfdistdir}/doc/fonts/txfonts
%dir %{_texmfdistdir}/doc/fonts/txfontsb
%dir %{_texmfdistdir}/doc/fonts/txuprcal
%dir %{_texmfdistdir}/doc/fonts/typicons
%dir %{_texmfdistdir}/doc/fonts/uhc
%dir %{_texmfdistdir}/doc/fonts/uhc/umj
%dir %{_texmfdistdir}/doc/fonts/umtypewriter
%dir %{_texmfdistdir}/doc/fonts/unfonts-core
%dir %{_texmfdistdir}/doc/fonts/unfonts-extra
%dir %{_texmfdistdir}/doc/fonts/universa
%dir %{_texmfdistdir}/doc/fonts/universalis
%dir %{_texmfdistdir}/doc/fonts/uppunctlm
%dir %{_texmfdistdir}/doc/fonts/uptex-fonts
%dir %{_texmfdistdir}/doc/fonts/urwchancal
%dir %{_texmfdistdir}/doc/fonts/utopia
%dir %{_texmfdistdir}/doc/fonts/variablelm
%dir %{_texmfdistdir}/doc/fonts/venturisadf
%dir %{_texmfdistdir}/doc/fonts/wadalab
%dir %{_texmfdistdir}/doc/fonts/wadalab/dgj
%dir %{_texmfdistdir}/doc/fonts/wadalab/dmj
%dir %{_texmfdistdir}/doc/fonts/wadalab/mc2j
%dir %{_texmfdistdir}/doc/fonts/wadalab/mcj
%dir %{_texmfdistdir}/doc/fonts/wadalab/mr2j
%dir %{_texmfdistdir}/doc/fonts/wadalab/mrj
%dir %{_texmfdistdir}/doc/fonts/wasy
%dir %{_texmfdistdir}/doc/fonts/wasy-type1
%dir %{_texmfdistdir}/doc/fonts/wnri
%dir %{_texmfdistdir}/doc/fonts/wnri/old
%dir %{_texmfdistdir}/doc/fonts/wsuipa
%dir %{_texmfdistdir}/doc/fonts/wsuipa/latex209
%dir %{_texmfdistdir}/doc/fonts/wsuipa/latex2e
%dir %{_texmfdistdir}/doc/fonts/wsuipa/text1
%dir %{_texmfdistdir}/doc/fonts/xcharter
%dir %{_texmfdistdir}/doc/fonts/xcharter-math
%dir %{_texmfdistdir}/doc/fonts/xits
%dir %{_texmfdistdir}/doc/fonts/xq
%dir %{_texmfdistdir}/doc/fonts/yannisgr
%dir %{_texmfdistdir}/doc/fonts/yfonts-otf
%dir %{_texmfdistdir}/doc/fonts/yfonts-t1
%dir %{_texmfdistdir}/doc/fonts/yhmath
%dir %{_texmfdistdir}/doc/fonts/yinit-otf
%dir %{_texmfdistdir}/doc/fonts/zhmetrics
%dir %{_texmfdistdir}/doc/fonts/zhmetrics-uptex
%dir %{_texmfdistdir}/doc/fonts/zhmetrics-uptex/doc
%dir %{_texmfdistdir}/doc/fonts/zlmtt
%dir %{_texmfdistdir}/doc/generic
%dir %{_texmfdistdir}/doc/generic/2up
%dir %{_texmfdistdir}/doc/generic/abbr
%dir %{_texmfdistdir}/doc/generic/apnum
%dir %{_texmfdistdir}/doc/generic/armenian
%dir %{_texmfdistdir}/doc/generic/armenian/examples
%dir %{_texmfdistdir}/doc/generic/armenian/examples/latex
%dir %{_texmfdistdir}/doc/generic/armenian/examples/plain
%dir %{_texmfdistdir}/doc/generic/around-the-bend
%dir %{_texmfdistdir}/doc/generic/arrayjobx
%dir %{_texmfdistdir}/doc/generic/autoaligne
%dir %{_texmfdistdir}/doc/generic/autosp
%dir %{_texmfdistdir}/doc/generic/babel-albanian
%dir %{_texmfdistdir}/doc/generic/babel-azerbaijani
%dir %{_texmfdistdir}/doc/generic/babel-basque
%dir %{_texmfdistdir}/doc/generic/babel-belarusian
%dir %{_texmfdistdir}/doc/generic/babel-bosnian
%dir %{_texmfdistdir}/doc/generic/babel-breton
%dir %{_texmfdistdir}/doc/generic/babel-bulgarian
%dir %{_texmfdistdir}/doc/generic/babel-catalan
%dir %{_texmfdistdir}/doc/generic/babel-croatian
%dir %{_texmfdistdir}/doc/generic/babel-czech
%dir %{_texmfdistdir}/doc/generic/babel-danish
%dir %{_texmfdistdir}/doc/generic/babel-dutch
%dir %{_texmfdistdir}/doc/generic/babel-english
%dir %{_texmfdistdir}/doc/generic/babel-esperanto
%dir %{_texmfdistdir}/doc/generic/babel-estonian
%dir %{_texmfdistdir}/doc/generic/babel-finnish
%dir %{_texmfdistdir}/doc/generic/babel-french
%dir %{_texmfdistdir}/doc/generic/babel-friulan
%dir %{_texmfdistdir}/doc/generic/babel-galician
%dir %{_texmfdistdir}/doc/generic/babel-georgian
%dir %{_texmfdistdir}/doc/generic/babel-german
%dir %{_texmfdistdir}/doc/generic/babel-greek
%dir %{_texmfdistdir}/doc/generic/babel-hebrew
%dir %{_texmfdistdir}/doc/generic/babel-hungarian
%dir %{_texmfdistdir}/doc/generic/babel-icelandic
%dir %{_texmfdistdir}/doc/generic/babel-indonesian
%dir %{_texmfdistdir}/doc/generic/babel-interlingua
%dir %{_texmfdistdir}/doc/generic/babel-irish
%dir %{_texmfdistdir}/doc/generic/babel-italian
%dir %{_texmfdistdir}/doc/generic/babel-japanese
%dir %{_texmfdistdir}/doc/generic/babel-kurmanji
%dir %{_texmfdistdir}/doc/generic/babel-latin
%dir %{_texmfdistdir}/doc/generic/babel-latvian
%dir %{_texmfdistdir}/doc/generic/babel-lithuanian
%dir %{_texmfdistdir}/doc/generic/babel-macedonian
%dir %{_texmfdistdir}/doc/generic/babel-malay
%dir %{_texmfdistdir}/doc/generic/babel-norsk
%dir %{_texmfdistdir}/doc/generic/babel-occitan
%dir %{_texmfdistdir}/doc/generic/babel-piedmontese
%dir %{_texmfdistdir}/doc/generic/babel-polish
%dir %{_texmfdistdir}/doc/generic/babel-portuges
%dir %{_texmfdistdir}/doc/generic/babel-romanian
%dir %{_texmfdistdir}/doc/generic/babel-romansh
%dir %{_texmfdistdir}/doc/generic/babel-russian
%dir %{_texmfdistdir}/doc/generic/babel-samin
%dir %{_texmfdistdir}/doc/generic/babel-scottish
%dir %{_texmfdistdir}/doc/generic/babel-serbian
%dir %{_texmfdistdir}/doc/generic/babel-serbianc
%dir %{_texmfdistdir}/doc/generic/babel-slovak
%dir %{_texmfdistdir}/doc/generic/babel-slovenian
%dir %{_texmfdistdir}/doc/generic/babel-sorbian
%dir %{_texmfdistdir}/doc/generic/babel-spanish
%dir %{_texmfdistdir}/doc/generic/babel-swedish
%dir %{_texmfdistdir}/doc/generic/babel-thai
%dir %{_texmfdistdir}/doc/generic/babel-turkish
%dir %{_texmfdistdir}/doc/generic/babel-ukrainian
%dir %{_texmfdistdir}/doc/generic/babel-vietnamese
%dir %{_texmfdistdir}/doc/generic/babel-welsh
%dir %{_texmfdistdir}/doc/generic/bagpipe
%dir %{_texmfdistdir}/doc/generic/barr
%dir %{_texmfdistdir}/doc/generic/bitelist
%dir %{_texmfdistdir}/doc/generic/borceux
%dir %{_texmfdistdir}/doc/generic/borceux/compatibility
%dir %{_texmfdistdir}/doc/generic/c-pascal
%dir %{_texmfdistdir}/doc/generic/c-pascal/prog
%dir %{_texmfdistdir}/doc/generic/catcodes
%dir %{_texmfdistdir}/doc/generic/chemfig
%dir %{_texmfdistdir}/doc/generic/chronosys
%dir %{_texmfdistdir}/doc/generic/circuitikz
%dir %{_texmfdistdir}/doc/generic/colorprofiles
%dir %{_texmfdistdir}/doc/generic/colortab
%dir %{_texmfdistdir}/doc/generic/commado
%dir %{_texmfdistdir}/doc/generic/commutative-diagrams
%dir %{_texmfdistdir}/doc/generic/components
%dir %{_texmfdistdir}/doc/generic/crossrefenum
%dir %{_texmfdistdir}/doc/generic/crossrefenum/doc
%dir %{_texmfdistdir}/doc/generic/crossrefenum/test
%dir %{_texmfdistdir}/doc/generic/dcpic
%dir %{_texmfdistdir}/doc/generic/dehyph-exptl
%dir %{_texmfdistdir}/doc/generic/dirtree
%dir %{_texmfdistdir}/doc/generic/doc-pictex
%dir %{_texmfdistdir}/doc/generic/docbytex
%dir %{_texmfdistdir}/doc/generic/dowith
%dir %{_texmfdistdir}/doc/generic/dratex
%dir %{_texmfdistdir}/doc/generic/e-french
%dir %{_texmfdistdir}/doc/generic/e-french/bin
%dir %{_texmfdistdir}/doc/generic/e-french/bin/linux
%dir %{_texmfdistdir}/doc/generic/e-french/bin/windows
%dir %{_texmfdistdir}/doc/generic/e-french/install
%dir %{_texmfdistdir}/doc/generic/e-french/manuels
%dir %{_texmfdistdir}/doc/generic/e-french/src
%dir %{_texmfdistdir}/doc/generic/e-french/test
%dir %{_texmfdistdir}/doc/generic/e-french/test/XeLaTeX
%dir %{_texmfdistdir}/doc/generic/e-french/test/tests-formats
%dir %{_texmfdistdir}/doc/generic/ean
%dir %{_texmfdistdir}/doc/generic/elhyphen
%dir %{_texmfdistdir}/doc/generic/enctex
%dir %{_texmfdistdir}/doc/generic/encxvlna
%dir %{_texmfdistdir}/doc/generic/epsf
%dir %{_texmfdistdir}/doc/generic/epsf/okay
%dir %{_texmfdistdir}/doc/generic/es-tex-faq
%dir %{_texmfdistdir}/doc/generic/expex
%dir %{_texmfdistdir}/doc/generic/expex-acro
%dir %{_texmfdistdir}/doc/generic/fenixpar
%dir %{_texmfdistdir}/doc/generic/fixjfm
%dir %{_texmfdistdir}/doc/generic/fltpoint
%dir %{_texmfdistdir}/doc/generic/fntproof
%dir %{_texmfdistdir}/doc/generic/formlett
%dir %{_texmfdistdir}/doc/generic/frame
%dir %{_texmfdistdir}/doc/generic/gates
%dir %{_texmfdistdir}/doc/generic/german
%dir %{_texmfdistdir}/doc/generic/german/betatest
%dir %{_texmfdistdir}/doc/generic/gobble
%dir %{_texmfdistdir}/doc/generic/gtl
%dir %{_texmfdistdir}/doc/generic/hlist
%dir %{_texmfdistdir}/doc/generic/hologo
%dir %{_texmfdistdir}/doc/generic/huhyphen
%dir %{_texmfdistdir}/doc/generic/hyph-utf8
%dir %{_texmfdistdir}/doc/generic/hyph-utf8/img
%dir %{_texmfdistdir}/doc/generic/hyph-utf8/languages
%dir %{_texmfdistdir}/doc/generic/hyph-utf8/languages/es
%dir %{_texmfdistdir}/doc/generic/hyph-utf8/languages/hu
%dir %{_texmfdistdir}/doc/generic/hyph-utf8/languages/sa
%dir %{_texmfdistdir}/doc/generic/ifptex
%dir %{_texmfdistdir}/doc/generic/iftex
%dir %{_texmfdistdir}/doc/generic/ifxptex
%dir %{_texmfdistdir}/doc/generic/insbox
%dir %{_texmfdistdir}/doc/generic/kastrup
%dir %{_texmfdistdir}/doc/generic/knuth-errata
%dir %{_texmfdistdir}/doc/generic/knuth-hint
%dir %{_texmfdistdir}/doc/generic/knuth-hint/bibtex
%dir %{_texmfdistdir}/doc/generic/knuth-hint/ctie
%dir %{_texmfdistdir}/doc/generic/knuth-hint/cweb
%dir %{_texmfdistdir}/doc/generic/knuth-hint/errata
%dir %{_texmfdistdir}/doc/generic/knuth-hint/etc
%dir %{_texmfdistdir}/doc/generic/knuth-hint/mf
%dir %{_texmfdistdir}/doc/generic/knuth-hint/mfware
%dir %{_texmfdistdir}/doc/generic/knuth-hint/other
%dir %{_texmfdistdir}/doc/generic/knuth-hint/pdftex
%dir %{_texmfdistdir}/doc/generic/knuth-hint/tex
%dir %{_texmfdistdir}/doc/generic/knuth-hint/texware
%dir %{_texmfdistdir}/doc/generic/knuth-hint/tie
%dir %{_texmfdistdir}/doc/generic/knuth-hint/web
%dir %{_texmfdistdir}/doc/generic/knuth-hint/xetex
%dir %{_texmfdistdir}/doc/generic/knuth-pdf
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/bibtex
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/ctie
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/cweb
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/errata
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/etc
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/mf
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/mfware
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/other
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/pdftex
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/tex
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/texware
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/tie
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/web
%dir %{_texmfdistdir}/doc/generic/knuth-pdf/xetex
%dir %{_texmfdistdir}/doc/generic/langcode
%dir %{_texmfdistdir}/doc/generic/latex-notes-zh-cn
%dir %{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src
%dir %{_texmfdistdir}/doc/generic/latex-notes-zh-cn/src/examples
%dir %{_texmfdistdir}/doc/generic/lecturer
%dir %{_texmfdistdir}/doc/generic/librarian
%dir %{_texmfdistdir}/doc/generic/listofitems
%dir %{_texmfdistdir}/doc/generic/localloc
%dir %{_texmfdistdir}/doc/generic/lpform
%dir %{_texmfdistdir}/doc/generic/lt3luabridge
%dir %{_texmfdistdir}/doc/generic/ltxcmds
%dir %{_texmfdistdir}/doc/generic/luatex85
%dir %{_texmfdistdir}/doc/generic/m-tx
%dir %{_texmfdistdir}/doc/generic/markdown
%dir %{_texmfdistdir}/doc/generic/mathdots
%dir %{_texmfdistdir}/doc/generic/mfpic
%dir %{_texmfdistdir}/doc/generic/mfpic/examples
%dir %{_texmfdistdir}/doc/generic/midnight
%dir %{_texmfdistdir}/doc/generic/minifp
%dir %{_texmfdistdir}/doc/generic/mkjobtexmf
%dir %{_texmfdistdir}/doc/generic/modulus
%dir %{_texmfdistdir}/doc/generic/multido
%dir %{_texmfdistdir}/doc/generic/multiexpand
%dir %{_texmfdistdir}/doc/generic/musixtex
%dir %{_texmfdistdir}/doc/generic/musixtex/examples
%dir %{_texmfdistdir}/doc/generic/musixtex/musixcrd
%dir %{_texmfdistdir}/doc/generic/musixtex/musixdoc
%dir %{_texmfdistdir}/doc/generic/musixtex/musixftab
%dir %{_texmfdistdir}/doc/generic/musixtex/musixlyr
%dir %{_texmfdistdir}/doc/generic/musixtex/musixlyr/examples
%dir %{_texmfdistdir}/doc/generic/musixtex/notationMistakes
%dir %{_texmfdistdir}/doc/generic/musixtex/psslurs
%dir %{_texmfdistdir}/doc/generic/musixtex/reference
%dir %{_texmfdistdir}/doc/generic/musixtex/scripts
%dir %{_texmfdistdir}/doc/generic/musixtnt
%dir %{_texmfdistdir}/doc/generic/namedef
%dir %{_texmfdistdir}/doc/generic/navigator
%dir %{_texmfdistdir}/doc/generic/ofs
%dir %{_texmfdistdir}/doc/generic/olsak-misc
%dir %{_texmfdistdir}/doc/generic/path
%dir %{_texmfdistdir}/doc/generic/pdf-trans
%dir %{_texmfdistdir}/doc/generic/pdfmsym
%dir %{_texmfdistdir}/doc/generic/pdftexcmds
%dir %{_texmfdistdir}/doc/generic/petri-nets
%dir %{_texmfdistdir}/doc/generic/pgf
%dir %{_texmfdistdir}/doc/generic/pgfplots
%dir %{_texmfdistdir}/doc/generic/pgfplots/license_prepcontour
%dir %{_texmfdistdir}/doc/generic/pictex
%dir %{_texmfdistdir}/doc/generic/plainpkg
%dir %{_texmfdistdir}/doc/generic/pmx
%dir %{_texmfdistdir}/doc/generic/pmx/examples
%dir %{_texmfdistdir}/doc/generic/polexpr
%dir %{_texmfdistdir}/doc/generic/poormanlog
%dir %{_texmfdistdir}/doc/generic/poster-mac
%dir %{_texmfdistdir}/doc/generic/pst-2dplot
%dir %{_texmfdistdir}/doc/generic/pst-3d
%dir %{_texmfdistdir}/doc/generic/pst-3dplot
%dir %{_texmfdistdir}/doc/generic/pst-abspos
%dir %{_texmfdistdir}/doc/generic/pst-am
%dir %{_texmfdistdir}/doc/generic/pst-antiprism
%dir %{_texmfdistdir}/doc/generic/pst-arrow
%dir %{_texmfdistdir}/doc/generic/pst-asr
%dir %{_texmfdistdir}/doc/generic/pst-bar
%dir %{_texmfdistdir}/doc/generic/pst-barcode
%dir %{_texmfdistdir}/doc/generic/pst-barcode/images
%dir %{_texmfdistdir}/doc/generic/pst-bezier
%dir %{_texmfdistdir}/doc/generic/pst-blur
%dir %{_texmfdistdir}/doc/generic/pst-bspline
%dir %{_texmfdistdir}/doc/generic/pst-calculate
%dir %{_texmfdistdir}/doc/generic/pst-cie
%dir %{_texmfdistdir}/doc/generic/pst-circ
%dir %{_texmfdistdir}/doc/generic/pst-coil
%dir %{_texmfdistdir}/doc/generic/pst-contourplot
%dir %{_texmfdistdir}/doc/generic/pst-contourplot/examples
%dir %{_texmfdistdir}/doc/generic/pst-cox
%dir %{_texmfdistdir}/doc/generic/pst-cox/pst-coxcoor
%dir %{_texmfdistdir}/doc/generic/pst-cox/pst-coxeterp
%dir %{_texmfdistdir}/doc/generic/pst-dart
%dir %{_texmfdistdir}/doc/generic/pst-dbicons
%dir %{_texmfdistdir}/doc/generic/pst-diffraction
%dir %{_texmfdistdir}/doc/generic/pst-electricfield
%dir %{_texmfdistdir}/doc/generic/pst-eps
%dir %{_texmfdistdir}/doc/generic/pst-eucl
%dir %{_texmfdistdir}/doc/generic/pst-feyn
%dir %{_texmfdistdir}/doc/generic/pst-feyn/data
%dir %{_texmfdistdir}/doc/generic/pst-fill
%dir %{_texmfdistdir}/doc/generic/pst-fit
%dir %{_texmfdistdir}/doc/generic/pst-fr3d
%dir %{_texmfdistdir}/doc/generic/pst-fractal
%dir %{_texmfdistdir}/doc/generic/pst-fun
%dir %{_texmfdistdir}/doc/generic/pst-func
%dir %{_texmfdistdir}/doc/generic/pst-gantt
%dir %{_texmfdistdir}/doc/generic/pst-geo
%dir %{_texmfdistdir}/doc/generic/pst-geo/examples
%dir %{_texmfdistdir}/doc/generic/pst-geometrictools
%dir %{_texmfdistdir}/doc/generic/pst-gr3d
%dir %{_texmfdistdir}/doc/generic/pst-grad
%dir %{_texmfdistdir}/doc/generic/pst-graphicx
%dir %{_texmfdistdir}/doc/generic/pst-hsb
%dir %{_texmfdistdir}/doc/generic/pst-infixplot
%dir %{_texmfdistdir}/doc/generic/pst-jtree
%dir %{_texmfdistdir}/doc/generic/pst-knot
%dir %{_texmfdistdir}/doc/generic/pst-labo
%dir %{_texmfdistdir}/doc/generic/pst-lens
%dir %{_texmfdistdir}/doc/generic/pst-light3d
%dir %{_texmfdistdir}/doc/generic/pst-lsystem
%dir %{_texmfdistdir}/doc/generic/pst-magneticfield
%dir %{_texmfdistdir}/doc/generic/pst-marble
%dir %{_texmfdistdir}/doc/generic/pst-marble/examples
%dir %{_texmfdistdir}/doc/generic/pst-math
%dir %{_texmfdistdir}/doc/generic/pst-mirror
%dir %{_texmfdistdir}/doc/generic/pst-mirror/createEPS
%dir %{_texmfdistdir}/doc/generic/pst-mirror/createEPS/scripts
%dir %{_texmfdistdir}/doc/generic/pst-moire
%dir %{_texmfdistdir}/doc/generic/pst-moire/examples
%dir %{_texmfdistdir}/doc/generic/pst-node
%dir %{_texmfdistdir}/doc/generic/pst-ob3d
%dir %{_texmfdistdir}/doc/generic/pst-ode
%dir %{_texmfdistdir}/doc/generic/pst-ode/examples
%dir %{_texmfdistdir}/doc/generic/pst-optic
%dir %{_texmfdistdir}/doc/generic/pst-osci
%dir %{_texmfdistdir}/doc/generic/pst-ovl
%dir %{_texmfdistdir}/doc/generic/pst-pad
%dir %{_texmfdistdir}/doc/generic/pst-pdgr
%dir %{_texmfdistdir}/doc/generic/pst-perspective
%dir %{_texmfdistdir}/doc/generic/pst-platon
%dir %{_texmfdistdir}/doc/generic/pst-plot
%dir %{_texmfdistdir}/doc/generic/pst-plot/data
%dir %{_texmfdistdir}/doc/generic/pst-poly
%dir %{_texmfdistdir}/doc/generic/pst-pulley
%dir %{_texmfdistdir}/doc/generic/pst-qtree
%dir %{_texmfdistdir}/doc/generic/pst-rputover
%dir %{_texmfdistdir}/doc/generic/pst-rubans
%dir %{_texmfdistdir}/doc/generic/pst-shell
%dir %{_texmfdistdir}/doc/generic/pst-shell/data
%dir %{_texmfdistdir}/doc/generic/pst-shell/images
%dir %{_texmfdistdir}/doc/generic/pst-sigsys
%dir %{_texmfdistdir}/doc/generic/pst-slpe
%dir %{_texmfdistdir}/doc/generic/pst-solarsystem
%dir %{_texmfdistdir}/doc/generic/pst-solides3d
%dir %{_texmfdistdir}/doc/generic/pst-solides3d/data
%dir %{_texmfdistdir}/doc/generic/pst-solides3d/images
%dir %{_texmfdistdir}/doc/generic/pst-solides3d/text
%dir %{_texmfdistdir}/doc/generic/pst-soroban
%dir %{_texmfdistdir}/doc/generic/pst-spectra
%dir %{_texmfdistdir}/doc/generic/pst-spinner
%dir %{_texmfdistdir}/doc/generic/pst-spinner/images
%dir %{_texmfdistdir}/doc/generic/pst-stru
%dir %{_texmfdistdir}/doc/generic/pst-support
%dir %{_texmfdistdir}/doc/generic/pst-text
%dir %{_texmfdistdir}/doc/generic/pst-thick
%dir %{_texmfdistdir}/doc/generic/pst-tools
%dir %{_texmfdistdir}/doc/generic/pst-tree
%dir %{_texmfdistdir}/doc/generic/pst-turtle
%dir %{_texmfdistdir}/doc/generic/pst-tvz
%dir %{_texmfdistdir}/doc/generic/pst-uml
%dir %{_texmfdistdir}/doc/generic/pst-vehicle
%dir %{_texmfdistdir}/doc/generic/pst-venn
%dir %{_texmfdistdir}/doc/generic/pstricks
%dir %{_texmfdistdir}/doc/generic/pstricks-add
%dir %{_texmfdistdir}/doc/generic/pstricks-add/data
%dir %{_texmfdistdir}/doc/generic/pstricks/images
%dir %{_texmfdistdir}/doc/generic/random
%dir %{_texmfdistdir}/doc/generic/randomlist
%dir %{_texmfdistdir}/doc/generic/reverxii
%dir %{_texmfdistdir}/doc/generic/rlepsf
%dir %{_texmfdistdir}/doc/generic/schemata
%dir %{_texmfdistdir}/doc/generic/shade
%dir %{_texmfdistdir}/doc/generic/shapepar
%dir %{_texmfdistdir}/doc/generic/simplekv
%dir %{_texmfdistdir}/doc/generic/soul
%dir %{_texmfdistdir}/doc/generic/systeme
%dir %{_texmfdistdir}/doc/generic/t2
%dir %{_texmfdistdir}/doc/generic/t2/etc
%dir %{_texmfdistdir}/doc/generic/t2/etc/rubibtex
%dir %{_texmfdistdir}/doc/generic/t2/etc/rumkidx
%dir %{_texmfdistdir}/doc/generic/t2/etc/utf-8
%dir %{_texmfdistdir}/doc/generic/t2/examples
%dir %{_texmfdistdir}/doc/generic/tap
%dir %{_texmfdistdir}/doc/generic/tap/tapcv
%dir %{_texmfdistdir}/doc/generic/tap/tapcv/sampdos
%dir %{_texmfdistdir}/doc/generic/tds
%dir %{_texmfdistdir}/doc/generic/termmenu
%dir %{_texmfdistdir}/doc/generic/tex-ewd
%dir %{_texmfdistdir}/doc/generic/tex-ini-files
%dir %{_texmfdistdir}/doc/generic/tex-locale
%dir %{_texmfdistdir}/doc/generic/tex-locale/samples
%dir %{_texmfdistdir}/doc/generic/tex-ps
%dir %{_texmfdistdir}/doc/generic/tex-ps/cmyk-hax
%dir %{_texmfdistdir}/doc/generic/tex-ps/poligraf
%dir %{_texmfdistdir}/doc/generic/tex-refs
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/context
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/fonty
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/gify
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/idx
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/kuchnia
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/listy
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/macro
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/spisy
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/latex2e/tytuly
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/poczatki
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/podstawy
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/prog
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/prog/bibtex
%dir %{_texmfdistdir}/doc/generic/tex-virtual-academy-pl/tex
%dir %{_texmfdistdir}/doc/generic/tex4ht
%dir %{_texmfdistdir}/doc/generic/texapi
%dir %{_texmfdistdir}/doc/generic/texdate
%dir %{_texmfdistdir}/doc/generic/texdimens
%dir %{_texmfdistdir}/doc/generic/textmerg
%dir %{_texmfdistdir}/doc/generic/thumbpdf
%dir %{_texmfdistdir}/doc/generic/tikzducks
%dir %{_texmfdistdir}/doc/generic/tokcycle
%dir %{_texmfdistdir}/doc/generic/tracklang
%dir %{_texmfdistdir}/doc/generic/tracklang/samples
%dir %{_texmfdistdir}/doc/generic/tracklang/samples/animals
%dir %{_texmfdistdir}/doc/generic/tracklang/samples/regions
%dir %{_texmfdistdir}/doc/generic/trigonometry
%dir %{_texmfdistdir}/doc/generic/ukrhyph
%dir %{_texmfdistdir}/doc/generic/ulem
%dir %{_texmfdistdir}/doc/generic/unicode-data
%dir %{_texmfdistdir}/doc/generic/upca
%dir %{_texmfdistdir}/doc/generic/upzhkinsoku
%dir %{_texmfdistdir}/doc/generic/variations
%dir %{_texmfdistdir}/doc/generic/vaucanson-g
%dir %{_texmfdistdir}/doc/generic/vaucanson-g/VCManual-src
%dir %{_texmfdistdir}/doc/generic/velthuis
%dir %{_texmfdistdir}/doc/generic/vntex
%dir %{_texmfdistdir}/doc/generic/witharrows
%dir %{_texmfdistdir}/doc/generic/xcomment
%dir %{_texmfdistdir}/doc/generic/xint
%dir %{_texmfdistdir}/doc/generic/xlop
%dir %{_texmfdistdir}/doc/generic/xstring
%dir %{_texmfdistdir}/doc/generic/xypic
%dir %{_texmfdistdir}/doc/generic/xypic-tut-pt
%dir %{_texmfdistdir}/doc/generic/xypic/support
%dir %{_texmfdistdir}/doc/generic/yax
%dir %{_texmfdistdir}/doc/generic/youngtab
%dir %{_texmfdistdir}/doc/generic/zhspacing
%dir %{_texmfdistdir}/doc/hitex
%dir %{_texmfdistdir}/doc/hitex/base
%dir %{_texmfdistdir}/doc/kpathsea
%dir %{_texmfdistdir}/doc/latex
%dir %{_texmfdistdir}/doc/latex-dev
%dir %{_texmfdistdir}/doc/latex-dev/amsmath
%dir %{_texmfdistdir}/doc/latex-dev/base
%dir %{_texmfdistdir}/doc/latex-dev/firstaid
%dir %{_texmfdistdir}/doc/latex-dev/graphics
%dir %{_texmfdistdir}/doc/latex-dev/latex-lab
%dir %{_texmfdistdir}/doc/latex-dev/tools
%dir %{_texmfdistdir}/doc/latex/12many
%dir %{_texmfdistdir}/doc/latex/a0poster
%dir %{_texmfdistdir}/doc/latex/a4wide
%dir %{_texmfdistdir}/doc/latex/a5comb
%dir %{_texmfdistdir}/doc/latex/aalok
%dir %{_texmfdistdir}/doc/latex/aastex
%dir %{_texmfdistdir}/doc/latex/abc
%dir %{_texmfdistdir}/doc/latex/abnt
%dir %{_texmfdistdir}/doc/latex/abntex2
%dir %{_texmfdistdir}/doc/latex/abntex2/examples
%dir %{_texmfdistdir}/doc/latex/abntexto
%dir %{_texmfdistdir}/doc/latex/abraces
%dir %{_texmfdistdir}/doc/latex/abspos
%dir %{_texmfdistdir}/doc/latex/abstract
%dir %{_texmfdistdir}/doc/latex/accents
%dir %{_texmfdistdir}/doc/latex/accessibility
%dir %{_texmfdistdir}/doc/latex/accsupp
%dir %{_texmfdistdir}/doc/latex/achemso
%dir %{_texmfdistdir}/doc/latex/acmart
%dir %{_texmfdistdir}/doc/latex/acmart/samples
%dir %{_texmfdistdir}/doc/latex/acmconf
%dir %{_texmfdistdir}/doc/latex/acro
%dir %{_texmfdistdir}/doc/latex/acro/examples
%dir %{_texmfdistdir}/doc/latex/acronym
%dir %{_texmfdistdir}/doc/latex/acroterm
%dir %{_texmfdistdir}/doc/latex/active-conf
%dir %{_texmfdistdir}/doc/latex/active-conf/example
%dir %{_texmfdistdir}/doc/latex/actuarialangle
%dir %{_texmfdistdir}/doc/latex/actuarialsymbol
%dir %{_texmfdistdir}/doc/latex/addfont
%dir %{_texmfdistdir}/doc/latex/addlines
%dir %{_texmfdistdir}/doc/latex/adfathesis
%dir %{_texmfdistdir}/doc/latex/adigraph
%dir %{_texmfdistdir}/doc/latex/adigraph/img_examples
%dir %{_texmfdistdir}/doc/latex/adjmulticol
%dir %{_texmfdistdir}/doc/latex/adjustbox
%dir %{_texmfdistdir}/doc/latex/adrconv
%dir %{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages
%dir %{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages/Contents
%dir %{_texmfdistdir}/doc/latex/adrconv/adrconv_pages08.pages/QuickLook
%dir %{_texmfdistdir}/doc/latex/adtrees
%dir %{_texmfdistdir}/doc/latex/advdate
%dir %{_texmfdistdir}/doc/latex/aeguill
%dir %{_texmfdistdir}/doc/latex/afparticle
%dir %{_texmfdistdir}/doc/latex/afthesis
%dir %{_texmfdistdir}/doc/latex/aguplus
%dir %{_texmfdistdir}/doc/latex/aiaa
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004/demos
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/paper
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/refs
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/subfigs
%dir %{_texmfdistdir}/doc/latex/aiaa/pre2004/demos/talk
%dir %{_texmfdistdir}/doc/latex/akktex
%dir %{_texmfdistdir}/doc/latex/akletter
%dir %{_texmfdistdir}/doc/latex/akshar
%dir %{_texmfdistdir}/doc/latex/alertmessage
%dir %{_texmfdistdir}/doc/latex/alg
%dir %{_texmfdistdir}/doc/latex/algobox
%dir %{_texmfdistdir}/doc/latex/algorithm2e
%dir %{_texmfdistdir}/doc/latex/algorithmicx
%dir %{_texmfdistdir}/doc/latex/algorithms
%dir %{_texmfdistdir}/doc/latex/algpseudocodex
%dir %{_texmfdistdir}/doc/latex/algxpar
%dir %{_texmfdistdir}/doc/latex/aligned-overset
%dir %{_texmfdistdir}/doc/latex/alnumsec
%dir %{_texmfdistdir}/doc/latex/alphalph
%dir %{_texmfdistdir}/doc/latex/alterqcm
%dir %{_texmfdistdir}/doc/latex/alterqcm/examples
%dir %{_texmfdistdir}/doc/latex/alterqcm/examples/iut
%dir %{_texmfdistdir}/doc/latex/alterqcm/examples/latex
%dir %{_texmfdistdir}/doc/latex/alterqcm/latex
%dir %{_texmfdistdir}/doc/latex/altfont
%dir %{_texmfdistdir}/doc/latex/altsubsup
%dir %{_texmfdistdir}/doc/latex/amiweb2c-guide
%dir %{_texmfdistdir}/doc/latex/amsaddr
%dir %{_texmfdistdir}/doc/latex/amscdx
%dir %{_texmfdistdir}/doc/latex/amscls
%dir %{_texmfdistdir}/doc/latex/amscls-doc
%dir %{_texmfdistdir}/doc/latex/amslatex-primer
%dir %{_texmfdistdir}/doc/latex/amsldoc-it
%dir %{_texmfdistdir}/doc/latex/amsldoc-vn
%dir %{_texmfdistdir}/doc/latex/amsmath
%dir %{_texmfdistdir}/doc/latex/amsmath-it
%dir %{_texmfdistdir}/doc/latex/amsrefs
%dir %{_texmfdistdir}/doc/latex/amsthdoc-it
%dir %{_texmfdistdir}/doc/latex/animate
%dir %{_texmfdistdir}/doc/latex/annee-scolaire
%dir %{_texmfdistdir}/doc/latex/annotate-equations
%dir %{_texmfdistdir}/doc/latex/anonchap
%dir %{_texmfdistdir}/doc/latex/anonymous-acm
%dir %{_texmfdistdir}/doc/latex/answers
%dir %{_texmfdistdir}/doc/latex/antanilipsum
%dir %{_texmfdistdir}/doc/latex/antt
%dir %{_texmfdistdir}/doc/latex/anufinalexam
%dir %{_texmfdistdir}/doc/latex/anyfontsize
%dir %{_texmfdistdir}/doc/latex/anysize
%dir %{_texmfdistdir}/doc/latex/aobs-tikz
%dir %{_texmfdistdir}/doc/latex/aomart
%dir %{_texmfdistdir}/doc/latex/apa
%dir %{_texmfdistdir}/doc/latex/apa6
%dir %{_texmfdistdir}/doc/latex/apa6/pseudoTeX
%dir %{_texmfdistdir}/doc/latex/apa6/samples
%dir %{_texmfdistdir}/doc/latex/apa6e
%dir %{_texmfdistdir}/doc/latex/apa7
%dir %{_texmfdistdir}/doc/latex/apa7/samples
%dir %{_texmfdistdir}/doc/latex/appendix
%dir %{_texmfdistdir}/doc/latex/appendixnumberbeamer
%dir %{_texmfdistdir}/doc/latex/apprends-latex
%dir %{_texmfdistdir}/doc/latex/apprends-latex/exemples
%dir %{_texmfdistdir}/doc/latex/apptools
%dir %{_texmfdistdir}/doc/latex/apxproof
%dir %{_texmfdistdir}/doc/latex/arabi
%dir %{_texmfdistdir}/doc/latex/arabi-add
%dir %{_texmfdistdir}/doc/latex/arabicfront
%dir %{_texmfdistdir}/doc/latex/arabtex
%dir %{_texmfdistdir}/doc/latex/aramaic-serto
%dir %{_texmfdistdir}/doc/latex/archaeologie
%dir %{_texmfdistdir}/doc/latex/arcs
%dir %{_texmfdistdir}/doc/latex/arraycols
%dir %{_texmfdistdir}/doc/latex/arraysort
%dir %{_texmfdistdir}/doc/latex/arsclassica
%dir %{_texmfdistdir}/doc/latex/arsclassica/Chapters
%dir %{_texmfdistdir}/doc/latex/arsclassica/FrontBackMatter
%dir %{_texmfdistdir}/doc/latex/arsclassica/Graphics
%dir %{_texmfdistdir}/doc/latex/articleingud
%dir %{_texmfdistdir}/doc/latex/arydshln
%dir %{_texmfdistdir}/doc/latex/asaetr
%dir %{_texmfdistdir}/doc/latex/ascelike
%dir %{_texmfdistdir}/doc/latex/asciilist
%dir %{_texmfdistdir}/doc/latex/ascmac
%dir %{_texmfdistdir}/doc/latex/askinclude
%dir %{_texmfdistdir}/doc/latex/askmaps
%dir %{_texmfdistdir}/doc/latex/asmeconf
%dir %{_texmfdistdir}/doc/latex/asmeconf/examples
%dir %{_texmfdistdir}/doc/latex/asmeconf/examples/asmeconf-wide-equation-example
%dir %{_texmfdistdir}/doc/latex/asmejour
%dir %{_texmfdistdir}/doc/latex/asmejour/asmewide_example
%dir %{_texmfdistdir}/doc/latex/aspectratio
%dir %{_texmfdistdir}/doc/latex/assignment
%dir %{_texmfdistdir}/doc/latex/assoccnt
%dir %{_texmfdistdir}/doc/latex/association-matrix
%dir %{_texmfdistdir}/doc/latex/asternote
%dir %{_texmfdistdir}/doc/latex/asyfig
%dir %{_texmfdistdir}/doc/latex/asyfig/example
%dir %{_texmfdistdir}/doc/latex/asypictureb
%dir %{_texmfdistdir}/doc/latex/atbegshi
%dir %{_texmfdistdir}/doc/latex/atenddvi
%dir %{_texmfdistdir}/doc/latex/atendofenv
%dir %{_texmfdistdir}/doc/latex/attachfile
%dir %{_texmfdistdir}/doc/latex/attachfile2
%dir %{_texmfdistdir}/doc/latex/atveryend
%dir %{_texmfdistdir}/doc/latex/aucklandthesis
%dir %{_texmfdistdir}/doc/latex/augie
%dir %{_texmfdistdir}/doc/latex/augie/other
%dir %{_texmfdistdir}/doc/latex/augie/vtex
%dir %{_texmfdistdir}/doc/latex/aurical
%dir %{_texmfdistdir}/doc/latex/aurl
%dir %{_texmfdistdir}/doc/latex/authoraftertitle
%dir %{_texmfdistdir}/doc/latex/authorarchive
%dir %{_texmfdistdir}/doc/latex/authorarchive/examples
%dir %{_texmfdistdir}/doc/latex/authorarchive/examples/bib
%dir %{_texmfdistdir}/doc/latex/authorindex
%dir %{_texmfdistdir}/doc/latex/auto-pst-pdf
%dir %{_texmfdistdir}/doc/latex/auto-pst-pdf-lua
%dir %{_texmfdistdir}/doc/latex/autoarea
%dir %{_texmfdistdir}/doc/latex/autoarea/autodemo
%dir %{_texmfdistdir}/doc/latex/autobreak
%dir %{_texmfdistdir}/doc/latex/autofancyhdr
%dir %{_texmfdistdir}/doc/latex/autonum
%dir %{_texmfdistdir}/doc/latex/autopdf
%dir %{_texmfdistdir}/doc/latex/auxhook
%dir %{_texmfdistdir}/doc/latex/avremu
%dir %{_texmfdistdir}/doc/latex/awesomebox
%dir %{_texmfdistdir}/doc/latex/axessibility
%dir %{_texmfdistdir}/doc/latex/axodraw2
%dir %{_texmfdistdir}/doc/latex/b1encoding
%dir %{_texmfdistdir}/doc/latex/babel
%dir %{_texmfdistdir}/doc/latex/background
%dir %{_texmfdistdir}/doc/latex/backnaur
%dir %{_texmfdistdir}/doc/latex/bangla
%dir %{_texmfdistdir}/doc/latex/bangorcsthesis
%dir %{_texmfdistdir}/doc/latex/bangorexam
%dir %{_texmfdistdir}/doc/latex/bangtex
%dir %{_texmfdistdir}/doc/latex/bankstatement
%dir %{_texmfdistdir}/doc/latex/barcodes
%dir %{_texmfdistdir}/doc/latex/bardiag
%dir %{_texmfdistdir}/doc/latex/bardiag/example
%dir %{_texmfdistdir}/doc/latex/bardiag/example/src
%dir %{_texmfdistdir}/doc/latex/bardiag/figs
%dir %{_texmfdistdir}/doc/latex/bardiag/src
%dir %{_texmfdistdir}/doc/latex/base
%dir %{_texmfdistdir}/doc/latex/bashful
%dir %{_texmfdistdir}/doc/latex/basicarith
%dir %{_texmfdistdir}/doc/latex/basque-book
%dir %{_texmfdistdir}/doc/latex/basque-date
%dir %{_texmfdistdir}/doc/latex/bbding
%dir %{_texmfdistdir}/doc/latex/bbm-macros
%dir %{_texmfdistdir}/doc/latex/bbold
%dir %{_texmfdistdir}/doc/latex/bchart
%dir %{_texmfdistdir}/doc/latex/bclogo
%dir %{_texmfdistdir}/doc/latex/beamer
%dir %{_texmfdistdir}/doc/latex/beamer-fuberlin
%dir %{_texmfdistdir}/doc/latex/beamer-tut-pt
%dir %{_texmfdistdir}/doc/latex/beamer-verona
%dir %{_texmfdistdir}/doc/latex/beamer/emulation-examples
%dir %{_texmfdistdir}/doc/latex/beamer/examples
%dir %{_texmfdistdir}/doc/latex/beamer/examples/a-conference-talk
%dir %{_texmfdistdir}/doc/latex/beamer/examples/a-lecture
%dir %{_texmfdistdir}/doc/latex/beamer/licenses
%dir %{_texmfdistdir}/doc/latex/beamer/solutions
%dir %{_texmfdistdir}/doc/latex/beamer/solutions/conference-talks
%dir %{_texmfdistdir}/doc/latex/beamer/solutions/generic-talks
%dir %{_texmfdistdir}/doc/latex/beamer/solutions/short-talks
%dir %{_texmfdistdir}/doc/latex/beamer2thesis
%dir %{_texmfdistdir}/doc/latex/beamerappendixnote
%dir %{_texmfdistdir}/doc/latex/beameraudience
%dir %{_texmfdistdir}/doc/latex/beamerauxtheme
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Hannover-dark
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Hannover-light
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Pittsburgh-dark
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/Pittsburgh-light
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/metropolis-dark
%dir %{_texmfdistdir}/doc/latex/beamercolorthemeowl/ex/metropolis-light
%dir %{_texmfdistdir}/doc/latex/beamerdarkthemes
%dir %{_texmfdistdir}/doc/latex/beamerposter
%dir %{_texmfdistdir}/doc/latex/beamersubframe
%dir %{_texmfdistdir}/doc/latex/beamerswitch
%dir %{_texmfdistdir}/doc/latex/beamertheme-arguelles
%dir %{_texmfdistdir}/doc/latex/beamertheme-arguelles/demo
%dir %{_texmfdistdir}/doc/latex/beamertheme-cuerna
%dir %{_texmfdistdir}/doc/latex/beamertheme-cuerna/pictures
%dir %{_texmfdistdir}/doc/latex/beamertheme-detlevcm
%dir %{_texmfdistdir}/doc/latex/beamertheme-epyt
%dir %{_texmfdistdir}/doc/latex/beamertheme-focus
%dir %{_texmfdistdir}/doc/latex/beamertheme-focus/focus-demo
%dir %{_texmfdistdir}/doc/latex/beamertheme-light
%dir %{_texmfdistdir}/doc/latex/beamertheme-metropolis
%dir %{_texmfdistdir}/doc/latex/beamertheme-npbt
%dir %{_texmfdistdir}/doc/latex/beamertheme-npbt/example
%dir %{_texmfdistdir}/doc/latex/beamertheme-phnompenh
%dir %{_texmfdistdir}/doc/latex/beamertheme-pure-minimalistic
%dir %{_texmfdistdir}/doc/latex/beamertheme-pure-minimalistic/logos
%dir %{_texmfdistdir}/doc/latex/beamertheme-saintpetersburg
%dir %{_texmfdistdir}/doc/latex/beamertheme-saintpetersburg/figures
%dir %{_texmfdistdir}/doc/latex/beamertheme-simpledarkblue
%dir %{_texmfdistdir}/doc/latex/beamertheme-simpleplus
%dir %{_texmfdistdir}/doc/latex/beamertheme-tcolorbox
%dir %{_texmfdistdir}/doc/latex/beamertheme-trigon
%dir %{_texmfdistdir}/doc/latex/beamertheme-upenn-bc
%dir %{_texmfdistdir}/doc/latex/beamerthemeamurmaple
%dir %{_texmfdistdir}/doc/latex/beamerthemelalic
%dir %{_texmfdistdir}/doc/latex/beamerthemenirma
%dir %{_texmfdistdir}/doc/latex/beamerthemenord
%dir %{_texmfdistdir}/doc/latex/beamerthemenord/screenshots
%dir %{_texmfdistdir}/doc/latex/bearwear
%dir %{_texmfdistdir}/doc/latex/beaulivre
%dir %{_texmfdistdir}/doc/latex/begingreek
%dir %{_texmfdistdir}/doc/latex/begriff
%dir %{_texmfdistdir}/doc/latex/beilstein
%dir %{_texmfdistdir}/doc/latex/betababel
%dir %{_texmfdistdir}/doc/latex/beton
%dir %{_texmfdistdir}/doc/latex/bewerbung
%dir %{_texmfdistdir}/doc/latex/bez123
%dir %{_texmfdistdir}/doc/latex/bfh-ci
%dir %{_texmfdistdir}/doc/latex/bgteubner
%dir %{_texmfdistdir}/doc/latex/bibarts
%dir %{_texmfdistdir}/doc/latex/biblatex
%dir %{_texmfdistdir}/doc/latex/biblatex-abnt
%dir %{_texmfdistdir}/doc/latex/biblatex-abnt/tests
%dir %{_texmfdistdir}/doc/latex/biblatex-ajc2020unofficial
%dir %{_texmfdistdir}/doc/latex/biblatex-anonymous
%dir %{_texmfdistdir}/doc/latex/biblatex-apa
%dir %{_texmfdistdir}/doc/latex/biblatex-apa6
%dir %{_texmfdistdir}/doc/latex/biblatex-archaeology
%dir %{_texmfdistdir}/doc/latex/biblatex-archaeology/example
%dir %{_texmfdistdir}/doc/latex/biblatex-arthistory-bonn
%dir %{_texmfdistdir}/doc/latex/biblatex-bath
%dir %{_texmfdistdir}/doc/latex/biblatex-bookinarticle
%dir %{_texmfdistdir}/doc/latex/biblatex-bookinarticle/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-bookinother
%dir %{_texmfdistdir}/doc/latex/biblatex-bookinother/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-bwl
%dir %{_texmfdistdir}/doc/latex/biblatex-bwl/doc
%dir %{_texmfdistdir}/doc/latex/biblatex-caspervector
%dir %{_texmfdistdir}/doc/latex/biblatex-cheatsheet
%dir %{_texmfdistdir}/doc/latex/biblatex-chem
%dir %{_texmfdistdir}/doc/latex/biblatex-chicago
%dir %{_texmfdistdir}/doc/latex/biblatex-claves
%dir %{_texmfdistdir}/doc/latex/biblatex-claves/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-cv
%dir %{_texmfdistdir}/doc/latex/biblatex-dw
%dir %{_texmfdistdir}/doc/latex/biblatex-dw/examples
%dir %{_texmfdistdir}/doc/latex/biblatex-enc
%dir %{_texmfdistdir}/doc/latex/biblatex-ext
%dir %{_texmfdistdir}/doc/latex/biblatex-fiwi
%dir %{_texmfdistdir}/doc/latex/biblatex-gb7714-2015
%dir %{_texmfdistdir}/doc/latex/biblatex-german-legal
%dir %{_texmfdistdir}/doc/latex/biblatex-gost
%dir %{_texmfdistdir}/doc/latex/biblatex-historian
%dir %{_texmfdistdir}/doc/latex/biblatex-ieee
%dir %{_texmfdistdir}/doc/latex/biblatex-ijsra
%dir %{_texmfdistdir}/doc/latex/biblatex-iso690
%dir %{_texmfdistdir}/doc/latex/biblatex-jura2
%dir %{_texmfdistdir}/doc/latex/biblatex-juradiss
%dir %{_texmfdistdir}/doc/latex/biblatex-license
%dir %{_texmfdistdir}/doc/latex/biblatex-lncs
%dir %{_texmfdistdir}/doc/latex/biblatex-lni
%dir %{_texmfdistdir}/doc/latex/biblatex-luh-ipw
%dir %{_texmfdistdir}/doc/latex/biblatex-manuscripts-philology
%dir %{_texmfdistdir}/doc/latex/biblatex-manuscripts-philology/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-mla
%dir %{_texmfdistdir}/doc/latex/biblatex-mla/doc
%dir %{_texmfdistdir}/doc/latex/biblatex-morenames
%dir %{_texmfdistdir}/doc/latex/biblatex-morenames/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-ms
%dir %{_texmfdistdir}/doc/latex/biblatex-ms/biber
%dir %{_texmfdistdir}/doc/latex/biblatex-ms/biber/bltxml
%dir %{_texmfdistdir}/doc/latex/biblatex-ms/examples
%dir %{_texmfdistdir}/doc/latex/biblatex-multiple-dm
%dir %{_texmfdistdir}/doc/latex/biblatex-musuos
%dir %{_texmfdistdir}/doc/latex/biblatex-nature
%dir %{_texmfdistdir}/doc/latex/biblatex-nejm
%dir %{_texmfdistdir}/doc/latex/biblatex-nottsclassic
%dir %{_texmfdistdir}/doc/latex/biblatex-opcit-booktitle
%dir %{_texmfdistdir}/doc/latex/biblatex-opcit-booktitle/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-oxref
%dir %{_texmfdistdir}/doc/latex/biblatex-philosophy
%dir %{_texmfdistdir}/doc/latex/biblatex-phys
%dir %{_texmfdistdir}/doc/latex/biblatex-publist
%dir %{_texmfdistdir}/doc/latex/biblatex-readbbl
%dir %{_texmfdistdir}/doc/latex/biblatex-realauthor
%dir %{_texmfdistdir}/doc/latex/biblatex-realauthor/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-sbl
%dir %{_texmfdistdir}/doc/latex/biblatex-science
%dir %{_texmfdistdir}/doc/latex/biblatex-shortfields
%dir %{_texmfdistdir}/doc/latex/biblatex-shortfields/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-socialscienceshuberlin
%dir %{_texmfdistdir}/doc/latex/biblatex-software
%dir %{_texmfdistdir}/doc/latex/biblatex-source-division
%dir %{_texmfdistdir}/doc/latex/biblatex-spbasic
%dir %{_texmfdistdir}/doc/latex/biblatex-subseries
%dir %{_texmfdistdir}/doc/latex/biblatex-subseries/documentation
%dir %{_texmfdistdir}/doc/latex/biblatex-swiss-legal
%dir %{_texmfdistdir}/doc/latex/biblatex-swiss-legal/doc_source
%dir %{_texmfdistdir}/doc/latex/biblatex-trad
%dir %{_texmfdistdir}/doc/latex/biblatex-true-citepages-omit
%dir %{_texmfdistdir}/doc/latex/biblatex-unified
%dir %{_texmfdistdir}/doc/latex/biblatex-vancouver
%dir %{_texmfdistdir}/doc/latex/biblatex/biber
%dir %{_texmfdistdir}/doc/latex/biblatex/biber/bltxml
%dir %{_texmfdistdir}/doc/latex/biblatex/examples
%dir %{_texmfdistdir}/doc/latex/biblatex2bibitem
%dir %{_texmfdistdir}/doc/latex/bibleref
%dir %{_texmfdistdir}/doc/latex/bibleref-french
%dir %{_texmfdistdir}/doc/latex/bibleref-german
%dir %{_texmfdistdir}/doc/latex/bibleref-lds
%dir %{_texmfdistdir}/doc/latex/bibleref-mouth
%dir %{_texmfdistdir}/doc/latex/bibleref-parse
%dir %{_texmfdistdir}/doc/latex/bibleref/samples
%dir %{_texmfdistdir}/doc/latex/bibletext
%dir %{_texmfdistdir}/doc/latex/biblist
%dir %{_texmfdistdir}/doc/latex/bibtopic
%dir %{_texmfdistdir}/doc/latex/bibtopicprefix
%dir %{_texmfdistdir}/doc/latex/bibunits
%dir %{_texmfdistdir}/doc/latex/bigfoot
%dir %{_texmfdistdir}/doc/latex/bigintcalc
%dir %{_texmfdistdir}/doc/latex/bigints
%dir %{_texmfdistdir}/doc/latex/bilingualpages
%dir %{_texmfdistdir}/doc/latex/binarytree
%dir %{_texmfdistdir}/doc/latex/binarytree/examples
%dir %{_texmfdistdir}/doc/latex/binomexp
%dir %{_texmfdistdir}/doc/latex/biochemistry-colors
%dir %{_texmfdistdir}/doc/latex/biocon
%dir %{_texmfdistdir}/doc/latex/bithesis
%dir %{_texmfdistdir}/doc/latex/bitpattern
%dir %{_texmfdistdir}/doc/latex/bitset
%dir %{_texmfdistdir}/doc/latex/bizcard
%dir %{_texmfdistdir}/doc/latex/bjfuthesis
%dir %{_texmfdistdir}/doc/latex/bjfuthesis/documentation
%dir %{_texmfdistdir}/doc/latex/bjfuthesis/example
%dir %{_texmfdistdir}/doc/latex/bjfuthesis/example/contents
%dir %{_texmfdistdir}/doc/latex/bjfuthesis/example/figures
%dir %{_texmfdistdir}/doc/latex/blindtext
%dir %{_texmfdistdir}/doc/latex/blkarray
%dir %{_texmfdistdir}/doc/latex/blochsphere
%dir %{_texmfdistdir}/doc/latex/block
%dir %{_texmfdistdir}/doc/latex/bloques
%dir %{_texmfdistdir}/doc/latex/blowup
%dir %{_texmfdistdir}/doc/latex/blox
%dir %{_texmfdistdir}/doc/latex/bmstu
%dir %{_texmfdistdir}/doc/latex/bmstu-iu8
%dir %{_texmfdistdir}/doc/latex/bmstu/examples
%dir %{_texmfdistdir}/doc/latex/bmstu/examples/inc
%dir %{_texmfdistdir}/doc/latex/bmstu/examples/inc/img
%dir %{_texmfdistdir}/doc/latex/bmstu/examples/inc/lst
%dir %{_texmfdistdir}/doc/latex/bnumexpr
%dir %{_texmfdistdir}/doc/latex/bodegraph
%dir %{_texmfdistdir}/doc/latex/bodegraph/gnuplot
%dir %{_texmfdistdir}/doc/latex/bodegraph/gnuplot/bodegraph
%dir %{_texmfdistdir}/doc/latex/bodeplot
%dir %{_texmfdistdir}/doc/latex/bohr
%dir %{_texmfdistdir}/doc/latex/boites
%dir %{_texmfdistdir}/doc/latex/bold-extra
%dir %{_texmfdistdir}/doc/latex/boldtensors
%dir %{_texmfdistdir}/doc/latex/bondgraph
%dir %{_texmfdistdir}/doc/latex/bondgraphs
%dir %{_texmfdistdir}/doc/latex/book-of-common-prayer
%dir %{_texmfdistdir}/doc/latex/bookcover
%dir %{_texmfdistdir}/doc/latex/bookcover/figures
%dir %{_texmfdistdir}/doc/latex/bookest
%dir %{_texmfdistdir}/doc/latex/booklet
%dir %{_texmfdistdir}/doc/latex/bookmark
%dir %{_texmfdistdir}/doc/latex/bookshelf
%dir %{_texmfdistdir}/doc/latex/booktabs
%dir %{_texmfdistdir}/doc/latex/booktabs-de
%dir %{_texmfdistdir}/doc/latex/booktabs-fr
%dir %{_texmfdistdir}/doc/latex/boolexpr
%dir %{_texmfdistdir}/doc/latex/bophook
%dir %{_texmfdistdir}/doc/latex/bosisio
%dir %{_texmfdistdir}/doc/latex/boxedminipage
%dir %{_texmfdistdir}/doc/latex/boxhandler
%dir %{_texmfdistdir}/doc/latex/bpchem
%dir %{_texmfdistdir}/doc/latex/br-lex
%dir %{_texmfdistdir}/doc/latex/bracketkey
%dir %{_texmfdistdir}/doc/latex/braids
%dir %{_texmfdistdir}/doc/latex/braille
%dir %{_texmfdistdir}/doc/latex/braket
%dir %{_texmfdistdir}/doc/latex/brandeis-dissertation
%dir %{_texmfdistdir}/doc/latex/brandeis-problemset
%dir %{_texmfdistdir}/doc/latex/brandeis-thesis
%dir %{_texmfdistdir}/doc/latex/breakcites
%dir %{_texmfdistdir}/doc/latex/breakurl
%dir %{_texmfdistdir}/doc/latex/bredzenie
%dir %{_texmfdistdir}/doc/latex/breqn
%dir %{_texmfdistdir}/doc/latex/bropd
%dir %{_texmfdistdir}/doc/latex/bubblesort
%dir %{_texmfdistdir}/doc/latex/bullcntr
%dir %{_texmfdistdir}/doc/latex/bussproofs
%dir %{_texmfdistdir}/doc/latex/bussproofs-extra
%dir %{_texmfdistdir}/doc/latex/bxbase
%dir %{_texmfdistdir}/doc/latex/bxcalc
%dir %{_texmfdistdir}/doc/latex/bxcjkjatype
%dir %{_texmfdistdir}/doc/latex/bxdpx-beamer
%dir %{_texmfdistdir}/doc/latex/bxdpx-beamer/sample
%dir %{_texmfdistdir}/doc/latex/bxdvidriver
%dir %{_texmfdistdir}/doc/latex/bxeepic
%dir %{_texmfdistdir}/doc/latex/bxenclose
%dir %{_texmfdistdir}/doc/latex/bxghost
%dir %{_texmfdistdir}/doc/latex/bxjaholiday
%dir %{_texmfdistdir}/doc/latex/bxjalipsum
%dir %{_texmfdistdir}/doc/latex/bxjaprnind
%dir %{_texmfdistdir}/doc/latex/bxjatoucs
%dir %{_texmfdistdir}/doc/latex/bxjscls
%dir %{_texmfdistdir}/doc/latex/bxnewfont
%dir %{_texmfdistdir}/doc/latex/bxorigcapt
%dir %{_texmfdistdir}/doc/latex/bxpapersize
%dir %{_texmfdistdir}/doc/latex/bxpdfver
%dir %{_texmfdistdir}/doc/latex/bxtexlogo
%dir %{_texmfdistdir}/doc/latex/bxwareki
%dir %{_texmfdistdir}/doc/latex/byo-twemojis
%dir %{_texmfdistdir}/doc/latex/bytefield
%dir %{_texmfdistdir}/doc/latex/cachepic
%dir %{_texmfdistdir}/doc/latex/calcage
%dir %{_texmfdistdir}/doc/latex/calctab
%dir %{_texmfdistdir}/doc/latex/calculation
%dir %{_texmfdistdir}/doc/latex/calculator
%dir %{_texmfdistdir}/doc/latex/calligra
%dir %{_texmfdistdir}/doc/latex/callouts
%dir %{_texmfdistdir}/doc/latex/calrsfs
%dir %{_texmfdistdir}/doc/latex/cals
%dir %{_texmfdistdir}/doc/latex/cals/examples
%dir %{_texmfdistdir}/doc/latex/cals/test
%dir %{_texmfdistdir}/doc/latex/cals/test/cell
%dir %{_texmfdistdir}/doc/latex/cals/test/colsep
%dir %{_texmfdistdir}/doc/latex/cals/test/decoration
%dir %{_texmfdistdir}/doc/latex/cals/test/llt
%dir %{_texmfdistdir}/doc/latex/cals/test/regression
%dir %{_texmfdistdir}/doc/latex/cals/test/rowsep
%dir %{_texmfdistdir}/doc/latex/cals/test/span
%dir %{_texmfdistdir}/doc/latex/cals/test/support
%dir %{_texmfdistdir}/doc/latex/cals/test/table
%dir %{_texmfdistdir}/doc/latex/cals/test/visual_tables
%dir %{_texmfdistdir}/doc/latex/calxxxx-yyyy
%dir %{_texmfdistdir}/doc/latex/cancel
%dir %{_texmfdistdir}/doc/latex/canoniclayout
%dir %{_texmfdistdir}/doc/latex/capt-of
%dir %{_texmfdistdir}/doc/latex/captcont
%dir %{_texmfdistdir}/doc/latex/captdef
%dir %{_texmfdistdir}/doc/latex/caption
%dir %{_texmfdistdir}/doc/latex/carbohydrates
%dir %{_texmfdistdir}/doc/latex/carlisle
%dir %{_texmfdistdir}/doc/latex/cartonaugh
%dir %{_texmfdistdir}/doc/latex/cartonaugh/test
%dir %{_texmfdistdir}/doc/latex/cascade
%dir %{_texmfdistdir}/doc/latex/cascadilla
%dir %{_texmfdistdir}/doc/latex/cases
%dir %{_texmfdistdir}/doc/latex/casyl
%dir %{_texmfdistdir}/doc/latex/catchfile
%dir %{_texmfdistdir}/doc/latex/catchfilebetweentags
%dir %{_texmfdistdir}/doc/latex/catechis
%dir %{_texmfdistdir}/doc/latex/catoptions
%dir %{_texmfdistdir}/doc/latex/causets
%dir %{_texmfdistdir}/doc/latex/cbcoptic
%dir %{_texmfdistdir}/doc/latex/ccaption
%dir %{_texmfdistdir}/doc/latex/ccfonts
%dir %{_texmfdistdir}/doc/latex/ccicons
%dir %{_texmfdistdir}/doc/latex/cclicenses
%dir %{_texmfdistdir}/doc/latex/ccool
%dir %{_texmfdistdir}/doc/latex/cd
%dir %{_texmfdistdir}/doc/latex/cd-cover
%dir %{_texmfdistdir}/doc/latex/cdcmd
%dir %{_texmfdistdir}/doc/latex/cdpbundl
%dir %{_texmfdistdir}/doc/latex/cell
%dir %{_texmfdistdir}/doc/latex/cellprops
%dir %{_texmfdistdir}/doc/latex/cellspace
%dir %{_texmfdistdir}/doc/latex/celtic
%dir %{_texmfdistdir}/doc/latex/censor
%dir %{_texmfdistdir}/doc/latex/centeredline
%dir %{_texmfdistdir}/doc/latex/centerlastline
%dir %{_texmfdistdir}/doc/latex/cesenaexam
%dir %{_texmfdistdir}/doc/latex/cfr-initials
%dir %{_texmfdistdir}/doc/latex/changebar
%dir %{_texmfdistdir}/doc/latex/changelayout
%dir %{_texmfdistdir}/doc/latex/changelog
%dir %{_texmfdistdir}/doc/latex/changepage
%dir %{_texmfdistdir}/doc/latex/changes
%dir %{_texmfdistdir}/doc/latex/changes/examples
%dir %{_texmfdistdir}/doc/latex/changes/regression
%dir %{_texmfdistdir}/doc/latex/changes/userdoc
%dir %{_texmfdistdir}/doc/latex/chappg
%dir %{_texmfdistdir}/doc/latex/chapterfolder
%dir %{_texmfdistdir}/doc/latex/chbibref
%dir %{_texmfdistdir}/doc/latex/cheatsheet
%dir %{_texmfdistdir}/doc/latex/checkend
%dir %{_texmfdistdir}/doc/latex/checklistings
%dir %{_texmfdistdir}/doc/latex/chembst
%dir %{_texmfdistdir}/doc/latex/chemcompounds
%dir %{_texmfdistdir}/doc/latex/chemcono
%dir %{_texmfdistdir}/doc/latex/chemexec
%dir %{_texmfdistdir}/doc/latex/chemformula
%dir %{_texmfdistdir}/doc/latex/chemgreek
%dir %{_texmfdistdir}/doc/latex/chemmacros
%dir %{_texmfdistdir}/doc/latex/chemnum
%dir %{_texmfdistdir}/doc/latex/chemobabel
%dir %{_texmfdistdir}/doc/latex/chemplants
%dir %{_texmfdistdir}/doc/latex/chemschemex
%dir %{_texmfdistdir}/doc/latex/chemsec
%dir %{_texmfdistdir}/doc/latex/chemstyle
%dir %{_texmfdistdir}/doc/latex/chess-problem-diagrams
%dir %{_texmfdistdir}/doc/latex/chessboard
%dir %{_texmfdistdir}/doc/latex/chessfss
%dir %{_texmfdistdir}/doc/latex/chet
%dir %{_texmfdistdir}/doc/latex/chextras
%dir %{_texmfdistdir}/doc/latex/chhaya
%dir %{_texmfdistdir}/doc/latex/chifoot
%dir %{_texmfdistdir}/doc/latex/childdoc
%dir %{_texmfdistdir}/doc/latex/chinesechess
%dir %{_texmfdistdir}/doc/latex/chkfloat
%dir %{_texmfdistdir}/doc/latex/chletter
%dir %{_texmfdistdir}/doc/latex/chngcntr
%dir %{_texmfdistdir}/doc/latex/chordbars
%dir %{_texmfdistdir}/doc/latex/chordbox
%dir %{_texmfdistdir}/doc/latex/chronology
%dir %{_texmfdistdir}/doc/latex/chs-physics-report
%dir %{_texmfdistdir}/doc/latex/chscite
%dir %{_texmfdistdir}/doc/latex/churchslavonic
%dir %{_texmfdistdir}/doc/latex/circ
%dir %{_texmfdistdir}/doc/latex/circledsteps
%dir %{_texmfdistdir}/doc/latex/circledtext
%dir %{_texmfdistdir}/doc/latex/circuit-macros
%dir %{_texmfdistdir}/doc/latex/circuit-macros/doc
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/dpv
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/extras
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/mf
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/mpost
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/psfrag
%dir %{_texmfdistdir}/doc/latex/circuit-macros/examples/xfig
%dir %{_texmfdistdir}/doc/latex/circuitikz
%dir %{_texmfdistdir}/doc/latex/citation-style-language
%dir %{_texmfdistdir}/doc/latex/cite
%dir %{_texmfdistdir}/doc/latex/citeall
%dir %{_texmfdistdir}/doc/latex/citeref
%dir %{_texmfdistdir}/doc/latex/cje
%dir %{_texmfdistdir}/doc/latex/cjhebrew
%dir %{_texmfdistdir}/doc/latex/cjk
%dir %{_texmfdistdir}/doc/latex/cjk-ko
%dir %{_texmfdistdir}/doc/latex/cjk/doc
%dir %{_texmfdistdir}/doc/latex/cjk/doc/chinese
%dir %{_texmfdistdir}/doc/latex/cjk/doc/cjk
%dir %{_texmfdistdir}/doc/latex/cjk/doc/japanese
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdf
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/Bg5
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/GB
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/JIS
%dir %{_texmfdistdir}/doc/latex/cjk/doc/pdfhowto/examples/texinput/SJIS
%dir %{_texmfdistdir}/doc/latex/cjk/examples
%dir %{_texmfdistdir}/doc/latex/cjk/examples/cjk
%dir %{_texmfdistdir}/doc/latex/cjk/examples/pdf
%dir %{_texmfdistdir}/doc/latex/cjk/texlive
%dir %{_texmfdistdir}/doc/latex/cjk/utils
%dir %{_texmfdistdir}/doc/latex/cjk/utils/pyhyphen
%dir %{_texmfdistdir}/doc/latex/cjkpunct
%dir %{_texmfdistdir}/doc/latex/cjkpunct/examples
%dir %{_texmfdistdir}/doc/latex/cjkpunct/setpunct
%dir %{_texmfdistdir}/doc/latex/classics
%dir %{_texmfdistdir}/doc/latex/classicthesis
%dir %{_texmfdistdir}/doc/latex/classicthesis/Chapters
%dir %{_texmfdistdir}/doc/latex/classicthesis/Examples
%dir %{_texmfdistdir}/doc/latex/classicthesis/FrontBackmatter
%dir %{_texmfdistdir}/doc/latex/classicthesis/gfx
%dir %{_texmfdistdir}/doc/latex/cleanthesis
%dir %{_texmfdistdir}/doc/latex/cleanthesis/content
%dir %{_texmfdistdir}/doc/latex/cleanthesis/doc
%dir %{_texmfdistdir}/doc/latex/cleanthesis/gfx
%dir %{_texmfdistdir}/doc/latex/clefval
%dir %{_texmfdistdir}/doc/latex/cleveref
%dir %{_texmfdistdir}/doc/latex/clicks
%dir %{_texmfdistdir}/doc/latex/clipboard
%dir %{_texmfdistdir}/doc/latex/clistmap
%dir %{_texmfdistdir}/doc/latex/clock
%dir %{_texmfdistdir}/doc/latex/clrdblpg
%dir %{_texmfdistdir}/doc/latex/clrscode
%dir %{_texmfdistdir}/doc/latex/clrscode3e
%dir %{_texmfdistdir}/doc/latex/clrstrip
%dir %{_texmfdistdir}/doc/latex/cmap
%dir %{_texmfdistdir}/doc/latex/cmbright
%dir %{_texmfdistdir}/doc/latex/cmdstring
%dir %{_texmfdistdir}/doc/latex/cmdtrack
%dir %{_texmfdistdir}/doc/latex/cmpica
%dir %{_texmfdistdir}/doc/latex/cmpj
%dir %{_texmfdistdir}/doc/latex/cmsd
%dir %{_texmfdistdir}/doc/latex/cmtiup
%dir %{_texmfdistdir}/doc/latex/cnbwp
%dir %{_texmfdistdir}/doc/latex/cnltx
%dir %{_texmfdistdir}/doc/latex/cntformats
%dir %{_texmfdistdir}/doc/latex/cntperchap
%dir %{_texmfdistdir}/doc/latex/codeanatomy
%dir %{_texmfdistdir}/doc/latex/codebox
%dir %{_texmfdistdir}/doc/latex/codedoc
%dir %{_texmfdistdir}/doc/latex/codehigh
%dir %{_texmfdistdir}/doc/latex/codepage
%dir %{_texmfdistdir}/doc/latex/codesection
%dir %{_texmfdistdir}/doc/latex/codicefiscaleitaliano
%dir %{_texmfdistdir}/doc/latex/coffeestains
%dir %{_texmfdistdir}/doc/latex/collcell
%dir %{_texmfdistdir}/doc/latex/collectbox
%dir %{_texmfdistdir}/doc/latex/collref
%dir %{_texmfdistdir}/doc/latex/colophon
%dir %{_texmfdistdir}/doc/latex/color-edits
%dir %{_texmfdistdir}/doc/latex/colordoc
%dir %{_texmfdistdir}/doc/latex/colorframed
%dir %{_texmfdistdir}/doc/latex/colorinfo
%dir %{_texmfdistdir}/doc/latex/coloring
%dir %{_texmfdistdir}/doc/latex/colorist
%dir %{_texmfdistdir}/doc/latex/colorspace
%dir %{_texmfdistdir}/doc/latex/colortbl
%dir %{_texmfdistdir}/doc/latex/colorwav
%dir %{_texmfdistdir}/doc/latex/colorweb
%dir %{_texmfdistdir}/doc/latex/colourchange
%dir %{_texmfdistdir}/doc/latex/combelow
%dir %{_texmfdistdir}/doc/latex/combine
%dir %{_texmfdistdir}/doc/latex/combinedgraphics
%dir %{_texmfdistdir}/doc/latex/combinedgraphics/test
%dir %{_texmfdistdir}/doc/latex/comicneue
%dir %{_texmfdistdir}/doc/latex/comma
%dir %{_texmfdistdir}/doc/latex/commath
%dir %{_texmfdistdir}/doc/latex/commedit
%dir %{_texmfdistdir}/doc/latex/comment
%dir %{_texmfdistdir}/doc/latex/commonunicode
%dir %{_texmfdistdir}/doc/latex/competences
%dir %{_texmfdistdir}/doc/latex/complexity
%dir %{_texmfdistdir}/doc/latex/comprehensive
%dir %{_texmfdistdir}/doc/latex/comprehensive/source
%dir %{_texmfdistdir}/doc/latex/computational-complexity
%dir %{_texmfdistdir}/doc/latex/concepts
%dir %{_texmfdistdir}/doc/latex/concprog
%dir %{_texmfdistdir}/doc/latex/conditext
%dir %{_texmfdistdir}/doc/latex/conditext/conditext-examples
%dir %{_texmfdistdir}/doc/latex/confproc
%dir %{_texmfdistdir}/doc/latex/confproc/example
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_001
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_003
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_005
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_pdftex/p_007
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_tex
%dir %{_texmfdistdir}/doc/latex/confproc/example/papers/sources_tex/p_009
%dir %{_texmfdistdir}/doc/latex/confproc/example/pictures
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_001
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_003
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_005
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_pdftex/p_007
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_tex
%dir %{_texmfdistdir}/doc/latex/confproc/example/sources_tex/p_009
%dir %{_texmfdistdir}/doc/latex/constants
%dir %{_texmfdistdir}/doc/latex/conteq
%dir %{_texmfdistdir}/doc/latex/continue
%dir %{_texmfdistdir}/doc/latex/contour
%dir %{_texmfdistdir}/doc/latex/contracard
%dir %{_texmfdistdir}/doc/latex/conv-xkv
%dir %{_texmfdistdir}/doc/latex/conv-xkv/doc
%dir %{_texmfdistdir}/doc/latex/conv-xkv/examples
%dir %{_texmfdistdir}/doc/latex/cooking
%dir %{_texmfdistdir}/doc/latex/cooking-units
%dir %{_texmfdistdir}/doc/latex/cookingsymbols
%dir %{_texmfdistdir}/doc/latex/cool
%dir %{_texmfdistdir}/doc/latex/coolfn
%dir %{_texmfdistdir}/doc/latex/coollist
%dir %{_texmfdistdir}/doc/latex/coolstr
%dir %{_texmfdistdir}/doc/latex/coolthms
%dir %{_texmfdistdir}/doc/latex/cooltooltips
%dir %{_texmfdistdir}/doc/latex/coop-writing
%dir %{_texmfdistdir}/doc/latex/coordsys
%dir %{_texmfdistdir}/doc/latex/copyedit
%dir %{_texmfdistdir}/doc/latex/copyedit/example
%dir %{_texmfdistdir}/doc/latex/copyrightbox
%dir %{_texmfdistdir}/doc/latex/correctmathalign
%dir %{_texmfdistdir}/doc/latex/coseoul
%dir %{_texmfdistdir}/doc/latex/counttexruns
%dir %{_texmfdistdir}/doc/latex/courseoutline
%dir %{_texmfdistdir}/doc/latex/coursepaper
%dir %{_texmfdistdir}/doc/latex/coverpage
%dir %{_texmfdistdir}/doc/latex/covington
%dir %{_texmfdistdir}/doc/latex/cprotect
%dir %{_texmfdistdir}/doc/latex/cprotectinside
%dir %{_texmfdistdir}/doc/latex/cquthesis
%dir %{_texmfdistdir}/doc/latex/cquthesis/contents
%dir %{_texmfdistdir}/doc/latex/cquthesis/figures
%dir %{_texmfdistdir}/doc/latex/cquthesis/ref
%dir %{_texmfdistdir}/doc/latex/crbox
%dir %{_texmfdistdir}/doc/latex/create-theorem
%dir %{_texmfdistdir}/doc/latex/crefthe
%dir %{_texmfdistdir}/doc/latex/crop
%dir %{_texmfdistdir}/doc/latex/crossreference
%dir %{_texmfdistdir}/doc/latex/crossreftools
%dir %{_texmfdistdir}/doc/latex/crossword
%dir %{_texmfdistdir}/doc/latex/crosswrd
%dir %{_texmfdistdir}/doc/latex/crumbs
%dir %{_texmfdistdir}/doc/latex/cryptocode
%dir %{_texmfdistdir}/doc/latex/cryst
%dir %{_texmfdistdir}/doc/latex/csassignments
%dir %{_texmfdistdir}/doc/latex/csbulletin
%dir %{_texmfdistdir}/doc/latex/csquotes
%dir %{_texmfdistdir}/doc/latex/csquotes-de
%dir %{_texmfdistdir}/doc/latex/css-colors
%dir %{_texmfdistdir}/doc/latex/csvmerge
%dir %{_texmfdistdir}/doc/latex/csvsimple
%dir %{_texmfdistdir}/doc/latex/ctable
%dir %{_texmfdistdir}/doc/latex/ctanify
%dir %{_texmfdistdir}/doc/latex/ctex
%dir %{_texmfdistdir}/doc/latex/ctex-faq
%dir %{_texmfdistdir}/doc/latex/ctex-faq/src
%dir %{_texmfdistdir}/doc/latex/ctib
%dir %{_texmfdistdir}/doc/latex/cuisine
%dir %{_texmfdistdir}/doc/latex/currency
%dir %{_texmfdistdir}/doc/latex/currfile
%dir %{_texmfdistdir}/doc/latex/currvita
%dir %{_texmfdistdir}/doc/latex/cursolatex
%dir %{_texmfdistdir}/doc/latex/curve
%dir %{_texmfdistdir}/doc/latex/curve/examples
%dir %{_texmfdistdir}/doc/latex/curve2e
%dir %{_texmfdistdir}/doc/latex/curves
%dir %{_texmfdistdir}/doc/latex/custom-bib
%dir %{_texmfdistdir}/doc/latex/customdice
%dir %{_texmfdistdir}/doc/latex/cutwin
%dir %{_texmfdistdir}/doc/latex/cv
%dir %{_texmfdistdir}/doc/latex/cv4tw
%dir %{_texmfdistdir}/doc/latex/cvss
%dir %{_texmfdistdir}/doc/latex/cweb-latex
%dir %{_texmfdistdir}/doc/latex/cweb-latex/contrib
%dir %{_texmfdistdir}/doc/latex/cweb-latex/contrib/cweb-hy
%dir %{_texmfdistdir}/doc/latex/cweb-latex/contrib/wagner
%dir %{_texmfdistdir}/doc/latex/cweb-latex/examples
%dir %{_texmfdistdir}/doc/latex/cweb-latex/examples/compare
%dir %{_texmfdistdir}/doc/latex/cweb-latex/src
%dir %{_texmfdistdir}/doc/latex/cweb-latex/src/style
%dir %{_texmfdistdir}/doc/latex/cweb-latex/src/test
%dir %{_texmfdistdir}/doc/latex/cyber
%dir %{_texmfdistdir}/doc/latex/cybercic
%dir %{_texmfdistdir}/doc/latex/cyrillic
%dir %{_texmfdistdir}/doc/latex/darkmode
%dir %{_texmfdistdir}/doc/latex/dashbox
%dir %{_texmfdistdir}/doc/latex/dashrule
%dir %{_texmfdistdir}/doc/latex/dashundergaps
%dir %{_texmfdistdir}/doc/latex/dataref
%dir %{_texmfdistdir}/doc/latex/datatool
%dir %{_texmfdistdir}/doc/latex/datatool/samples
%dir %{_texmfdistdir}/doc/latex/datax
%dir %{_texmfdistdir}/doc/latex/dateiliste
%dir %{_texmfdistdir}/doc/latex/datenumber
%dir %{_texmfdistdir}/doc/latex/datetime
%dir %{_texmfdistdir}/doc/latex/datetime/samples
%dir %{_texmfdistdir}/doc/latex/datetime2
%dir %{_texmfdistdir}/doc/latex/datetime2-bahasai
%dir %{_texmfdistdir}/doc/latex/datetime2-basque
%dir %{_texmfdistdir}/doc/latex/datetime2-breton
%dir %{_texmfdistdir}/doc/latex/datetime2-bulgarian
%dir %{_texmfdistdir}/doc/latex/datetime2-catalan
%dir %{_texmfdistdir}/doc/latex/datetime2-croatian
%dir %{_texmfdistdir}/doc/latex/datetime2-czech
%dir %{_texmfdistdir}/doc/latex/datetime2-danish
%dir %{_texmfdistdir}/doc/latex/datetime2-dutch
%dir %{_texmfdistdir}/doc/latex/datetime2-en-fulltext
%dir %{_texmfdistdir}/doc/latex/datetime2-english
%dir %{_texmfdistdir}/doc/latex/datetime2-esperanto
%dir %{_texmfdistdir}/doc/latex/datetime2-estonian
%dir %{_texmfdistdir}/doc/latex/datetime2-finnish
%dir %{_texmfdistdir}/doc/latex/datetime2-french
%dir %{_texmfdistdir}/doc/latex/datetime2-galician
%dir %{_texmfdistdir}/doc/latex/datetime2-german
%dir %{_texmfdistdir}/doc/latex/datetime2-greek
%dir %{_texmfdistdir}/doc/latex/datetime2-hebrew
%dir %{_texmfdistdir}/doc/latex/datetime2-icelandic
%dir %{_texmfdistdir}/doc/latex/datetime2-irish
%dir %{_texmfdistdir}/doc/latex/datetime2-it-fulltext
%dir %{_texmfdistdir}/doc/latex/datetime2-it-fulltext/samples
%dir %{_texmfdistdir}/doc/latex/datetime2-italian
%dir %{_texmfdistdir}/doc/latex/datetime2-italian/sample
%dir %{_texmfdistdir}/doc/latex/datetime2-latin
%dir %{_texmfdistdir}/doc/latex/datetime2-lsorbian
%dir %{_texmfdistdir}/doc/latex/datetime2-magyar
%dir %{_texmfdistdir}/doc/latex/datetime2-norsk
%dir %{_texmfdistdir}/doc/latex/datetime2-polish
%dir %{_texmfdistdir}/doc/latex/datetime2-portuges
%dir %{_texmfdistdir}/doc/latex/datetime2-romanian
%dir %{_texmfdistdir}/doc/latex/datetime2-russian
%dir %{_texmfdistdir}/doc/latex/datetime2-samin
%dir %{_texmfdistdir}/doc/latex/datetime2-scottish
%dir %{_texmfdistdir}/doc/latex/datetime2-serbian
%dir %{_texmfdistdir}/doc/latex/datetime2-slovak
%dir %{_texmfdistdir}/doc/latex/datetime2-slovene
%dir %{_texmfdistdir}/doc/latex/datetime2-spanish
%dir %{_texmfdistdir}/doc/latex/datetime2-swedish
%dir %{_texmfdistdir}/doc/latex/datetime2-turkish
%dir %{_texmfdistdir}/doc/latex/datetime2-ukrainian
%dir %{_texmfdistdir}/doc/latex/datetime2-usorbian
%dir %{_texmfdistdir}/doc/latex/datetime2-welsh
%dir %{_texmfdistdir}/doc/latex/datetime2/samples
%dir %{_texmfdistdir}/doc/latex/dblfloatfix
%dir %{_texmfdistdir}/doc/latex/dbshow
%dir %{_texmfdistdir}/doc/latex/dccpaper
%dir %{_texmfdistdir}/doc/latex/ddphonism
%dir %{_texmfdistdir}/doc/latex/debate
%dir %{_texmfdistdir}/doc/latex/decimal
%dir %{_texmfdistdir}/doc/latex/decision-table
%dir %{_texmfdistdir}/doc/latex/decorule
%dir %{_texmfdistdir}/doc/latex/delim
%dir %{_texmfdistdir}/doc/latex/delimseasy
%dir %{_texmfdistdir}/doc/latex/delimset
%dir %{_texmfdistdir}/doc/latex/delimtxt
%dir %{_texmfdistdir}/doc/latex/democodetools
%dir %{_texmfdistdir}/doc/latex/denisbdoc
%dir %{_texmfdistdir}/doc/latex/derivative
%dir %{_texmfdistdir}/doc/latex/dhua
%dir %{_texmfdistdir}/doc/latex/diabetes-logbook
%dir %{_texmfdistdir}/doc/latex/diabetes-logbook/QQ
%dir %{_texmfdistdir}/doc/latex/diabetes-logbook/QQ/TEST
%dir %{_texmfdistdir}/doc/latex/diadia
%dir %{_texmfdistdir}/doc/latex/diagbox
%dir %{_texmfdistdir}/doc/latex/diagmac2
%dir %{_texmfdistdir}/doc/latex/diagmac2/doc
%dir %{_texmfdistdir}/doc/latex/diagnose
%dir %{_texmfdistdir}/doc/latex/dialogl
%dir %{_texmfdistdir}/doc/latex/dichokey
%dir %{_texmfdistdir}/doc/latex/dickimaw
%dir %{_texmfdistdir}/doc/latex/dickimaw/src
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/minexample
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/novices
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/novices/pictures
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/novices/term-defs
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/thesis
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/thesis/imgsource
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/thesis/listing-samples
%dir %{_texmfdistdir}/doc/latex/dickimaw/src/thesis/pictures
%dir %{_texmfdistdir}/doc/latex/diffcoeff
%dir %{_texmfdistdir}/doc/latex/digiconfigs
%dir %{_texmfdistdir}/doc/latex/dijkstra
%dir %{_texmfdistdir}/doc/latex/dimnum
%dir %{_texmfdistdir}/doc/latex/din1505
%dir %{_texmfdistdir}/doc/latex/dinbrief
%dir %{_texmfdistdir}/doc/latex/directory
%dir %{_texmfdistdir}/doc/latex/dirtytalk
%dir %{_texmfdistdir}/doc/latex/disser
%dir %{_texmfdistdir}/doc/latex/disser/include
%dir %{_texmfdistdir}/doc/latex/disser/templates
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/bachelor
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/bachelor/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/candidate
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/candidate/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/doctor
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/doctor/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/master
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/master/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/specialist
%dir %{_texmfdistdir}/doc/latex/disser/templates-utf8/specialist/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates/bachelor
%dir %{_texmfdistdir}/doc/latex/disser/templates/bachelor/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates/candidate
%dir %{_texmfdistdir}/doc/latex/disser/templates/candidate/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates/doctor
%dir %{_texmfdistdir}/doc/latex/disser/templates/doctor/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates/master
%dir %{_texmfdistdir}/doc/latex/disser/templates/master/fig
%dir %{_texmfdistdir}/doc/latex/disser/templates/specialist
%dir %{_texmfdistdir}/doc/latex/disser/templates/specialist/fig
%dir %{_texmfdistdir}/doc/latex/ditaa
%dir %{_texmfdistdir}/doc/latex/ditaa/resources
%dir %{_texmfdistdir}/doc/latex/ditaa/resources/ditaa
%dir %{_texmfdistdir}/doc/latex/dithesis
%dir %{_texmfdistdir}/doc/latex/dk-bib
%dir %{_texmfdistdir}/doc/latex/dlfltxb
%dir %{_texmfdistdir}/doc/latex/dnaseq
%dir %{_texmfdistdir}/doc/latex/doclicense
%dir %{_texmfdistdir}/doc/latex/docmfp
%dir %{_texmfdistdir}/doc/latex/docmute
%dir %{_texmfdistdir}/doc/latex/docshots
%dir %{_texmfdistdir}/doc/latex/docsurvey
%dir %{_texmfdistdir}/doc/latex/doctools
%dir %{_texmfdistdir}/doc/latex/documentation
%dir %{_texmfdistdir}/doc/latex/docutils
%dir %{_texmfdistdir}/doc/latex/doi
%dir %{_texmfdistdir}/doc/latex/doipubmed
%dir %{_texmfdistdir}/doc/latex/dot2texi
%dir %{_texmfdistdir}/doc/latex/dot2texi/examples
%dir %{_texmfdistdir}/doc/latex/dotarrow
%dir %{_texmfdistdir}/doc/latex/dotlessi
%dir %{_texmfdistdir}/doc/latex/dotseqn
%dir %{_texmfdistdir}/doc/latex/dottex
%dir %{_texmfdistdir}/doc/latex/download
%dir %{_texmfdistdir}/doc/latex/dox
%dir %{_texmfdistdir}/doc/latex/dpcircling
%dir %{_texmfdistdir}/doc/latex/dpfloat
%dir %{_texmfdistdir}/doc/latex/dprogress
%dir %{_texmfdistdir}/doc/latex/drac
%dir %{_texmfdistdir}/doc/latex/draftcopy
%dir %{_texmfdistdir}/doc/latex/draftfigure
%dir %{_texmfdistdir}/doc/latex/draftwatermark
%dir %{_texmfdistdir}/doc/latex/dramatist
%dir %{_texmfdistdir}/doc/latex/drawmatrix
%dir %{_texmfdistdir}/doc/latex/drawstack
%dir %{_texmfdistdir}/doc/latex/droit-fr
%dir %{_texmfdistdir}/doc/latex/droit-fr/example
%dir %{_texmfdistdir}/doc/latex/drs
%dir %{_texmfdistdir}/doc/latex/dsptricks
%dir %{_texmfdistdir}/doc/latex/dtk
%dir %{_texmfdistdir}/doc/latex/dtk/doc
%dir %{_texmfdistdir}/doc/latex/dtxdescribe
%dir %{_texmfdistdir}/doc/latex/dtxgallery
%dir %{_texmfdistdir}/doc/latex/dtxtut
%dir %{_texmfdistdir}/doc/latex/ducksay
%dir %{_texmfdistdir}/doc/latex/duckuments
%dir %{_texmfdistdir}/doc/latex/duerer-latex
%dir %{_texmfdistdir}/doc/latex/duotenzor
%dir %{_texmfdistdir}/doc/latex/dvdcoll
%dir %{_texmfdistdir}/doc/latex/dvgloss
%dir %{_texmfdistdir}/doc/latex/dviasm
%dir %{_texmfdistdir}/doc/latex/dviinfox
%dir %{_texmfdistdir}/doc/latex/dynamicnumber
%dir %{_texmfdistdir}/doc/latex/dynblocks
%dir %{_texmfdistdir}/doc/latex/dynblocks/images
%dir %{_texmfdistdir}/doc/latex/dynkin-diagrams
%dir %{_texmfdistdir}/doc/latex/dyntree
%dir %{_texmfdistdir}/doc/latex/ean13isbn
%dir %{_texmfdistdir}/doc/latex/easing
%dir %{_texmfdistdir}/doc/latex/easy
%dir %{_texmfdistdir}/doc/latex/easy-todo
%dir %{_texmfdistdir}/doc/latex/easy/for-latex2html
%dir %{_texmfdistdir}/doc/latex/easybook
%dir %{_texmfdistdir}/doc/latex/easyfig
%dir %{_texmfdistdir}/doc/latex/easyfloats
%dir %{_texmfdistdir}/doc/latex/easyfloats/content
%dir %{_texmfdistdir}/doc/latex/easyfloats/lexer
%dir %{_texmfdistdir}/doc/latex/easyfloats/preamble
%dir %{_texmfdistdir}/doc/latex/easyformat
%dir %{_texmfdistdir}/doc/latex/easylist
%dir %{_texmfdistdir}/doc/latex/easyreview
%dir %{_texmfdistdir}/doc/latex/easyreview/doc
%dir %{_texmfdistdir}/doc/latex/ebezier
%dir %{_texmfdistdir}/doc/latex/ebook
%dir %{_texmfdistdir}/doc/latex/ebproof
%dir %{_texmfdistdir}/doc/latex/ebsthesis
%dir %{_texmfdistdir}/doc/latex/ecclesiastic
%dir %{_texmfdistdir}/doc/latex/ecgdraw
%dir %{_texmfdistdir}/doc/latex/ecltree
%dir %{_texmfdistdir}/doc/latex/ecobiblatex
%dir %{_texmfdistdir}/doc/latex/econlipsum
%dir %{_texmfdistdir}/doc/latex/econometrics
%dir %{_texmfdistdir}/doc/latex/ecothesis
%dir %{_texmfdistdir}/doc/latex/ecothesis/capitulos
%dir %{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap01
%dir %{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap02
%dir %{_texmfdistdir}/doc/latex/ecothesis/capitulos/cap03
%dir %{_texmfdistdir}/doc/latex/ecothesis/preambulo
%dir %{_texmfdistdir}/doc/latex/ecv
%dir %{_texmfdistdir}/doc/latex/ecv/template
%dir %{_texmfdistdir}/doc/latex/ed
%dir %{_texmfdistdir}/doc/latex/edfnotes
%dir %{_texmfdistdir}/doc/latex/edichokey
%dir %{_texmfdistdir}/doc/latex/edmac
%dir %{_texmfdistdir}/doc/latex/edmargin
%dir %{_texmfdistdir}/doc/latex/eemeir
%dir %{_texmfdistdir}/doc/latex/eepic
%dir %{_texmfdistdir}/doc/latex/eepic/fig2eepic
%dir %{_texmfdistdir}/doc/latex/efbox
%dir %{_texmfdistdir}/doc/latex/egameps
%dir %{_texmfdistdir}/doc/latex/egplot
%dir %{_texmfdistdir}/doc/latex/ehhline
%dir %{_texmfdistdir}/doc/latex/eiad-ltx
%dir %{_texmfdistdir}/doc/latex/einfart
%dir %{_texmfdistdir}/doc/latex/ejpecp
%dir %{_texmfdistdir}/doc/latex/ekaia
%dir %{_texmfdistdir}/doc/latex/elbioimp
%dir %{_texmfdistdir}/doc/latex/eledform
%dir %{_texmfdistdir}/doc/latex/eledform/include
%dir %{_texmfdistdir}/doc/latex/eledmac
%dir %{_texmfdistdir}/doc/latex/eledmac/examples
%dir %{_texmfdistdir}/doc/latex/elements
%dir %{_texmfdistdir}/doc/latex/ellipse
%dir %{_texmfdistdir}/doc/latex/ellipsis
%dir %{_texmfdistdir}/doc/latex/elmath
%dir %{_texmfdistdir}/doc/latex/elocalloc
%dir %{_texmfdistdir}/doc/latex/elpres
%dir %{_texmfdistdir}/doc/latex/els-cas-templates
%dir %{_texmfdistdir}/doc/latex/els-cas-templates/doc
%dir %{_texmfdistdir}/doc/latex/elsarticle
%dir %{_texmfdistdir}/doc/latex/elteikthesis
%dir %{_texmfdistdir}/doc/latex/elteikthesis/images
%dir %{_texmfdistdir}/doc/latex/elteikthesis/samples_en
%dir %{_texmfdistdir}/doc/latex/elteikthesis/samples_hu
%dir %{_texmfdistdir}/doc/latex/eltex
%dir %{_texmfdistdir}/doc/latex/elzcards
%dir %{_texmfdistdir}/doc/latex/emarks
%dir %{_texmfdistdir}/doc/latex/embedall
%dir %{_texmfdistdir}/doc/latex/embedfile
%dir %{_texmfdistdir}/doc/latex/embrac
%dir %{_texmfdistdir}/doc/latex/emf
%dir %{_texmfdistdir}/doc/latex/emisa
%dir %{_texmfdistdir}/doc/latex/emoji
%dir %{_texmfdistdir}/doc/latex/emp
%dir %{_texmfdistdir}/doc/latex/emptypage
%dir %{_texmfdistdir}/doc/latex/emulateapj
%dir %{_texmfdistdir}/doc/latex/endfloat
%dir %{_texmfdistdir}/doc/latex/endheads
%dir %{_texmfdistdir}/doc/latex/endiagram
%dir %{_texmfdistdir}/doc/latex/endnotes
%dir %{_texmfdistdir}/doc/latex/endnotes-hy
%dir %{_texmfdistdir}/doc/latex/endnotes-hy/docs
%dir %{_texmfdistdir}/doc/latex/endnotes-hy/examples
%dir %{_texmfdistdir}/doc/latex/endnotesj
%dir %{_texmfdistdir}/doc/latex/endofproofwd
%dir %{_texmfdistdir}/doc/latex/engpron
%dir %{_texmfdistdir}/doc/latex/engrec
%dir %{_texmfdistdir}/doc/latex/engtlc
%dir %{_texmfdistdir}/doc/latex/enotez
%dir %{_texmfdistdir}/doc/latex/enumitem
%dir %{_texmfdistdir}/doc/latex/enumitem-zref
%dir %{_texmfdistdir}/doc/latex/envbig
%dir %{_texmfdistdir}/doc/latex/environ
%dir %{_texmfdistdir}/doc/latex/envlab
%dir %{_texmfdistdir}/doc/latex/eolang
%dir %{_texmfdistdir}/doc/latex/epigraph
%dir %{_texmfdistdir}/doc/latex/epigraph-keys
%dir %{_texmfdistdir}/doc/latex/epiolmec
%dir %{_texmfdistdir}/doc/latex/epsdice
%dir %{_texmfdistdir}/doc/latex/epslatex-fr
%dir %{_texmfdistdir}/doc/latex/epspdfconversion
%dir %{_texmfdistdir}/doc/latex/epspdfconversion/example
%dir %{_texmfdistdir}/doc/latex/epstopdf-pkg
%dir %{_texmfdistdir}/doc/latex/eq-pin2corr
%dir %{_texmfdistdir}/doc/latex/eq-pin2corr/doc
%dir %{_texmfdistdir}/doc/latex/eq-pin2corr/examples
%dir %{_texmfdistdir}/doc/latex/eqell
%dir %{_texmfdistdir}/doc/latex/eqexpl
%dir %{_texmfdistdir}/doc/latex/eqlist
%dir %{_texmfdistdir}/doc/latex/eqnalign
%dir %{_texmfdistdir}/doc/latex/eqnarray
%dir %{_texmfdistdir}/doc/latex/eqnnumwarn
%dir %{_texmfdistdir}/doc/latex/eqparbox
%dir %{_texmfdistdir}/doc/latex/erdc
%dir %{_texmfdistdir}/doc/latex/errata
%dir %{_texmfdistdir}/doc/latex/erw-l3
%dir %{_texmfdistdir}/doc/latex/esami
%dir %{_texmfdistdir}/doc/latex/esami/doc
%dir %{_texmfdistdir}/doc/latex/esami/doc/examples
%dir %{_texmfdistdir}/doc/latex/esdiff
%dir %{_texmfdistdir}/doc/latex/esieecv
%dir %{_texmfdistdir}/doc/latex/esindex
%dir %{_texmfdistdir}/doc/latex/esint
%dir %{_texmfdistdir}/doc/latex/esk
%dir %{_texmfdistdir}/doc/latex/eskd
%dir %{_texmfdistdir}/doc/latex/eskdx
%dir %{_texmfdistdir}/doc/latex/eskdx/manual
%dir %{_texmfdistdir}/doc/latex/eskdx/source
%dir %{_texmfdistdir}/doc/latex/eskdx/test
%dir %{_texmfdistdir}/doc/latex/eso-pic
%dir %{_texmfdistdir}/doc/latex/estcpmm
%dir %{_texmfdistdir}/doc/latex/esvect
%dir %{_texmfdistdir}/doc/latex/etaremune
%dir %{_texmfdistdir}/doc/latex/etdipa
%dir %{_texmfdistdir}/doc/latex/etdipa/Data
%dir %{_texmfdistdir}/doc/latex/etdipa/Help
%dir %{_texmfdistdir}/doc/latex/etdipa/Images
%dir %{_texmfdistdir}/doc/latex/etdipa/Textparts
%dir %{_texmfdistdir}/doc/latex/etex-pkg
%dir %{_texmfdistdir}/doc/latex/etexcmds
%dir %{_texmfdistdir}/doc/latex/etextools
%dir %{_texmfdistdir}/doc/latex/ethiop
%dir %{_texmfdistdir}/doc/latex/ethiop-t1
%dir %{_texmfdistdir}/doc/latex/etl
%dir %{_texmfdistdir}/doc/latex/etoc
%dir %{_texmfdistdir}/doc/latex/etoolbox
%dir %{_texmfdistdir}/doc/latex/etoolbox-de
%dir %{_texmfdistdir}/doc/latex/etsvthor
%dir %{_texmfdistdir}/doc/latex/euclideangeometry
%dir %{_texmfdistdir}/doc/latex/euenc
%dir %{_texmfdistdir}/doc/latex/euflag
%dir %{_texmfdistdir}/doc/latex/eukdate
%dir %{_texmfdistdir}/doc/latex/euler
%dir %{_texmfdistdir}/doc/latex/eulervm
%dir %{_texmfdistdir}/doc/latex/euro
%dir %{_texmfdistdir}/doc/latex/europasscv
%dir %{_texmfdistdir}/doc/latex/europasscv/example
%dir %{_texmfdistdir}/doc/latex/europecv
%dir %{_texmfdistdir}/doc/latex/europecv/examples
%dir %{_texmfdistdir}/doc/latex/europecv/templates
%dir %{_texmfdistdir}/doc/latex/everyhook
%dir %{_texmfdistdir}/doc/latex/everypage
%dir %{_texmfdistdir}/doc/latex/everysel
%dir %{_texmfdistdir}/doc/latex/everyshi
%dir %{_texmfdistdir}/doc/latex/exam
%dir %{_texmfdistdir}/doc/latex/exam-lite
%dir %{_texmfdistdir}/doc/latex/exam-lite/imgs
%dir %{_texmfdistdir}/doc/latex/exam-n
%dir %{_texmfdistdir}/doc/latex/exam-n/sample
%dir %{_texmfdistdir}/doc/latex/exam-n/sample/fig
%dir %{_texmfdistdir}/doc/latex/exam-randomizechoices
%dir %{_texmfdistdir}/doc/latex/examdesign
%dir %{_texmfdistdir}/doc/latex/examplep
%dir %{_texmfdistdir}/doc/latex/exceltex
%dir %{_texmfdistdir}/doc/latex/excludeonly
%dir %{_texmfdistdir}/doc/latex/exercise
%dir %{_texmfdistdir}/doc/latex/exercisebank
%dir %{_texmfdistdir}/doc/latex/exercisepoints
%dir %{_texmfdistdir}/doc/latex/exercises
%dir %{_texmfdistdir}/doc/latex/exesheet
%dir %{_texmfdistdir}/doc/latex/exframe
%dir %{_texmfdistdir}/doc/latex/exp-testopt
%dir %{_texmfdistdir}/doc/latex/expdlist
%dir %{_texmfdistdir}/doc/latex/expkv-bundle
%dir %{_texmfdistdir}/doc/latex/export
%dir %{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019
%dir %{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/bibliographie
%dir %{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/codes
%dir %{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/extensions
%dir %{_texmfdistdir}/doc/latex/expose-expl3-dunkerque-2019/glosaires
%dir %{_texmfdistdir}/doc/latex/exsheets
%dir %{_texmfdistdir}/doc/latex/exsol
%dir %{_texmfdistdir}/doc/latex/extarrows
%dir %{_texmfdistdir}/doc/latex/extpfeil
%dir %{_texmfdistdir}/doc/latex/extract
%dir %{_texmfdistdir}/doc/latex/extsizes
%dir %{_texmfdistdir}/doc/latex/facsimile
%dir %{_texmfdistdir}/doc/latex/factura
%dir %{_texmfdistdir}/doc/latex/faktor
%dir %{_texmfdistdir}/doc/latex/familytree
%dir %{_texmfdistdir}/doc/latex/familytree/doc-ja
%dir %{_texmfdistdir}/doc/latex/familytree/doc-ja/figs
%dir %{_texmfdistdir}/doc/latex/familytree/figs
%dir %{_texmfdistdir}/doc/latex/familytree/samples
%dir %{_texmfdistdir}/doc/latex/familytree/samples/Asai
%dir %{_texmfdistdir}/doc/latex/familytree/samples/Tokugawa
%dir %{_texmfdistdir}/doc/latex/fancybox
%dir %{_texmfdistdir}/doc/latex/fancyhandout
%dir %{_texmfdistdir}/doc/latex/fancyhdr
%dir %{_texmfdistdir}/doc/latex/fancyhdr-it
%dir %{_texmfdistdir}/doc/latex/fancylabel
%dir %{_texmfdistdir}/doc/latex/fancynum
%dir %{_texmfdistdir}/doc/latex/fancypar
%dir %{_texmfdistdir}/doc/latex/fancyqr
%dir %{_texmfdistdir}/doc/latex/fancyref
%dir %{_texmfdistdir}/doc/latex/fancyslides
%dir %{_texmfdistdir}/doc/latex/fancyslides/doc
%dir %{_texmfdistdir}/doc/latex/fancytabs
%dir %{_texmfdistdir}/doc/latex/fancytooltips
%dir %{_texmfdistdir}/doc/latex/fancytooltips/examples
%dir %{_texmfdistdir}/doc/latex/fancytooltips/examples/pics
%dir %{_texmfdistdir}/doc/latex/fancyvrb
%dir %{_texmfdistdir}/doc/latex/fascicules
%dir %{_texmfdistdir}/doc/latex/fascicules/guide
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/ch4_mon_chapitre
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/ch4_mon_chapitre/content
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/ch4_mon_chapitre/img
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/content
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/content/img
%dir %{_texmfdistdir}/doc/latex/fascicules/guide/solutions
%dir %{_texmfdistdir}/doc/latex/fast-diagram
%dir %{_texmfdistdir}/doc/latex/fast-diagram/sources_help
%dir %{_texmfdistdir}/doc/latex/fast-diagram/sources_help/images
%dir %{_texmfdistdir}/doc/latex/fbithesis
%dir %{_texmfdistdir}/doc/latex/fbox
%dir %{_texmfdistdir}/doc/latex/fcavtex
%dir %{_texmfdistdir}/doc/latex/fcavtex/examples
%dir %{_texmfdistdir}/doc/latex/fcavtex/manual
%dir %{_texmfdistdir}/doc/latex/fcltxdoc
%dir %{_texmfdistdir}/doc/latex/fcolumn
%dir %{_texmfdistdir}/doc/latex/fdsymbol
%dir %{_texmfdistdir}/doc/latex/fduthesis
%dir %{_texmfdistdir}/doc/latex/fei
%dir %{_texmfdistdir}/doc/latex/fetchcls
%dir %{_texmfdistdir}/doc/latex/feupphdteses
%dir %{_texmfdistdir}/doc/latex/feupphdteses/Figures
%dir %{_texmfdistdir}/doc/latex/fewerfloatpages
%dir %{_texmfdistdir}/doc/latex/feynmf
%dir %{_texmfdistdir}/doc/latex/feynmp-auto
%dir %{_texmfdistdir}/doc/latex/ffcode
%dir %{_texmfdistdir}/doc/latex/ffslides
%dir %{_texmfdistdir}/doc/latex/fgruler
%dir %{_texmfdistdir}/doc/latex/fifinddo-info
%dir %{_texmfdistdir}/doc/latex/fifinddo-info/variants
%dir %{_texmfdistdir}/doc/latex/fifo-stack
%dir %{_texmfdistdir}/doc/latex/figbib
%dir %{_texmfdistdir}/doc/latex/figchild
%dir %{_texmfdistdir}/doc/latex/figput
%dir %{_texmfdistdir}/doc/latex/figput/example
%dir %{_texmfdistdir}/doc/latex/figput/figput-manual
%dir %{_texmfdistdir}/doc/latex/figput/javascript
%dir %{_texmfdistdir}/doc/latex/figput/javascript/development
%dir %{_texmfdistdir}/doc/latex/figput/javascript/release
%dir %{_texmfdistdir}/doc/latex/figsize
%dir %{_texmfdistdir}/doc/latex/filecontents
%dir %{_texmfdistdir}/doc/latex/filecontentsdef
%dir %{_texmfdistdir}/doc/latex/filedate
%dir %{_texmfdistdir}/doc/latex/filehook
%dir %{_texmfdistdir}/doc/latex/fileinfo
%dir %{_texmfdistdir}/doc/latex/filemod
%dir %{_texmfdistdir}/doc/latex/fink
%dir %{_texmfdistdir}/doc/latex/finstrut
%dir %{_texmfdistdir}/doc/latex/first-latex-doc
%dir %{_texmfdistdir}/doc/latex/firstaid
%dir %{_texmfdistdir}/doc/latex/fistrum
%dir %{_texmfdistdir}/doc/latex/fitbox
%dir %{_texmfdistdir}/doc/latex/fithesis
%dir %{_texmfdistdir}/doc/latex/fix2col
%dir %{_texmfdistdir}/doc/latex/fixcmex
%dir %{_texmfdistdir}/doc/latex/fixdif
%dir %{_texmfdistdir}/doc/latex/fixfoot
%dir %{_texmfdistdir}/doc/latex/fixltxhyph
%dir %{_texmfdistdir}/doc/latex/fixmath
%dir %{_texmfdistdir}/doc/latex/fixme
%dir %{_texmfdistdir}/doc/latex/fixmetodonotes
%dir %{_texmfdistdir}/doc/latex/fjodor
%dir %{_texmfdistdir}/doc/latex/flabels
%dir %{_texmfdistdir}/doc/latex/flacards
%dir %{_texmfdistdir}/doc/latex/flagderiv
%dir %{_texmfdistdir}/doc/latex/flashcards
%dir %{_texmfdistdir}/doc/latex/flashmovie
%dir %{_texmfdistdir}/doc/latex/flashmovie/flv-player-license
%dir %{_texmfdistdir}/doc/latex/flexipage
%dir %{_texmfdistdir}/doc/latex/flipbook
%dir %{_texmfdistdir}/doc/latex/flipbook/Images
%dir %{_texmfdistdir}/doc/latex/flipbook/Images/Anims
%dir %{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an1b
%dir %{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an2
%dir %{_texmfdistdir}/doc/latex/flipbook/Images/Anims/an3
%dir %{_texmfdistdir}/doc/latex/flipbook/Images/Anims/anASCII
%dir %{_texmfdistdir}/doc/latex/flippdf
%dir %{_texmfdistdir}/doc/latex/float
%dir %{_texmfdistdir}/doc/latex/floatrow
%dir %{_texmfdistdir}/doc/latex/flowchart
%dir %{_texmfdistdir}/doc/latex/flowfram
%dir %{_texmfdistdir}/doc/latex/flowfram/samples
%dir %{_texmfdistdir}/doc/latex/fmp
%dir %{_texmfdistdir}/doc/latex/fmtcount
%dir %{_texmfdistdir}/doc/latex/fn2end
%dir %{_texmfdistdir}/doc/latex/fnbreak
%dir %{_texmfdistdir}/doc/latex/fncychap
%dir %{_texmfdistdir}/doc/latex/fncylab
%dir %{_texmfdistdir}/doc/latex/fnpara
%dir %{_texmfdistdir}/doc/latex/fnpct
%dir %{_texmfdistdir}/doc/latex/fnspe
%dir %{_texmfdistdir}/doc/latex/fnumprint
%dir %{_texmfdistdir}/doc/latex/foekfont
%dir %{_texmfdistdir}/doc/latex/foilhtml
%dir %{_texmfdistdir}/doc/latex/foliono
%dir %{_texmfdistdir}/doc/latex/foliono/pics
%dir %{_texmfdistdir}/doc/latex/fontaxes
%dir %{_texmfdistdir}/doc/latex/fontsetup
%dir %{_texmfdistdir}/doc/latex/fontsize
%dir %{_texmfdistdir}/doc/latex/fontspec
%dir %{_texmfdistdir}/doc/latex/fonttable
%dir %{_texmfdistdir}/doc/latex/footbib
%dir %{_texmfdistdir}/doc/latex/footmisc
%dir %{_texmfdistdir}/doc/latex/footmisx
%dir %{_texmfdistdir}/doc/latex/footnotebackref
%dir %{_texmfdistdir}/doc/latex/footnotehyper
%dir %{_texmfdistdir}/doc/latex/footnoterange
%dir %{_texmfdistdir}/doc/latex/footnpag
%dir %{_texmfdistdir}/doc/latex/footnpag/test
%dir %{_texmfdistdir}/doc/latex/forarray
%dir %{_texmfdistdir}/doc/latex/foreign
%dir %{_texmfdistdir}/doc/latex/forest
%dir %{_texmfdistdir}/doc/latex/forest-quickstart
%dir %{_texmfdistdir}/doc/latex/forloop
%dir %{_texmfdistdir}/doc/latex/formal-grammar
%dir %{_texmfdistdir}/doc/latex/formation-latex-ul
%dir %{_texmfdistdir}/doc/latex/forms16be
%dir %{_texmfdistdir}/doc/latex/forms16be/doc
%dir %{_texmfdistdir}/doc/latex/forms16be/examples
%dir %{_texmfdistdir}/doc/latex/formular
%dir %{_texmfdistdir}/doc/latex/fouridx
%dir %{_texmfdistdir}/doc/latex/fp
%dir %{_texmfdistdir}/doc/latex/fragments
%dir %{_texmfdistdir}/doc/latex/framed
%dir %{_texmfdistdir}/doc/latex/frankenstein
%dir %{_texmfdistdir}/doc/latex/frankenstein/unsupported
%dir %{_texmfdistdir}/doc/latex/frege
%dir %{_texmfdistdir}/doc/latex/frenchmath
%dir %{_texmfdistdir}/doc/latex/frletter
%dir %{_texmfdistdir}/doc/latex/frontespizio
%dir %{_texmfdistdir}/doc/latex/froufrou
%dir %{_texmfdistdir}/doc/latex/frpseudocode
%dir %{_texmfdistdir}/doc/latex/ftc-notebook
%dir %{_texmfdistdir}/doc/latex/ftc-notebook/src
%dir %{_texmfdistdir}/doc/latex/ftc-notebook/src/aug19
%dir %{_texmfdistdir}/doc/latex/ftc-notebook/src/bio
%dir %{_texmfdistdir}/doc/latex/ftc-notebook/src/images
%dir %{_texmfdistdir}/doc/latex/ftcap
%dir %{_texmfdistdir}/doc/latex/ftnxtra
%dir %{_texmfdistdir}/doc/latex/fullblck
%dir %{_texmfdistdir}/doc/latex/fullminipage
%dir %{_texmfdistdir}/doc/latex/fullwidth
%dir %{_texmfdistdir}/doc/latex/functan
%dir %{_texmfdistdir}/doc/latex/functional
%dir %{_texmfdistdir}/doc/latex/fundus-calligra
%dir %{_texmfdistdir}/doc/latex/fundus-sueterlin
%dir %{_texmfdistdir}/doc/latex/fvextra
%dir %{_texmfdistdir}/doc/latex/fwlw
%dir %{_texmfdistdir}/doc/latex/g-brief
%dir %{_texmfdistdir}/doc/latex/gaceta
%dir %{_texmfdistdir}/doc/latex/galois
%dir %{_texmfdistdir}/doc/latex/gamebook
%dir %{_texmfdistdir}/doc/latex/gamebooklib
%dir %{_texmfdistdir}/doc/latex/gammas
%dir %{_texmfdistdir}/doc/latex/gastex
%dir %{_texmfdistdir}/doc/latex/gatherenum
%dir %{_texmfdistdir}/doc/latex/gauss
%dir %{_texmfdistdir}/doc/latex/gb4e
%dir %{_texmfdistdir}/doc/latex/gcard
%dir %{_texmfdistdir}/doc/latex/gchords
%dir %{_texmfdistdir}/doc/latex/gcite
%dir %{_texmfdistdir}/doc/latex/gckanbun
%dir %{_texmfdistdir}/doc/latex/gender
%dir %{_texmfdistdir}/doc/latex/gene-logic
%dir %{_texmfdistdir}/doc/latex/genealogytree
%dir %{_texmfdistdir}/doc/latex/genmpage
%dir %{_texmfdistdir}/doc/latex/gensymb
%dir %{_texmfdistdir}/doc/latex/gentombow
%dir %{_texmfdistdir}/doc/latex/geometry
%dir %{_texmfdistdir}/doc/latex/geradwp
%dir %{_texmfdistdir}/doc/latex/germkorr
%dir %{_texmfdistdir}/doc/latex/geschichtsfrkl
%dir %{_texmfdistdir}/doc/latex/getfiledate
%dir %{_texmfdistdir}/doc/latex/getitems
%dir %{_texmfdistdir}/doc/latex/getmap
%dir %{_texmfdistdir}/doc/latex/gettitlestring
%dir %{_texmfdistdir}/doc/latex/gfdl
%dir %{_texmfdistdir}/doc/latex/ghab
%dir %{_texmfdistdir}/doc/latex/ghsystem
%dir %{_texmfdistdir}/doc/latex/gillcm
%dir %{_texmfdistdir}/doc/latex/gincltex
%dir %{_texmfdistdir}/doc/latex/gindex
%dir %{_texmfdistdir}/doc/latex/ginpenc
%dir %{_texmfdistdir}/doc/latex/gitinfo
%dir %{_texmfdistdir}/doc/latex/gitinfo2
%dir %{_texmfdistdir}/doc/latex/gitlog
%dir %{_texmfdistdir}/doc/latex/gitstatus
%dir %{_texmfdistdir}/doc/latex/gitver
%dir %{_texmfdistdir}/doc/latex/globalvals
%dir %{_texmfdistdir}/doc/latex/glosmathtools
%dir %{_texmfdistdir}/doc/latex/gloss
%dir %{_texmfdistdir}/doc/latex/gloss-occitan
%dir %{_texmfdistdir}/doc/latex/glossaries
%dir %{_texmfdistdir}/doc/latex/glossaries-danish
%dir %{_texmfdistdir}/doc/latex/glossaries-dutch
%dir %{_texmfdistdir}/doc/latex/glossaries-english
%dir %{_texmfdistdir}/doc/latex/glossaries-estonian
%dir %{_texmfdistdir}/doc/latex/glossaries-extra
%dir %{_texmfdistdir}/doc/latex/glossaries-extra/glossaries-extra-manual-examples
%dir %{_texmfdistdir}/doc/latex/glossaries-extra/samples
%dir %{_texmfdistdir}/doc/latex/glossaries-finnish
%dir %{_texmfdistdir}/doc/latex/glossaries-french
%dir %{_texmfdistdir}/doc/latex/glossaries-german
%dir %{_texmfdistdir}/doc/latex/glossaries-irish
%dir %{_texmfdistdir}/doc/latex/glossaries-italian
%dir %{_texmfdistdir}/doc/latex/glossaries-magyar
%dir %{_texmfdistdir}/doc/latex/glossaries-nynorsk
%dir %{_texmfdistdir}/doc/latex/glossaries-polish
%dir %{_texmfdistdir}/doc/latex/glossaries-portuges
%dir %{_texmfdistdir}/doc/latex/glossaries-serbian
%dir %{_texmfdistdir}/doc/latex/glossaries-slovene
%dir %{_texmfdistdir}/doc/latex/glossaries-spanish
%dir %{_texmfdistdir}/doc/latex/glossaries/glossaries-user-examples
%dir %{_texmfdistdir}/doc/latex/glossaries/samples
%dir %{_texmfdistdir}/doc/latex/gmdoc
%dir %{_texmfdistdir}/doc/latex/gmdoc-enhance
%dir %{_texmfdistdir}/doc/latex/gmdoc/basedrivers
%dir %{_texmfdistdir}/doc/latex/gmiflink
%dir %{_texmfdistdir}/doc/latex/gmp
%dir %{_texmfdistdir}/doc/latex/gmutils
%dir %{_texmfdistdir}/doc/latex/gmverb
%dir %{_texmfdistdir}/doc/latex/gmverse
%dir %{_texmfdistdir}/doc/latex/gnuplottex
%dir %{_texmfdistdir}/doc/latex/gotoh
%dir %{_texmfdistdir}/doc/latex/grabbox
%dir %{_texmfdistdir}/doc/latex/gradient-text
%dir %{_texmfdistdir}/doc/latex/gradientframe
%dir %{_texmfdistdir}/doc/latex/grading-scheme
%dir %{_texmfdistdir}/doc/latex/gradstudentresume
%dir %{_texmfdistdir}/doc/latex/grafcet
%dir %{_texmfdistdir}/doc/latex/grant
%dir %{_texmfdistdir}/doc/latex/graph35
%dir %{_texmfdistdir}/doc/latex/graphbox
%dir %{_texmfdistdir}/doc/latex/graphics
%dir %{_texmfdistdir}/doc/latex/graphics-cfg
%dir %{_texmfdistdir}/doc/latex/graphics-def
%dir %{_texmfdistdir}/doc/latex/graphicscache
%dir %{_texmfdistdir}/doc/latex/graphicx-psmin
%dir %{_texmfdistdir}/doc/latex/graphicxbox
%dir %{_texmfdistdir}/doc/latex/graphicxbox/doc
%dir %{_texmfdistdir}/doc/latex/graphicxbox/examples
%dir %{_texmfdistdir}/doc/latex/graphicxbox/examples/graphics
%dir %{_texmfdistdir}/doc/latex/graphicxpsd
%dir %{_texmfdistdir}/doc/latex/graphpaper
%dir %{_texmfdistdir}/doc/latex/graphviz
%dir %{_texmfdistdir}/doc/latex/graphviz/test
%dir %{_texmfdistdir}/doc/latex/grayhints
%dir %{_texmfdistdir}/doc/latex/grayhints/doc
%dir %{_texmfdistdir}/doc/latex/grayhints/examples
%dir %{_texmfdistdir}/doc/latex/greek-fontenc
%dir %{_texmfdistdir}/doc/latex/greek-inputenc
%dir %{_texmfdistdir}/doc/latex/greekdates
%dir %{_texmfdistdir}/doc/latex/greektonoi
%dir %{_texmfdistdir}/doc/latex/grfext
%dir %{_texmfdistdir}/doc/latex/grffile
%dir %{_texmfdistdir}/doc/latex/grfpaste
%dir %{_texmfdistdir}/doc/latex/grfpaste/doc
%dir %{_texmfdistdir}/doc/latex/grid
%dir %{_texmfdistdir}/doc/latex/grid-system
%dir %{_texmfdistdir}/doc/latex/gridpapers
%dir %{_texmfdistdir}/doc/latex/gridpapers/examples
%dir %{_texmfdistdir}/doc/latex/gridset
%dir %{_texmfdistdir}/doc/latex/gridslides
%dir %{_texmfdistdir}/doc/latex/gridslides/figures
%dir %{_texmfdistdir}/doc/latex/grundgesetze
%dir %{_texmfdistdir}/doc/latex/gs1
%dir %{_texmfdistdir}/doc/latex/gsemthesis
%dir %{_texmfdistdir}/doc/latex/gtrcrd
%dir %{_texmfdistdir}/doc/latex/gtrlib-largetrees
%dir %{_texmfdistdir}/doc/latex/gu
%dir %{_texmfdistdir}/doc/latex/guide-to-latex
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap10
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap11
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap15
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap2
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap3
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap4
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap5
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap6
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap7
%dir %{_texmfdistdir}/doc/latex/guide-to-latex/exercises/chap8
%dir %{_texmfdistdir}/doc/latex/guitar
%dir %{_texmfdistdir}/doc/latex/guitarchordschemes
%dir %{_texmfdistdir}/doc/latex/guitartabs
%dir %{_texmfdistdir}/doc/latex/guitlogo
%dir %{_texmfdistdir}/doc/latex/gzt
%dir %{_texmfdistdir}/doc/latex/gzt/english
%dir %{_texmfdistdir}/doc/latex/gzt/french
%dir %{_texmfdistdir}/doc/latex/gzt/french/sections
%dir %{_texmfdistdir}/doc/latex/h2020proposal
%dir %{_texmfdistdir}/doc/latex/h2020proposal/manual
%dir %{_texmfdistdir}/doc/latex/h2020proposal/template-fet
%dir %{_texmfdistdir}/doc/latex/h2020proposal/template-ict
%dir %{_texmfdistdir}/doc/latex/ha-prosper
%dir %{_texmfdistdir}/doc/latex/hackthefootline
%dir %{_texmfdistdir}/doc/latex/hackthefootline/doc
%dir %{_texmfdistdir}/doc/latex/hagenberg-thesis
%dir %{_texmfdistdir}/doc/latex/halloweenmath
%dir %{_texmfdistdir}/doc/latex/handin
%dir %{_texmfdistdir}/doc/latex/handout
%dir %{_texmfdistdir}/doc/latex/handout/examples
%dir %{_texmfdistdir}/doc/latex/handout/examples/txt
%dir %{_texmfdistdir}/doc/latex/handoutwithnotes
%dir %{_texmfdistdir}/doc/latex/hang
%dir %{_texmfdistdir}/doc/latex/hanging
%dir %{_texmfdistdir}/doc/latex/har2nat
%dir %{_texmfdistdir}/doc/latex/hardwrap
%dir %{_texmfdistdir}/doc/latex/harmony
%dir %{_texmfdistdir}/doc/latex/harnon-cv
%dir %{_texmfdistdir}/doc/latex/harpoon
%dir %{_texmfdistdir}/doc/latex/harvard
%dir %{_texmfdistdir}/doc/latex/harveyballs
%dir %{_texmfdistdir}/doc/latex/hausarbeit-jura
%dir %{_texmfdistdir}/doc/latex/havannah
%dir %{_texmfdistdir}/doc/latex/hc
%dir %{_texmfdistdir}/doc/latex/he-she
%dir %{_texmfdistdir}/doc/latex/hecthese
%dir %{_texmfdistdir}/doc/latex/hep
%dir %{_texmfdistdir}/doc/latex/hep-acronym
%dir %{_texmfdistdir}/doc/latex/hep-bibliography
%dir %{_texmfdistdir}/doc/latex/hep-float
%dir %{_texmfdistdir}/doc/latex/hep-math
%dir %{_texmfdistdir}/doc/latex/hep-paper
%dir %{_texmfdistdir}/doc/latex/hep-reference
%dir %{_texmfdistdir}/doc/latex/hep-text
%dir %{_texmfdistdir}/doc/latex/hep-title
%dir %{_texmfdistdir}/doc/latex/hepnames
%dir %{_texmfdistdir}/doc/latex/hepparticles
%dir %{_texmfdistdir}/doc/latex/hepthesis
%dir %{_texmfdistdir}/doc/latex/hepthesis/example
%dir %{_texmfdistdir}/doc/latex/hepunits
%dir %{_texmfdistdir}/doc/latex/here
%dir %{_texmfdistdir}/doc/latex/hereapplies
%dir %{_texmfdistdir}/doc/latex/hereapplies/lyx-module
%dir %{_texmfdistdir}/doc/latex/hexboard
%dir %{_texmfdistdir}/doc/latex/hexgame
%dir %{_texmfdistdir}/doc/latex/hf-tikz
%dir %{_texmfdistdir}/doc/latex/hfutexam
%dir %{_texmfdistdir}/doc/latex/hhtensor
%dir %{_texmfdistdir}/doc/latex/hideanswer
%dir %{_texmfdistdir}/doc/latex/highlightlatex
%dir %{_texmfdistdir}/doc/latex/hindawi-latex-template
%dir %{_texmfdistdir}/doc/latex/histogr
%dir %{_texmfdistdir}/doc/latex/historische-zeitschrift
%dir %{_texmfdistdir}/doc/latex/hitec
%dir %{_texmfdistdir}/doc/latex/hitreport
%dir %{_texmfdistdir}/doc/latex/hitreport/data
%dir %{_texmfdistdir}/doc/latex/hitreport/figures
%dir %{_texmfdistdir}/doc/latex/hitreport/photo
%dir %{_texmfdistdir}/doc/latex/hitreport/ref
%dir %{_texmfdistdir}/doc/latex/hitszbeamer
%dir %{_texmfdistdir}/doc/latex/hitszbeamer/figures
%dir %{_texmfdistdir}/doc/latex/hitszthesis
%dir %{_texmfdistdir}/doc/latex/hitszthesis/back
%dir %{_texmfdistdir}/doc/latex/hitszthesis/body
%dir %{_texmfdistdir}/doc/latex/hitszthesis/figures
%dir %{_texmfdistdir}/doc/latex/hitszthesis/front
%dir %{_texmfdistdir}/doc/latex/hletter
%dir %{_texmfdistdir}/doc/latex/hobby
%dir %{_texmfdistdir}/doc/latex/hobete
%dir %{_texmfdistdir}/doc/latex/hobsub
%dir %{_texmfdistdir}/doc/latex/hopatch
%dir %{_texmfdistdir}/doc/latex/horoscop
%dir %{_texmfdistdir}/doc/latex/hpsdiss
%dir %{_texmfdistdir}/doc/latex/href-ul
%dir %{_texmfdistdir}/doc/latex/hrefhide
%dir %{_texmfdistdir}/doc/latex/hrlatex
%dir %{_texmfdistdir}/doc/latex/huawei
%dir %{_texmfdistdir}/doc/latex/huaz
%dir %{_texmfdistdir}/doc/latex/hulipsum
%dir %{_texmfdistdir}/doc/latex/hustthesis
%dir %{_texmfdistdir}/doc/latex/hvarabic
%dir %{_texmfdistdir}/doc/latex/hvextern
%dir %{_texmfdistdir}/doc/latex/hvfloat
%dir %{_texmfdistdir}/doc/latex/hvindex
%dir %{_texmfdistdir}/doc/latex/hvlogos
%dir %{_texmfdistdir}/doc/latex/hvpygmentex
%dir %{_texmfdistdir}/doc/latex/hvqrurl
%dir %{_texmfdistdir}/doc/latex/hwemoji
%dir %{_texmfdistdir}/doc/latex/hycolor
%dir %{_texmfdistdir}/doc/latex/hypdestopt
%dir %{_texmfdistdir}/doc/latex/hypdoc
%dir %{_texmfdistdir}/doc/latex/hypdvips
%dir %{_texmfdistdir}/doc/latex/hypdvips/images
%dir %{_texmfdistdir}/doc/latex/hyper
%dir %{_texmfdistdir}/doc/latex/hyper/contrib
%dir %{_texmfdistdir}/doc/latex/hyper/scontrib
%dir %{_texmfdistdir}/doc/latex/hyperbar
%dir %{_texmfdistdir}/doc/latex/hypernat
%dir %{_texmfdistdir}/doc/latex/hyperref
%dir %{_texmfdistdir}/doc/latex/hyperxmp
%dir %{_texmfdistdir}/doc/latex/hyphenat
%dir %{_texmfdistdir}/doc/latex/ibrackets
%dir %{_texmfdistdir}/doc/latex/ibycus-babel
%dir %{_texmfdistdir}/doc/latex/icite
%dir %{_texmfdistdir}/doc/latex/icite/samples
%dir %{_texmfdistdir}/doc/latex/icsv
%dir %{_texmfdistdir}/doc/latex/identkey
%dir %{_texmfdistdir}/doc/latex/idxcmds
%dir %{_texmfdistdir}/doc/latex/idxlayout
%dir %{_texmfdistdir}/doc/latex/ieeeconf
%dir %{_texmfdistdir}/doc/latex/ieeepes
%dir %{_texmfdistdir}/doc/latex/ieeetran
%dir %{_texmfdistdir}/doc/latex/ieeetran/bibtex
%dir %{_texmfdistdir}/doc/latex/ieeetran/tools
%dir %{_texmfdistdir}/doc/latex/iexec
%dir %{_texmfdistdir}/doc/latex/ifallfalse
%dir %{_texmfdistdir}/doc/latex/iffont
%dir %{_texmfdistdir}/doc/latex/ifmslide
%dir %{_texmfdistdir}/doc/latex/ifmtarg
%dir %{_texmfdistdir}/doc/latex/ifnextok
%dir %{_texmfdistdir}/doc/latex/ifoddpage
%dir %{_texmfdistdir}/doc/latex/ifplatform
%dir %{_texmfdistdir}/doc/latex/ifthenx
%dir %{_texmfdistdir}/doc/latex/iitem
%dir %{_texmfdistdir}/doc/latex/ijmart
%dir %{_texmfdistdir}/doc/latex/ijsra
%dir %{_texmfdistdir}/doc/latex/imac
%dir %{_texmfdistdir}/doc/latex/image-gallery
%dir %{_texmfdistdir}/doc/latex/imakeidx
%dir %{_texmfdistdir}/doc/latex/impnattypo
%dir %{_texmfdistdir}/doc/latex/import
%dir %{_texmfdistdir}/doc/latex/imtekda
%dir %{_texmfdistdir}/doc/latex/imtekda/figures
%dir %{_texmfdistdir}/doc/latex/incgraph
%dir %{_texmfdistdir}/doc/latex/includernw
%dir %{_texmfdistdir}/doc/latex/index
%dir %{_texmfdistdir}/doc/latex/indextools
%dir %{_texmfdistdir}/doc/latex/infwarerr
%dir %{_texmfdistdir}/doc/latex/inkpaper
%dir %{_texmfdistdir}/doc/latex/inline-images
%dir %{_texmfdistdir}/doc/latex/inline-images/examples
%dir %{_texmfdistdir}/doc/latex/inline-images/screenshots
%dir %{_texmfdistdir}/doc/latex/inlinedef
%dir %{_texmfdistdir}/doc/latex/inlinelabel
%dir %{_texmfdistdir}/doc/latex/inputenx
%dir %{_texmfdistdir}/doc/latex/inputnormalization
%dir %{_texmfdistdir}/doc/latex/inputtrc
%dir %{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn
%dir %{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn/appendix
%dir %{_texmfdistdir}/doc/latex/install-latex-guide-zh-cn/chapter
%dir %{_texmfdistdir}/doc/latex/intcalc
%dir %{_texmfdistdir}/doc/latex/interactiveworkbook
%dir %{_texmfdistdir}/doc/latex/interactiveworkbook/documentation
%dir %{_texmfdistdir}/doc/latex/interactiveworkbook/epsfiles
%dir %{_texmfdistdir}/doc/latex/interactiveworkbook/samplefiles
%dir %{_texmfdistdir}/doc/latex/interfaces
%dir %{_texmfdistdir}/doc/latex/interval
%dir %{_texmfdistdir}/doc/latex/intopdf
%dir %{_texmfdistdir}/doc/latex/intro-scientific
%dir %{_texmfdistdir}/doc/latex/inversepath
%dir %{_texmfdistdir}/doc/latex/invoice
%dir %{_texmfdistdir}/doc/latex/invoice-class
%dir %{_texmfdistdir}/doc/latex/invoice-class/doc
%dir %{_texmfdistdir}/doc/latex/invoice2
%dir %{_texmfdistdir}/doc/latex/iodhbwm
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/abstract
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/acronyms
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/appendix
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/bibliography
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/customizing
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/how-to-use-iodhbwm
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/listings
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/references
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/titlepages
%dir %{_texmfdistdir}/doc/latex/iodhbwm/examples/titlepages/img
%dir %{_texmfdistdir}/doc/latex/iodhbwm/i18n
%dir %{_texmfdistdir}/doc/latex/iodhbwm/i18n/english
%dir %{_texmfdistdir}/doc/latex/iodhbwm/i18n/ngerman
%dir %{_texmfdistdir}/doc/latex/ionumbers
%dir %{_texmfdistdir}/doc/latex/iscram
%dir %{_texmfdistdir}/doc/latex/iso
%dir %{_texmfdistdir}/doc/latex/iso10303
%dir %{_texmfdistdir}/doc/latex/isodate
%dir %{_texmfdistdir}/doc/latex/isodoc
%dir %{_texmfdistdir}/doc/latex/isomath
%dir %{_texmfdistdir}/doc/latex/isonums
%dir %{_texmfdistdir}/doc/latex/isopt
%dir %{_texmfdistdir}/doc/latex/isorot
%dir %{_texmfdistdir}/doc/latex/isotope
%dir %{_texmfdistdir}/doc/latex/issuulinks
%dir %{_texmfdistdir}/doc/latex/istgame
%dir %{_texmfdistdir}/doc/latex/itnumpar
%dir %{_texmfdistdir}/doc/latex/iwhdp
%dir %{_texmfdistdir}/doc/latex/jacow
%dir %{_texmfdistdir}/doc/latex/jamtimes
%dir %{_texmfdistdir}/doc/latex/jeuxcartes
%dir %{_texmfdistdir}/doc/latex/jigsaw
%dir %{_texmfdistdir}/doc/latex/jkmath
%dir %{_texmfdistdir}/doc/latex/jknapltx
%dir %{_texmfdistdir}/doc/latex/jlabels
%dir %{_texmfdistdir}/doc/latex/jlreq
%dir %{_texmfdistdir}/doc/latex/jmlr
%dir %{_texmfdistdir}/doc/latex/jmsdelim
%dir %{_texmfdistdir}/doc/latex/jneurosci
%dir %{_texmfdistdir}/doc/latex/jnuexam
%dir %{_texmfdistdir}/doc/latex/jobname-suffix
%dir %{_texmfdistdir}/doc/latex/jourcl
%dir %{_texmfdistdir}/doc/latex/jourcl/imgs
%dir %{_texmfdistdir}/doc/latex/jpneduenumerate
%dir %{_texmfdistdir}/doc/latex/jpnedumathsymbols
%dir %{_texmfdistdir}/doc/latex/jpsj
%dir %{_texmfdistdir}/doc/latex/jslectureplanner
%dir %{_texmfdistdir}/doc/latex/jslectureplanner/examples
%dir %{_texmfdistdir}/doc/latex/jslectureplanner/examples/English
%dir %{_texmfdistdir}/doc/latex/jslectureplanner/examples/German
%dir %{_texmfdistdir}/doc/latex/jumplines
%dir %{_texmfdistdir}/doc/latex/jupynotex
%dir %{_texmfdistdir}/doc/latex/jupynotex/example
%dir %{_texmfdistdir}/doc/latex/jupynotex/tests
%dir %{_texmfdistdir}/doc/latex/jura
%dir %{_texmfdistdir}/doc/latex/juraabbrev
%dir %{_texmfdistdir}/doc/latex/jurabib
%dir %{_texmfdistdir}/doc/latex/jurabib/docs
%dir %{_texmfdistdir}/doc/latex/jurabib/docs/english
%dir %{_texmfdistdir}/doc/latex/jurabib/docs/german
%dir %{_texmfdistdir}/doc/latex/juramisc
%dir %{_texmfdistdir}/doc/latex/juramisc/doc
%dir %{_texmfdistdir}/doc/latex/juramisc/doc/jbook
%dir %{_texmfdistdir}/doc/latex/jurarsp
%dir %{_texmfdistdir}/doc/latex/jvlisting
%dir %{_texmfdistdir}/doc/latex/jwjournal
%dir %{_texmfdistdir}/doc/latex/kalendarium
%dir %{_texmfdistdir}/doc/latex/kanbun
%dir %{_texmfdistdir}/doc/latex/kantlipsum
%dir %{_texmfdistdir}/doc/latex/karnaugh
%dir %{_texmfdistdir}/doc/latex/karnaugh-map
%dir %{_texmfdistdir}/doc/latex/karnaughmap
%dir %{_texmfdistdir}/doc/latex/kaytannollista-latexia
%dir %{_texmfdistdir}/doc/latex/kblocks
%dir %{_texmfdistdir}/doc/latex/kdgdocs
%dir %{_texmfdistdir}/doc/latex/kdpcover
%dir %{_texmfdistdir}/doc/latex/kerntest
%dir %{_texmfdistdir}/doc/latex/keycommand
%dir %{_texmfdistdir}/doc/latex/keyfloat
%dir %{_texmfdistdir}/doc/latex/keyfloat/images
%dir %{_texmfdistdir}/doc/latex/keyindex
%dir %{_texmfdistdir}/doc/latex/keyparse
%dir %{_texmfdistdir}/doc/latex/keyreader
%dir %{_texmfdistdir}/doc/latex/keystroke
%dir %{_texmfdistdir}/doc/latex/keyval2e
%dir %{_texmfdistdir}/doc/latex/keyvaltable
%dir %{_texmfdistdir}/doc/latex/kfupm-math-exam
%dir %{_texmfdistdir}/doc/latex/kinematikz
%dir %{_texmfdistdir}/doc/latex/kix
%dir %{_texmfdistdir}/doc/latex/kluwer
%dir %{_texmfdistdir}/doc/latex/knittingpattern
%dir %{_texmfdistdir}/doc/latex/knowledge
%dir %{_texmfdistdir}/doc/latex/koma-moderncvclassic
%dir %{_texmfdistdir}/doc/latex/koma-script
%dir %{_texmfdistdir}/doc/latex/koma-script-examples
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-B/source
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Anhang-C/source
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-11/source
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-15/source
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-19/source
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/result
%dir %{_texmfdistdir}/doc/latex/koma-script-examples/Kapitel-4/source
%dir %{_texmfdistdir}/doc/latex/koma-script-sfs
%dir %{_texmfdistdir}/doc/latex/koma-script/examples
%dir %{_texmfdistdir}/doc/latex/komacv
%dir %{_texmfdistdir}/doc/latex/komacv-rg
%dir %{_texmfdistdir}/doc/latex/komacv/examples
%dir %{_texmfdistdir}/doc/latex/kotex-oblivoir
%dir %{_texmfdistdir}/doc/latex/kotex-utf
%dir %{_texmfdistdir}/doc/latex/kotex-utf/fig
%dir %{_texmfdistdir}/doc/latex/kotex-utils
%dir %{_texmfdistdir}/doc/latex/ksp-thesis
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/full
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/appendix
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/content/front
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/full/preamble
%dir %{_texmfdistdir}/doc/latex/ksp-thesis/demo/minimal
%dir %{_texmfdistdir}/doc/latex/ktv-texdata
%dir %{_texmfdistdir}/doc/latex/ku-template
%dir %{_texmfdistdir}/doc/latex/ku-template/images
%dir %{_texmfdistdir}/doc/latex/kvdefinekeys
%dir %{_texmfdistdir}/doc/latex/kvmap
%dir %{_texmfdistdir}/doc/latex/kvoptions
%dir %{_texmfdistdir}/doc/latex/kvsetkeys
%dir %{_texmfdistdir}/doc/latex/l2picfaq
%dir %{_texmfdistdir}/doc/latex/l2tabu
%dir %{_texmfdistdir}/doc/latex/l2tabu-english
%dir %{_texmfdistdir}/doc/latex/l2tabu-french
%dir %{_texmfdistdir}/doc/latex/l2tabu-italian
%dir %{_texmfdistdir}/doc/latex/l2tabu-spanish
%dir %{_texmfdistdir}/doc/latex/l3backend
%dir %{_texmfdistdir}/doc/latex/l3build
%dir %{_texmfdistdir}/doc/latex/l3experimental
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3benchmark
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3bitset
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3draw
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3graphics
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3opacity
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3str
%dir %{_texmfdistdir}/doc/latex/l3experimental/l3sys-shell
%dir %{_texmfdistdir}/doc/latex/l3experimental/xcoffins
%dir %{_texmfdistdir}/doc/latex/l3experimental/xgalley
%dir %{_texmfdistdir}/doc/latex/l3kernel
%dir %{_texmfdistdir}/doc/latex/l3packages
%dir %{_texmfdistdir}/doc/latex/l3packages/l3keys2e
%dir %{_texmfdistdir}/doc/latex/l3packages/xfp
%dir %{_texmfdistdir}/doc/latex/l3packages/xfrac
%dir %{_texmfdistdir}/doc/latex/l3packages/xparse
%dir %{_texmfdistdir}/doc/latex/l3packages/xtemplate
%dir %{_texmfdistdir}/doc/latex/labbook
%dir %{_texmfdistdir}/doc/latex/labels
%dir %{_texmfdistdir}/doc/latex/labels/test
%dir %{_texmfdistdir}/doc/latex/labels4easylist
%dir %{_texmfdistdir}/doc/latex/labelschanged
%dir %{_texmfdistdir}/doc/latex/labyrinth
%dir %{_texmfdistdir}/doc/latex/ladder
%dir %{_texmfdistdir}/doc/latex/lambdax
%dir %{_texmfdistdir}/doc/latex/langnames
%dir %{_texmfdistdir}/doc/latex/langsci-avm
%dir %{_texmfdistdir}/doc/latex/lapdf
%dir %{_texmfdistdir}/doc/latex/lastpackage
%dir %{_texmfdistdir}/doc/latex/lastpage
%dir %{_texmfdistdir}/doc/latex/latex-brochure
%dir %{_texmfdistdir}/doc/latex/latex-course
%dir %{_texmfdistdir}/doc/latex/latex-course/Graphics
%dir %{_texmfdistdir}/doc/latex/latex-doc-ptr
%dir %{_texmfdistdir}/doc/latex/latex-for-undergraduates
%dir %{_texmfdistdir}/doc/latex/latex-for-undergraduates/images
%dir %{_texmfdistdir}/doc/latex/latex-graphics-companion
%dir %{_texmfdistdir}/doc/latex/latex-graphics-companion/inputs
%dir %{_texmfdistdir}/doc/latex/latex-lab
%dir %{_texmfdistdir}/doc/latex/latex-mr
%dir %{_texmfdistdir}/doc/latex/latex-refsheet
%dir %{_texmfdistdir}/doc/latex/latex-uni8
%dir %{_texmfdistdir}/doc/latex/latex-veryshortguide
%dir %{_texmfdistdir}/doc/latex/latex-via-exemplos
%dir %{_texmfdistdir}/doc/latex/latex-web-companion
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/apa
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/apb
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/apc
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch2
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch3
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch4
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch6
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch7
%dir %{_texmfdistdir}/doc/latex/latex-web-companion/ch7/SGMLS
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo-fr
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo-spanish
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo/graphics
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo/graphics/asy
%dir %{_texmfdistdir}/doc/latex/latex2e-help-texinfo/latex2e-figures
%dir %{_texmfdistdir}/doc/latex/latex4musicians
%dir %{_texmfdistdir}/doc/latex/latex4musicians/Figures
%dir %{_texmfdistdir}/doc/latex/latex4wp
%dir %{_texmfdistdir}/doc/latex/latex4wp-it
%dir %{_texmfdistdir}/doc/latex/latexbangla
%dir %{_texmfdistdir}/doc/latex/latexbug
%dir %{_texmfdistdir}/doc/latex/latexcheat
%dir %{_texmfdistdir}/doc/latex/latexcheat-de
%dir %{_texmfdistdir}/doc/latex/latexcheat-esmx
%dir %{_texmfdistdir}/doc/latex/latexcheat-ptbr
%dir %{_texmfdistdir}/doc/latex/latexcolors
%dir %{_texmfdistdir}/doc/latex/latexcourse-rug
%dir %{_texmfdistdir}/doc/latex/latexdemo
%dir %{_texmfdistdir}/doc/latex/latexfileinfo-pkgs
%dir %{_texmfdistdir}/doc/latex/latexgit
%dir %{_texmfdistdir}/doc/latex/latino-sine-flexione
%dir %{_texmfdistdir}/doc/latex/layaureo
%dir %{_texmfdistdir}/doc/latex/layouts
%dir %{_texmfdistdir}/doc/latex/lazylist
%dir %{_texmfdistdir}/doc/latex/lccaps
%dir %{_texmfdistdir}/doc/latex/lcd
%dir %{_texmfdistdir}/doc/latex/lcg
%dir %{_texmfdistdir}/doc/latex/lcyw
%dir %{_texmfdistdir}/doc/latex/leading
%dir %{_texmfdistdir}/doc/latex/leadsheets
%dir %{_texmfdistdir}/doc/latex/leaflet
%dir %{_texmfdistdir}/doc/latex/lebhart
%dir %{_texmfdistdir}/doc/latex/lectures
%dir %{_texmfdistdir}/doc/latex/lectureslides
%dir %{_texmfdistdir}/doc/latex/ledmac
%dir %{_texmfdistdir}/doc/latex/leftidx
%dir %{_texmfdistdir}/doc/latex/leftindex
%dir %{_texmfdistdir}/doc/latex/leipzig
%dir %{_texmfdistdir}/doc/latex/lengthconvert
%dir %{_texmfdistdir}/doc/latex/letltxmacro
%dir %{_texmfdistdir}/doc/latex/letterswitharrows
%dir %{_texmfdistdir}/doc/latex/lettre
%dir %{_texmfdistdir}/doc/latex/lettrine
%dir %{_texmfdistdir}/doc/latex/lewis
%dir %{_texmfdistdir}/doc/latex/lexikon
%dir %{_texmfdistdir}/doc/latex/lexref
%dir %{_texmfdistdir}/doc/latex/lgreek
%dir %{_texmfdistdir}/doc/latex/lgrmath
%dir %{_texmfdistdir}/doc/latex/lhelp
%dir %{_texmfdistdir}/doc/latex/libgreek
%dir %{_texmfdistdir}/doc/latex/lie-hasse
%dir %{_texmfdistdir}/doc/latex/liftarm
%dir %{_texmfdistdir}/doc/latex/lilyglyphs
%dir %{_texmfdistdir}/doc/latex/lilyglyphs/documentation
%dir %{_texmfdistdir}/doc/latex/lilyglyphs/documentation/lilyglyphs_logo
%dir %{_texmfdistdir}/doc/latex/lilyglyphs/documentation/resources
%dir %{_texmfdistdir}/doc/latex/lilyglyphs/license
%dir %{_texmfdistdir}/doc/latex/limap
%dir %{_texmfdistdir}/doc/latex/limap/samples
%dir %{_texmfdistdir}/doc/latex/limecv
%dir %{_texmfdistdir}/doc/latex/limecv/examples
%dir %{_texmfdistdir}/doc/latex/linegoal
%dir %{_texmfdistdir}/doc/latex/lineno
%dir %{_texmfdistdir}/doc/latex/ling-macros
%dir %{_texmfdistdir}/doc/latex/linguex
%dir %{_texmfdistdir}/doc/latex/linop
%dir %{_texmfdistdir}/doc/latex/lion-msc
%dir %{_texmfdistdir}/doc/latex/lipsum
%dir %{_texmfdistdir}/doc/latex/lisp-on-tex
%dir %{_texmfdistdir}/doc/latex/lisp-on-tex/examples
%dir %{_texmfdistdir}/doc/latex/listbib
%dir %{_texmfdistdir}/doc/latex/listing
%dir %{_texmfdistdir}/doc/latex/listings
%dir %{_texmfdistdir}/doc/latex/listings-ext
%dir %{_texmfdistdir}/doc/latex/listingsutf8
%dir %{_texmfdistdir}/doc/latex/listlbls
%dir %{_texmfdistdir}/doc/latex/listliketab
%dir %{_texmfdistdir}/doc/latex/listofsymbols
%dir %{_texmfdistdir}/doc/latex/lithuanian
%dir %{_texmfdistdir}/doc/latex/liturg
%dir %{_texmfdistdir}/doc/latex/lkproof
%dir %{_texmfdistdir}/doc/latex/llncs
%dir %{_texmfdistdir}/doc/latex/llncsconf
%dir %{_texmfdistdir}/doc/latex/llncsconf/example
%dir %{_texmfdistdir}/doc/latex/lmake
%dir %{_texmfdistdir}/doc/latex/lni
%dir %{_texmfdistdir}/doc/latex/locality
%dir %{_texmfdistdir}/doc/latex/logbox
%dir %{_texmfdistdir}/doc/latex/logical-markup-utils
%dir %{_texmfdistdir}/doc/latex/logicproof
%dir %{_texmfdistdir}/doc/latex/logicpuzzle
%dir %{_texmfdistdir}/doc/latex/logpap
%dir %{_texmfdistdir}/doc/latex/logreq
%dir %{_texmfdistdir}/doc/latex/logreq/examples
%dir %{_texmfdistdir}/doc/latex/longdivision
%dir %{_texmfdistdir}/doc/latex/longfbox
%dir %{_texmfdistdir}/doc/latex/longfigure
%dir %{_texmfdistdir}/doc/latex/longnamefilelist
%dir %{_texmfdistdir}/doc/latex/loops
%dir %{_texmfdistdir}/doc/latex/lpic
%dir %{_texmfdistdir}/doc/latex/lplfitch
%dir %{_texmfdistdir}/doc/latex/lps
%dir %{_texmfdistdir}/doc/latex/lroundrect
%dir %{_texmfdistdir}/doc/latex/lsc
%dir %{_texmfdistdir}/doc/latex/lshort-bulgarian
%dir %{_texmfdistdir}/doc/latex/lshort-bulgarian/src
%dir %{_texmfdistdir}/doc/latex/lshort-chinese
%dir %{_texmfdistdir}/doc/latex/lshort-chinese/src
%dir %{_texmfdistdir}/doc/latex/lshort-chinese/src/chap
%dir %{_texmfdistdir}/doc/latex/lshort-czech
%dir %{_texmfdistdir}/doc/latex/lshort-czech/src
%dir %{_texmfdistdir}/doc/latex/lshort-dutch
%dir %{_texmfdistdir}/doc/latex/lshort-english
%dir %{_texmfdistdir}/doc/latex/lshort-estonian
%dir %{_texmfdistdir}/doc/latex/lshort-estonian/src
%dir %{_texmfdistdir}/doc/latex/lshort-finnish
%dir %{_texmfdistdir}/doc/latex/lshort-finnish/src
%dir %{_texmfdistdir}/doc/latex/lshort-french
%dir %{_texmfdistdir}/doc/latex/lshort-german
%dir %{_texmfdistdir}/doc/latex/lshort-italian
%dir %{_texmfdistdir}/doc/latex/lshort-japanese
%dir %{_texmfdistdir}/doc/latex/lshort-korean
%dir %{_texmfdistdir}/doc/latex/lshort-mongol
%dir %{_texmfdistdir}/doc/latex/lshort-mongol/src
%dir %{_texmfdistdir}/doc/latex/lshort-persian
%dir %{_texmfdistdir}/doc/latex/lshort-polish
%dir %{_texmfdistdir}/doc/latex/lshort-portuguese
%dir %{_texmfdistdir}/doc/latex/lshort-russian
%dir %{_texmfdistdir}/doc/latex/lshort-slovak
%dir %{_texmfdistdir}/doc/latex/lshort-slovenian
%dir %{_texmfdistdir}/doc/latex/lshort-slovenian/src
%dir %{_texmfdistdir}/doc/latex/lshort-spanish
%dir %{_texmfdistdir}/doc/latex/lshort-spanish/fuente
%dir %{_texmfdistdir}/doc/latex/lshort-spanish/fuente/src
%dir %{_texmfdistdir}/doc/latex/lshort-thai
%dir %{_texmfdistdir}/doc/latex/lshort-turkish
%dir %{_texmfdistdir}/doc/latex/lshort-ukr
%dir %{_texmfdistdir}/doc/latex/lshort-vietnamese
%dir %{_texmfdistdir}/doc/latex/lshort-vietnamese/src
%dir %{_texmfdistdir}/doc/latex/lstaddons
%dir %{_texmfdistdir}/doc/latex/lstbayes
%dir %{_texmfdistdir}/doc/latex/lstfiracode
%dir %{_texmfdistdir}/doc/latex/lt3graph
%dir %{_texmfdistdir}/doc/latex/lt3rawobjects
%dir %{_texmfdistdir}/doc/latex/ltablex
%dir %{_texmfdistdir}/doc/latex/ltabptch
%dir %{_texmfdistdir}/doc/latex/ltb2bib
%dir %{_texmfdistdir}/doc/latex/ltxdockit
%dir %{_texmfdistdir}/doc/latex/ltxguidex
%dir %{_texmfdistdir}/doc/latex/ltxkeys
%dir %{_texmfdistdir}/doc/latex/ltxnew
%dir %{_texmfdistdir}/doc/latex/ltxtools
%dir %{_texmfdistdir}/doc/latex/luacolor
%dir %{_texmfdistdir}/doc/latex/lualatex-doc-de
%dir %{_texmfdistdir}/doc/latex/lwarp
%dir %{_texmfdistdir}/doc/latex/ly1
%dir %{_texmfdistdir}/doc/latex/macrolist
%dir %{_texmfdistdir}/doc/latex/macros2e
%dir %{_texmfdistdir}/doc/latex/macroswap
%dir %{_texmfdistdir}/doc/latex/mafr
%dir %{_texmfdistdir}/doc/latex/magaz
%dir %{_texmfdistdir}/doc/latex/magicnum
%dir %{_texmfdistdir}/doc/latex/magicwatermark
%dir %{_texmfdistdir}/doc/latex/mahjong
%dir %{_texmfdistdir}/doc/latex/mailing
%dir %{_texmfdistdir}/doc/latex/mailmerge
%dir %{_texmfdistdir}/doc/latex/makebarcode
%dir %{_texmfdistdir}/doc/latex/makebase
%dir %{_texmfdistdir}/doc/latex/makebox
%dir %{_texmfdistdir}/doc/latex/makecell
%dir %{_texmfdistdir}/doc/latex/makecmds
%dir %{_texmfdistdir}/doc/latex/makeglos
%dir %{_texmfdistdir}/doc/latex/makelabels
%dir %{_texmfdistdir}/doc/latex/makeplot
%dir %{_texmfdistdir}/doc/latex/maker
%dir %{_texmfdistdir}/doc/latex/makerobust
%dir %{_texmfdistdir}/doc/latex/makeshape
%dir %{_texmfdistdir}/doc/latex/mandi
%dir %{_texmfdistdir}/doc/latex/manfnt
%dir %{_texmfdistdir}/doc/latex/manuscript
%dir %{_texmfdistdir}/doc/latex/manyind
%dir %{_texmfdistdir}/doc/latex/marathi
%dir %{_texmfdistdir}/doc/latex/margbib
%dir %{_texmfdistdir}/doc/latex/marginfit
%dir %{_texmfdistdir}/doc/latex/marginfix
%dir %{_texmfdistdir}/doc/latex/marginnote
%dir %{_texmfdistdir}/doc/latex/markdown
%dir %{_texmfdistdir}/doc/latex/markdown/examples
%dir %{_texmfdistdir}/doc/latex/matapli
%dir %{_texmfdistdir}/doc/latex/matapli/auto
%dir %{_texmfdistdir}/doc/latex/matapli/examples
%dir %{_texmfdistdir}/doc/latex/matapli/examples/couverture
%dir %{_texmfdistdir}/doc/latex/matapli/examples/modeleauteur
%dir %{_texmfdistdir}/doc/latex/matc3
%dir %{_texmfdistdir}/doc/latex/matc3mem
%dir %{_texmfdistdir}/doc/latex/math-into-latex-4
%dir %{_texmfdistdir}/doc/latex/mathalpha
%dir %{_texmfdistdir}/doc/latex/mathastext
%dir %{_texmfdistdir}/doc/latex/mathcommand
%dir %{_texmfdistdir}/doc/latex/mathcomp
%dir %{_texmfdistdir}/doc/latex/mathexam
%dir %{_texmfdistdir}/doc/latex/mathfam256
%dir %{_texmfdistdir}/doc/latex/mathfixs
%dir %{_texmfdistdir}/doc/latex/mathfont
%dir %{_texmfdistdir}/doc/latex/mathpartir
%dir %{_texmfdistdir}/doc/latex/mathpazo
%dir %{_texmfdistdir}/doc/latex/mathpunctspace
%dir %{_texmfdistdir}/doc/latex/maths-symbols
%dir %{_texmfdistdir}/doc/latex/mathsemantics
%dir %{_texmfdistdir}/doc/latex/mathspic
%dir %{_texmfdistdir}/doc/latex/mathtools
%dir %{_texmfdistdir}/doc/latex/matlab-prettifier
%dir %{_texmfdistdir}/doc/latex/matrix-skeleton
%dir %{_texmfdistdir}/doc/latex/mattens
%dir %{_texmfdistdir}/doc/latex/maybemath
%dir %{_texmfdistdir}/doc/latex/maze
%dir %{_texmfdistdir}/doc/latex/mcaption
%dir %{_texmfdistdir}/doc/latex/mceinleger
%dir %{_texmfdistdir}/doc/latex/mcexam
%dir %{_texmfdistdir}/doc/latex/mcite
%dir %{_texmfdistdir}/doc/latex/mciteplus
%dir %{_texmfdistdir}/doc/latex/mcmthesis
%dir %{_texmfdistdir}/doc/latex/mcmthesis/code
%dir %{_texmfdistdir}/doc/latex/mcmthesis/figures
%dir %{_texmfdistdir}/doc/latex/mdframed
%dir %{_texmfdistdir}/doc/latex/mdputu
%dir %{_texmfdistdir}/doc/latex/mdsymbol
%dir %{_texmfdistdir}/doc/latex/mdwtools
%dir %{_texmfdistdir}/doc/latex/mecaso
%dir %{_texmfdistdir}/doc/latex/media4svg
%dir %{_texmfdistdir}/doc/latex/media4svg/example
%dir %{_texmfdistdir}/doc/latex/media9
%dir %{_texmfdistdir}/doc/latex/medstarbeamer
%dir %{_texmfdistdir}/doc/latex/meetingmins
%dir %{_texmfdistdir}/doc/latex/meetingmins/samples
%dir %{_texmfdistdir}/doc/latex/membranecomputing
%dir %{_texmfdistdir}/doc/latex/memexsupp
%dir %{_texmfdistdir}/doc/latex/memoir
%dir %{_texmfdistdir}/doc/latex/memoirchapterstyles
%dir %{_texmfdistdir}/doc/latex/memory
%dir %{_texmfdistdir}/doc/latex/memorygraphs
%dir %{_texmfdistdir}/doc/latex/mensa-tex
%dir %{_texmfdistdir}/doc/latex/mensa-tex/doc
%dir %{_texmfdistdir}/doc/latex/mentis
%dir %{_texmfdistdir}/doc/latex/menu
%dir %{_texmfdistdir}/doc/latex/menucard
%dir %{_texmfdistdir}/doc/latex/menukeys
%dir %{_texmfdistdir}/doc/latex/mercatormap
%dir %{_texmfdistdir}/doc/latex/messagepassing
%dir %{_texmfdistdir}/doc/latex/metalogo
%dir %{_texmfdistdir}/doc/latex/metalogox
%dir %{_texmfdistdir}/doc/latex/metanorma
%dir %{_texmfdistdir}/doc/latex/metaplot
%dir %{_texmfdistdir}/doc/latex/metaplot/examples
%dir %{_texmfdistdir}/doc/latex/metastr
%dir %{_texmfdistdir}/doc/latex/method
%dir %{_texmfdistdir}/doc/latex/metre
%dir %{_texmfdistdir}/doc/latex/metrix
%dir %{_texmfdistdir}/doc/latex/mfirstuc
%dir %{_texmfdistdir}/doc/latex/mflogo
%dir %{_texmfdistdir}/doc/latex/mfnfss
%dir %{_texmfdistdir}/doc/latex/mfpic4ode
%dir %{_texmfdistdir}/doc/latex/mfpic4ode/demo
%dir %{_texmfdistdir}/doc/latex/mftinc
%dir %{_texmfdistdir}/doc/latex/mgltex
%dir %{_texmfdistdir}/doc/latex/mhchem
%dir %{_texmfdistdir}/doc/latex/mhequ
%dir %{_texmfdistdir}/doc/latex/mi-solns
%dir %{_texmfdistdir}/doc/latex/mi-solns/docs
%dir %{_texmfdistdir}/doc/latex/mi-solns/examples
%dir %{_texmfdistdir}/doc/latex/microtype
%dir %{_texmfdistdir}/doc/latex/microtype-de
%dir %{_texmfdistdir}/doc/latex/midpage
%dir %{_texmfdistdir}/doc/latex/miller
%dir %{_texmfdistdir}/doc/latex/milog
%dir %{_texmfdistdir}/doc/latex/milsymb
%dir %{_texmfdistdir}/doc/latex/milsymb/manual_examples
%dir %{_texmfdistdir}/doc/latex/milsymb/manual_scripts
%dir %{_texmfdistdir}/doc/latex/mindflow
%dir %{_texmfdistdir}/doc/latex/minibox
%dir %{_texmfdistdir}/doc/latex/minidocument
%dir %{_texmfdistdir}/doc/latex/minim-hatching
%dir %{_texmfdistdir}/doc/latex/minimalist
%dir %{_texmfdistdir}/doc/latex/minipage-marginpar
%dir %{_texmfdistdir}/doc/latex/miniplot
%dir %{_texmfdistdir}/doc/latex/minitoc
%dir %{_texmfdistdir}/doc/latex/minitoc/examples
%dir %{_texmfdistdir}/doc/latex/minitoc/images
%dir %{_texmfdistdir}/doc/latex/minorrevision
%dir %{_texmfdistdir}/doc/latex/minted
%dir %{_texmfdistdir}/doc/latex/minutes
%dir %{_texmfdistdir}/doc/latex/mismath
%dir %{_texmfdistdir}/doc/latex/mla-paper
%dir %{_texmfdistdir}/doc/latex/mlacls
%dir %{_texmfdistdir}/doc/latex/mleftright
%dir %{_texmfdistdir}/doc/latex/mlist
%dir %{_texmfdistdir}/doc/latex/mltex
%dir %{_texmfdistdir}/doc/latex/mluexercise
%dir %{_texmfdistdir}/doc/latex/mmap
%dir %{_texmfdistdir}/doc/latex/mnotes
%dir %{_texmfdistdir}/doc/latex/mnras
%dir %{_texmfdistdir}/doc/latex/mnras/legacy
%dir %{_texmfdistdir}/doc/latex/mnsymbol
%dir %{_texmfdistdir}/doc/latex/modeles-factures-belges-assocs
%dir %{_texmfdistdir}/doc/latex/moderncv
%dir %{_texmfdistdir}/doc/latex/moderncv/manual
%dir %{_texmfdistdir}/doc/latex/modernposter
%dir %{_texmfdistdir}/doc/latex/moderntimeline
%dir %{_texmfdistdir}/doc/latex/modiagram
%dir %{_texmfdistdir}/doc/latex/modref
%dir %{_texmfdistdir}/doc/latex/modroman
%dir %{_texmfdistdir}/doc/latex/modular
%dir %{_texmfdistdir}/doc/latex/modular/doc
%dir %{_texmfdistdir}/doc/latex/modular/doc/example
%dir %{_texmfdistdir}/doc/latex/modular/doc/example/octopus
%dir %{_texmfdistdir}/doc/latex/mongolian-babel
%dir %{_texmfdistdir}/doc/latex/monofill
%dir %{_texmfdistdir}/doc/latex/montex
%dir %{_texmfdistdir}/doc/latex/montex/mfinput
%dir %{_texmfdistdir}/doc/latex/montex/mfinput/bithe
%dir %{_texmfdistdir}/doc/latex/moodle
%dir %{_texmfdistdir}/doc/latex/moodle/test
%dir %{_texmfdistdir}/doc/latex/moodle/test/fig
%dir %{_texmfdistdir}/doc/latex/moodle/test/latin1ref
%dir %{_texmfdistdir}/doc/latex/moodle/test/utf8ref
%dir %{_texmfdistdir}/doc/latex/moreenum
%dir %{_texmfdistdir}/doc/latex/morefloats
%dir %{_texmfdistdir}/doc/latex/morehype
%dir %{_texmfdistdir}/doc/latex/morehype/blogdemo
%dir %{_texmfdistdir}/doc/latex/morehype/blogdemo/hellowor
%dir %{_texmfdistdir}/doc/latex/morehype/blogdemo/writings
%dir %{_texmfdistdir}/doc/latex/moresize
%dir %{_texmfdistdir}/doc/latex/moreverb
%dir %{_texmfdistdir}/doc/latex/morewrites
%dir %{_texmfdistdir}/doc/latex/movie15
%dir %{_texmfdistdir}/doc/latex/movie15/files
%dir %{_texmfdistdir}/doc/latex/movie15/javascript
%dir %{_texmfdistdir}/doc/latex/mparhack
%dir %{_texmfdistdir}/doc/latex/mpgraphics
%dir %{_texmfdistdir}/doc/latex/mpostinl
%dir %{_texmfdistdir}/doc/latex/ms
%dir %{_texmfdistdir}/doc/latex/msc
%dir %{_texmfdistdir}/doc/latex/msg
%dir %{_texmfdistdir}/doc/latex/mslapa
%dir %{_texmfdistdir}/doc/latex/msu-thesis
%dir %{_texmfdistdir}/doc/latex/msu-thesis/docs
%dir %{_texmfdistdir}/doc/latex/msu-thesis/samples
%dir %{_texmfdistdir}/doc/latex/mtgreek
%dir %{_texmfdistdir}/doc/latex/mucproc
%dir %{_texmfdistdir}/doc/latex/mugsthesis
%dir %{_texmfdistdir}/doc/latex/mugsthesis/sample
%dir %{_texmfdistdir}/doc/latex/muling
%dir %{_texmfdistdir}/doc/latex/multenum
%dir %{_texmfdistdir}/doc/latex/multiaudience
%dir %{_texmfdistdir}/doc/latex/multibbl
%dir %{_texmfdistdir}/doc/latex/multibib
%dir %{_texmfdistdir}/doc/latex/multibibliography
%dir %{_texmfdistdir}/doc/latex/multicap
%dir %{_texmfdistdir}/doc/latex/multicolrule
%dir %{_texmfdistdir}/doc/latex/multidef
%dir %{_texmfdistdir}/doc/latex/multienv
%dir %{_texmfdistdir}/doc/latex/multifootnote
%dir %{_texmfdistdir}/doc/latex/multilang
%dir %{_texmfdistdir}/doc/latex/multiobjective
%dir %{_texmfdistdir}/doc/latex/multiple-choice
%dir %{_texmfdistdir}/doc/latex/multirow
%dir %{_texmfdistdir}/doc/latex/munich
%dir %{_texmfdistdir}/doc/latex/musical
%dir %{_texmfdistdir}/doc/latex/musicography
%dir %{_texmfdistdir}/doc/latex/musikui
%dir %{_texmfdistdir}/doc/latex/musixguit
%dir %{_texmfdistdir}/doc/latex/musuos
%dir %{_texmfdistdir}/doc/latex/muthesis
%dir %{_texmfdistdir}/doc/latex/mversion
%dir %{_texmfdistdir}/doc/latex/mwcls
%dir %{_texmfdistdir}/doc/latex/mwe
%dir %{_texmfdistdir}/doc/latex/mweights
%dir %{_texmfdistdir}/doc/latex/mycv
%dir %{_texmfdistdir}/doc/latex/mycv/Doc
%dir %{_texmfdistdir}/doc/latex/mycv/Doc/Images
%dir %{_texmfdistdir}/doc/latex/mycv/Examples
%dir %{_texmfdistdir}/doc/latex/mylatex
%dir %{_texmfdistdir}/doc/latex/mylatexformat
%dir %{_texmfdistdir}/doc/latex/nag
%dir %{_texmfdistdir}/doc/latex/naive-ebnf
%dir %{_texmfdistdir}/doc/latex/nameauth
%dir %{_texmfdistdir}/doc/latex/namedtensor
%dir %{_texmfdistdir}/doc/latex/namespc
%dir %{_texmfdistdir}/doc/latex/natbib
%dir %{_texmfdistdir}/doc/latex/natded
%dir %{_texmfdistdir}/doc/latex/nath
%dir %{_texmfdistdir}/doc/latex/nature
%dir %{_texmfdistdir}/doc/latex/navydocs
%dir %{_texmfdistdir}/doc/latex/navydocs/graphics
%dir %{_texmfdistdir}/doc/latex/ncclatex
%dir %{_texmfdistdir}/doc/latex/ncctools
%dir %{_texmfdistdir}/doc/latex/nchairx
%dir %{_texmfdistdir}/doc/latex/nddiss
%dir %{_texmfdistdir}/doc/latex/ndsu-thesis
%dir %{_texmfdistdir}/doc/latex/ndsu-thesis-2022
%dir %{_texmfdistdir}/doc/latex/ndsu-thesis-2022/figures
%dir %{_texmfdistdir}/doc/latex/needspace
%dir %{_texmfdistdir}/doc/latex/neuralnetwork
%dir %{_texmfdistdir}/doc/latex/neuralnetwork/examples
%dir %{_texmfdistdir}/doc/latex/nevelok
%dir %{_texmfdistdir}/doc/latex/newcommand
%dir %{_texmfdistdir}/doc/latex/newenviron
%dir %{_texmfdistdir}/doc/latex/newfile
%dir %{_texmfdistdir}/doc/latex/newfloat
%dir %{_texmfdistdir}/doc/latex/newlfm
%dir %{_texmfdistdir}/doc/latex/newpax
%dir %{_texmfdistdir}/doc/latex/newspaper
%dir %{_texmfdistdir}/doc/latex/newunicodechar
%dir %{_texmfdistdir}/doc/latex/newvbtm
%dir %{_texmfdistdir}/doc/latex/newverbs
%dir %{_texmfdistdir}/doc/latex/nfssext-cfr
%dir %{_texmfdistdir}/doc/latex/nicefilelist
%dir %{_texmfdistdir}/doc/latex/niceframe
%dir %{_texmfdistdir}/doc/latex/nicematrix
%dir %{_texmfdistdir}/doc/latex/nicetext
%dir %{_texmfdistdir}/doc/latex/nicetext/demo
%dir %{_texmfdistdir}/doc/latex/nidanfloat
%dir %{_texmfdistdir}/doc/latex/nih
%dir %{_texmfdistdir}/doc/latex/nihbiosketch
%dir %{_texmfdistdir}/doc/latex/nimsticks
%dir %{_texmfdistdir}/doc/latex/ninecolors
%dir %{_texmfdistdir}/doc/latex/njurepo
%dir %{_texmfdistdir}/doc/latex/njurepo/ref
%dir %{_texmfdistdir}/doc/latex/njustthesis
%dir %{_texmfdistdir}/doc/latex/njuthesis
%dir %{_texmfdistdir}/doc/latex/njuvisual
%dir %{_texmfdistdir}/doc/latex/nl-interval
%dir %{_texmfdistdir}/doc/latex/nlctdoc
%dir %{_texmfdistdir}/doc/latex/nmbib
%dir %{_texmfdistdir}/doc/latex/nndraw
%dir %{_texmfdistdir}/doc/latex/nnext
%dir %{_texmfdistdir}/doc/latex/noconflict
%dir %{_texmfdistdir}/doc/latex/noindentafter
%dir %{_texmfdistdir}/doc/latex/noitcrul
%dir %{_texmfdistdir}/doc/latex/nolbreaks
%dir %{_texmfdistdir}/doc/latex/nomencl
%dir %{_texmfdistdir}/doc/latex/nomentbl
%dir %{_texmfdistdir}/doc/latex/nonfloat
%dir %{_texmfdistdir}/doc/latex/nonumonpart
%dir %{_texmfdistdir}/doc/latex/nopageno
%dir %{_texmfdistdir}/doc/latex/normalcolor
%dir %{_texmfdistdir}/doc/latex/nostarch
%dir %{_texmfdistdir}/doc/latex/notes
%dir %{_texmfdistdir}/doc/latex/notes2bib
%dir %{_texmfdistdir}/doc/latex/notespages
%dir %{_texmfdistdir}/doc/latex/notestex
%dir %{_texmfdistdir}/doc/latex/notoccite
%dir %{_texmfdistdir}/doc/latex/nowidow
%dir %{_texmfdistdir}/doc/latex/nox
%dir %{_texmfdistdir}/doc/latex/nrc
%dir %{_texmfdistdir}/doc/latex/ntgclass
%dir %{_texmfdistdir}/doc/latex/ntheorem
%dir %{_texmfdistdir}/doc/latex/ntheorem-vn
%dir %{_texmfdistdir}/doc/latex/ntheorem-vn/src
%dir %{_texmfdistdir}/doc/latex/nuc
%dir %{_texmfdistdir}/doc/latex/nucleardata
%dir %{_texmfdistdir}/doc/latex/numberedblock
%dir %{_texmfdistdir}/doc/latex/numberpt
%dir %{_texmfdistdir}/doc/latex/numerica
%dir %{_texmfdistdir}/doc/latex/numerica-plus
%dir %{_texmfdistdir}/doc/latex/numerica-tables
%dir %{_texmfdistdir}/doc/latex/numericplots
%dir %{_texmfdistdir}/doc/latex/numericplots/src
%dir %{_texmfdistdir}/doc/latex/numericplots/src/examples
%dir %{_texmfdistdir}/doc/latex/numname
%dir %{_texmfdistdir}/doc/latex/numnameru
%dir %{_texmfdistdir}/doc/latex/numprint
%dir %{_texmfdistdir}/doc/latex/numspell
%dir %{_texmfdistdir}/doc/latex/nwafuthesis
%dir %{_texmfdistdir}/doc/latex/nwafuthesis/logo
%dir %{_texmfdistdir}/doc/latex/nwejm
%dir %{_texmfdistdir}/doc/latex/nwejm/addons
%dir %{_texmfdistdir}/doc/latex/nwejm/addons/completion
%dir %{_texmfdistdir}/doc/latex/nwejm/english
%dir %{_texmfdistdir}/doc/latex/nwejm/examples
%dir %{_texmfdistdir}/doc/latex/nwejm/french
%dir %{_texmfdistdir}/doc/latex/oberdiek
%dir %{_texmfdistdir}/doc/latex/oberdiek/example
%dir %{_texmfdistdir}/doc/latex/objectz
%dir %{_texmfdistdir}/doc/latex/ocg-p
%dir %{_texmfdistdir}/doc/latex/ocg-p/examples
%dir %{_texmfdistdir}/doc/latex/ocgx
%dir %{_texmfdistdir}/doc/latex/ocgx2
%dir %{_texmfdistdir}/doc/latex/ocr-latex
%dir %{_texmfdistdir}/doc/latex/octave
%dir %{_texmfdistdir}/doc/latex/octavo
%dir %{_texmfdistdir}/doc/latex/oldstyle
%dir %{_texmfdistdir}/doc/latex/onedown
%dir %{_texmfdistdir}/doc/latex/onedown/examples
%dir %{_texmfdistdir}/doc/latex/onlyamsmath
%dir %{_texmfdistdir}/doc/latex/onrannual
%dir %{_texmfdistdir}/doc/latex/opcit
%dir %{_texmfdistdir}/doc/latex/opencolor
%dir %{_texmfdistdir}/doc/latex/oplotsymbl
%dir %{_texmfdistdir}/doc/latex/opteng
%dir %{_texmfdistdir}/doc/latex/optidef
%dir %{_texmfdistdir}/doc/latex/optional
%dir %{_texmfdistdir}/doc/latex/options
%dir %{_texmfdistdir}/doc/latex/orcidlink
%dir %{_texmfdistdir}/doc/latex/ordinalpt
%dir %{_texmfdistdir}/doc/latex/orientation
%dir %{_texmfdistdir}/doc/latex/oscola
%dir %{_texmfdistdir}/doc/latex/ot-tableau
%dir %{_texmfdistdir}/doc/latex/othello
%dir %{_texmfdistdir}/doc/latex/othelloboard
%dir %{_texmfdistdir}/doc/latex/otibet
%dir %{_texmfdistdir}/doc/latex/oubraces
%dir %{_texmfdistdir}/doc/latex/oup-authoring-template
%dir %{_texmfdistdir}/doc/latex/oup-authoring-template/doc
%dir %{_texmfdistdir}/doc/latex/outilsgeomtikz
%dir %{_texmfdistdir}/doc/latex/outline
%dir %{_texmfdistdir}/doc/latex/outliner
%dir %{_texmfdistdir}/doc/latex/outlines
%dir %{_texmfdistdir}/doc/latex/outlining
%dir %{_texmfdistdir}/doc/latex/overarrows
%dir %{_texmfdistdir}/doc/latex/overlays
%dir %{_texmfdistdir}/doc/latex/overpic
%dir %{_texmfdistdir}/doc/latex/padcount
%dir %{_texmfdistdir}/doc/latex/pagecolor
%dir %{_texmfdistdir}/doc/latex/pagecont
%dir %{_texmfdistdir}/doc/latex/pagegrid
%dir %{_texmfdistdir}/doc/latex/pagelayout
%dir %{_texmfdistdir}/doc/latex/pagenote
%dir %{_texmfdistdir}/doc/latex/pagerange
%dir %{_texmfdistdir}/doc/latex/pagesel
%dir %{_texmfdistdir}/doc/latex/pageslts
%dir %{_texmfdistdir}/doc/latex/palette
%dir %{_texmfdistdir}/doc/latex/pangram
%dir %{_texmfdistdir}/doc/latex/paper
%dir %{_texmfdistdir}/doc/latex/papercdcase
%dir %{_texmfdistdir}/doc/latex/papermas
%dir %{_texmfdistdir}/doc/latex/papertex
%dir %{_texmfdistdir}/doc/latex/papertex/example
%dir %{_texmfdistdir}/doc/latex/papertex/example/img
%dir %{_texmfdistdir}/doc/latex/papertex/example/img/weather
%dir %{_texmfdistdir}/doc/latex/paracol
%dir %{_texmfdistdir}/doc/latex/parades
%dir %{_texmfdistdir}/doc/latex/parades/example
%dir %{_texmfdistdir}/doc/latex/paralist
%dir %{_texmfdistdir}/doc/latex/parallel
%dir %{_texmfdistdir}/doc/latex/paresse
%dir %{_texmfdistdir}/doc/latex/parnotes
%dir %{_texmfdistdir}/doc/latex/parrun
%dir %{_texmfdistdir}/doc/latex/parselines
%dir %{_texmfdistdir}/doc/latex/parskip
%dir %{_texmfdistdir}/doc/latex/pas-cours
%dir %{_texmfdistdir}/doc/latex/pas-crosswords
%dir %{_texmfdistdir}/doc/latex/pas-cv
%dir %{_texmfdistdir}/doc/latex/pas-cv/examples
%dir %{_texmfdistdir}/doc/latex/pas-tableur
%dir %{_texmfdistdir}/doc/latex/pascaltriangle
%dir %{_texmfdistdir}/doc/latex/patchcmd
%dir %{_texmfdistdir}/doc/latex/pauldoc
%dir %{_texmfdistdir}/doc/latex/pawpict
%dir %{_texmfdistdir}/doc/latex/pax
%dir %{_texmfdistdir}/doc/latex/pb-diagram
%dir %{_texmfdistdir}/doc/latex/pbalance
%dir %{_texmfdistdir}/doc/latex/pbibtex-manual
%dir %{_texmfdistdir}/doc/latex/pbox
%dir %{_texmfdistdir}/doc/latex/pbsheet
%dir %{_texmfdistdir}/doc/latex/pbsheet/xpl
%dir %{_texmfdistdir}/doc/latex/pbsheet/xpl/img
%dir %{_texmfdistdir}/doc/latex/pbsheet/xpl/pgm
%dir %{_texmfdistdir}/doc/latex/pdf14
%dir %{_texmfdistdir}/doc/latex/pdfcol
%dir %{_texmfdistdir}/doc/latex/pdfcolfoot
%dir %{_texmfdistdir}/doc/latex/pdfcolmk
%dir %{_texmfdistdir}/doc/latex/pdfcomment
%dir %{_texmfdistdir}/doc/latex/pdfcprot
%dir %{_texmfdistdir}/doc/latex/pdfescape
%dir %{_texmfdistdir}/doc/latex/pdflscape
%dir %{_texmfdistdir}/doc/latex/pdfmanagement-testphase
%dir %{_texmfdistdir}/doc/latex/pdfmarginpar
%dir %{_texmfdistdir}/doc/latex/pdfoverlay
%dir %{_texmfdistdir}/doc/latex/pdfpagediff
%dir %{_texmfdistdir}/doc/latex/pdfpagediff/doc
%dir %{_texmfdistdir}/doc/latex/pdfpagediff/example
%dir %{_texmfdistdir}/doc/latex/pdfpages
%dir %{_texmfdistdir}/doc/latex/pdfpc
%dir %{_texmfdistdir}/doc/latex/pdfpc-movie
%dir %{_texmfdistdir}/doc/latex/pdfprivacy
%dir %{_texmfdistdir}/doc/latex/pdfreview
%dir %{_texmfdistdir}/doc/latex/pdfscreen
%dir %{_texmfdistdir}/doc/latex/pdfslide
%dir %{_texmfdistdir}/doc/latex/pdfsync
%dir %{_texmfdistdir}/doc/latex/pdftricks
%dir %{_texmfdistdir}/doc/latex/pdftricks2
%dir %{_texmfdistdir}/doc/latex/pdfwin
%dir %{_texmfdistdir}/doc/latex/pdfx
%dir %{_texmfdistdir}/doc/latex/pecha
%dir %{_texmfdistdir}/doc/latex/penrose
%dir %{_texmfdistdir}/doc/latex/perfectcut
%dir %{_texmfdistdir}/doc/latex/perltex
%dir %{_texmfdistdir}/doc/latex/permute
%dir %{_texmfdistdir}/doc/latex/petiteannonce
%dir %{_texmfdistdir}/doc/latex/pfarrei
%dir %{_texmfdistdir}/doc/latex/pfdicons
%dir %{_texmfdistdir}/doc/latex/pgf-blur
%dir %{_texmfdistdir}/doc/latex/pgf-interference
%dir %{_texmfdistdir}/doc/latex/pgf-periodictable
%dir %{_texmfdistdir}/doc/latex/pgf-periodictable/manualfiles
%dir %{_texmfdistdir}/doc/latex/pgf-pie
%dir %{_texmfdistdir}/doc/latex/pgf-pie/demo
%dir %{_texmfdistdir}/doc/latex/pgf-soroban
%dir %{_texmfdistdir}/doc/latex/pgf-spectra
%dir %{_texmfdistdir}/doc/latex/pgf-umlcd
%dir %{_texmfdistdir}/doc/latex/pgf-umlcd/demo
%dir %{_texmfdistdir}/doc/latex/pgf-umlsd
%dir %{_texmfdistdir}/doc/latex/pgf-umlsd/demo
%dir %{_texmfdistdir}/doc/latex/pgfgantt
%dir %{_texmfdistdir}/doc/latex/pgfkeyx
%dir %{_texmfdistdir}/doc/latex/pgfmath-xfp
%dir %{_texmfdistdir}/doc/latex/pgfmorepages
%dir %{_texmfdistdir}/doc/latex/pgfopts
%dir %{_texmfdistdir}/doc/latex/pgfornament
%dir %{_texmfdistdir}/doc/latex/pgfornament-han
%dir %{_texmfdistdir}/doc/latex/pgfplots
%dir %{_texmfdistdir}/doc/latex/phfcc
%dir %{_texmfdistdir}/doc/latex/phfextendedabstract
%dir %{_texmfdistdir}/doc/latex/phffullpagefigure
%dir %{_texmfdistdir}/doc/latex/phfnote
%dir %{_texmfdistdir}/doc/latex/phfparen
%dir %{_texmfdistdir}/doc/latex/phfqit
%dir %{_texmfdistdir}/doc/latex/phfquotetext
%dir %{_texmfdistdir}/doc/latex/phfsvnwatermark
%dir %{_texmfdistdir}/doc/latex/phfthm
%dir %{_texmfdistdir}/doc/latex/philex
%dir %{_texmfdistdir}/doc/latex/philosophersimprint
%dir %{_texmfdistdir}/doc/latex/phonenumbers
%dir %{_texmfdistdir}/doc/latex/phonrule
%dir %{_texmfdistdir}/doc/latex/photo
%dir %{_texmfdistdir}/doc/latex/photobook
%dir %{_texmfdistdir}/doc/latex/photobook/scripts
%dir %{_texmfdistdir}/doc/latex/physconst
%dir %{_texmfdistdir}/doc/latex/physics
%dir %{_texmfdistdir}/doc/latex/physics2
%dir %{_texmfdistdir}/doc/latex/physunits
%dir %{_texmfdistdir}/doc/latex/piano
%dir %{_texmfdistdir}/doc/latex/picinpar
%dir %{_texmfdistdir}/doc/latex/pict2e
%dir %{_texmfdistdir}/doc/latex/pictexsum
%dir %{_texmfdistdir}/doc/latex/picture
%dir %{_texmfdistdir}/doc/latex/piff
%dir %{_texmfdistdir}/doc/latex/pigpen
%dir %{_texmfdistdir}/doc/latex/pinlabel
%dir %{_texmfdistdir}/doc/latex/pinlabel/src
%dir %{_texmfdistdir}/doc/latex/pinoutikz
%dir %{_texmfdistdir}/doc/latex/pittetd
%dir %{_texmfdistdir}/doc/latex/pixelart
%dir %{_texmfdistdir}/doc/latex/pixelarttikz
%dir %{_texmfdistdir}/doc/latex/pkgloader
%dir %{_texmfdistdir}/doc/latex/pkuthss
%dir %{_texmfdistdir}/doc/latex/pkuthss/example
%dir %{_texmfdistdir}/doc/latex/pkuthss/example/chap
%dir %{_texmfdistdir}/doc/latex/pkuthss/readme
%dir %{_texmfdistdir}/doc/latex/pkuthss/readme/chap
%dir %{_texmfdistdir}/doc/latex/placeins
%dir %{_texmfdistdir}/doc/latex/plantslabels
%dir %{_texmfdistdir}/doc/latex/plantslabels/doc
%dir %{_texmfdistdir}/doc/latex/plantslabels/doc/pdf
%dir %{_texmfdistdir}/doc/latex/plantslabels/doc/tex
%dir %{_texmfdistdir}/doc/latex/plantslabels/example
%dir %{_texmfdistdir}/doc/latex/plantslabels/example/pdf
%dir %{_texmfdistdir}/doc/latex/plantslabels/example/tex
%dir %{_texmfdistdir}/doc/latex/plari
%dir %{_texmfdistdir}/doc/latex/plates
%dir %{_texmfdistdir}/doc/latex/platex-tools
%dir %{_texmfdistdir}/doc/latex/platexcheat
%dir %{_texmfdistdir}/doc/latex/plautopatch
%dir %{_texmfdistdir}/doc/latex/play
%dir %{_texmfdistdir}/doc/latex/plweb
%dir %{_texmfdistdir}/doc/latex/pm-isomath
%dir %{_texmfdistdir}/doc/latex/pmboxdraw
%dir %{_texmfdistdir}/doc/latex/pmgraph
%dir %{_texmfdistdir}/doc/latex/pmhanguljamo
%dir %{_texmfdistdir}/doc/latex/poemscol
%dir %{_texmfdistdir}/doc/latex/poetry
%dir %{_texmfdistdir}/doc/latex/poetrytex
%dir %{_texmfdistdir}/doc/latex/polski
%dir %{_texmfdistdir}/doc/latex/polyglossia
%dir %{_texmfdistdir}/doc/latex/polynom
%dir %{_texmfdistdir}/doc/latex/polynomial
%dir %{_texmfdistdir}/doc/latex/polytable
%dir %{_texmfdistdir}/doc/latex/postage
%dir %{_texmfdistdir}/doc/latex/postcards
%dir %{_texmfdistdir}/doc/latex/postnotes
%dir %{_texmfdistdir}/doc/latex/powerdot
%dir %{_texmfdistdir}/doc/latex/powerdot-fuberlin
%dir %{_texmfdistdir}/doc/latex/powerdot-tuliplab
%dir %{_texmfdistdir}/doc/latex/ppr-prv
%dir %{_texmfdistdir}/doc/latex/ppt-slides
%dir %{_texmfdistdir}/doc/latex/pracjourn
%dir %{_texmfdistdir}/doc/latex/practicalreports
%dir %{_texmfdistdir}/doc/latex/precattl
%dir %{_texmfdistdir}/doc/latex/prelim2e
%dir %{_texmfdistdir}/doc/latex/preprint
%dir %{_texmfdistdir}/doc/latex/prerex
%dir %{_texmfdistdir}/doc/latex/pressrelease
%dir %{_texmfdistdir}/doc/latex/pressrelease/samples
%dir %{_texmfdistdir}/doc/latex/prettyref
%dir %{_texmfdistdir}/doc/latex/prettytok
%dir %{_texmfdistdir}/doc/latex/preview
%dir %{_texmfdistdir}/doc/latex/prftree
%dir %{_texmfdistdir}/doc/latex/principia
%dir %{_texmfdistdir}/doc/latex/printlen
%dir %{_texmfdistdir}/doc/latex/proba
%dir %{_texmfdistdir}/doc/latex/probsoln
%dir %{_texmfdistdir}/doc/latex/probsoln/samples
%dir %{_texmfdistdir}/doc/latex/prociagssymp
%dir %{_texmfdistdir}/doc/latex/productbox
%dir %{_texmfdistdir}/doc/latex/profcollege
%dir %{_texmfdistdir}/doc/latex/proflabo
%dir %{_texmfdistdir}/doc/latex/proflycee
%dir %{_texmfdistdir}/doc/latex/proflycee/graphics
%dir %{_texmfdistdir}/doc/latex/program
%dir %{_texmfdistdir}/doc/latex/progress
%dir %{_texmfdistdir}/doc/latex/progressbar
%dir %{_texmfdistdir}/doc/latex/projlib
%dir %{_texmfdistdir}/doc/latex/proof-at-the-end
%dir %{_texmfdistdir}/doc/latex/proofread
%dir %{_texmfdistdir}/doc/latex/prooftrees
%dir %{_texmfdistdir}/doc/latex/properties
%dir %{_texmfdistdir}/doc/latex/proposal
%dir %{_texmfdistdir}/doc/latex/proposal/base
%dir %{_texmfdistdir}/doc/latex/proposal/dfg
%dir %{_texmfdistdir}/doc/latex/proposal/dfg/proposal
%dir %{_texmfdistdir}/doc/latex/proposal/dfg/report
%dir %{_texmfdistdir}/doc/latex/proposal/eu
%dir %{_texmfdistdir}/doc/latex/proposal/eu/strep
%dir %{_texmfdistdir}/doc/latex/prosper
%dir %{_texmfdistdir}/doc/latex/protex
%dir %{_texmfdistdir}/doc/latex/protocol
%dir %{_texmfdistdir}/doc/latex/prtec
%dir %{_texmfdistdir}/doc/latex/przechlewski-book
%dir %{_texmfdistdir}/doc/latex/psbao
%dir %{_texmfdistdir}/doc/latex/pseudo
%dir %{_texmfdistdir}/doc/latex/pseudo/doc
%dir %{_texmfdistdir}/doc/latex/pseudo/doc/fig
%dir %{_texmfdistdir}/doc/latex/pseudo/test
%dir %{_texmfdistdir}/doc/latex/pseudocode
%dir %{_texmfdistdir}/doc/latex/psfrag
%dir %{_texmfdistdir}/doc/latex/psfrag-italian
%dir %{_texmfdistdir}/doc/latex/psfragx
%dir %{_texmfdistdir}/doc/latex/psgo
%dir %{_texmfdistdir}/doc/latex/psnfss
%dir %{_texmfdistdir}/doc/latex/psnfss/test
%dir %{_texmfdistdir}/doc/latex/pspicture
%dir %{_texmfdistdir}/doc/latex/pst-calendar
%dir %{_texmfdistdir}/doc/latex/pst-eucl-translation-bg
%dir %{_texmfdistdir}/doc/latex/pst-eucl-translation-bg/Exemples
%dir %{_texmfdistdir}/doc/latex/pst-exa
%dir %{_texmfdistdir}/doc/latex/pst-flags
%dir %{_texmfdistdir}/doc/latex/pst-intersect
%dir %{_texmfdistdir}/doc/latex/pst-layout
%dir %{_texmfdistdir}/doc/latex/pst-optexp
%dir %{_texmfdistdir}/doc/latex/pst-pdf
%dir %{_texmfdistdir}/doc/latex/pst-poker
%dir %{_texmfdistdir}/doc/latex/pst-vectorian
%dir %{_texmfdistdir}/doc/latex/pst-vowel
%dir %{_texmfdistdir}/doc/latex/pstool
%dir %{_texmfdistdir}/doc/latex/pstricks_calcnotes
%dir %{_texmfdistdir}/doc/latex/pstricks_calcnotes/Convert_PstricksCode_To_Pdf
%dir %{_texmfdistdir}/doc/latex/pstricks_calcnotes/For_Pdf_Output
%dir %{_texmfdistdir}/doc/latex/pstricks_calcnotes/For_Ps_Output
%dir %{_texmfdistdir}/doc/latex/pstring
%dir %{_texmfdistdir}/doc/latex/ptex2pdf
%dir %{_texmfdistdir}/doc/latex/ptolemaicastronomy
%dir %{_texmfdistdir}/doc/latex/ptptex
%dir %{_texmfdistdir}/doc/latex/punk-latex
%dir %{_texmfdistdir}/doc/latex/puyotikz
%dir %{_texmfdistdir}/doc/latex/pxcjkcat
%dir %{_texmfdistdir}/doc/latex/pxgreeks
%dir %{_texmfdistdir}/doc/latex/pxjodel
%dir %{_texmfdistdir}/doc/latex/pxpgfmark
%dir %{_texmfdistdir}/doc/latex/pxpic
%dir %{_texmfdistdir}/doc/latex/pxtatescale
%dir %{_texmfdistdir}/doc/latex/pxufont
%dir %{_texmfdistdir}/doc/latex/pygmentex
%dir %{_texmfdistdir}/doc/latex/python
%dir %{_texmfdistdir}/doc/latex/pythonhighlight
%dir %{_texmfdistdir}/doc/latex/pythonimmediate
%dir %{_texmfdistdir}/doc/latex/pythontex
%dir %{_texmfdistdir}/doc/latex/qcircuit
%dir %{_texmfdistdir}/doc/latex/qcm
%dir %{_texmfdistdir}/doc/latex/qobitree
%dir %{_texmfdistdir}/doc/latex/qrbill
%dir %{_texmfdistdir}/doc/latex/qrcode
%dir %{_texmfdistdir}/doc/latex/qsharp
%dir %{_texmfdistdir}/doc/latex/qstest
%dir %{_texmfdistdir}/doc/latex/qsymbols
%dir %{_texmfdistdir}/doc/latex/qtree
%dir %{_texmfdistdir}/doc/latex/quantikz
%dir %{_texmfdistdir}/doc/latex/quantumarticle
%dir %{_texmfdistdir}/doc/latex/quicktype
%dir %{_texmfdistdir}/doc/latex/quiz2socrative
%dir %{_texmfdistdir}/doc/latex/quotchap
%dir %{_texmfdistdir}/doc/latex/quoting
%dir %{_texmfdistdir}/doc/latex/quotmark
%dir %{_texmfdistdir}/doc/latex/quran
%dir %{_texmfdistdir}/doc/latex/quran-bn
%dir %{_texmfdistdir}/doc/latex/quran-ur
%dir %{_texmfdistdir}/doc/latex/qyxf-book
%dir %{_texmfdistdir}/doc/latex/qyxf-book/figure
%dir %{_texmfdistdir}/doc/latex/r_und_s
%dir %{_texmfdistdir}/doc/latex/ragged2e
%dir %{_texmfdistdir}/doc/latex/raleway
%dir %{_texmfdistdir}/doc/latex/ran_toks
%dir %{_texmfdistdir}/doc/latex/ran_toks/docs
%dir %{_texmfdistdir}/doc/latex/ran_toks/examples
%dir %{_texmfdistdir}/doc/latex/randbild
%dir %{_texmfdistdir}/doc/latex/randomwalk
%dir %{_texmfdistdir}/doc/latex/randtext
%dir %{_texmfdistdir}/doc/latex/rank-2-roots
%dir %{_texmfdistdir}/doc/latex/rbt-mathnotes
%dir %{_texmfdistdir}/doc/latex/rbt-mathnotes/examples
%dir %{_texmfdistdir}/doc/latex/rccol
%dir %{_texmfdistdir}/doc/latex/rcs
%dir %{_texmfdistdir}/doc/latex/rcs-multi
%dir %{_texmfdistdir}/doc/latex/rcsinfo
%dir %{_texmfdistdir}/doc/latex/readablecv
%dir %{_texmfdistdir}/doc/latex/readarray
%dir %{_texmfdistdir}/doc/latex/realboxes
%dir %{_texmfdistdir}/doc/latex/realhats
%dir %{_texmfdistdir}/doc/latex/realhats/readme_images
%dir %{_texmfdistdir}/doc/latex/realscripts
%dir %{_texmfdistdir}/doc/latex/realtranspose
%dir %{_texmfdistdir}/doc/latex/rec-thy
%dir %{_texmfdistdir}/doc/latex/recipe
%dir %{_texmfdistdir}/doc/latex/recipebook
%dir %{_texmfdistdir}/doc/latex/recipebook/images
%dir %{_texmfdistdir}/doc/latex/recipecard
%dir %{_texmfdistdir}/doc/latex/recorder-fingering
%dir %{_texmfdistdir}/doc/latex/rectopma
%dir %{_texmfdistdir}/doc/latex/refcheck
%dir %{_texmfdistdir}/doc/latex/refcount
%dir %{_texmfdistdir}/doc/latex/refenums
%dir %{_texmfdistdir}/doc/latex/refenums/test
%dir %{_texmfdistdir}/doc/latex/reflectgraphics
%dir %{_texmfdistdir}/doc/latex/refman
%dir %{_texmfdistdir}/doc/latex/refstyle
%dir %{_texmfdistdir}/doc/latex/regcount
%dir %{_texmfdistdir}/doc/latex/regexpatch
%dir %{_texmfdistdir}/doc/latex/register
%dir %{_texmfdistdir}/doc/latex/regstats
%dir %{_texmfdistdir}/doc/latex/reledmac
%dir %{_texmfdistdir}/doc/latex/reledmac/doc-include
%dir %{_texmfdistdir}/doc/latex/reledmac/doc-more
%dir %{_texmfdistdir}/doc/latex/reledmac/examples
%dir %{_texmfdistdir}/doc/latex/relenc
%dir %{_texmfdistdir}/doc/latex/relsize
%dir %{_texmfdistdir}/doc/latex/reotex
%dir %{_texmfdistdir}/doc/latex/repeatindex
%dir %{_texmfdistdir}/doc/latex/repltext
%dir %{_texmfdistdir}/doc/latex/rerunfilecheck
%dir %{_texmfdistdir}/doc/latex/rescansync
%dir %{_texmfdistdir}/doc/latex/resmes
%dir %{_texmfdistdir}/doc/latex/resolsysteme
%dir %{_texmfdistdir}/doc/latex/resphilosophica
%dir %{_texmfdistdir}/doc/latex/rest-api
%dir %{_texmfdistdir}/doc/latex/returntogrid
%dir %{_texmfdistdir}/doc/latex/revquantum
%dir %{_texmfdistdir}/doc/latex/revtex
%dir %{_texmfdistdir}/doc/latex/revtex/aip
%dir %{_texmfdistdir}/doc/latex/revtex/aps
%dir %{_texmfdistdir}/doc/latex/revtex/auguide
%dir %{_texmfdistdir}/doc/latex/revtex/sample
%dir %{_texmfdistdir}/doc/latex/revtex/sample/aapm
%dir %{_texmfdistdir}/doc/latex/revtex/sample/aip
%dir %{_texmfdistdir}/doc/latex/revtex/sample/aps
%dir %{_texmfdistdir}/doc/latex/revtex/sample/sor
%dir %{_texmfdistdir}/doc/latex/revtex4
%dir %{_texmfdistdir}/doc/latex/revtex4-1
%dir %{_texmfdistdir}/doc/latex/revtex4-1/aip
%dir %{_texmfdistdir}/doc/latex/revtex4-1/aps
%dir %{_texmfdistdir}/doc/latex/revtex4-1/auguide
%dir %{_texmfdistdir}/doc/latex/revtex4-1/sample
%dir %{_texmfdistdir}/doc/latex/revtex4-1/sample/aip
%dir %{_texmfdistdir}/doc/latex/revtex4-1/sample/aps
%dir %{_texmfdistdir}/doc/latex/revtex4-1/source
%dir %{_texmfdistdir}/doc/latex/rgltxdoc
%dir %{_texmfdistdir}/doc/latex/ribbonproofs
%dir %{_texmfdistdir}/doc/latex/rjlparshap
%dir %{_texmfdistdir}/doc/latex/rmathbr
%dir %{_texmfdistdir}/doc/latex/rmpage
%dir %{_texmfdistdir}/doc/latex/robotarm
%dir %{_texmfdistdir}/doc/latex/robustcommand
%dir %{_texmfdistdir}/doc/latex/robustindex
%dir %{_texmfdistdir}/doc/latex/romanbar
%dir %{_texmfdistdir}/doc/latex/romanbarpagenumber
%dir %{_texmfdistdir}/doc/latex/romanneg
%dir %{_texmfdistdir}/doc/latex/romannum
%dir %{_texmfdistdir}/doc/latex/rotfloat
%dir %{_texmfdistdir}/doc/latex/rotpages
%dir %{_texmfdistdir}/doc/latex/rotpages/Documentation
%dir %{_texmfdistdir}/doc/latex/rotpages/Examples
%dir %{_texmfdistdir}/doc/latex/roundbox
%dir %{_texmfdistdir}/doc/latex/rrgtrees
%dir %{_texmfdistdir}/doc/latex/rsc
%dir %{_texmfdistdir}/doc/latex/rterface
%dir %{_texmfdistdir}/doc/latex/rtkinenc
%dir %{_texmfdistdir}/doc/latex/rtklage
%dir %{_texmfdistdir}/doc/latex/rubik
%dir %{_texmfdistdir}/doc/latex/rulerbox
%dir %{_texmfdistdir}/doc/latex/rulercompass
%dir %{_texmfdistdir}/doc/latex/runcode
%dir %{_texmfdistdir}/doc/latex/runcode/generated
%dir %{_texmfdistdir}/doc/latex/russ
%dir %{_texmfdistdir}/doc/latex/rutitlepage
%dir %{_texmfdistdir}/doc/latex/rviewport
%dir %{_texmfdistdir}/doc/latex/rvwrite
%dir %{_texmfdistdir}/doc/latex/ryersonsgsthesis
%dir %{_texmfdistdir}/doc/latex/ryethesis
%dir %{_texmfdistdir}/doc/latex/sa-tikz
%dir %{_texmfdistdir}/doc/latex/sacsymb
%dir %{_texmfdistdir}/doc/latex/sageep
%dir %{_texmfdistdir}/doc/latex/sanitize-umlaut
%dir %{_texmfdistdir}/doc/latex/sankey
%dir %{_texmfdistdir}/doc/latex/sanskrit
%dir %{_texmfdistdir}/doc/latex/sansmath
%dir %{_texmfdistdir}/doc/latex/sapthesis
%dir %{_texmfdistdir}/doc/latex/sasnrdisplay
%dir %{_texmfdistdir}/doc/latex/sauerj
%dir %{_texmfdistdir}/doc/latex/sauterfonts
%dir %{_texmfdistdir}/doc/latex/saveenv
%dir %{_texmfdistdir}/doc/latex/savefnmark
%dir %{_texmfdistdir}/doc/latex/savetrees
%dir %{_texmfdistdir}/doc/latex/scale
%dir %{_texmfdistdir}/doc/latex/scalebar
%dir %{_texmfdistdir}/doc/latex/scalerel
%dir %{_texmfdistdir}/doc/latex/scanpages
%dir %{_texmfdistdir}/doc/latex/schedule
%dir %{_texmfdistdir}/doc/latex/schemabloc
%dir %{_texmfdistdir}/doc/latex/schooldocs
%dir %{_texmfdistdir}/doc/latex/schule
%dir %{_texmfdistdir}/doc/latex/schule/Abbildungen
%dir %{_texmfdistdir}/doc/latex/schule/Beispiele
%dir %{_texmfdistdir}/doc/latex/schule/source
%dir %{_texmfdistdir}/doc/latex/schule/source/Module
%dir %{_texmfdistdir}/doc/latex/schule/source/Module/GENord
%dir %{_texmfdistdir}/doc/latex/schule/source/Module/GENordLogbuch
%dir %{_texmfdistdir}/doc/latex/schulmathematik
%dir %{_texmfdistdir}/doc/latex/schwalbe-chess
%dir %{_texmfdistdir}/doc/latex/scientific-thesis-cover
%dir %{_texmfdistdir}/doc/latex/sciposter
%dir %{_texmfdistdir}/doc/latex/sciposter/sciposterexample
%dir %{_texmfdistdir}/doc/latex/sciposter/sciposterexample/auto
%dir %{_texmfdistdir}/doc/latex/sclang-prettifier
%dir %{_texmfdistdir}/doc/latex/scontents
%dir %{_texmfdistdir}/doc/latex/scrabble
%dir %{_texmfdistdir}/doc/latex/scrambledenvs
%dir %{_texmfdistdir}/doc/latex/scratch
%dir %{_texmfdistdir}/doc/latex/scratch3
%dir %{_texmfdistdir}/doc/latex/scratchx
%dir %{_texmfdistdir}/doc/latex/screenplay
%dir %{_texmfdistdir}/doc/latex/screenplay-pkg
%dir %{_texmfdistdir}/doc/latex/scripture
%dir %{_texmfdistdir}/doc/latex/scrjrnl
%dir %{_texmfdistdir}/doc/latex/scrlayer-fancyhdr
%dir %{_texmfdistdir}/doc/latex/scrlttr2copy
%dir %{_texmfdistdir}/doc/latex/scsnowman
%dir %{_texmfdistdir}/doc/latex/sdaps
%dir %{_texmfdistdir}/doc/latex/sdaps/html
%dir %{_texmfdistdir}/doc/latex/sdaps/html/_images
%dir %{_texmfdistdir}/doc/latex/sdaps/html/_sources
%dir %{_texmfdistdir}/doc/latex/sdaps/html/_static
%dir %{_texmfdistdir}/doc/latex/sdaps/html/_static/css
%dir %{_texmfdistdir}/doc/latex/sdrt
%dir %{_texmfdistdir}/doc/latex/sduthesis
%dir %{_texmfdistdir}/doc/latex/se2thesis
%dir %{_texmfdistdir}/doc/latex/secdot
%dir %{_texmfdistdir}/doc/latex/secnum
%dir %{_texmfdistdir}/doc/latex/section
%dir %{_texmfdistdir}/doc/latex/sectionbox
%dir %{_texmfdistdir}/doc/latex/sectionbox/example
%dir %{_texmfdistdir}/doc/latex/sectionbreak
%dir %{_texmfdistdir}/doc/latex/sectsty
%dir %{_texmfdistdir}/doc/latex/seealso
%dir %{_texmfdistdir}/doc/latex/selectp
%dir %{_texmfdistdir}/doc/latex/selinput
%dir %{_texmfdistdir}/doc/latex/semantex
%dir %{_texmfdistdir}/doc/latex/semantic
%dir %{_texmfdistdir}/doc/latex/semantic-markup
%dir %{_texmfdistdir}/doc/latex/seminar
%dir %{_texmfdistdir}/doc/latex/semioneside
%dir %{_texmfdistdir}/doc/latex/semproc
%dir %{_texmfdistdir}/doc/latex/semtex
%dir %{_texmfdistdir}/doc/latex/sepfootnotes
%dir %{_texmfdistdir}/doc/latex/sepnum
%dir %{_texmfdistdir}/doc/latex/seqsplit
%dir %{_texmfdistdir}/doc/latex/serbian-apostrophe
%dir %{_texmfdistdir}/doc/latex/serbian-date-lat
%dir %{_texmfdistdir}/doc/latex/serbian-def-cyr
%dir %{_texmfdistdir}/doc/latex/serbian-lig
%dir %{_texmfdistdir}/doc/latex/sesamanuel
%dir %{_texmfdistdir}/doc/latex/sesstime
%dir %{_texmfdistdir}/doc/latex/setdeck
%dir %{_texmfdistdir}/doc/latex/setspace
%dir %{_texmfdistdir}/doc/latex/seu-ml-assign
%dir %{_texmfdistdir}/doc/latex/seuthesis
%dir %{_texmfdistdir}/doc/latex/seuthesis/a3cover
%dir %{_texmfdistdir}/doc/latex/seuthesis/figures
%dir %{_texmfdistdir}/doc/latex/seuthesis/zharticle
%dir %{_texmfdistdir}/doc/latex/seuthesix
%dir %{_texmfdistdir}/doc/latex/seuthesix/figures
%dir %{_texmfdistdir}/doc/latex/sf298
%dir %{_texmfdistdir}/doc/latex/sffms
%dir %{_texmfdistdir}/doc/latex/sfg
%dir %{_texmfdistdir}/doc/latex/sgame
%dir %{_texmfdistdir}/doc/latex/shadethm
%dir %{_texmfdistdir}/doc/latex/shadow
%dir %{_texmfdistdir}/doc/latex/shadowtext
%dir %{_texmfdistdir}/doc/latex/shdoc
%dir %{_texmfdistdir}/doc/latex/shipunov
%dir %{_texmfdistdir}/doc/latex/shipunov/scripts
%dir %{_texmfdistdir}/doc/latex/short-math-guide
%dir %{_texmfdistdir}/doc/latex/shortmathj
%dir %{_texmfdistdir}/doc/latex/shorttoc
%dir %{_texmfdistdir}/doc/latex/show2e
%dir %{_texmfdistdir}/doc/latex/showcharinbox
%dir %{_texmfdistdir}/doc/latex/showdim
%dir %{_texmfdistdir}/doc/latex/showexpl
%dir %{_texmfdistdir}/doc/latex/showlabels
%dir %{_texmfdistdir}/doc/latex/showtags
%dir %{_texmfdistdir}/doc/latex/shtthesis
%dir %{_texmfdistdir}/doc/latex/shuffle
%dir %{_texmfdistdir}/doc/latex/sidecap
%dir %{_texmfdistdir}/doc/latex/sidenotes
%dir %{_texmfdistdir}/doc/latex/sidenotesplus
%dir %{_texmfdistdir}/doc/latex/sides
%dir %{_texmfdistdir}/doc/latex/signchart
%dir %{_texmfdistdir}/doc/latex/silence
%dir %{_texmfdistdir}/doc/latex/sillypage
%dir %{_texmfdistdir}/doc/latex/simplebnf
%dir %{_texmfdistdir}/doc/latex/simplecd
%dir %{_texmfdistdir}/doc/latex/simplecv
%dir %{_texmfdistdir}/doc/latex/simpleinvoice
%dir %{_texmfdistdir}/doc/latex/simpleinvoice/doc
%dir %{_texmfdistdir}/doc/latex/simpleinvoice/doc/examples
%dir %{_texmfdistdir}/doc/latex/simplenodes
%dir %{_texmfdistdir}/doc/latex/simpleoptics
%dir %{_texmfdistdir}/doc/latex/simpler-wick
%dir %{_texmfdistdir}/doc/latex/simples-matrices
%dir %{_texmfdistdir}/doc/latex/simplewick
%dir %{_texmfdistdir}/doc/latex/simplified-latex
%dir %{_texmfdistdir}/doc/latex/simplivre
%dir %{_texmfdistdir}/doc/latex/sistyle
%dir %{_texmfdistdir}/doc/latex/sitem
%dir %{_texmfdistdir}/doc/latex/siunits
%dir %{_texmfdistdir}/doc/latex/siunitx
%dir %{_texmfdistdir}/doc/latex/skak
%dir %{_texmfdistdir}/doc/latex/skb
%dir %{_texmfdistdir}/doc/latex/skb/user-guide
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/database
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/database/bibtex
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/examples
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/figures
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/figures/dirtree
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/figures/multiexample
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository/exa-doc
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository/getting-started
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository/manual
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository/separate
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/repository/story
%dir %{_texmfdistdir}/doc/latex/skb/user-guide/slides
%dir %{_texmfdistdir}/doc/latex/skdoc
%dir %{_texmfdistdir}/doc/latex/skeldoc
%dir %{_texmfdistdir}/doc/latex/skeycommand
%dir %{_texmfdistdir}/doc/latex/skeyval
%dir %{_texmfdistdir}/doc/latex/skills
%dir %{_texmfdistdir}/doc/latex/skmath
%dir %{_texmfdistdir}/doc/latex/skrapport
%dir %{_texmfdistdir}/doc/latex/slantsc
%dir %{_texmfdistdir}/doc/latex/smalltableof
%dir %{_texmfdistdir}/doc/latex/smart-eqn
%dir %{_texmfdistdir}/doc/latex/smartdiagram
%dir %{_texmfdistdir}/doc/latex/smartref
%dir %{_texmfdistdir}/doc/latex/smartunits
%dir %{_texmfdistdir}/doc/latex/smflatex
%dir %{_texmfdistdir}/doc/latex/snapshot
%dir %{_texmfdistdir}/doc/latex/snaptodo
%dir %{_texmfdistdir}/doc/latex/snaptodo/test
%dir %{_texmfdistdir}/doc/latex/snotez
%dir %{_texmfdistdir}/doc/latex/songbook
%dir %{_texmfdistdir}/doc/latex/songbook/contrib
%dir %{_texmfdistdir}/doc/latex/songbook/contrib/CarolBook
%dir %{_texmfdistdir}/doc/latex/songbook/contrib/crd2sb
%dir %{_texmfdistdir}/doc/latex/songproj
%dir %{_texmfdistdir}/doc/latex/songproj/examples
%dir %{_texmfdistdir}/doc/latex/songs
%dir %{_texmfdistdir}/doc/latex/songs/sample
%dir %{_texmfdistdir}/doc/latex/songs/songidx
%dir %{_texmfdistdir}/doc/latex/soton
%dir %{_texmfdistdir}/doc/latex/soulpos
%dir %{_texmfdistdir}/doc/latex/soup
%dir %{_texmfdistdir}/doc/latex/sourcecodepro
%dir %{_texmfdistdir}/doc/latex/sourcesanspro
%dir %{_texmfdistdir}/doc/latex/sourceserifpro
%dir %{_texmfdistdir}/doc/latex/spacingtricks
%dir %{_texmfdistdir}/doc/latex/spalign
%dir %{_texmfdistdir}/doc/latex/sparklines
%dir %{_texmfdistdir}/doc/latex/spath3
%dir %{_texmfdistdir}/doc/latex/spbmark
%dir %{_texmfdistdir}/doc/latex/spectralsequences
%dir %{_texmfdistdir}/doc/latex/spectralsequences/examples
%dir %{_texmfdistdir}/doc/latex/spectralsequences/manual
%dir %{_texmfdistdir}/doc/latex/spectralsequences/manual/examples
%dir %{_texmfdistdir}/doc/latex/sphdthesis
%dir %{_texmfdistdir}/doc/latex/sphdthesis/example
%dir %{_texmfdistdir}/doc/latex/spie
%dir %{_texmfdistdir}/doc/latex/splitbib
%dir %{_texmfdistdir}/doc/latex/splitindex
%dir %{_texmfdistdir}/doc/latex/spot
%dir %{_texmfdistdir}/doc/latex/spotcolor
%dir %{_texmfdistdir}/doc/latex/spreadtab
%dir %{_texmfdistdir}/doc/latex/spverbatim
%dir %{_texmfdistdir}/doc/latex/sr-vorl
%dir %{_texmfdistdir}/doc/latex/srbook-mem
%dir %{_texmfdistdir}/doc/latex/srcltx
%dir %{_texmfdistdir}/doc/latex/srdp-mathematik
%dir %{_texmfdistdir}/doc/latex/sseq
%dir %{_texmfdistdir}/doc/latex/sslides
%dir %{_texmfdistdir}/doc/latex/stackengine
%dir %{_texmfdistdir}/doc/latex/stage
%dir %{_texmfdistdir}/doc/latex/standalone
%dir %{_texmfdistdir}/doc/latex/stanli
%dir %{_texmfdistdir}/doc/latex/statex
%dir %{_texmfdistdir}/doc/latex/statex2
%dir %{_texmfdistdir}/doc/latex/statistics
%dir %{_texmfdistdir}/doc/latex/statistik
%dir %{_texmfdistdir}/doc/latex/statmath
%dir %{_texmfdistdir}/doc/latex/stdclsdv
%dir %{_texmfdistdir}/doc/latex/stdpage
%dir %{_texmfdistdir}/doc/latex/stealcaps
%dir %{_texmfdistdir}/doc/latex/stealcaps/testfile
%dir %{_texmfdistdir}/doc/latex/steinmetz
%dir %{_texmfdistdir}/doc/latex/stellenbosch
%dir %{_texmfdistdir}/doc/latex/stellenbosch/templates
%dir %{_texmfdistdir}/doc/latex/stex
%dir %{_texmfdistdir}/doc/latex/stex/img
%dir %{_texmfdistdir}/doc/latex/stex/packages
%dir %{_texmfdistdir}/doc/latex/storebox
%dir %{_texmfdistdir}/doc/latex/storecmd
%dir %{_texmfdistdir}/doc/latex/strands
%dir %{_texmfdistdir}/doc/latex/stringenc
%dir %{_texmfdistdir}/doc/latex/stringstrings
%dir %{_texmfdistdir}/doc/latex/structmech
%dir %{_texmfdistdir}/doc/latex/struktex
%dir %{_texmfdistdir}/doc/latex/sttools
%dir %{_texmfdistdir}/doc/latex/stubs
%dir %{_texmfdistdir}/doc/latex/studenthandouts
%dir %{_texmfdistdir}/doc/latex/studenthandouts/samplecode
%dir %{_texmfdistdir}/doc/latex/studenthandouts/samplecode/worksheets
%dir %{_texmfdistdir}/doc/latex/styledcmd
%dir %{_texmfdistdir}/doc/latex/subdepth
%dir %{_texmfdistdir}/doc/latex/subdocs
%dir %{_texmfdistdir}/doc/latex/subeqn
%dir %{_texmfdistdir}/doc/latex/subeqnarray
%dir %{_texmfdistdir}/doc/latex/subfig
%dir %{_texmfdistdir}/doc/latex/subfigmat
%dir %{_texmfdistdir}/doc/latex/subfigure
%dir %{_texmfdistdir}/doc/latex/subfiles
%dir %{_texmfdistdir}/doc/latex/subfloat
%dir %{_texmfdistdir}/doc/latex/substances
%dir %{_texmfdistdir}/doc/latex/substitutefont
%dir %{_texmfdistdir}/doc/latex/substr
%dir %{_texmfdistdir}/doc/latex/subsupscripts
%dir %{_texmfdistdir}/doc/latex/subtext
%dir %{_texmfdistdir}/doc/latex/sudoku
%dir %{_texmfdistdir}/doc/latex/sudokubundle
%dir %{_texmfdistdir}/doc/latex/suftesi
%dir %{_texmfdistdir}/doc/latex/sugconf
%dir %{_texmfdistdir}/doc/latex/supertabular
%dir %{_texmfdistdir}/doc/latex/suppose
%dir %{_texmfdistdir}/doc/latex/susy
%dir %{_texmfdistdir}/doc/latex/svg
%dir %{_texmfdistdir}/doc/latex/svg-inkscape
%dir %{_texmfdistdir}/doc/latex/svgcolor
%dir %{_texmfdistdir}/doc/latex/svn
%dir %{_texmfdistdir}/doc/latex/svn-multi
%dir %{_texmfdistdir}/doc/latex/svn-prov
%dir %{_texmfdistdir}/doc/latex/svninfo
%dir %{_texmfdistdir}/doc/latex/swebib
%dir %{_texmfdistdir}/doc/latex/swfigure
%dir %{_texmfdistdir}/doc/latex/swimgraf
%dir %{_texmfdistdir}/doc/latex/swungdash
%dir %{_texmfdistdir}/doc/latex/syllogism
%dir %{_texmfdistdir}/doc/latex/synproof
%dir %{_texmfdistdir}/doc/latex/syntax
%dir %{_texmfdistdir}/doc/latex/syntaxdi
%dir %{_texmfdistdir}/doc/latex/syntrace
%dir %{_texmfdistdir}/doc/latex/synttree
%dir %{_texmfdistdir}/doc/latex/t-angles
%dir %{_texmfdistdir}/doc/latex/tabbing
%dir %{_texmfdistdir}/doc/latex/tabfigures
%dir %{_texmfdistdir}/doc/latex/table-fct
%dir %{_texmfdistdir}/doc/latex/tableaux
%dir %{_texmfdistdir}/doc/latex/tablefootnote
%dir %{_texmfdistdir}/doc/latex/tableof
%dir %{_texmfdistdir}/doc/latex/tablists
%dir %{_texmfdistdir}/doc/latex/tablor
%dir %{_texmfdistdir}/doc/latex/tablor/Figures
%dir %{_texmfdistdir}/doc/latex/tablor/auto
%dir %{_texmfdistdir}/doc/latex/tabls
%dir %{_texmfdistdir}/doc/latex/tablvar
%dir %{_texmfdistdir}/doc/latex/tabriz-thesis
%dir %{_texmfdistdir}/doc/latex/tabstackengine
%dir %{_texmfdistdir}/doc/latex/tabto-ltx
%dir %{_texmfdistdir}/doc/latex/tabu
%dir %{_texmfdistdir}/doc/latex/tabularborder
%dir %{_texmfdistdir}/doc/latex/tabularcalc
%dir %{_texmfdistdir}/doc/latex/tabularew
%dir %{_texmfdistdir}/doc/latex/tabularray
%dir %{_texmfdistdir}/doc/latex/tabulary
%dir %{_texmfdistdir}/doc/latex/tabvar
%dir %{_texmfdistdir}/doc/latex/tagging
%dir %{_texmfdistdir}/doc/latex/tagpair
%dir %{_texmfdistdir}/doc/latex/tagpdf
%dir %{_texmfdistdir}/doc/latex/talk
%dir %{_texmfdistdir}/doc/latex/tamefloats
%dir %{_texmfdistdir}/doc/latex/tangramtikz
%dir %{_texmfdistdir}/doc/latex/tasks
%dir %{_texmfdistdir}/doc/latex/tcldoc
%dir %{_texmfdistdir}/doc/latex/tcldoc/examples
%dir %{_texmfdistdir}/doc/latex/tcldoc/tools
%dir %{_texmfdistdir}/doc/latex/tcolorbox
%dir %{_texmfdistdir}/doc/latex/tdclock
%dir %{_texmfdistdir}/doc/latex/tdsfrmath
%dir %{_texmfdistdir}/doc/latex/technics
%dir %{_texmfdistdir}/doc/latex/ted
%dir %{_texmfdistdir}/doc/latex/templates-fenn
%dir %{_texmfdistdir}/doc/latex/templates-sommer
%dir %{_texmfdistdir}/doc/latex/templatetools
%dir %{_texmfdistdir}/doc/latex/tengwarscript
%dir %{_texmfdistdir}/doc/latex/tensind
%dir %{_texmfdistdir}/doc/latex/tensor
%dir %{_texmfdistdir}/doc/latex/termcal
%dir %{_texmfdistdir}/doc/latex/termcal-de
%dir %{_texmfdistdir}/doc/latex/termlist
%dir %{_texmfdistdir}/doc/latex/termsim
%dir %{_texmfdistdir}/doc/latex/testhyphens
%dir %{_texmfdistdir}/doc/latex/testidx
%dir %{_texmfdistdir}/doc/latex/testidx/samples
%dir %{_texmfdistdir}/doc/latex/teubner
%dir %{_texmfdistdir}/doc/latex/tex-font-errors-cheatsheet
%dir %{_texmfdistdir}/doc/latex/tex-label
%dir %{_texmfdistdir}/doc/latex/tex-overview
%dir %{_texmfdistdir}/doc/latex/tex-vpat
%dir %{_texmfdistdir}/doc/latex/texmate
%dir %{_texmfdistdir}/doc/latex/texments
%dir %{_texmfdistdir}/doc/latex/texnegar
%dir %{_texmfdistdir}/doc/latex/texpower
%dir %{_texmfdistdir}/doc/latex/texpower/contrib
%dir %{_texmfdistdir}/doc/latex/texpower/tpslifonts
%dir %{_texmfdistdir}/doc/latex/texproposal
%dir %{_texmfdistdir}/doc/latex/texproposal/contents
%dir %{_texmfdistdir}/doc/latex/texproposal/figures
%dir %{_texmfdistdir}/doc/latex/texproposal/ref
%dir %{_texmfdistdir}/doc/latex/texproposal/scripts
%dir %{_texmfdistdir}/doc/latex/texshade
%dir %{_texmfdistdir}/doc/latex/texsurgery
%dir %{_texmfdistdir}/doc/latex/textcase
%dir %{_texmfdistdir}/doc/latex/textcsc
%dir %{_texmfdistdir}/doc/latex/textfit
%dir %{_texmfdistdir}/doc/latex/textglos
%dir %{_texmfdistdir}/doc/latex/textgreek
%dir %{_texmfdistdir}/doc/latex/textopo
%dir %{_texmfdistdir}/doc/latex/textpos
%dir %{_texmfdistdir}/doc/latex/textpos/examples
%dir %{_texmfdistdir}/doc/latex/textualicomma
%dir %{_texmfdistdir}/doc/latex/texvc
%dir %{_texmfdistdir}/doc/latex/thaienum
%dir %{_texmfdistdir}/doc/latex/thaispec
%dir %{_texmfdistdir}/doc/latex/thalie
%dir %{_texmfdistdir}/doc/latex/theatre
%dir %{_texmfdistdir}/doc/latex/theatre/doc
%dir %{_texmfdistdir}/doc/latex/theatre/doc/help_source
%dir %{_texmfdistdir}/doc/latex/theatre/doc/help_source/util
%dir %{_texmfdistdir}/doc/latex/theatre/tex
%dir %{_texmfdistdir}/doc/latex/theoremref
%dir %{_texmfdistdir}/doc/latex/thermodynamics
%dir %{_texmfdistdir}/doc/latex/thesis-ekf
%dir %{_texmfdistdir}/doc/latex/thesis-gwu
%dir %{_texmfdistdir}/doc/latex/thesis-gwu/figures
%dir %{_texmfdistdir}/doc/latex/thesis-gwu/tex
%dir %{_texmfdistdir}/doc/latex/thesis-titlepage-fhac
%dir %{_texmfdistdir}/doc/latex/thinsp
%dir %{_texmfdistdir}/doc/latex/thmbox
%dir %{_texmfdistdir}/doc/latex/thmtools
%dir %{_texmfdistdir}/doc/latex/threadcol
%dir %{_texmfdistdir}/doc/latex/threeparttable
%dir %{_texmfdistdir}/doc/latex/threeparttablex
%dir %{_texmfdistdir}/doc/latex/thuaslogos
%dir %{_texmfdistdir}/doc/latex/thubeamer
%dir %{_texmfdistdir}/doc/latex/thucoursework
%dir %{_texmfdistdir}/doc/latex/thumb
%dir %{_texmfdistdir}/doc/latex/thumbs
%dir %{_texmfdistdir}/doc/latex/thumby
%dir %{_texmfdistdir}/doc/latex/thuthesis
%dir %{_texmfdistdir}/doc/latex/thuthesis/data
%dir %{_texmfdistdir}/doc/latex/thuthesis/ref
%dir %{_texmfdistdir}/doc/latex/ticket
%dir %{_texmfdistdir}/doc/latex/ticollege
%dir %{_texmfdistdir}/doc/latex/tidyres
%dir %{_texmfdistdir}/doc/latex/tikz-3dplot
%dir %{_texmfdistdir}/doc/latex/tikz-among-us
%dir %{_texmfdistdir}/doc/latex/tikz-bagua
%dir %{_texmfdistdir}/doc/latex/tikz-bayesnet
%dir %{_texmfdistdir}/doc/latex/tikz-bbox
%dir %{_texmfdistdir}/doc/latex/tikz-cd
%dir %{_texmfdistdir}/doc/latex/tikz-dependency
%dir %{_texmfdistdir}/doc/latex/tikz-dimline
%dir %{_texmfdistdir}/doc/latex/tikz-ext
%dir %{_texmfdistdir}/doc/latex/tikz-feynhand
%dir %{_texmfdistdir}/doc/latex/tikz-feynman
%dir %{_texmfdistdir}/doc/latex/tikz-imagelabels
%dir %{_texmfdistdir}/doc/latex/tikz-inet
%dir %{_texmfdistdir}/doc/latex/tikz-kalender
%dir %{_texmfdistdir}/doc/latex/tikz-karnaugh
%dir %{_texmfdistdir}/doc/latex/tikz-ladder
%dir %{_texmfdistdir}/doc/latex/tikz-lake-fig
%dir %{_texmfdistdir}/doc/latex/tikz-layers
%dir %{_texmfdistdir}/doc/latex/tikz-mirror-lens
%dir %{_texmfdistdir}/doc/latex/tikz-nef
%dir %{_texmfdistdir}/doc/latex/tikz-network
%dir %{_texmfdistdir}/doc/latex/tikz-network/data
%dir %{_texmfdistdir}/doc/latex/tikz-opm
%dir %{_texmfdistdir}/doc/latex/tikz-optics
%dir %{_texmfdistdir}/doc/latex/tikz-page
%dir %{_texmfdistdir}/doc/latex/tikz-palattice
%dir %{_texmfdistdir}/doc/latex/tikz-planets
%dir %{_texmfdistdir}/doc/latex/tikz-qtree
%dir %{_texmfdistdir}/doc/latex/tikz-relay
%dir %{_texmfdistdir}/doc/latex/tikz-sfc
%dir %{_texmfdistdir}/doc/latex/tikz-swigs
%dir %{_texmfdistdir}/doc/latex/tikz-timing
%dir %{_texmfdistdir}/doc/latex/tikz-trackschematic
%dir %{_texmfdistdir}/doc/latex/tikz-trackschematic/tikz-trackschematic-examples
%dir %{_texmfdistdir}/doc/latex/tikz-trackschematic/tikz-trackschematic-snippets
%dir %{_texmfdistdir}/doc/latex/tikz-truchet
%dir %{_texmfdistdir}/doc/latex/tikzbricks
%dir %{_texmfdistdir}/doc/latex/tikzcodeblocks
%dir %{_texmfdistdir}/doc/latex/tikzcodeblocks/examples
%dir %{_texmfdistdir}/doc/latex/tikzfill
%dir %{_texmfdistdir}/doc/latex/tikzinclude
%dir %{_texmfdistdir}/doc/latex/tikzlings
%dir %{_texmfdistdir}/doc/latex/tikzmark
%dir %{_texmfdistdir}/doc/latex/tikzmarmots
%dir %{_texmfdistdir}/doc/latex/tikzorbital
%dir %{_texmfdistdir}/doc/latex/tikzpackets
%dir %{_texmfdistdir}/doc/latex/tikzpagenodes
%dir %{_texmfdistdir}/doc/latex/tikzpeople
%dir %{_texmfdistdir}/doc/latex/tikzpfeile
%dir %{_texmfdistdir}/doc/latex/tikzpingus
%dir %{_texmfdistdir}/doc/latex/tikzposter
%dir %{_texmfdistdir}/doc/latex/tikzscale
%dir %{_texmfdistdir}/doc/latex/tikzsymbols
%dir %{_texmfdistdir}/doc/latex/tikzviolinplots
%dir %{_texmfdistdir}/doc/latex/tile-graphic
%dir %{_texmfdistdir}/doc/latex/tile-graphic/docs
%dir %{_texmfdistdir}/doc/latex/tile-graphic/examples
%dir %{_texmfdistdir}/doc/latex/tile-graphic/examples/choo
%dir %{_texmfdistdir}/doc/latex/tile-graphic/examples/postscript
%dir %{_texmfdistdir}/doc/latex/timbreicmc
%dir %{_texmfdistdir}/doc/latex/timing-diagrams
%dir %{_texmfdistdir}/doc/latex/tipa-de
%dir %{_texmfdistdir}/doc/latex/tipauni
%dir %{_texmfdistdir}/doc/latex/tipfr
%dir %{_texmfdistdir}/doc/latex/tiscreen
%dir %{_texmfdistdir}/doc/latex/titlecaps
%dir %{_texmfdistdir}/doc/latex/titlepages
%dir %{_texmfdistdir}/doc/latex/titlepic
%dir %{_texmfdistdir}/doc/latex/titleref
%dir %{_texmfdistdir}/doc/latex/titlesec
%dir %{_texmfdistdir}/doc/latex/titling
%dir %{_texmfdistdir}/doc/latex/tkz-base
%dir %{_texmfdistdir}/doc/latex/tkz-berge
%dir %{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs
%dir %{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/doc
%dir %{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/doc/latex
%dir %{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/examples
%dir %{_texmfdistdir}/doc/latex/tkz-berge/NamedGraphs/examples/latex
%dir %{_texmfdistdir}/doc/latex/tkz-berge/doc
%dir %{_texmfdistdir}/doc/latex/tkz-berge/doc/latex
%dir %{_texmfdistdir}/doc/latex/tkz-berge/examples
%dir %{_texmfdistdir}/doc/latex/tkz-berge/examples/latex
%dir %{_texmfdistdir}/doc/latex/tkz-doc
%dir %{_texmfdistdir}/doc/latex/tkz-doc/doc
%dir %{_texmfdistdir}/doc/latex/tkz-doc/doc/latex
%dir %{_texmfdistdir}/doc/latex/tkz-doc/latex
%dir %{_texmfdistdir}/doc/latex/tkz-euclide
%dir %{_texmfdistdir}/doc/latex/tkz-fct
%dir %{_texmfdistdir}/doc/latex/tkz-graph
%dir %{_texmfdistdir}/doc/latex/tkz-graph/doc
%dir %{_texmfdistdir}/doc/latex/tkz-graph/doc/latex
%dir %{_texmfdistdir}/doc/latex/tkz-orm
%dir %{_texmfdistdir}/doc/latex/tkz-tab
%dir %{_texmfdistdir}/doc/latex/tkzexample
%dir %{_texmfdistdir}/doc/latex/tlc-article
%dir %{_texmfdistdir}/doc/latex/tlc-article/bin
%dir %{_texmfdistdir}/doc/latex/tlc-article/data
%dir %{_texmfdistdir}/doc/latex/tlc-article/doc
%dir %{_texmfdistdir}/doc/latex/tlc-article/images
%dir %{_texmfdistdir}/doc/latex/tlc2
%dir %{_texmfdistdir}/doc/latex/tlc3-examples
%dir %{_texmfdistdir}/doc/latex/tlc3-examples/example-sources
%dir %{_texmfdistdir}/doc/latex/to-be-determined
%dir %{_texmfdistdir}/doc/latex/tocbibind
%dir %{_texmfdistdir}/doc/latex/tocdata
%dir %{_texmfdistdir}/doc/latex/tocloft
%dir %{_texmfdistdir}/doc/latex/tocvsec2
%dir %{_texmfdistdir}/doc/latex/todo
%dir %{_texmfdistdir}/doc/latex/todonotes
%dir %{_texmfdistdir}/doc/latex/todonotes/examples
%dir %{_texmfdistdir}/doc/latex/todonotes/img
%dir %{_texmfdistdir}/doc/latex/tokenizer
%dir %{_texmfdistdir}/doc/latex/tonevalue
%dir %{_texmfdistdir}/doc/latex/toolbox
%dir %{_texmfdistdir}/doc/latex/tools
%dir %{_texmfdistdir}/doc/latex/topfloat
%dir %{_texmfdistdir}/doc/latex/topiclongtable
%dir %{_texmfdistdir}/doc/latex/topletter
%dir %{_texmfdistdir}/doc/latex/toptesi
%dir %{_texmfdistdir}/doc/latex/totalcount
%dir %{_texmfdistdir}/doc/latex/totcount
%dir %{_texmfdistdir}/doc/latex/totpages
%dir %{_texmfdistdir}/doc/latex/tpslifonts
%dir %{_texmfdistdir}/doc/latex/tqft
%dir %{_texmfdistdir}/doc/latex/trajan
%dir %{_texmfdistdir}/doc/latex/tram
%dir %{_texmfdistdir}/doc/latex/tramlines
%dir %{_texmfdistdir}/doc/latex/translation-array-fr
%dir %{_texmfdistdir}/doc/latex/translation-arsclassica-de
%dir %{_texmfdistdir}/doc/latex/translation-biblatex-de
%dir %{_texmfdistdir}/doc/latex/translation-chemsym-de
%dir %{_texmfdistdir}/doc/latex/translation-dcolumn-fr
%dir %{_texmfdistdir}/doc/latex/translation-ecv-de
%dir %{_texmfdistdir}/doc/latex/translation-enumitem-de
%dir %{_texmfdistdir}/doc/latex/translation-europecv-de
%dir %{_texmfdistdir}/doc/latex/translation-europecv-de/Beispiele
%dir %{_texmfdistdir}/doc/latex/translation-europecv-de/templates
%dir %{_texmfdistdir}/doc/latex/translation-filecontents-de
%dir %{_texmfdistdir}/doc/latex/translation-moreverb-de
%dir %{_texmfdistdir}/doc/latex/translation-natbib-fr
%dir %{_texmfdistdir}/doc/latex/translation-tabbing-fr
%dir %{_texmfdistdir}/doc/latex/translations
%dir %{_texmfdistdir}/doc/latex/translator
%dir %{_texmfdistdir}/doc/latex/transparent
%dir %{_texmfdistdir}/doc/latex/tree-dvips
%dir %{_texmfdistdir}/doc/latex/trfsigns
%dir %{_texmfdistdir}/doc/latex/trimspaces
%dir %{_texmfdistdir}/doc/latex/trivfloat
%dir %{_texmfdistdir}/doc/latex/trsym
%dir %{_texmfdistdir}/doc/latex/truncate
%dir %{_texmfdistdir}/doc/latex/tucv
%dir %{_texmfdistdir}/doc/latex/tuda-ci
%dir %{_texmfdistdir}/doc/latex/tudscr
%dir %{_texmfdistdir}/doc/latex/tudscr/tutorials
%dir %{_texmfdistdir}/doc/latex/tufte-latex
%dir %{_texmfdistdir}/doc/latex/tufte-latex/graphics
%dir %{_texmfdistdir}/doc/latex/tugboat
%dir %{_texmfdistdir}/doc/latex/tui
%dir %{_texmfdistdir}/doc/latex/tui/example
%dir %{_texmfdistdir}/doc/latex/tui/template
%dir %{_texmfdistdir}/doc/latex/turabian
%dir %{_texmfdistdir}/doc/latex/turabian-formatting
%dir %{_texmfdistdir}/doc/latex/turkmen
%dir %{_texmfdistdir}/doc/latex/turnstile
%dir %{_texmfdistdir}/doc/latex/turnthepage
%dir %{_texmfdistdir}/doc/latex/twemojis
%dir %{_texmfdistdir}/doc/latex/twoinone
%dir %{_texmfdistdir}/doc/latex/twoup
%dir %{_texmfdistdir}/doc/latex/txgreeks
%dir %{_texmfdistdir}/doc/latex/type1cm
%dir %{_texmfdistdir}/doc/latex/typed-checklist
%dir %{_texmfdistdir}/doc/latex/typeface
%dir %{_texmfdistdir}/doc/latex/typehtml
%dir %{_texmfdistdir}/doc/latex/typoaid
%dir %{_texmfdistdir}/doc/latex/typogrid
%dir %{_texmfdistdir}/doc/latex/tzplot
%dir %{_texmfdistdir}/doc/latex/uaclasses
%dir %{_texmfdistdir}/doc/latex/uafthesis
%dir %{_texmfdistdir}/doc/latex/uafthesis/bib_styles
%dir %{_texmfdistdir}/doc/latex/uafthesis/example
%dir %{_texmfdistdir}/doc/latex/uafthesis/example/fig
%dir %{_texmfdistdir}/doc/latex/uantwerpendocs
%dir %{_texmfdistdir}/doc/latex/uassign
%dir %{_texmfdistdir}/doc/latex/ucalgmthesis
%dir %{_texmfdistdir}/doc/latex/ucbthesis
%dir %{_texmfdistdir}/doc/latex/ucbthesis/example
%dir %{_texmfdistdir}/doc/latex/ucdavisthesis
%dir %{_texmfdistdir}/doc/latex/ucdavisthesis/example
%dir %{_texmfdistdir}/doc/latex/ucharcat
%dir %{_texmfdistdir}/doc/latex/ucs
%dir %{_texmfdistdir}/doc/latex/ucs/config
%dir %{_texmfdistdir}/doc/latex/ucs/unsupported
%dir %{_texmfdistdir}/doc/latex/ucs/utils
%dir %{_texmfdistdir}/doc/latex/ucsmonograph
%dir %{_texmfdistdir}/doc/latex/ucthesis
%dir %{_texmfdistdir}/doc/latex/udes-genie-these
%dir %{_texmfdistdir}/doc/latex/udes-genie-these/Exemple
%dir %{_texmfdistdir}/doc/latex/udesoftec
%dir %{_texmfdistdir}/doc/latex/uebungsblatt
%dir %{_texmfdistdir}/doc/latex/uestcthesis
%dir %{_texmfdistdir}/doc/latex/uestcthesis/doc
%dir %{_texmfdistdir}/doc/latex/uestcthesis/doc/chapters
%dir %{_texmfdistdir}/doc/latex/uestcthesis/doc/contents
%dir %{_texmfdistdir}/doc/latex/uestcthesis/doc/pics
%dir %{_texmfdistdir}/doc/latex/uestcthesis/source
%dir %{_texmfdistdir}/doc/latex/ufrgscca
%dir %{_texmfdistdir}/doc/latex/uhhassignment
%dir %{_texmfdistdir}/doc/latex/uhrzeit
%dir %{_texmfdistdir}/doc/latex/uiucredborder
%dir %{_texmfdistdir}/doc/latex/uiucthesis
%dir %{_texmfdistdir}/doc/latex/ukbill
%dir %{_texmfdistdir}/doc/latex/ulqda
%dir %{_texmfdistdir}/doc/latex/ulthese
%dir %{_texmfdistdir}/doc/latex/umbclegislation
%dir %{_texmfdistdir}/doc/latex/umich-thesis
%dir %{_texmfdistdir}/doc/latex/uml
%dir %{_texmfdistdir}/doc/latex/umlaute
%dir %{_texmfdistdir}/doc/latex/umoline
%dir %{_texmfdistdir}/doc/latex/umthesis
%dir %{_texmfdistdir}/doc/latex/unam-thesis
%dir %{_texmfdistdir}/doc/latex/unamth-template
%dir %{_texmfdistdir}/doc/latex/unamth-template/Agradecimientos
%dir %{_texmfdistdir}/doc/latex/unamth-template/Apendice1
%dir %{_texmfdistdir}/doc/latex/unamth-template/Bibliografia
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo1
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo2
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo3
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo3/figs
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo4
%dir %{_texmfdistdir}/doc/latex/unamth-template/Capitulo5
%dir %{_texmfdistdir}/doc/latex/unamth-template/Declaracion
%dir %{_texmfdistdir}/doc/latex/unamth-template/Latex
%dir %{_texmfdistdir}/doc/latex/unamth-template/Latex/Classes
%dir %{_texmfdistdir}/doc/latex/unamth-template/Latex/Classes/Escudos
%dir %{_texmfdistdir}/doc/latex/unamth-template/Latex/Macros
%dir %{_texmfdistdir}/doc/latex/unamth-template/Resumen
%dir %{_texmfdistdir}/doc/latex/unamthesis
%dir %{_texmfdistdir}/doc/latex/unbtex
%dir %{_texmfdistdir}/doc/latex/unbtex/unbtex-example
%dir %{_texmfdistdir}/doc/latex/unbtex/unbtex-example/codigos
%dir %{_texmfdistdir}/doc/latex/unbtex/unbtex-example/figuras
%dir %{_texmfdistdir}/doc/latex/undergradmath
%dir %{_texmfdistdir}/doc/latex/underlin
%dir %{_texmfdistdir}/doc/latex/underoverlap
%dir %{_texmfdistdir}/doc/latex/underscore
%dir %{_texmfdistdir}/doc/latex/undolabl
%dir %{_texmfdistdir}/doc/latex/uni-titlepage
%dir %{_texmfdistdir}/doc/latex/uni-wtal-ger
%dir %{_texmfdistdir}/doc/latex/uni-wtal-lin
%dir %{_texmfdistdir}/doc/latex/unicode-alphabets
%dir %{_texmfdistdir}/doc/latex/unicode-math
%dir %{_texmfdistdir}/doc/latex/unicodefonttable
%dir %{_texmfdistdir}/doc/latex/unifith
%dir %{_texmfdistdir}/doc/latex/unifith/examples
%dir %{_texmfdistdir}/doc/latex/unigrazpub
%dir %{_texmfdistdir}/doc/latex/unigrazpub/examples
%dir %{_texmfdistdir}/doc/latex/unigrazpub/examples/monografie
%dir %{_texmfdistdir}/doc/latex/unigrazpub/examples/sammelband
%dir %{_texmfdistdir}/doc/latex/uniquecounter
%dir %{_texmfdistdir}/doc/latex/unisc
%dir %{_texmfdistdir}/doc/latex/unitn-bimrep
%dir %{_texmfdistdir}/doc/latex/unitn-bimrep/examples
%dir %{_texmfdistdir}/doc/latex/units
%dir %{_texmfdistdir}/doc/latex/unitsdef
%dir %{_texmfdistdir}/doc/latex/univie-ling
%dir %{_texmfdistdir}/doc/latex/univie-ling/templates
%dir %{_texmfdistdir}/doc/latex/unizgklasa
%dir %{_texmfdistdir}/doc/latex/unravel
%dir %{_texmfdistdir}/doc/latex/unswcover
%dir %{_texmfdistdir}/doc/latex/uol-physics-report
%dir %{_texmfdistdir}/doc/latex/uothesis
%dir %{_texmfdistdir}/doc/latex/uowthesis
%dir %{_texmfdistdir}/doc/latex/uowthesistitlepage
%dir %{_texmfdistdir}/doc/latex/upmethodology
%dir %{_texmfdistdir}/doc/latex/upquote
%dir %{_texmfdistdir}/doc/latex/urcls
%dir %{_texmfdistdir}/doc/latex/uri
%dir %{_texmfdistdir}/doc/latex/url
%dir %{_texmfdistdir}/doc/latex/usebib
%dir %{_texmfdistdir}/doc/latex/ushort
%dir %{_texmfdistdir}/doc/latex/uspace
%dir %{_texmfdistdir}/doc/latex/uspatent
%dir %{_texmfdistdir}/doc/latex/ut-thesis
%dir %{_texmfdistdir}/doc/latex/utexasthesis
%dir %{_texmfdistdir}/doc/latex/utf8add
%dir %{_texmfdistdir}/doc/latex/utfsym
%dir %{_texmfdistdir}/doc/latex/uvaletter
%dir %{_texmfdistdir}/doc/latex/uvaletter/demo
%dir %{_texmfdistdir}/doc/latex/uwa-colours
%dir %{_texmfdistdir}/doc/latex/uwa-letterhead
%dir %{_texmfdistdir}/doc/latex/uwa-pcf
%dir %{_texmfdistdir}/doc/latex/uwa-pif
%dir %{_texmfdistdir}/doc/latex/uwmslide
%dir %{_texmfdistdir}/doc/latex/uwthesis
%dir %{_texmfdistdir}/doc/latex/varindex
%dir %{_texmfdistdir}/doc/latex/varsfromjobname
%dir %{_texmfdistdir}/doc/latex/varwidth
%dir %{_texmfdistdir}/doc/latex/vcell
%dir %{_texmfdistdir}/doc/latex/vdmlisting
%dir %{_texmfdistdir}/doc/latex/venndiagram
%dir %{_texmfdistdir}/doc/latex/venndiagram/samples
%dir %{_texmfdistdir}/doc/latex/verbasef
%dir %{_texmfdistdir}/doc/latex/verbatimbox
%dir %{_texmfdistdir}/doc/latex/verbatimcopy
%dir %{_texmfdistdir}/doc/latex/verbdef
%dir %{_texmfdistdir}/doc/latex/verbments
%dir %{_texmfdistdir}/doc/latex/verifica
%dir %{_texmfdistdir}/doc/latex/verifiche
%dir %{_texmfdistdir}/doc/latex/verse
%dir %{_texmfdistdir}/doc/latex/version
%dir %{_texmfdistdir}/doc/latex/versions
%dir %{_texmfdistdir}/doc/latex/versonotes
%dir %{_texmfdistdir}/doc/latex/vertbars
%dir %{_texmfdistdir}/doc/latex/vgrid
%dir %{_texmfdistdir}/doc/latex/vhistory
%dir %{_texmfdistdir}/doc/latex/visualfaq
%dir %{_texmfdistdir}/doc/latex/visualfaq-fr
%dir %{_texmfdistdir}/doc/latex/visualfaq-fr/source
%dir %{_texmfdistdir}/doc/latex/visualfaq-fr/source/latex-books
%dir %{_texmfdistdir}/doc/latex/visualfaq/source
%dir %{_texmfdistdir}/doc/latex/visualpstricks
%dir %{_texmfdistdir}/doc/latex/visualpstricks/Source
%dir %{_texmfdistdir}/doc/latex/visualtikz
%dir %{_texmfdistdir}/doc/latex/visualtikz/Source
%dir %{_texmfdistdir}/doc/latex/vmargin
%dir %{_texmfdistdir}/doc/latex/vocaltract
%dir %{_texmfdistdir}/doc/latex/volumes
%dir %{_texmfdistdir}/doc/latex/voss-mathcol
%dir %{_texmfdistdir}/doc/latex/vpe
%dir %{_texmfdistdir}/doc/latex/vruler
%dir %{_texmfdistdir}/doc/latex/vtable
%dir %{_texmfdistdir}/doc/latex/vwcol
%dir %{_texmfdistdir}/doc/latex/wallpaper
%dir %{_texmfdistdir}/doc/latex/wallpaper/example
%dir %{_texmfdistdir}/doc/latex/wallpaper/example/auto
%dir %{_texmfdistdir}/doc/latex/wargame
%dir %{_texmfdistdir}/doc/latex/wargame/tutorial
%dir %{_texmfdistdir}/doc/latex/warning
%dir %{_texmfdistdir}/doc/latex/warpcol
%dir %{_texmfdistdir}/doc/latex/was
%dir %{_texmfdistdir}/doc/latex/wasysym
%dir %{_texmfdistdir}/doc/latex/webguide
%dir %{_texmfdistdir}/doc/latex/webquiz
%dir %{_texmfdistdir}/doc/latex/webquiz/examples
%dir %{_texmfdistdir}/doc/latex/webquiz/www
%dir %{_texmfdistdir}/doc/latex/webquiz/www/css
%dir %{_texmfdistdir}/doc/latex/webquiz/www/doc
%dir %{_texmfdistdir}/doc/latex/webquiz/www/js
%dir %{_texmfdistdir}/doc/latex/wheelchart
%dir %{_texmfdistdir}/doc/latex/widetable
%dir %{_texmfdistdir}/doc/latex/widows-and-orphans
%dir %{_texmfdistdir}/doc/latex/williams
%dir %{_texmfdistdir}/doc/latex/willowtreebook
%dir %{_texmfdistdir}/doc/latex/windycity
%dir %{_texmfdistdir}/doc/latex/withargs
%dir %{_texmfdistdir}/doc/latex/wnri-latex
%dir %{_texmfdistdir}/doc/latex/wordcount
%dir %{_texmfdistdir}/doc/latex/wordlike
%dir %{_texmfdistdir}/doc/latex/worksheet
%dir %{_texmfdistdir}/doc/latex/worldflags
%dir %{_texmfdistdir}/doc/latex/wrapfig
%dir %{_texmfdistdir}/doc/latex/wrapfig2
%dir %{_texmfdistdir}/doc/latex/wrapstuff
%dir %{_texmfdistdir}/doc/latex/writeongrid
%dir %{_texmfdistdir}/doc/latex/wsemclassic
%dir %{_texmfdistdir}/doc/latex/wtref
%dir %{_texmfdistdir}/doc/latex/xargs
%dir %{_texmfdistdir}/doc/latex/xassoccnt
%dir %{_texmfdistdir}/doc/latex/xbmks
%dir %{_texmfdistdir}/doc/latex/xbmks/docs
%dir %{_texmfdistdir}/doc/latex/xbmks/examples
%dir %{_texmfdistdir}/doc/latex/xcite
%dir %{_texmfdistdir}/doc/latex/xcjk2uni
%dir %{_texmfdistdir}/doc/latex/xcntperchap
%dir %{_texmfdistdir}/doc/latex/xcolor
%dir %{_texmfdistdir}/doc/latex/xcolor-material
%dir %{_texmfdistdir}/doc/latex/xcolor-solarized
%dir %{_texmfdistdir}/doc/latex/xcookybooky
%dir %{_texmfdistdir}/doc/latex/xcookybooky/example
%dir %{_texmfdistdir}/doc/latex/xcookybooky/example/pic
%dir %{_texmfdistdir}/doc/latex/xcookybooky/example/tex
%dir %{_texmfdistdir}/doc/latex/xcpdftips
%dir %{_texmfdistdir}/doc/latex/xdoc
%dir %{_texmfdistdir}/doc/latex/xduthesis
%dir %{_texmfdistdir}/doc/latex/xduthesis/examples
%dir %{_texmfdistdir}/doc/latex/xebaposter
%dir %{_texmfdistdir}/doc/latex/xebaposter/images
%dir %{_texmfdistdir}/doc/latex/xecyrmongolian
%dir %{_texmfdistdir}/doc/latex/xellipsis
%dir %{_texmfdistdir}/doc/latex/xfakebold
%dir %{_texmfdistdir}/doc/latex/xfor
%dir %{_texmfdistdir}/doc/latex/xgreek
%dir %{_texmfdistdir}/doc/latex/xhfill
%dir %{_texmfdistdir}/doc/latex/xifthen
%dir %{_texmfdistdir}/doc/latex/xistercian
%dir %{_texmfdistdir}/doc/latex/xkcdcolors
%dir %{_texmfdistdir}/doc/latex/xkeyval
%dir %{_texmfdistdir}/doc/latex/xltabular
%dir %{_texmfdistdir}/doc/latex/xmpincl
%dir %{_texmfdistdir}/doc/latex/xmuthesis
%dir %{_texmfdistdir}/doc/latex/xnewcommand
%dir %{_texmfdistdir}/doc/latex/xoptarg
%dir %{_texmfdistdir}/doc/latex/xpatch
%dir %{_texmfdistdir}/doc/latex/xpeek
%dir %{_texmfdistdir}/doc/latex/xpiano
%dir %{_texmfdistdir}/doc/latex/xpicture
%dir %{_texmfdistdir}/doc/latex/xpinyin
%dir %{_texmfdistdir}/doc/latex/xprintlen
%dir %{_texmfdistdir}/doc/latex/xpunctuate
%dir %{_texmfdistdir}/doc/latex/xsavebox
%dir %{_texmfdistdir}/doc/latex/xsim
%dir %{_texmfdistdir}/doc/latex/xsim/examples
%dir %{_texmfdistdir}/doc/latex/xskak
%dir %{_texmfdistdir}/doc/latex/xtab
%dir %{_texmfdistdir}/doc/latex/xtuthesis
%dir %{_texmfdistdir}/doc/latex/xtuthesis/body
%dir %{_texmfdistdir}/doc/latex/xtuthesis/figures
%dir %{_texmfdistdir}/doc/latex/xtuthesis/preface
%dir %{_texmfdistdir}/doc/latex/xtuthesis/reference
%dir %{_texmfdistdir}/doc/latex/xurl
%dir %{_texmfdistdir}/doc/latex/xwatermark
%dir %{_texmfdistdir}/doc/latex/xyling
%dir %{_texmfdistdir}/doc/latex/xymtex
%dir %{_texmfdistdir}/doc/latex/xymtex/doc
%dir %{_texmfdistdir}/doc/latex/xymtex/readme
%dir %{_texmfdistdir}/doc/latex/xymtex/readme/oldreadme
%dir %{_texmfdistdir}/doc/latex/xytree
%dir %{_texmfdistdir}/doc/latex/yafoot
%dir %{_texmfdistdir}/doc/latex/yagusylo
%dir %{_texmfdistdir}/doc/latex/yaletter
%dir %{_texmfdistdir}/doc/latex/yathesis
%dir %{_texmfdistdir}/doc/latex/yathesis/addons
%dir %{_texmfdistdir}/doc/latex/yathesis/addons/completion
%dir %{_texmfdistdir}/doc/latex/yathesis/english
%dir %{_texmfdistdir}/doc/latex/yathesis/french
%dir %{_texmfdistdir}/doc/latex/yathesis/french/code
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/annexes
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/configuration
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/corps
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/extraits-these
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/glossaries
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/liminaires
%dir %{_texmfdistdir}/doc/latex/yathesis/french/documentation/tableaux
%dir %{_texmfdistdir}/doc/latex/yathesis/french/exemples
%dir %{_texmfdistdir}/doc/latex/yathesis/french/exemples/specimen
%dir %{_texmfdistdir}/doc/latex/yathesis/french/exemples/specimen/a-plat
%dir %{_texmfdistdir}/doc/latex/yb-book
%dir %{_texmfdistdir}/doc/latex/ycbook
%dir %{_texmfdistdir}/doc/latex/ydoc
%dir %{_texmfdistdir}/doc/latex/yet-another-guide-latex2e
%dir %{_texmfdistdir}/doc/latex/yfonts
%dir %{_texmfdistdir}/doc/latex/york-thesis
%dir %{_texmfdistdir}/doc/latex/yplan
%dir %{_texmfdistdir}/doc/latex/yquant
%dir %{_texmfdistdir}/doc/latex/ytableau
%dir %{_texmfdistdir}/doc/latex/zebra-goodies
%dir %{_texmfdistdir}/doc/latex/zed-csp
%dir %{_texmfdistdir}/doc/latex/zennote
%dir %{_texmfdistdir}/doc/latex/zhlineskip
%dir %{_texmfdistdir}/doc/latex/zhlipsum
%dir %{_texmfdistdir}/doc/latex/zhnumber
%dir %{_texmfdistdir}/doc/latex/ziffer
%dir %{_texmfdistdir}/doc/latex/zref
%dir %{_texmfdistdir}/doc/latex/zref-check
%dir %{_texmfdistdir}/doc/latex/zref-clever
%dir %{_texmfdistdir}/doc/latex/zref-vario
%dir %{_texmfdistdir}/doc/latex/zwgetfdate
%dir %{_texmfdistdir}/doc/latex/zwpagelayout
%dir %{_texmfdistdir}/doc/latex/zx-calculus
%dir %{_texmfdistdir}/doc/latex/zxjafbfont
%dir %{_texmfdistdir}/doc/latex/zxjafont
%dir %{_texmfdistdir}/doc/latex/zxjatype
%dir %{_texmfdistdir}/doc/latex/zxjatype/example
%dir %{_texmfdistdir}/doc/lualatex
%dir %{_texmfdistdir}/doc/lualatex/addliga
%dir %{_texmfdistdir}/doc/lualatex/arabluatex
%dir %{_texmfdistdir}/doc/lualatex/arabluatex/samples
%dir %{_texmfdistdir}/doc/lualatex/autopuncitems
%dir %{_texmfdistdir}/doc/lualatex/beamer-rl
%dir %{_texmfdistdir}/doc/lualatex/bezierplot
%dir %{_texmfdistdir}/doc/lualatex/combofont
%dir %{_texmfdistdir}/doc/lualatex/cstypo
%dir %{_texmfdistdir}/doc/lualatex/datestamp
%dir %{_texmfdistdir}/doc/lualatex/ekdosis
%dir %{_texmfdistdir}/doc/lualatex/ekdosis/samples
%dir %{_texmfdistdir}/doc/lualatex/emojicite
%dir %{_texmfdistdir}/doc/lualatex/hmtrump
%dir %{_texmfdistdir}/doc/lualatex/hmtrump/nkd04_playing_cards_index
%dir %{_texmfdistdir}/doc/lualatex/hu-berlin-bundle
%dir %{_texmfdistdir}/doc/lualatex/hu-berlin-bundle/img
%dir %{_texmfdistdir}/doc/lualatex/innerscript
%dir %{_texmfdistdir}/doc/lualatex/japanese-mathformulas
%dir %{_texmfdistdir}/doc/lualatex/letgut
%dir %{_texmfdistdir}/doc/lualatex/ligtype
%dir %{_texmfdistdir}/doc/lualatex/linebreaker
%dir %{_texmfdistdir}/doc/lualatex/lua-check-hyphen
%dir %{_texmfdistdir}/doc/lualatex/lua-check-hyphen/doc
%dir %{_texmfdistdir}/doc/lualatex/lua-physical
%dir %{_texmfdistdir}/doc/lualatex/lua-physical/test
%dir %{_texmfdistdir}/doc/lualatex/lua-typo
%dir %{_texmfdistdir}/doc/lualatex/lua-ul
%dir %{_texmfdistdir}/doc/lualatex/luabibentry
%dir %{_texmfdistdir}/doc/lualatex/luabidi
%dir %{_texmfdistdir}/doc/lualatex/luacas
%dir %{_texmfdistdir}/doc/lualatex/luacas/appendix
%dir %{_texmfdistdir}/doc/lualatex/luacas/intro
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_algebra
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_algebra/ref_algebra_classes
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_algebra/ref_algebra_methods
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_calculus
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_calculus/ref_calculus_classes
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_calculus/ref_calculus_methods
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_core
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_core/ref_core_classes
%dir %{_texmfdistdir}/doc/lualatex/luacas/reference/ref_core/ref_core_methods
%dir %{_texmfdistdir}/doc/lualatex/luacas/tutorial
%dir %{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut1
%dir %{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut2
%dir %{_texmfdistdir}/doc/lualatex/luacas/tutorial/tut3
%dir %{_texmfdistdir}/doc/lualatex/luacensor
%dir %{_texmfdistdir}/doc/lualatex/luacode
%dir %{_texmfdistdir}/doc/lualatex/luacomplex
%dir %{_texmfdistdir}/doc/lualatex/luagcd
%dir %{_texmfdistdir}/doc/lualatex/luahyphenrules
%dir %{_texmfdistdir}/doc/lualatex/luaimageembed
%dir %{_texmfdistdir}/doc/lualatex/luaindex
%dir %{_texmfdistdir}/doc/lualatex/luainputenc
%dir %{_texmfdistdir}/doc/lualatex/lualatex-doc
%dir %{_texmfdistdir}/doc/lualatex/lualatex-math
%dir %{_texmfdistdir}/doc/lualatex/lualatex-truncate
%dir %{_texmfdistdir}/doc/lualatex/lualinalg
%dir %{_texmfdistdir}/doc/lualatex/luamathalign
%dir %{_texmfdistdir}/doc/lualatex/luamaths
%dir %{_texmfdistdir}/doc/lualatex/luamesh
%dir %{_texmfdistdir}/doc/lualatex/luamodulartables
%dir %{_texmfdistdir}/doc/lualatex/luaoptions
%dir %{_texmfdistdir}/doc/lualatex/luaprogtable
%dir %{_texmfdistdir}/doc/lualatex/luapstricks
%dir %{_texmfdistdir}/doc/lualatex/luaquotes
%dir %{_texmfdistdir}/doc/lualatex/luarandom
%dir %{_texmfdistdir}/doc/lualatex/luaset
%dir %{_texmfdistdir}/doc/lualatex/luasseq
%dir %{_texmfdistdir}/doc/lualatex/luatextra
%dir %{_texmfdistdir}/doc/lualatex/luatodonotes
%dir %{_texmfdistdir}/doc/lualatex/luatruthtable
%dir %{_texmfdistdir}/doc/lualatex/makecookbook
%dir %{_texmfdistdir}/doc/lualatex/makecookbook/mycookbook
%dir %{_texmfdistdir}/doc/lualatex/makecookbook/mycookbook/img
%dir %{_texmfdistdir}/doc/lualatex/makecookbook/mycookbook/tex
%dir %{_texmfdistdir}/doc/lualatex/novel
%dir %{_texmfdistdir}/doc/lualatex/novel/extras
%dir %{_texmfdistdir}/doc/lualatex/novel/html-resources
%dir %{_texmfdistdir}/doc/lualatex/odsfile
%dir %{_texmfdistdir}/doc/lualatex/pdfarticle
%dir %{_texmfdistdir}/doc/lualatex/pgfmolbio
%dir %{_texmfdistdir}/doc/lualatex/piton
%dir %{_texmfdistdir}/doc/lualatex/placeat
%dir %{_texmfdistdir}/doc/lualatex/plantuml
%dir %{_texmfdistdir}/doc/lualatex/pyluatex
%dir %{_texmfdistdir}/doc/lualatex/pyluatex/example
%dir %{_texmfdistdir}/doc/lualatex/scikgtex
%dir %{_texmfdistdir}/doc/lualatex/selnolig
%dir %{_texmfdistdir}/doc/lualatex/semesterplanner
%dir %{_texmfdistdir}/doc/lualatex/showhyphenation
%dir %{_texmfdistdir}/doc/lualatex/showkerning
%dir %{_texmfdistdir}/doc/lualatex/simurgh
%dir %{_texmfdistdir}/doc/lualatex/spacekern
%dir %{_texmfdistdir}/doc/lualatex/stricttex
%dir %{_texmfdistdir}/doc/lualatex/truthtable
%dir %{_texmfdistdir}/doc/lualatex/truthtable/res
%dir %{_texmfdistdir}/doc/lualatex/typewriter
%dir %{_texmfdistdir}/doc/lualatex/uninormalize
%dir %{_texmfdistdir}/doc/lualatex/unitconv
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc/auto
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/cal-burst
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/data
%dir %{_texmfdistdir}/doc/lualatex/wallcalendar/doc/examples/photos
%dir %{_texmfdistdir}/doc/lualatex/xindex
%dir %{_texmfdistdir}/doc/lualatex/xindex/tests
%dir %{_texmfdistdir}/doc/lualatex/yamlvars
%dir %{_texmfdistdir}/doc/luatex
%dir %{_texmfdistdir}/doc/luatex/barracuda
%dir %{_texmfdistdir}/doc/luatex/barracuda/doc
%dir %{_texmfdistdir}/doc/luatex/barracuda/doc/ga-graphic-asm
%dir %{_texmfdistdir}/doc/luatex/barracuda/doc/manual
%dir %{_texmfdistdir}/doc/luatex/barracuda/doc/manual/image
%dir %{_texmfdistdir}/doc/luatex/barracuda/test
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-barracuda-package
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-code128
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-code39
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-ean
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-ga-pdfliteral
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-ga-svg
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-i2of5
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-libgeo
%dir %{_texmfdistdir}/doc/luatex/barracuda/test/test-upc
%dir %{_texmfdistdir}/doc/luatex/base
%dir %{_texmfdistdir}/doc/luatex/base/graphics
%dir %{_texmfdistdir}/doc/luatex/blopentype
%dir %{_texmfdistdir}/doc/luatex/chickenize
%dir %{_texmfdistdir}/doc/luatex/chinese-jfm
%dir %{_texmfdistdir}/doc/luatex/cloze
%dir %{_texmfdistdir}/doc/luatex/ctablestack
%dir %{_texmfdistdir}/doc/luatex/evangelion-jfm
%dir %{_texmfdistdir}/doc/luatex/gregoriotex
%dir %{_texmfdistdir}/doc/luatex/gregoriotex/examples
%dir %{_texmfdistdir}/doc/luatex/hyph-utf8
%dir %{_texmfdistdir}/doc/luatex/interpreter
%dir %{_texmfdistdir}/doc/luatex/kanaparser
%dir %{_texmfdistdir}/doc/luatex/lparse
%dir %{_texmfdistdir}/doc/luatex/lua-uni-algos
%dir %{_texmfdistdir}/doc/luatex/lua-visual-debug
%dir %{_texmfdistdir}/doc/luatex/lua-widow-control
%dir %{_texmfdistdir}/doc/luatex/luaaddplot
%dir %{_texmfdistdir}/doc/luatex/luaintro
%dir %{_texmfdistdir}/doc/luatex/luakeys
%dir %{_texmfdistdir}/doc/luatex/lualibs
%dir %{_texmfdistdir}/doc/luatex/luamplib
%dir %{_texmfdistdir}/doc/luatex/luaotfload
%dir %{_texmfdistdir}/doc/luatex/luapackageloader
%dir %{_texmfdistdir}/doc/luatex/luatexbase
%dir %{_texmfdistdir}/doc/luatex/luatexja
%dir %{_texmfdistdir}/doc/luatex/luatexko
%dir %{_texmfdistdir}/doc/luatex/luavlna
%dir %{_texmfdistdir}/doc/luatex/luaxml
%dir %{_texmfdistdir}/doc/luatex/lutabulartools
%dir %{_texmfdistdir}/doc/luatex/minim
%dir %{_texmfdistdir}/doc/luatex/minim-math
%dir %{_texmfdistdir}/doc/luatex/minim-mp
%dir %{_texmfdistdir}/doc/luatex/minim-pdf
%dir %{_texmfdistdir}/doc/luatex/minim-xmp
%dir %{_texmfdistdir}/doc/luatex/nodetree
%dir %{_texmfdistdir}/doc/luatex/penlight
%dir %{_texmfdistdir}/doc/luatex/spelling
%dir %{_texmfdistdir}/doc/luatex/tsvtemplate
%dir %{_texmfdistdir}/doc/metapost
%dir %{_texmfdistdir}/doc/metapost/automata
%dir %{_texmfdistdir}/doc/metapost/base
%dir %{_texmfdistdir}/doc/metapost/base/source-manual
%dir %{_texmfdistdir}/doc/metapost/base/source-tutorial
%dir %{_texmfdistdir}/doc/metapost/bbcard
%dir %{_texmfdistdir}/doc/metapost/blockdraw_mp
%dir %{_texmfdistdir}/doc/metapost/bpolynomial
%dir %{_texmfdistdir}/doc/metapost/byrne
%dir %{_texmfdistdir}/doc/metapost/cmarrows
%dir %{_texmfdistdir}/doc/metapost/drv
%dir %{_texmfdistdir}/doc/metapost/drv/doc
%dir %{_texmfdistdir}/doc/metapost/drv/sample
%dir %{_texmfdistdir}/doc/metapost/drv/template
%dir %{_texmfdistdir}/doc/metapost/dviincl
%dir %{_texmfdistdir}/doc/metapost/epsincl
%dir %{_texmfdistdir}/doc/metapost/expressg
%dir %{_texmfdistdir}/doc/metapost/exteps
%dir %{_texmfdistdir}/doc/metapost/featpost
%dir %{_texmfdistdir}/doc/metapost/featpost/bash
%dir %{_texmfdistdir}/doc/metapost/featpost/doc
%dir %{_texmfdistdir}/doc/metapost/featpost/doc/metapostpropagandafiles
%dir %{_texmfdistdir}/doc/metapost/featpost/doc/otherinfo
%dir %{_texmfdistdir}/doc/metapost/featpost/example
%dir %{_texmfdistdir}/doc/metapost/featpost/png
%dir %{_texmfdistdir}/doc/metapost/fiziko
%dir %{_texmfdistdir}/doc/metapost/garrigues
%dir %{_texmfdistdir}/doc/metapost/hatching
%dir %{_texmfdistdir}/doc/metapost/hershey-mp
%dir %{_texmfdistdir}/doc/metapost/latexmp
%dir %{_texmfdistdir}/doc/metapost/makecirc
%dir %{_texmfdistdir}/doc/metapost/mcf2graph
%dir %{_texmfdistdir}/doc/metapost/metago
%dir %{_texmfdistdir}/doc/metapost/metaobj
%dir %{_texmfdistdir}/doc/metapost/metapost-colorbrewer
%dir %{_texmfdistdir}/doc/metapost/metapost-examples
%dir %{_texmfdistdir}/doc/metapost/metauml
%dir %{_texmfdistdir}/doc/metapost/metauml/manual
%dir %{_texmfdistdir}/doc/metapost/metauml/manual/fig
%dir %{_texmfdistdir}/doc/metapost/mp3d
%dir %{_texmfdistdir}/doc/metapost/mparrows
%dir %{_texmfdistdir}/doc/metapost/mpattern
%dir %{_texmfdistdir}/doc/metapost/mpcolornames
%dir %{_texmfdistdir}/doc/metapost/mpman-ru
%dir %{_texmfdistdir}/doc/metapost/mptrees
%dir %{_texmfdistdir}/doc/metapost/piechartmp
%dir %{_texmfdistdir}/doc/metapost/piechartmp/examples
%dir %{_texmfdistdir}/doc/metapost/repere
%dir %{_texmfdistdir}/doc/metapost/roundrect
%dir %{_texmfdistdir}/doc/metapost/shapes
%dir %{_texmfdistdir}/doc/metapost/slideshow
%dir %{_texmfdistdir}/doc/metapost/splines
%dir %{_texmfdistdir}/doc/metapost/suanpan
%dir %{_texmfdistdir}/doc/metapost/textpath
%dir %{_texmfdistdir}/doc/metapost/threeddice
%dir %{_texmfdistdir}/doc/metapost/venn
%dir %{_texmfdistdir}/doc/mex
%dir %{_texmfdistdir}/doc/mex/base
%dir %{_texmfdistdir}/doc/mex/utf8mex
%dir %{_texmfdistdir}/doc/mex/utf8mex/examples
%dir %{_texmfdistdir}/doc/omega
%dir %{_texmfdistdir}/doc/omega/antomega
%dir %{_texmfdistdir}/doc/omega/base
%dir %{_texmfdistdir}/doc/omega/ocherokee
%dir %{_texmfdistdir}/doc/optex
%dir %{_texmfdistdir}/doc/optex/base
%dir %{_texmfdistdir}/doc/optex/pdfextra
%dir %{_texmfdistdir}/doc/optex/pdfextra/examples
%dir %{_texmfdistdir}/doc/otherformats
%dir %{_texmfdistdir}/doc/otherformats/jadetex
%dir %{_texmfdistdir}/doc/otherformats/jadetex/base
%dir %{_texmfdistdir}/doc/otherformats/lollipop
%dir %{_texmfdistdir}/doc/otherformats/lollipop/manual
%dir %{_texmfdistdir}/doc/otherformats/psizzl
%dir %{_texmfdistdir}/doc/otherformats/psizzl/base
%dir %{_texmfdistdir}/doc/otherformats/startex
%dir %{_texmfdistdir}/doc/otherformats/texsis
%dir %{_texmfdistdir}/doc/otherformats/texsis/base
%dir %{_texmfdistdir}/doc/otherformats/xmltex
%dir %{_texmfdistdir}/doc/otherformats/xmltex/base
%dir %{_texmfdistdir}/doc/pdftex
%dir %{_texmfdistdir}/doc/pdftex/manual
%dir %{_texmfdistdir}/doc/pdftex/samplepdftex
%dir %{_texmfdistdir}/doc/pdftex/tests
%dir %{_texmfdistdir}/doc/pdftex/tests/01-fake-interword-space
%dir %{_texmfdistdir}/doc/pdftex/tests/02-pdfmatch
%dir %{_texmfdistdir}/doc/pdftex/tests/03-deterministic-output
%dir %{_texmfdistdir}/doc/pdftex/tests/04-pdfsuppressptexinfo
%dir %{_texmfdistdir}/doc/pdftex/tests/05-mediabox
%dir %{_texmfdistdir}/doc/pdftex/tests/06-pkmap
%dir %{_texmfdistdir}/doc/pdftex/tests/07-mapwarn
%dir %{_texmfdistdir}/doc/pdftex/tests/08-pdfprimitive
%dir %{_texmfdistdir}/doc/pdftex/tests/09-fontobjnum
%dir %{_texmfdistdir}/doc/pdftex/tests/10-moddate
%dir %{_texmfdistdir}/doc/pdftex/tests/11-omitcharset
%dir %{_texmfdistdir}/doc/pdftex/tests/12-pdf2
%dir %{_texmfdistdir}/doc/plain
%dir %{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex
%dir %{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/cover
%dir %{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/fonts
%dir %{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/output
%dir %{_texmfdistdir}/doc/plain/apprendre-a-programmer-en-tex/source
%dir %{_texmfdistdir}/doc/plain/epsf-dvipdfmx
%dir %{_texmfdistdir}/doc/plain/figflow
%dir %{_texmfdistdir}/doc/plain/font-change
%dir %{_texmfdistdir}/doc/plain/fontch
%dir %{_texmfdistdir}/doc/plain/gentle
%dir %{_texmfdistdir}/doc/plain/getoptk
%dir %{_texmfdistdir}/doc/plain/gfnotation
%dir %{_texmfdistdir}/doc/plain/graphics-pln
%dir %{_texmfdistdir}/doc/plain/gustlib
%dir %{_texmfdistdir}/doc/plain/happy4th
%dir %{_texmfdistdir}/doc/plain/harvmac
%dir %{_texmfdistdir}/doc/plain/hyplain
%dir %{_texmfdistdir}/doc/plain/impatient
%dir %{_texmfdistdir}/doc/plain/impatient-cn
%dir %{_texmfdistdir}/doc/plain/impatient-fr
%dir %{_texmfdistdir}/doc/plain/impatient/diffs
%dir %{_texmfdistdir}/doc/plain/js-misc
%dir %{_texmfdistdir}/doc/plain/js-misc/xfig
%dir %{_texmfdistdir}/doc/plain/kotex-plain
%dir %{_texmfdistdir}/doc/plain/lambda-lists
%dir %{_texmfdistdir}/doc/plain/metatex
%dir %{_texmfdistdir}/doc/plain/metatex/mtpaper
%dir %{_texmfdistdir}/doc/plain/mkpattern
%dir %{_texmfdistdir}/doc/plain/newsletr
%dir %{_texmfdistdir}/doc/plain/pgfplots
%dir %{_texmfdistdir}/doc/plain/pitex
%dir %{_texmfdistdir}/doc/plain/plain-doc
%dir %{_texmfdistdir}/doc/plain/plipsum
%dir %{_texmfdistdir}/doc/plain/plnfss
%dir %{_texmfdistdir}/doc/plain/plstmary
%dir %{_texmfdistdir}/doc/plain/present
%dir %{_texmfdistdir}/doc/plain/pwebmac
%dir %{_texmfdistdir}/doc/plain/resumemac
%dir %{_texmfdistdir}/doc/plain/tex-nutshell
%dir %{_texmfdistdir}/doc/plain/texbytopic
%dir %{_texmfdistdir}/doc/plain/texonly
%dir %{_texmfdistdir}/doc/plain/transparent-io
%dir %{_texmfdistdir}/doc/plain/treetex
%dir %{_texmfdistdir}/doc/plain/tugboat-plain
%dir %{_texmfdistdir}/doc/plain/varisize
%dir %{_texmfdistdir}/doc/plain/xii
%dir %{_texmfdistdir}/doc/plain/xii-lat
%dir %{_texmfdistdir}/doc/plain/xintsession
%dir %{_texmfdistdir}/doc/plain/zztex
%dir %{_texmfdistdir}/doc/platex
%dir %{_texmfdistdir}/doc/platex/base
%dir %{_texmfdistdir}/doc/platex/jlreq-deluxe
%dir %{_texmfdistdir}/doc/platex/jsclasses
%dir %{_texmfdistdir}/doc/platex/pxbase
%dir %{_texmfdistdir}/doc/platex/pxchfon
%dir %{_texmfdistdir}/doc/platex/pxjahyper
%dir %{_texmfdistdir}/doc/platex/pxrubrica
%dir %{_texmfdistdir}/doc/platex/pxrubrica/sample
%dir %{_texmfdistdir}/doc/pmxchords
%dir %{_texmfdistdir}/doc/pmxchords/examples
%dir %{_texmfdistdir}/doc/pmxchords/examples/jazz
%dir %{_texmfdistdir}/doc/pmxchords/examples/jazz/misty
%dir %{_texmfdistdir}/doc/pmxchords/examples/jazz/schema
%dir %{_texmfdistdir}/doc/pmxchords/examples/noel
%dir %{_texmfdistdir}/doc/pmxchords/examples/noel/aj_co_to_hlasaju
%dir %{_texmfdistdir}/doc/pmxchords/examples/noel/pasli_ovce_valasi
%dir %{_texmfdistdir}/doc/ptex
%dir %{_texmfdistdir}/doc/ptex/pbibtex
%dir %{_texmfdistdir}/doc/ptex/ptex-base
%dir %{_texmfdistdir}/doc/ptex/ptex-manual
%dir %{_texmfdistdir}/doc/support
%dir %{_texmfdistdir}/doc/support/a2ping
%dir %{_texmfdistdir}/doc/support/adhocfilelist
%dir %{_texmfdistdir}/doc/support/adhocfilelist/demo
%dir %{_texmfdistdir}/doc/support/albatross
%dir %{_texmfdistdir}/doc/support/arara
%dir %{_texmfdistdir}/doc/support/arara/resources
%dir %{_texmfdistdir}/doc/support/ascii-chart
%dir %{_texmfdistdir}/doc/support/asymptote-by-example-zh-cn
%dir %{_texmfdistdir}/doc/support/asymptote-by-example-zh-cn/src
%dir %{_texmfdistdir}/doc/support/asymptote-by-example-zh-cn/src/figure-src
%dir %{_texmfdistdir}/doc/support/asymptote-faq-zh-cn
%dir %{_texmfdistdir}/doc/support/asymptote-faq-zh-cn/src
%dir %{_texmfdistdir}/doc/support/asymptote-faq-zh-cn/src/figures
%dir %{_texmfdistdir}/doc/support/asymptote-manual-zh-cn
%dir %{_texmfdistdir}/doc/support/asymptote-manual-zh-cn/src
%dir %{_texmfdistdir}/doc/support/bib2gls
%dir %{_texmfdistdir}/doc/support/bib2gls/examples
%dir %{_texmfdistdir}/doc/support/bundledoc
%dir %{_texmfdistdir}/doc/support/checkcites
%dir %{_texmfdistdir}/doc/support/chklref
%dir %{_texmfdistdir}/doc/support/classpack
%dir %{_texmfdistdir}/doc/support/clojure-pamphlet
%dir %{_texmfdistdir}/doc/support/cluttex
%dir %{_texmfdistdir}/doc/support/cluttex/bin
%dir %{_texmfdistdir}/doc/support/cluttex/doc
%dir %{_texmfdistdir}/doc/support/cluttex/example
%dir %{_texmfdistdir}/doc/support/cluttex/example/biblatex
%dir %{_texmfdistdir}/doc/support/cluttex/example/bibtex
%dir %{_texmfdistdir}/doc/support/cluttex/example/empty
%dir %{_texmfdistdir}/doc/support/cluttex/example/epstopdf
%dir %{_texmfdistdir}/doc/support/cluttex/example/epstopdf/fig
%dir %{_texmfdistdir}/doc/support/cluttex/example/include
%dir %{_texmfdistdir}/doc/support/cluttex/example/include/path
%dir %{_texmfdistdir}/doc/support/cluttex/example/include/path/to
%dir %{_texmfdistdir}/doc/support/cluttex/example/makeindex
%dir %{_texmfdistdir}/doc/support/cluttex/example/minted
%dir %{_texmfdistdir}/doc/support/cluttex/example/simple
%dir %{_texmfdistdir}/doc/support/cluttex/example/simple-ja
%dir %{_texmfdistdir}/doc/support/cluttex/src
%dir %{_texmfdistdir}/doc/support/cluttex/src/texrunner
%dir %{_texmfdistdir}/doc/support/convbkmk
%dir %{_texmfdistdir}/doc/support/crossrefware
%dir %{_texmfdistdir}/doc/support/ctan-o-mat
%dir %{_texmfdistdir}/doc/support/ctan-o-mat/lib
%dir %{_texmfdistdir}/doc/support/ctan_chk
%dir %{_texmfdistdir}/doc/support/ctanbib
%dir %{_texmfdistdir}/doc/support/ctanupload
%dir %{_texmfdistdir}/doc/support/de-macro
%dir %{_texmfdistdir}/doc/support/digestif
%dir %{_texmfdistdir}/doc/support/digestif/bin
%dir %{_texmfdistdir}/doc/support/dosepsbin
%dir %{_texmfdistdir}/doc/support/dtxgen
%dir %{_texmfdistdir}/doc/support/epspdf
%dir %{_texmfdistdir}/doc/support/epspdf/images
%dir %{_texmfdistdir}/doc/support/epstopdf
%dir %{_texmfdistdir}/doc/support/fig4latex
%dir %{_texmfdistdir}/doc/support/fig4latex/figs
%dir %{_texmfdistdir}/doc/support/findhyph
%dir %{_texmfdistdir}/doc/support/fontools
%dir %{_texmfdistdir}/doc/support/fragmaster
%dir %{_texmfdistdir}/doc/support/fragmaster/example
%dir %{_texmfdistdir}/doc/support/git-latexdiff
%dir %{_texmfdistdir}/doc/support/gitfile-info
%dir %{_texmfdistdir}/doc/support/gustprog
%dir %{_texmfdistdir}/doc/support/hook-pre-commit-pkg
%dir %{_texmfdistdir}/doc/support/ketcindy
%dir %{_texmfdistdir}/doc/support/ketcindy/forLinux
%dir %{_texmfdistdir}/doc/support/ketcindy/forMac
%dir %{_texmfdistdir}/doc/support/ketcindy/forMac/Forsettingmanually
%dir %{_texmfdistdir}/doc/support/ketcindy/forWindows
%dir %{_texmfdistdir}/doc/support/ketcindy/forWindows/Forsettingmanually
%dir %{_texmfdistdir}/doc/support/ketcindy/ketcindyjs
%dir %{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex
%dir %{_texmfdistdir}/doc/support/ketcindy/ketcindyjs/katex/fonts
%dir %{_texmfdistdir}/doc/support/ketcindy/ketmanual
%dir %{_texmfdistdir}/doc/support/ketcindy/samples
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s01figure
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s02graph
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s03table
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s04bezier
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s05spacefigure
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s06animation
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s07slides
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s07slides/figwall
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s08R
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s09surfaceC
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s10maxima
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s11asir
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s12fricas
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s13objview
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s14dataprocessing
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s15surfaceR
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s16ketJSmisc
%dir %{_texmfdistdir}/doc/support/ketcindy/samples/s17spacekc
%dir %{_texmfdistdir}/doc/support/ketcindy/source
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/config
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/config/META-INF
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/config/META-INF/services
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/lib
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/src
%dir %{_texmfdistdir}/doc/support/ketcindy/source/KetCindyPlugin/srcold
%dir %{_texmfdistdir}/doc/support/ketcindy/source/cdy-templates
%dir %{_texmfdistdir}/doc/support/ketcindy/source/howtoinstall
%dir %{_texmfdistdir}/doc/support/ketcindy/source/ketmanual
%dir %{_texmfdistdir}/doc/support/ketcindy/source/ketmanual/Fig
%dir %{_texmfdistdir}/doc/support/ketcindy/source/readme
%dir %{_texmfdistdir}/doc/support/ketcindy/source/spacekc
%dir %{_texmfdistdir}/doc/support/latex-git-log
%dir %{_texmfdistdir}/doc/support/latex-git-log/po
%dir %{_texmfdistdir}/doc/support/latex-make
%dir %{_texmfdistdir}/doc/support/latex-papersize
%dir %{_texmfdistdir}/doc/support/latex2man
%dir %{_texmfdistdir}/doc/support/latex2nemeth
%dir %{_texmfdistdir}/doc/support/latex2nemeth/contrib
%dir %{_texmfdistdir}/doc/support/latex2nemeth/doc
%dir %{_texmfdistdir}/doc/support/latex2nemeth/encodings
%dir %{_texmfdistdir}/doc/support/latex2nemeth/examples
%dir %{_texmfdistdir}/doc/support/latexdiff
%dir %{_texmfdistdir}/doc/support/latexdiff/contrib
%dir %{_texmfdistdir}/doc/support/latexdiff/doc
%dir %{_texmfdistdir}/doc/support/latexdiff/example
%dir %{_texmfdistdir}/doc/support/latexfileversion
%dir %{_texmfdistdir}/doc/support/latexindent
%dir %{_texmfdistdir}/doc/support/latexmk
%dir %{_texmfdistdir}/doc/support/latexmk/example_rcfiles
%dir %{_texmfdistdir}/doc/support/latexmk/extra-scripts
%dir %{_texmfdistdir}/doc/support/latexpand
%dir %{_texmfdistdir}/doc/support/light-latex-make
%dir %{_texmfdistdir}/doc/support/ltxfileinfo
%dir %{_texmfdistdir}/doc/support/ltximg
%dir %{_texmfdistdir}/doc/support/lua-alt-getopt
%dir %{_texmfdistdir}/doc/support/lua-alt-getopt/tests
%dir %{_texmfdistdir}/doc/support/lua-uca
%dir %{_texmfdistdir}/doc/support/luafindfont
%dir %{_texmfdistdir}/doc/support/lyluatex
%dir %{_texmfdistdir}/doc/support/lyluatex/ly
%dir %{_texmfdistdir}/doc/support/make4ht
%dir %{_texmfdistdir}/doc/support/makedtx
%dir %{_texmfdistdir}/doc/support/makeindex
%dir %{_texmfdistdir}/doc/support/match_parens
%dir %{_texmfdistdir}/doc/support/mendex-doc
%dir %{_texmfdistdir}/doc/support/mf2pt1
%dir %{_texmfdistdir}/doc/support/mkgrkindex
%dir %{_texmfdistdir}/doc/support/mkpic
%dir %{_texmfdistdir}/doc/support/optexcount
%dir %{_texmfdistdir}/doc/support/patgen2-tutorial
%dir %{_texmfdistdir}/doc/support/pdfbook2
%dir %{_texmfdistdir}/doc/support/pdfcrop
%dir %{_texmfdistdir}/doc/support/pdfjam
%dir %{_texmfdistdir}/doc/support/pdflatexpicscale
%dir %{_texmfdistdir}/doc/support/pdftex-quiet
%dir %{_texmfdistdir}/doc/support/pdfxup
%dir %{_texmfdistdir}/doc/support/pedigree-perl
%dir %{_texmfdistdir}/doc/support/pedigree-perl/Pedigree
%dir %{_texmfdistdir}/doc/support/pedigree-perl/doc
%dir %{_texmfdistdir}/doc/support/pedigree-perl/examples
%dir %{_texmfdistdir}/doc/support/pkfix
%dir %{_texmfdistdir}/doc/support/pkfix-helper
%dir %{_texmfdistdir}/doc/support/pst2pdf
%dir %{_texmfdistdir}/doc/support/purifyeps
%dir %{_texmfdistdir}/doc/support/spix
%dir %{_texmfdistdir}/doc/support/srcredact
%dir %{_texmfdistdir}/doc/support/sty2dtx
%dir %{_texmfdistdir}/doc/support/svn-multi
%dir %{_texmfdistdir}/doc/support/tex4ebook
%dir %{_texmfdistdir}/doc/support/texaccents
%dir %{_texmfdistdir}/doc/support/texcount
%dir %{_texmfdistdir}/doc/support/texcount/doc
%dir %{_texmfdistdir}/doc/support/texdef
%dir %{_texmfdistdir}/doc/support/texdiff
%dir %{_texmfdistdir}/doc/support/texdirflatten
%dir %{_texmfdistdir}/doc/support/texdoc
%dir %{_texmfdistdir}/doc/support/texdraw
%dir %{_texmfdistdir}/doc/support/texdraw/examples
%dir %{_texmfdistdir}/doc/support/texdraw/test
%dir %{_texmfdistdir}/doc/support/texfot
%dir %{_texmfdistdir}/doc/support/texliveonfly
%dir %{_texmfdistdir}/doc/support/texloganalyser
%dir %{_texmfdistdir}/doc/support/texlogfilter
%dir %{_texmfdistdir}/doc/support/texlogsieve
%dir %{_texmfdistdir}/doc/support/texosquery
%dir %{_texmfdistdir}/doc/support/texplate
%dir %{_texmfdistdir}/doc/support/tikztosvg
%dir %{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn
%dir %{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn/body
%dir %{_texmfdistdir}/doc/support/tlmgr-intro-zh-cn/fig
%dir %{_texmfdistdir}/doc/support/tlmgrbasics
%dir %{_texmfdistdir}/doc/support/typeoutfileinfo
%dir %{_texmfdistdir}/doc/support/upmendex
%dir %{_texmfdistdir}/doc/support/upmendex/samples
%dir %{_texmfdistdir}/doc/support/upmendex/samples/alphabet
%dir %{_texmfdistdir}/doc/support/upmendex/samples/latex
%dir %{_texmfdistdir}/doc/support/upmendex/samples/option
%dir %{_texmfdistdir}/doc/texlive
%dir %{_texmfdistdir}/doc/texlive/texlive-common
%dir %{_texmfdistdir}/doc/texlive/texlive-common/examples
%dir %{_texmfdistdir}/doc/texlive/texlive-cz
%dir %{_texmfdistdir}/doc/texlive/texlive-de
%dir %{_texmfdistdir}/doc/texlive/texlive-en
%dir %{_texmfdistdir}/doc/texlive/texlive-en/archive
%dir %{_texmfdistdir}/doc/texlive/texlive-es
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2017
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2018
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2019
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2020
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2021
%dir %{_texmfdistdir}/doc/texlive/texlive-es/archive/2022-march-2022-dec
%dir %{_texmfdistdir}/doc/texlive/texlive-fr
%dir %{_texmfdistdir}/doc/texlive/texlive-it
%dir %{_texmfdistdir}/doc/texlive/texlive-ja
%dir %{_texmfdistdir}/doc/texlive/texlive-ja/img
%dir %{_texmfdistdir}/doc/texlive/texlive-pl
%dir %{_texmfdistdir}/doc/texlive/texlive-ru
%dir %{_texmfdistdir}/doc/texlive/texlive-sr
%dir %{_texmfdistdir}/doc/texlive/texlive-sr/images
%dir %{_texmfdistdir}/doc/texlive/texlive-zh-cn
%dir %{_texmfdistdir}/doc/texlive/tlbuild
%dir %{_texmfdistdir}/doc/tpic2pdftex
%dir %{_texmfdistdir}/doc/ttf2pk
%dir %{_texmfdistdir}/doc/uplatex
%dir %{_texmfdistdir}/doc/uplatex/base
%dir %{_texmfdistdir}/doc/uptex
%dir %{_texmfdistdir}/doc/uptex/uptex-base
%dir %{_texmfdistdir}/doc/uptex/uptex-base/samples
%dir %{_texmfdistdir}/doc/vlna
%dir %{_texmfdistdir}/doc/web2c
%dir %{_texmfdistdir}/doc/xelatex
%dir %{_texmfdistdir}/doc/xelatex/arabic-book
%dir %{_texmfdistdir}/doc/xelatex/arabxetex
%dir %{_texmfdistdir}/doc/xelatex/arabxetex/examples
%dir %{_texmfdistdir}/doc/xelatex/bhcexam
%dir %{_texmfdistdir}/doc/xelatex/bhcexam/examples
%dir %{_texmfdistdir}/doc/xelatex/bidi
%dir %{_texmfdistdir}/doc/xelatex/bidi-atbegshi
%dir %{_texmfdistdir}/doc/xelatex/bidicontour
%dir %{_texmfdistdir}/doc/xelatex/bidihl
%dir %{_texmfdistdir}/doc/xelatex/bidipagegrid
%dir %{_texmfdistdir}/doc/xelatex/bidipresentation
%dir %{_texmfdistdir}/doc/xelatex/bidishadowtext
%dir %{_texmfdistdir}/doc/xelatex/buctthesis
%dir %{_texmfdistdir}/doc/xelatex/businesscard-qrcode
%dir %{_texmfdistdir}/doc/xelatex/businesscard-qrcode/examples
%dir %{_texmfdistdir}/doc/xelatex/businesscard-qrcode/screenshots
%dir %{_texmfdistdir}/doc/xelatex/cqubeamer
%dir %{_texmfdistdir}/doc/xelatex/cqubeamer/demo_code
%dir %{_texmfdistdir}/doc/xelatex/cqubeamer/figure
%dir %{_texmfdistdir}/doc/xelatex/cqubeamer/logo
%dir %{_texmfdistdir}/doc/xelatex/exam-zh
%dir %{_texmfdistdir}/doc/xelatex/exam-zh/doc
%dir %{_texmfdistdir}/doc/xelatex/exam-zh/doc/back
%dir %{_texmfdistdir}/doc/xelatex/exam-zh/doc/body
%dir %{_texmfdistdir}/doc/xelatex/exam-zh/doc/figures
%dir %{_texmfdistdir}/doc/xelatex/exam-zh/examples
%dir %{_texmfdistdir}/doc/xelatex/facture
%dir %{_texmfdistdir}/doc/xelatex/facture-belge-simple-sans-tva
%dir %{_texmfdistdir}/doc/xelatex/fixlatvian
%dir %{_texmfdistdir}/doc/xelatex/fontbook
%dir %{_texmfdistdir}/doc/xelatex/fontwrap
%dir %{_texmfdistdir}/doc/xelatex/hanzibox
%dir %{_texmfdistdir}/doc/xelatex/hfutthesis
%dir %{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-bib
%dir %{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-chapters
%dir %{_texmfdistdir}/doc/xelatex/hfutthesis/hfut-figures
%dir %{_texmfdistdir}/doc/xelatex/hithesis
%dir %{_texmfdistdir}/doc/xelatex/hithesis/back
%dir %{_texmfdistdir}/doc/xelatex/hithesis/body
%dir %{_texmfdistdir}/doc/xelatex/hithesis/figures
%dir %{_texmfdistdir}/doc/xelatex/hithesis/front
%dir %{_texmfdistdir}/doc/xelatex/imsproc
%dir %{_texmfdistdir}/doc/xelatex/interchar
%dir %{_texmfdistdir}/doc/xelatex/kurdishlipsum
%dir %{_texmfdistdir}/doc/xelatex/langsci
%dir %{_texmfdistdir}/doc/xelatex/langsci/documentation
%dir %{_texmfdistdir}/doc/xelatex/langsci/examples
%dir %{_texmfdistdir}/doc/xelatex/mathspec
%dir %{_texmfdistdir}/doc/xelatex/mynsfc
%dir %{_texmfdistdir}/doc/xelatex/na-box
%dir %{_texmfdistdir}/doc/xelatex/na-position
%dir %{_texmfdistdir}/doc/xelatex/nanicolle
%dir %{_texmfdistdir}/doc/xelatex/parsa
%dir %{_texmfdistdir}/doc/xelatex/persian-bib
%dir %{_texmfdistdir}/doc/xelatex/philokalia
%dir %{_texmfdistdir}/doc/xelatex/ptext
%dir %{_texmfdistdir}/doc/xelatex/quran-de
%dir %{_texmfdistdir}/doc/xelatex/resumecls
%dir %{_texmfdistdir}/doc/xelatex/resumecls/example
%dir %{_texmfdistdir}/doc/xelatex/sexam
%dir %{_texmfdistdir}/doc/xelatex/simple-resume-cv
%dir %{_texmfdistdir}/doc/xelatex/simple-thesis-dissertation
%dir %{_texmfdistdir}/doc/xelatex/simple-thesis-dissertation/Figures
%dir %{_texmfdistdir}/doc/xelatex/tabriz-thesis
%dir %{_texmfdistdir}/doc/xelatex/technion-thesis-template
%dir %{_texmfdistdir}/doc/xelatex/technion-thesis-template/Example
%dir %{_texmfdistdir}/doc/xelatex/tetragonos
%dir %{_texmfdistdir}/doc/xelatex/thesis-qom
%dir %{_texmfdistdir}/doc/xelatex/ucharclasses
%dir %{_texmfdistdir}/doc/xelatex/unicode-bidi
%dir %{_texmfdistdir}/doc/xelatex/unisugar
%dir %{_texmfdistdir}/doc/xelatex/xduts
%dir %{_texmfdistdir}/doc/xelatex/xechangebar
%dir %{_texmfdistdir}/doc/xelatex/xecjk
%dir %{_texmfdistdir}/doc/xelatex/xecjk/example
%dir %{_texmfdistdir}/doc/xelatex/xecolor
%dir %{_texmfdistdir}/doc/xelatex/xecyr
%dir %{_texmfdistdir}/doc/xelatex/xecyr/combined_hyphenation
%dir %{_texmfdistdir}/doc/xelatex/xecyr/inputs
%dir %{_texmfdistdir}/doc/xelatex/xecyr/old
%dir %{_texmfdistdir}/doc/xelatex/xeindex
%dir %{_texmfdistdir}/doc/xelatex/xepersian
%dir %{_texmfdistdir}/doc/xelatex/xepersian-hm
%dir %{_texmfdistdir}/doc/xelatex/xepersian/img
%dir %{_texmfdistdir}/doc/xelatex/xepersian/img/weather
%dir %{_texmfdistdir}/doc/xelatex/xespotcolor
%dir %{_texmfdistdir}/doc/xelatex/xetex-itrans
%dir %{_texmfdistdir}/doc/xelatex/xevlna
%dir %{_texmfdistdir}/doc/xelatex/xltxtra
%dir %{_texmfdistdir}/doc/xelatex/xunicode
%dir %{_texmfdistdir}/doc/xelatex/yazd-thesis
%dir %{_texmfdistdir}/doc/xelatex/yazd-thesis/figures
%dir %{_texmfdistdir}/doc/xelatex/zbmath-review-template
%dir %{_texmfdistdir}/doc/xelatex/zbmath-review-template/figures
%dir %{_texmfdistdir}/doc/xelatex/zitie
%dir %{_texmfdistdir}/doc/xetex
%dir %{_texmfdistdir}/doc/xetex/base
%dir %{_texmfdistdir}/doc/xetex/font-change-xetex
%dir %{_texmfdistdir}/doc/xetex/unimath-plain-xetex
%dir %{_texmfdistdir}/doc/xetex/xesearch
%dir %{_texmfdistdir}/doc/xetex/xetex-devanagari
%dir %{_texmfdistdir}/doc/xetex/xetex-pstricks
%dir %{_texmfdistdir}/doc/xetex/xetex-tibetan
%dir %{_texmfdistdir}/doc/xetex/xetexfontinfo
%dir %{_texmfdistdir}/doc/xetex/xetexko
%dir %{_texmfdistdir}/doc/xetex/xetexref
%dir %{_texmfdistdir}/dvipdfmx
%dir %{_texmfdistdir}/dvips
%dir %{_texmfdistdir}/dvips/arphic
%dir %{_texmfdistdir}/dvips/avantgar
%dir %{_texmfdistdir}/dvips/base
%dir %{_texmfdistdir}/dvips/bookman
%dir %{_texmfdistdir}/dvips/brushscr
%dir %{_texmfdistdir}/dvips/cm-super
%dir %{_texmfdistdir}/dvips/colorsep
%dir %{_texmfdistdir}/dvips/config
%dir %{_texmfdistdir}/dvips/courier
%dir %{_texmfdistdir}/dvips/dvipsconfig
%dir %{_texmfdistdir}/dvips/esint-type1
%dir %{_texmfdistdir}/dvips/garuda-c90
%dir %{_texmfdistdir}/dvips/gastex
%dir %{_texmfdistdir}/dvips/gsftopk
%dir %{_texmfdistdir}/dvips/helvetic
%dir %{_texmfdistdir}/dvips/initials
%dir %{_texmfdistdir}/dvips/l3backend
%dir %{_texmfdistdir}/dvips/mathdesign
%dir %{_texmfdistdir}/dvips/musixtex
%dir %{_texmfdistdir}/dvips/ncntrsbk
%dir %{_texmfdistdir}/dvips/norasi-c90
%dir %{_texmfdistdir}/dvips/omega
%dir %{_texmfdistdir}/dvips/palatino
%dir %{_texmfdistdir}/dvips/pl
%dir %{_texmfdistdir}/dvips/psfrag
%dir %{_texmfdistdir}/dvips/pspicture
%dir %{_texmfdistdir}/dvips/pst-3d
%dir %{_texmfdistdir}/dvips/pst-3dplot
%dir %{_texmfdistdir}/dvips/pst-antiprism
%dir %{_texmfdistdir}/dvips/pst-bar
%dir %{_texmfdistdir}/dvips/pst-barcode
%dir %{_texmfdistdir}/dvips/pst-bezier
%dir %{_texmfdistdir}/dvips/pst-blur
%dir %{_texmfdistdir}/dvips/pst-bspline
%dir %{_texmfdistdir}/dvips/pst-cie
%dir %{_texmfdistdir}/dvips/pst-circ
%dir %{_texmfdistdir}/dvips/pst-coil
%dir %{_texmfdistdir}/dvips/pst-cox
%dir %{_texmfdistdir}/dvips/pst-electricfield
%dir %{_texmfdistdir}/dvips/pst-eucl
%dir %{_texmfdistdir}/dvips/pst-feyn
%dir %{_texmfdistdir}/dvips/pst-fractal
%dir %{_texmfdistdir}/dvips/pst-fun
%dir %{_texmfdistdir}/dvips/pst-func
%dir %{_texmfdistdir}/dvips/pst-geo
%dir %{_texmfdistdir}/dvips/pst-grad
%dir %{_texmfdistdir}/dvips/pst-intersect
%dir %{_texmfdistdir}/dvips/pst-knot
%dir %{_texmfdistdir}/dvips/pst-light3d
%dir %{_texmfdistdir}/dvips/pst-lsystem
%dir %{_texmfdistdir}/dvips/pst-magneticfield
%dir %{_texmfdistdir}/dvips/pst-marble
%dir %{_texmfdistdir}/dvips/pst-math
%dir %{_texmfdistdir}/dvips/pst-mirror
%dir %{_texmfdistdir}/dvips/pst-moire
%dir %{_texmfdistdir}/dvips/pst-node
%dir %{_texmfdistdir}/dvips/pst-ode
%dir %{_texmfdistdir}/dvips/pst-optexp
%dir %{_texmfdistdir}/dvips/pst-ovl
%dir %{_texmfdistdir}/dvips/pst-shell
%dir %{_texmfdistdir}/dvips/pst-slpe
%dir %{_texmfdistdir}/dvips/pst-solarsystem
%dir %{_texmfdistdir}/dvips/pst-solides3d
%dir %{_texmfdistdir}/dvips/pst-spectra
%dir %{_texmfdistdir}/dvips/pst-spinner
%dir %{_texmfdistdir}/dvips/pst-text
%dir %{_texmfdistdir}/dvips/pst-tools
%dir %{_texmfdistdir}/dvips/pst-turtle
%dir %{_texmfdistdir}/dvips/pst-vectorian
%dir %{_texmfdistdir}/dvips/pstricks
%dir %{_texmfdistdir}/dvips/pstricks-add
%dir %{_texmfdistdir}/dvips/symbol
%dir %{_texmfdistdir}/dvips/tetex
%dir %{_texmfdistdir}/dvips/tex-ps
%dir %{_texmfdistdir}/dvips/times
%dir %{_texmfdistdir}/dvips/tree-dvips
%dir %{_texmfdistdir}/dvips/uhc
%dir %{_texmfdistdir}/dvips/xcolor
%dir %{_texmfdistdir}/dvips/xdvi
%dir %{_texmfdistdir}/dvips/xypic
%dir %{_texmfdistdir}/dvips/yfonts-t1
%dir %{_texmfdistdir}/dvips/zapfchan
%dir %{_texmfdistdir}/dvips/zapfding
%dir %{_texmfdistdir}/fonts
%dir %{_texmfdistdir}/fonts/afm
%dir %{_texmfdistdir}/fonts/afm/adobe
%dir %{_texmfdistdir}/fonts/afm/adobe/avantgar
%dir %{_texmfdistdir}/fonts/afm/adobe/bookman
%dir %{_texmfdistdir}/fonts/afm/adobe/courier
%dir %{_texmfdistdir}/fonts/afm/adobe/helvetic
%dir %{_texmfdistdir}/fonts/afm/adobe/ncntrsbk
%dir %{_texmfdistdir}/fonts/afm/adobe/palatino
%dir %{_texmfdistdir}/fonts/afm/adobe/symbol
%dir %{_texmfdistdir}/fonts/afm/adobe/times
%dir %{_texmfdistdir}/fonts/afm/adobe/utopia
%dir %{_texmfdistdir}/fonts/afm/adobe/zapfchan
%dir %{_texmfdistdir}/fonts/afm/adobe/zapfding
%dir %{_texmfdistdir}/fonts/afm/arabi
%dir %{_texmfdistdir}/fonts/afm/arabi/arabeyes
%dir %{_texmfdistdir}/fonts/afm/arkandis
%dir %{_texmfdistdir}/fonts/afm/arkandis/adforn
%dir %{_texmfdistdir}/fonts/afm/arkandis/adfsymbols
%dir %{_texmfdistdir}/fonts/afm/arkandis/baskervald
%dir %{_texmfdistdir}/fonts/afm/arkandis/berenisadf
%dir %{_texmfdistdir}/fonts/afm/arkandis/electrum
%dir %{_texmfdistdir}/fonts/afm/arkandis/libris
%dir %{_texmfdistdir}/fonts/afm/arkandis/romande
%dir %{_texmfdistdir}/fonts/afm/arkandis/venturis
%dir %{_texmfdistdir}/fonts/afm/arkandis/venturis2
%dir %{_texmfdistdir}/fonts/afm/arkandis/venturisold
%dir %{_texmfdistdir}/fonts/afm/arkandis/venturissans
%dir %{_texmfdistdir}/fonts/afm/arkandis/venturissans2
%dir %{_texmfdistdir}/fonts/afm/arphic
%dir %{_texmfdistdir}/fonts/afm/arphic/bkaiu
%dir %{_texmfdistdir}/fonts/afm/arphic/bsmiu
%dir %{_texmfdistdir}/fonts/afm/arphic/gbsnu
%dir %{_texmfdistdir}/fonts/afm/arphic/gkaiu
%dir %{_texmfdistdir}/fonts/afm/bitstrea
%dir %{_texmfdistdir}/fonts/afm/bitstrea/charter
%dir %{_texmfdistdir}/fonts/afm/esstix
%dir %{_texmfdistdir}/fonts/afm/gust
%dir %{_texmfdistdir}/fonts/afm/gust/poltawski
%dir %{_texmfdistdir}/fonts/afm/hoekwater
%dir %{_texmfdistdir}/fonts/afm/hoekwater/context
%dir %{_texmfdistdir}/fonts/afm/hoekwater/manfnt-font
%dir %{_texmfdistdir}/fonts/afm/hoekwater/mflogo-font
%dir %{_texmfdistdir}/fonts/afm/jmn
%dir %{_texmfdistdir}/fonts/afm/jmn/hans
%dir %{_texmfdistdir}/fonts/afm/metapost
%dir %{_texmfdistdir}/fonts/afm/nowacki
%dir %{_texmfdistdir}/fonts/afm/nowacki/iwona
%dir %{_texmfdistdir}/fonts/afm/nowacki/kurier
%dir %{_texmfdistdir}/fonts/afm/paratype
%dir %{_texmfdistdir}/fonts/afm/paratype/ptmono
%dir %{_texmfdistdir}/fonts/afm/paratype/ptsans
%dir %{_texmfdistdir}/fonts/afm/paratype/ptserif
%dir %{_texmfdistdir}/fonts/afm/public
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/cm
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/cmextra
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/cyrillic
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/euler
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/latxfont
%dir %{_texmfdistdir}/fonts/afm/public/amsfonts/symbols
%dir %{_texmfdistdir}/fonts/afm/public/anonymouspro
%dir %{_texmfdistdir}/fonts/afm/public/antt
%dir %{_texmfdistdir}/fonts/afm/public/aramaic-serto
%dir %{_texmfdistdir}/fonts/afm/public/archaic
%dir %{_texmfdistdir}/fonts/afm/public/arev
%dir %{_texmfdistdir}/fonts/afm/public/armenian
%dir %{_texmfdistdir}/fonts/afm/public/augie
%dir %{_texmfdistdir}/fonts/afm/public/auncial-new
%dir %{_texmfdistdir}/fonts/afm/public/aurical
%dir %{_texmfdistdir}/fonts/afm/public/baskervaldx
%dir %{_texmfdistdir}/fonts/afm/public/bbold-type1
%dir %{_texmfdistdir}/fonts/afm/public/bboldx
%dir %{_texmfdistdir}/fonts/afm/public/bera
%dir %{_texmfdistdir}/fonts/afm/public/bookhands
%dir %{_texmfdistdir}/fonts/afm/public/brushscr
%dir %{_texmfdistdir}/fonts/afm/public/calligra-type1
%dir %{_texmfdistdir}/fonts/afm/public/carolmin-ps
%dir %{_texmfdistdir}/fonts/afm/public/chemarrow
%dir %{_texmfdistdir}/fonts/afm/public/cjhebrew
%dir %{_texmfdistdir}/fonts/afm/public/cm-lgc
%dir %{_texmfdistdir}/fonts/afm/public/cm-super
%dir %{_texmfdistdir}/fonts/afm/public/cm-unicode
%dir %{_texmfdistdir}/fonts/afm/public/cmsrb
%dir %{_texmfdistdir}/fonts/afm/public/cmupint
%dir %{_texmfdistdir}/fonts/afm/public/cochineal
%dir %{_texmfdistdir}/fonts/afm/public/countriesofeurope
%dir %{_texmfdistdir}/fonts/afm/public/cryst
%dir %{_texmfdistdir}/fonts/afm/public/cyklop
%dir %{_texmfdistdir}/fonts/afm/public/dad
%dir %{_texmfdistdir}/fonts/afm/public/dejavu
%dir %{_texmfdistdir}/fonts/afm/public/dictsym
%dir %{_texmfdistdir}/fonts/afm/public/dozenal
%dir %{_texmfdistdir}/fonts/afm/public/drm
%dir %{_texmfdistdir}/fonts/afm/public/dsserif
%dir %{_texmfdistdir}/fonts/afm/public/dutchcal
%dir %{_texmfdistdir}/fonts/afm/public/epigrafica
%dir %{_texmfdistdir}/fonts/afm/public/erewhon
%dir %{_texmfdistdir}/fonts/afm/public/etbb
%dir %{_texmfdistdir}/fonts/afm/public/fetamont
%dir %{_texmfdistdir}/fonts/afm/public/figbas
%dir %{_texmfdistdir}/fonts/afm/public/fonetika
%dir %{_texmfdistdir}/fonts/afm/public/fonts-tlwg
%dir %{_texmfdistdir}/fonts/afm/public/fourier
%dir %{_texmfdistdir}/fonts/afm/public/fouriernc
%dir %{_texmfdistdir}/fonts/afm/public/fpl
%dir %{_texmfdistdir}/fonts/afm/public/frimurer
%dir %{_texmfdistdir}/fonts/afm/public/gentium-tug
%dir %{_texmfdistdir}/fonts/afm/public/gfsartemisia
%dir %{_texmfdistdir}/fonts/afm/public/gfsbaskerville
%dir %{_texmfdistdir}/fonts/afm/public/gfsbodoni
%dir %{_texmfdistdir}/fonts/afm/public/gfscomplutum
%dir %{_texmfdistdir}/fonts/afm/public/gfsdidot
%dir %{_texmfdistdir}/fonts/afm/public/gfsneohellenic
%dir %{_texmfdistdir}/fonts/afm/public/gfsporson
%dir %{_texmfdistdir}/fonts/afm/public/gfssolomos
%dir %{_texmfdistdir}/fonts/afm/public/hfbright
%dir %{_texmfdistdir}/fonts/afm/public/ibygrk
%dir %{_texmfdistdir}/fonts/afm/public/initials
%dir %{_texmfdistdir}/fonts/afm/public/kerkis
%dir %{_texmfdistdir}/fonts/afm/public/knitting
%dir %{_texmfdistdir}/fonts/afm/public/kpfonts
%dir %{_texmfdistdir}/fonts/afm/public/libertinust1math
%dir %{_texmfdistdir}/fonts/afm/public/lineara
%dir %{_texmfdistdir}/fonts/afm/public/lm
%dir %{_texmfdistdir}/fonts/afm/public/marvosym
%dir %{_texmfdistdir}/fonts/afm/public/mathpazo
%dir %{_texmfdistdir}/fonts/afm/public/miama
%dir %{_texmfdistdir}/fonts/afm/public/mxedruli
%dir %{_texmfdistdir}/fonts/afm/public/nanumtype1
%dir %{_texmfdistdir}/fonts/afm/public/newpx
%dir %{_texmfdistdir}/fonts/afm/public/newtx
%dir %{_texmfdistdir}/fonts/afm/public/niceframe-type1
%dir %{_texmfdistdir}/fonts/afm/public/nimbus15
%dir %{_texmfdistdir}/fonts/afm/public/ocherokee
%dir %{_texmfdistdir}/fonts/afm/public/old-arrows
%dir %{_texmfdistdir}/fonts/afm/public/omega
%dir %{_texmfdistdir}/fonts/afm/public/phaistos
%dir %{_texmfdistdir}/fonts/afm/public/pl
%dir %{_texmfdistdir}/fonts/afm/public/plimsoll
%dir %{_texmfdistdir}/fonts/afm/public/prodint
%dir %{_texmfdistdir}/fonts/afm/public/pxfonts
%dir %{_texmfdistdir}/fonts/afm/public/rsfs
%dir %{_texmfdistdir}/fonts/afm/public/scholax
%dir %{_texmfdistdir}/fonts/afm/public/semaphor
%dir %{_texmfdistdir}/fonts/afm/public/skaknew
%dir %{_texmfdistdir}/fonts/afm/public/starfont
%dir %{_texmfdistdir}/fonts/afm/public/stickstoo
%dir %{_texmfdistdir}/fonts/afm/public/stmaryrd
%dir %{_texmfdistdir}/fonts/afm/public/svrsymbols
%dir %{_texmfdistdir}/fonts/afm/public/tabvar
%dir %{_texmfdistdir}/fonts/afm/public/tempora
%dir %{_texmfdistdir}/fonts/afm/public/tex-gyre
%dir %{_texmfdistdir}/fonts/afm/public/tfrupee
%dir %{_texmfdistdir}/fonts/afm/public/trajan
%dir %{_texmfdistdir}/fonts/afm/public/txfonts
%dir %{_texmfdistdir}/fonts/afm/public/txfontsb
%dir %{_texmfdistdir}/fonts/afm/public/velthuis
%dir %{_texmfdistdir}/fonts/afm/public/wasy-type1
%dir %{_texmfdistdir}/fonts/afm/public/xcharter
%dir %{_texmfdistdir}/fonts/afm/public/xypic
%dir %{_texmfdistdir}/fonts/afm/public/yfonts-t1
%dir %{_texmfdistdir}/fonts/afm/uhc
%dir %{_texmfdistdir}/fonts/afm/uhc/umj
%dir %{_texmfdistdir}/fonts/afm/urw
%dir %{_texmfdistdir}/fonts/afm/urw/antiqua
%dir %{_texmfdistdir}/fonts/afm/urw/avantgar
%dir %{_texmfdistdir}/fonts/afm/urw/bookman
%dir %{_texmfdistdir}/fonts/afm/urw/courier
%dir %{_texmfdistdir}/fonts/afm/urw/grotesq
%dir %{_texmfdistdir}/fonts/afm/urw/helvetic
%dir %{_texmfdistdir}/fonts/afm/urw/ncntrsbk
%dir %{_texmfdistdir}/fonts/afm/urw/palatino
%dir %{_texmfdistdir}/fonts/afm/urw/symbol
%dir %{_texmfdistdir}/fonts/afm/urw/times
%dir %{_texmfdistdir}/fonts/afm/urw/zapfchan
%dir %{_texmfdistdir}/fonts/afm/urw/zapfding
%dir %{_texmfdistdir}/fonts/afm/vntex
%dir %{_texmfdistdir}/fonts/afm/vntex/chartervn
%dir %{_texmfdistdir}/fonts/afm/vntex/grotesqvn
%dir %{_texmfdistdir}/fonts/afm/vntex/urwvn
%dir %{_texmfdistdir}/fonts/afm/vntex/vntopia
%dir %{_texmfdistdir}/fonts/afm/wadalab
%dir %{_texmfdistdir}/fonts/afm/wadalab/dgj
%dir %{_texmfdistdir}/fonts/afm/wadalab/dmj
%dir %{_texmfdistdir}/fonts/afm/wadalab/mc2j
%dir %{_texmfdistdir}/fonts/afm/wadalab/mcj
%dir %{_texmfdistdir}/fonts/afm/wadalab/mr2j
%dir %{_texmfdistdir}/fonts/afm/wadalab/mrj
%dir %{_texmfdistdir}/fonts/cid
%dir %{_texmfdistdir}/fonts/cid/fontforge
%dir %{_texmfdistdir}/fonts/cmap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-CNS1-7
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-CNS1-7/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-GB1-5
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-GB1-5/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Identity-0
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Identity-0/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Japan1-7
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Japan1-7/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-KR-9
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-KR-9/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Korea1-2
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/cmap-resources/Adobe-Korea1-2/CMap
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/mapping-resources-pdf
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/mapping-resources-pdf/pdf2other
%dir %{_texmfdistdir}/fonts/cmap/adobemapping/mapping-resources-pdf/pdf2unicode
%dir %{_texmfdistdir}/fonts/cmap/dvipdfmx
%dir %{_texmfdistdir}/fonts/cmap/ptex-fontmaps
%dir %{_texmfdistdir}/fonts/cmap/uptex-fonts
%dir %{_texmfdistdir}/fonts/enc
%dir %{_texmfdistdir}/fonts/enc/dvips
%dir %{_texmfdistdir}/fonts/enc/dvips/accanthis
%dir %{_texmfdistdir}/fonts/enc/dvips/adforn
%dir %{_texmfdistdir}/fonts/enc/dvips/adfsymbols
%dir %{_texmfdistdir}/fonts/enc/dvips/aesupp
%dir %{_texmfdistdir}/fonts/enc/dvips/afm2pl
%dir %{_texmfdistdir}/fonts/enc/dvips/alegreya
%dir %{_texmfdistdir}/fonts/enc/dvips/alfaslabone
%dir %{_texmfdistdir}/fonts/enc/dvips/algolrevived
%dir %{_texmfdistdir}/fonts/enc/dvips/almendra
%dir %{_texmfdistdir}/fonts/enc/dvips/andika
%dir %{_texmfdistdir}/fonts/enc/dvips/anonymouspro
%dir %{_texmfdistdir}/fonts/enc/dvips/antt
%dir %{_texmfdistdir}/fonts/enc/dvips/arabi
%dir %{_texmfdistdir}/fonts/enc/dvips/archivo
%dir %{_texmfdistdir}/fonts/enc/dvips/arev
%dir %{_texmfdistdir}/fonts/enc/dvips/arimo
%dir %{_texmfdistdir}/fonts/enc/dvips/arvo
%dir %{_texmfdistdir}/fonts/enc/dvips/atkinson
%dir %{_texmfdistdir}/fonts/enc/dvips/b1encoding
%dir %{_texmfdistdir}/fonts/enc/dvips/base
%dir %{_texmfdistdir}/fonts/enc/dvips/baskervald
%dir %{_texmfdistdir}/fonts/enc/dvips/baskervaldx
%dir %{_texmfdistdir}/fonts/enc/dvips/baskervillef
%dir %{_texmfdistdir}/fonts/enc/dvips/bboldx
%dir %{_texmfdistdir}/fonts/enc/dvips/berenisadf
%dir %{_texmfdistdir}/fonts/enc/dvips/bitter
%dir %{_texmfdistdir}/fonts/enc/dvips/c90
%dir %{_texmfdistdir}/fonts/enc/dvips/cabin
%dir %{_texmfdistdir}/fonts/enc/dvips/caladea
%dir %{_texmfdistdir}/fonts/enc/dvips/cantarell
%dir %{_texmfdistdir}/fonts/enc/dvips/carlito
%dir %{_texmfdistdir}/fonts/enc/dvips/cascadia-code
%dir %{_texmfdistdir}/fonts/enc/dvips/cbfonts
%dir %{_texmfdistdir}/fonts/enc/dvips/ccicons
%dir %{_texmfdistdir}/fonts/enc/dvips/cfr-lm
%dir %{_texmfdistdir}/fonts/enc/dvips/charissil
%dir %{_texmfdistdir}/fonts/enc/dvips/chessfss
%dir %{_texmfdistdir}/fonts/enc/dvips/chivo
%dir %{_texmfdistdir}/fonts/enc/dvips/cinzel
%dir %{_texmfdistdir}/fonts/enc/dvips/cjhebrew
%dir %{_texmfdistdir}/fonts/enc/dvips/clara
%dir %{_texmfdistdir}/fonts/enc/dvips/clearsans
%dir %{_texmfdistdir}/fonts/enc/dvips/cm-lgc
%dir %{_texmfdistdir}/fonts/enc/dvips/cm-super
%dir %{_texmfdistdir}/fonts/enc/dvips/cm-unicode
%dir %{_texmfdistdir}/fonts/enc/dvips/cmathbb
%dir %{_texmfdistdir}/fonts/enc/dvips/cmsrb
%dir %{_texmfdistdir}/fonts/enc/dvips/cochineal
%dir %{_texmfdistdir}/fonts/enc/dvips/coelacanth
%dir %{_texmfdistdir}/fonts/enc/dvips/comfortaa
%dir %{_texmfdistdir}/fonts/enc/dvips/comicneue
%dir %{_texmfdistdir}/fonts/enc/dvips/cooperhewitt
%dir %{_texmfdistdir}/fonts/enc/dvips/cormorantgaramond
%dir %{_texmfdistdir}/fonts/enc/dvips/countriesofeurope
%dir %{_texmfdistdir}/fonts/enc/dvips/courierten
%dir %{_texmfdistdir}/fonts/enc/dvips/crimson
%dir %{_texmfdistdir}/fonts/enc/dvips/crimsonpro
%dir %{_texmfdistdir}/fonts/enc/dvips/cs
%dir %{_texmfdistdir}/fonts/enc/dvips/cyklop
%dir %{_texmfdistdir}/fonts/enc/dvips/dantelogo
%dir %{_texmfdistdir}/fonts/enc/dvips/dejavu
%dir %{_texmfdistdir}/fonts/enc/dvips/domitian
%dir %{_texmfdistdir}/fonts/enc/dvips/droid
%dir %{_texmfdistdir}/fonts/enc/dvips/ebgaramond
%dir %{_texmfdistdir}/fonts/enc/dvips/ebgaramond-maths
%dir %{_texmfdistdir}/fonts/enc/dvips/electrum
%dir %{_texmfdistdir}/fonts/enc/dvips/epigrafica
%dir %{_texmfdistdir}/fonts/enc/dvips/erewhon
%dir %{_texmfdistdir}/fonts/enc/dvips/etbb
%dir %{_texmfdistdir}/fonts/enc/dvips/fbb
%dir %{_texmfdistdir}/fonts/enc/dvips/fdsymbol
%dir %{_texmfdistdir}/fonts/enc/dvips/fira
%dir %{_texmfdistdir}/fonts/enc/dvips/fontawesome
%dir %{_texmfdistdir}/fonts/enc/dvips/fontawesome5
%dir %{_texmfdistdir}/fonts/enc/dvips/fontools
%dir %{_texmfdistdir}/fonts/enc/dvips/fonts-tlwg
%dir %{_texmfdistdir}/fonts/enc/dvips/forum
%dir %{_texmfdistdir}/fonts/enc/dvips/frimurer
%dir %{_texmfdistdir}/fonts/enc/dvips/garamond-libre
%dir %{_texmfdistdir}/fonts/enc/dvips/gentium-tug
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsartemisia
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsbaskerville
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsbodoni
%dir %{_texmfdistdir}/fonts/enc/dvips/gfscomplutum
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsdidot
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsneohellenic
%dir %{_texmfdistdir}/fonts/enc/dvips/gfsporson
%dir %{_texmfdistdir}/fonts/enc/dvips/gfssolomos
%dir %{_texmfdistdir}/fonts/enc/dvips/gillius
%dir %{_texmfdistdir}/fonts/enc/dvips/gofonts
%dir %{_texmfdistdir}/fonts/enc/dvips/gudea
%dir %{_texmfdistdir}/fonts/enc/dvips/heuristica
%dir %{_texmfdistdir}/fonts/enc/dvips/hfbright
%dir %{_texmfdistdir}/fonts/enc/dvips/hindmadurai
%dir %{_texmfdistdir}/fonts/enc/dvips/ibarra
%dir %{_texmfdistdir}/fonts/enc/dvips/ibygrk
%dir %{_texmfdistdir}/fonts/enc/dvips/imfellenglish
%dir %{_texmfdistdir}/fonts/enc/dvips/inconsolata
%dir %{_texmfdistdir}/fonts/enc/dvips/inriafonts
%dir %{_texmfdistdir}/fonts/enc/dvips/inter
%dir %{_texmfdistdir}/fonts/enc/dvips/ipaex-type1
%dir %{_texmfdistdir}/fonts/enc/dvips/iwona
%dir %{_texmfdistdir}/fonts/enc/dvips/jmn
%dir %{_texmfdistdir}/fonts/enc/dvips/josefin
%dir %{_texmfdistdir}/fonts/enc/dvips/junicode
%dir %{_texmfdistdir}/fonts/enc/dvips/kerkis
%dir %{_texmfdistdir}/fonts/enc/dvips/kpfonts
%dir %{_texmfdistdir}/fonts/enc/dvips/kurier
%dir %{_texmfdistdir}/fonts/enc/dvips/lato
%dir %{_texmfdistdir}/fonts/enc/dvips/libertine
%dir %{_texmfdistdir}/fonts/enc/dvips/libertinegc
%dir %{_texmfdistdir}/fonts/enc/dvips/libertinus-type1
%dir %{_texmfdistdir}/fonts/enc/dvips/libertinust1math
%dir %{_texmfdistdir}/fonts/enc/dvips/librebaskerville
%dir %{_texmfdistdir}/fonts/enc/dvips/librebodoni
%dir %{_texmfdistdir}/fonts/enc/dvips/librecaslon
%dir %{_texmfdistdir}/fonts/enc/dvips/librefranklin
%dir %{_texmfdistdir}/fonts/enc/dvips/libris
%dir %{_texmfdistdir}/fonts/enc/dvips/linguisticspro
%dir %{_texmfdistdir}/fonts/enc/dvips/lithuanian
%dir %{_texmfdistdir}/fonts/enc/dvips/lm
%dir %{_texmfdistdir}/fonts/enc/dvips/lobster2
%dir %{_texmfdistdir}/fonts/enc/dvips/ly1
%dir %{_texmfdistdir}/fonts/enc/dvips/magra
%dir %{_texmfdistdir}/fonts/enc/dvips/marcellus
%dir %{_texmfdistdir}/fonts/enc/dvips/mathdesign
%dir %{_texmfdistdir}/fonts/enc/dvips/mdsymbol
%dir %{_texmfdistdir}/fonts/enc/dvips/merriweather
%dir %{_texmfdistdir}/fonts/enc/dvips/metapost
%dir %{_texmfdistdir}/fonts/enc/dvips/miama
%dir %{_texmfdistdir}/fonts/enc/dvips/mintspirit
%dir %{_texmfdistdir}/fonts/enc/dvips/mnsymbol
%dir %{_texmfdistdir}/fonts/enc/dvips/montserrat
%dir %{_texmfdistdir}/fonts/enc/dvips/newpx
%dir %{_texmfdistdir}/fonts/enc/dvips/newtx
%dir %{_texmfdistdir}/fonts/enc/dvips/newtxtt
%dir %{_texmfdistdir}/fonts/enc/dvips/nimbus15
%dir %{_texmfdistdir}/fonts/enc/dvips/noto
%dir %{_texmfdistdir}/fonts/enc/dvips/nunito
%dir %{_texmfdistdir}/fonts/enc/dvips/old-arrows
%dir %{_texmfdistdir}/fonts/enc/dvips/oldstandard
%dir %{_texmfdistdir}/fonts/enc/dvips/opensans
%dir %{_texmfdistdir}/fonts/enc/dvips/oswald
%dir %{_texmfdistdir}/fonts/enc/dvips/overlock
%dir %{_texmfdistdir}/fonts/enc/dvips/paratype
%dir %{_texmfdistdir}/fonts/enc/dvips/pl
%dir %{_texmfdistdir}/fonts/enc/dvips/playfair
%dir %{_texmfdistdir}/fonts/enc/dvips/plex
%dir %{_texmfdistdir}/fonts/enc/dvips/plimsoll
%dir %{_texmfdistdir}/fonts/enc/dvips/poiretone
%dir %{_texmfdistdir}/fonts/enc/dvips/poltawski
%dir %{_texmfdistdir}/fonts/enc/dvips/quattrocento
%dir %{_texmfdistdir}/fonts/enc/dvips/raleway
%dir %{_texmfdistdir}/fonts/enc/dvips/roboto
%dir %{_texmfdistdir}/fonts/enc/dvips/romande
%dir %{_texmfdistdir}/fonts/enc/dvips/rosario
%dir %{_texmfdistdir}/fonts/enc/dvips/scholax
%dir %{_texmfdistdir}/fonts/enc/dvips/semaphor
%dir %{_texmfdistdir}/fonts/enc/dvips/simpleicons
%dir %{_texmfdistdir}/fonts/enc/dvips/sourcecodepro
%dir %{_texmfdistdir}/fonts/enc/dvips/sourcesanspro
%dir %{_texmfdistdir}/fonts/enc/dvips/sourceserifpro
%dir %{_texmfdistdir}/fonts/enc/dvips/spectral
%dir %{_texmfdistdir}/fonts/enc/dvips/srbtiks
%dir %{_texmfdistdir}/fonts/enc/dvips/step
%dir %{_texmfdistdir}/fonts/enc/dvips/stepgreek
%dir %{_texmfdistdir}/fonts/enc/dvips/stickstoo
%dir %{_texmfdistdir}/fonts/enc/dvips/stix
%dir %{_texmfdistdir}/fonts/enc/dvips/stix2-type1
%dir %{_texmfdistdir}/fonts/enc/dvips/superiors
%dir %{_texmfdistdir}/fonts/enc/dvips/tempora
%dir %{_texmfdistdir}/fonts/enc/dvips/tengwarscript
%dir %{_texmfdistdir}/fonts/enc/dvips/tetex
%dir %{_texmfdistdir}/fonts/enc/dvips/tex-gyre
%dir %{_texmfdistdir}/fonts/enc/dvips/theanodidot
%dir %{_texmfdistdir}/fonts/enc/dvips/theanomodern
%dir %{_texmfdistdir}/fonts/enc/dvips/theanooldstyle
%dir %{_texmfdistdir}/fonts/enc/dvips/tinos
%dir %{_texmfdistdir}/fonts/enc/dvips/txfonts
%dir %{_texmfdistdir}/fonts/enc/dvips/txfontsb
%dir %{_texmfdistdir}/fonts/enc/dvips/ucs
%dir %{_texmfdistdir}/fonts/enc/dvips/universalis
%dir %{_texmfdistdir}/fonts/enc/dvips/venturisadf
%dir %{_texmfdistdir}/fonts/enc/dvips/vntex
%dir %{_texmfdistdir}/fonts/enc/dvips/xcharter
%dir %{_texmfdistdir}/fonts/enc/dvips/xypic
%dir %{_texmfdistdir}/fonts/enc/pdftex
%dir %{_texmfdistdir}/fonts/enc/pdftex/vntex
%dir %{_texmfdistdir}/fonts/enc/t2
%dir %{_texmfdistdir}/fonts/enc/ttf2pk
%dir %{_texmfdistdir}/fonts/enc/ttf2pk/base
%dir %{_texmfdistdir}/fonts/lig
%dir %{_texmfdistdir}/fonts/lig/afm2pl
%dir %{_texmfdistdir}/fonts/map
%dir %{_texmfdistdir}/fonts/map/dvipdfm
%dir %{_texmfdistdir}/fonts/map/dvipdfm/lm
%dir %{_texmfdistdir}/fonts/map/dvipdfmx
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/morisawa
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/adobe
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/apple
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/arphic
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/baekmuk
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/bizud
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/canon
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/cjkunifonts-ttf
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/dynacomware
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/fandol
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/founder
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/haranoaji
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/hiragino
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/hiragino-pron
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ipa
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ipaex
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/kozuka-pr6n
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/moga-mobo-ex
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/morisawa
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/morisawa-pr6n
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms-osx
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ms-win10
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noEmbed
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noto
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/noto-otc
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/solaris
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/sourcehan
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/sourcehan-otc
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/ume
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/unfonts
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-osx
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-win
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/ptex-fontmaps/yu-win10
%dir %{_texmfdistdir}/fonts/map/dvips
%dir %{_texmfdistdir}/fonts/map/dvips/accanthis
%dir %{_texmfdistdir}/fonts/map/dvips/adforn
%dir %{_texmfdistdir}/fonts/map/dvips/adfsymbols
%dir %{_texmfdistdir}/fonts/map/dvips/aesupp
%dir %{_texmfdistdir}/fonts/map/dvips/alegreya
%dir %{_texmfdistdir}/fonts/map/dvips/alfaslabone
%dir %{_texmfdistdir}/fonts/map/dvips/algolrevived
%dir %{_texmfdistdir}/fonts/map/dvips/allrunes
%dir %{_texmfdistdir}/fonts/map/dvips/almendra
%dir %{_texmfdistdir}/fonts/map/dvips/amsfonts
%dir %{_texmfdistdir}/fonts/map/dvips/andika
%dir %{_texmfdistdir}/fonts/map/dvips/anonymouspro
%dir %{_texmfdistdir}/fonts/map/dvips/antiqua
%dir %{_texmfdistdir}/fonts/map/dvips/antt
%dir %{_texmfdistdir}/fonts/map/dvips/arabi
%dir %{_texmfdistdir}/fonts/map/dvips/arabtex
%dir %{_texmfdistdir}/fonts/map/dvips/aramaic-serto
%dir %{_texmfdistdir}/fonts/map/dvips/archaic
%dir %{_texmfdistdir}/fonts/map/dvips/archivo
%dir %{_texmfdistdir}/fonts/map/dvips/arev
%dir %{_texmfdistdir}/fonts/map/dvips/arimo
%dir %{_texmfdistdir}/fonts/map/dvips/armenian
%dir %{_texmfdistdir}/fonts/map/dvips/arphic
%dir %{_texmfdistdir}/fonts/map/dvips/arvo
%dir %{_texmfdistdir}/fonts/map/dvips/ascii-font
%dir %{_texmfdistdir}/fonts/map/dvips/ascmac
%dir %{_texmfdistdir}/fonts/map/dvips/aspectratio
%dir %{_texmfdistdir}/fonts/map/dvips/atkinson
%dir %{_texmfdistdir}/fonts/map/dvips/augie
%dir %{_texmfdistdir}/fonts/map/dvips/auncial-new
%dir %{_texmfdistdir}/fonts/map/dvips/aurical
%dir %{_texmfdistdir}/fonts/map/dvips/avantgar
%dir %{_texmfdistdir}/fonts/map/dvips/baskervald
%dir %{_texmfdistdir}/fonts/map/dvips/baskervaldx
%dir %{_texmfdistdir}/fonts/map/dvips/baskervillef
%dir %{_texmfdistdir}/fonts/map/dvips/bbold-type1
%dir %{_texmfdistdir}/fonts/map/dvips/bboldx
%dir %{_texmfdistdir}/fonts/map/dvips/belleek
%dir %{_texmfdistdir}/fonts/map/dvips/bera
%dir %{_texmfdistdir}/fonts/map/dvips/berenisadf
%dir %{_texmfdistdir}/fonts/map/dvips/beuron
%dir %{_texmfdistdir}/fonts/map/dvips/bguq
%dir %{_texmfdistdir}/fonts/map/dvips/bitter
%dir %{_texmfdistdir}/fonts/map/dvips/bookhands
%dir %{_texmfdistdir}/fonts/map/dvips/bookman
%dir %{_texmfdistdir}/fonts/map/dvips/boondox
%dir %{_texmfdistdir}/fonts/map/dvips/brushscr
%dir %{_texmfdistdir}/fonts/map/dvips/burmese
%dir %{_texmfdistdir}/fonts/map/dvips/cabin
%dir %{_texmfdistdir}/fonts/map/dvips/caladea
%dir %{_texmfdistdir}/fonts/map/dvips/calligra-type1
%dir %{_texmfdistdir}/fonts/map/dvips/cantarell
%dir %{_texmfdistdir}/fonts/map/dvips/carlito
%dir %{_texmfdistdir}/fonts/map/dvips/carolmin-ps
%dir %{_texmfdistdir}/fonts/map/dvips/cascadia-code
%dir %{_texmfdistdir}/fonts/map/dvips/cbfonts
%dir %{_texmfdistdir}/fonts/map/dvips/cc-pl
%dir %{_texmfdistdir}/fonts/map/dvips/ccicons
%dir %{_texmfdistdir}/fonts/map/dvips/cfr-lm
%dir %{_texmfdistdir}/fonts/map/dvips/charissil
%dir %{_texmfdistdir}/fonts/map/dvips/chemarrow
%dir %{_texmfdistdir}/fonts/map/dvips/chivo
%dir %{_texmfdistdir}/fonts/map/dvips/cinzel
%dir %{_texmfdistdir}/fonts/map/dvips/cjhebrew
%dir %{_texmfdistdir}/fonts/map/dvips/clara
%dir %{_texmfdistdir}/fonts/map/dvips/clearsans
%dir %{_texmfdistdir}/fonts/map/dvips/cm
%dir %{_texmfdistdir}/fonts/map/dvips/cm-lgc
%dir %{_texmfdistdir}/fonts/map/dvips/cm-super
%dir %{_texmfdistdir}/fonts/map/dvips/cm-unicode
%dir %{_texmfdistdir}/fonts/map/dvips/cmathbb
%dir %{_texmfdistdir}/fonts/map/dvips/cmcyr
%dir %{_texmfdistdir}/fonts/map/dvips/cmexb
%dir %{_texmfdistdir}/fonts/map/dvips/cmll
%dir %{_texmfdistdir}/fonts/map/dvips/cmsrb
%dir %{_texmfdistdir}/fonts/map/dvips/cmupint
%dir %{_texmfdistdir}/fonts/map/dvips/cochineal
%dir %{_texmfdistdir}/fonts/map/dvips/coelacanth
%dir %{_texmfdistdir}/fonts/map/dvips/comfortaa
%dir %{_texmfdistdir}/fonts/map/dvips/comicneue
%dir %{_texmfdistdir}/fonts/map/dvips/context
%dir %{_texmfdistdir}/fonts/map/dvips/cooperhewitt
%dir %{_texmfdistdir}/fonts/map/dvips/cormorantgaramond
%dir %{_texmfdistdir}/fonts/map/dvips/countriesofeurope
%dir %{_texmfdistdir}/fonts/map/dvips/courier
%dir %{_texmfdistdir}/fonts/map/dvips/courierten
%dir %{_texmfdistdir}/fonts/map/dvips/crimson
%dir %{_texmfdistdir}/fonts/map/dvips/crimsonpro
%dir %{_texmfdistdir}/fonts/map/dvips/cs
%dir %{_texmfdistdir}/fonts/map/dvips/cuprum
%dir %{_texmfdistdir}/fonts/map/dvips/cyklop
%dir %{_texmfdistdir}/fonts/map/dvips/dad
%dir %{_texmfdistdir}/fonts/map/dvips/dantelogo
%dir %{_texmfdistdir}/fonts/map/dvips/dejavu
%dir %{_texmfdistdir}/fonts/map/dvips/dictsym
%dir %{_texmfdistdir}/fonts/map/dvips/domitian
%dir %{_texmfdistdir}/fonts/map/dvips/doublestroke
%dir %{_texmfdistdir}/fonts/map/dvips/dozenal
%dir %{_texmfdistdir}/fonts/map/dvips/drm
%dir %{_texmfdistdir}/fonts/map/dvips/droid
%dir %{_texmfdistdir}/fonts/map/dvips/dsserif
%dir %{_texmfdistdir}/fonts/map/dvips/dummy-space
%dir %{_texmfdistdir}/fonts/map/dvips/dutchcal
%dir %{_texmfdistdir}/fonts/map/dvips/ebgaramond
%dir %{_texmfdistdir}/fonts/map/dvips/ebgaramond-maths
%dir %{_texmfdistdir}/fonts/map/dvips/electrum
%dir %{_texmfdistdir}/fonts/map/dvips/epigrafica
%dir %{_texmfdistdir}/fonts/map/dvips/epiolmec
%dir %{_texmfdistdir}/fonts/map/dvips/erewhon
%dir %{_texmfdistdir}/fonts/map/dvips/esint-type1
%dir %{_texmfdistdir}/fonts/map/dvips/esrelation
%dir %{_texmfdistdir}/fonts/map/dvips/esstix
%dir %{_texmfdistdir}/fonts/map/dvips/esvect
%dir %{_texmfdistdir}/fonts/map/dvips/etbb
%dir %{_texmfdistdir}/fonts/map/dvips/ethiop-t1
%dir %{_texmfdistdir}/fonts/map/dvips/eurosym
%dir %{_texmfdistdir}/fonts/map/dvips/fbb
%dir %{_texmfdistdir}/fonts/map/dvips/fdsymbol
%dir %{_texmfdistdir}/fonts/map/dvips/fetamont
%dir %{_texmfdistdir}/fonts/map/dvips/fge
%dir %{_texmfdistdir}/fonts/map/dvips/figbas
%dir %{_texmfdistdir}/fonts/map/dvips/fira
%dir %{_texmfdistdir}/fonts/map/dvips/foekfont
%dir %{_texmfdistdir}/fonts/map/dvips/fonetika
%dir %{_texmfdistdir}/fonts/map/dvips/fontawesome
%dir %{_texmfdistdir}/fonts/map/dvips/fontawesome5
%dir %{_texmfdistdir}/fonts/map/dvips/fonts-tlwg
%dir %{_texmfdistdir}/fonts/map/dvips/forum
%dir %{_texmfdistdir}/fonts/map/dvips/fourier
%dir %{_texmfdistdir}/fonts/map/dvips/frcursive
%dir %{_texmfdistdir}/fonts/map/dvips/garamond-libre
%dir %{_texmfdistdir}/fonts/map/dvips/garuda-c90
%dir %{_texmfdistdir}/fonts/map/dvips/gentium-tug
%dir %{_texmfdistdir}/fonts/map/dvips/gfsartemisia
%dir %{_texmfdistdir}/fonts/map/dvips/gfsbaskerville
%dir %{_texmfdistdir}/fonts/map/dvips/gfsbodoni
%dir %{_texmfdistdir}/fonts/map/dvips/gfscomplutum
%dir %{_texmfdistdir}/fonts/map/dvips/gfsdidot
%dir %{_texmfdistdir}/fonts/map/dvips/gfsneohellenic
%dir %{_texmfdistdir}/fonts/map/dvips/gfsporson
%dir %{_texmfdistdir}/fonts/map/dvips/gfssolomos
%dir %{_texmfdistdir}/fonts/map/dvips/gillcm
%dir %{_texmfdistdir}/fonts/map/dvips/gillius
%dir %{_texmfdistdir}/fonts/map/dvips/gofonts
%dir %{_texmfdistdir}/fonts/map/dvips/greektonoi
%dir %{_texmfdistdir}/fonts/map/dvips/grotesq
%dir %{_texmfdistdir}/fonts/map/dvips/gudea
%dir %{_texmfdistdir}/fonts/map/dvips/hacm
%dir %{_texmfdistdir}/fonts/map/dvips/helvetic
%dir %{_texmfdistdir}/fonts/map/dvips/heuristica
%dir %{_texmfdistdir}/fonts/map/dvips/hfbright
%dir %{_texmfdistdir}/fonts/map/dvips/hindmadurai
%dir %{_texmfdistdir}/fonts/map/dvips/ibarra
%dir %{_texmfdistdir}/fonts/map/dvips/ibygrk
%dir %{_texmfdistdir}/fonts/map/dvips/imfellenglish
%dir %{_texmfdistdir}/fonts/map/dvips/inconsolata
%dir %{_texmfdistdir}/fonts/map/dvips/initials
%dir %{_texmfdistdir}/fonts/map/dvips/inriafonts
%dir %{_texmfdistdir}/fonts/map/dvips/inter
%dir %{_texmfdistdir}/fonts/map/dvips/ipaex-type1
%dir %{_texmfdistdir}/fonts/map/dvips/iwona
%dir %{_texmfdistdir}/fonts/map/dvips/jamtimes
%dir %{_texmfdistdir}/fonts/map/dvips/jmn
%dir %{_texmfdistdir}/fonts/map/dvips/josefin
%dir %{_texmfdistdir}/fonts/map/dvips/junicode
%dir %{_texmfdistdir}/fonts/map/dvips/kerkis
%dir %{_texmfdistdir}/fonts/map/dvips/knitting
%dir %{_texmfdistdir}/fonts/map/dvips/kpfonts
%dir %{_texmfdistdir}/fonts/map/dvips/kurier
%dir %{_texmfdistdir}/fonts/map/dvips/lato
%dir %{_texmfdistdir}/fonts/map/dvips/libertine
%dir %{_texmfdistdir}/fonts/map/dvips/libertinegc
%dir %{_texmfdistdir}/fonts/map/dvips/libertinus-type1
%dir %{_texmfdistdir}/fonts/map/dvips/libertinust1math
%dir %{_texmfdistdir}/fonts/map/dvips/librebaskerville
%dir %{_texmfdistdir}/fonts/map/dvips/librebodoni
%dir %{_texmfdistdir}/fonts/map/dvips/librecaslon
%dir %{_texmfdistdir}/fonts/map/dvips/librefranklin
%dir %{_texmfdistdir}/fonts/map/dvips/libris
%dir %{_texmfdistdir}/fonts/map/dvips/lineara
%dir %{_texmfdistdir}/fonts/map/dvips/linguisticspro
%dir %{_texmfdistdir}/fonts/map/dvips/lithuanian
%dir %{_texmfdistdir}/fonts/map/dvips/lm
%dir %{_texmfdistdir}/fonts/map/dvips/lobster2
%dir %{_texmfdistdir}/fonts/map/dvips/lxfonts
%dir %{_texmfdistdir}/fonts/map/dvips/ly1
%dir %{_texmfdistdir}/fonts/map/dvips/magra
%dir %{_texmfdistdir}/fonts/map/dvips/manfnt-font
%dir %{_texmfdistdir}/fonts/map/dvips/marcellus
%dir %{_texmfdistdir}/fonts/map/dvips/marvosym
%dir %{_texmfdistdir}/fonts/map/dvips/mathabx-type1
%dir %{_texmfdistdir}/fonts/map/dvips/mathdesign
%dir %{_texmfdistdir}/fonts/map/dvips/mdsymbol
%dir %{_texmfdistdir}/fonts/map/dvips/merriweather
%dir %{_texmfdistdir}/fonts/map/dvips/metapost
%dir %{_texmfdistdir}/fonts/map/dvips/mflogo-font
%dir %{_texmfdistdir}/fonts/map/dvips/miama
%dir %{_texmfdistdir}/fonts/map/dvips/mintspirit
%dir %{_texmfdistdir}/fonts/map/dvips/mlmodern
%dir %{_texmfdistdir}/fonts/map/dvips/mnsymbol
%dir %{_texmfdistdir}/fonts/map/dvips/montex
%dir %{_texmfdistdir}/fonts/map/dvips/montserrat
%dir %{_texmfdistdir}/fonts/map/dvips/mpfonts
%dir %{_texmfdistdir}/fonts/map/dvips/musixtex-fonts
%dir %{_texmfdistdir}/fonts/map/dvips/mxedruli
%dir %{_texmfdistdir}/fonts/map/dvips/nanumtype1
%dir %{_texmfdistdir}/fonts/map/dvips/ncntrsbk
%dir %{_texmfdistdir}/fonts/map/dvips/newpx
%dir %{_texmfdistdir}/fonts/map/dvips/newtx
%dir %{_texmfdistdir}/fonts/map/dvips/newtxsf
%dir %{_texmfdistdir}/fonts/map/dvips/newtxtt
%dir %{_texmfdistdir}/fonts/map/dvips/niceframe-type1
%dir %{_texmfdistdir}/fonts/map/dvips/nimbus15
%dir %{_texmfdistdir}/fonts/map/dvips/norasi-c90
%dir %{_texmfdistdir}/fonts/map/dvips/noto
%dir %{_texmfdistdir}/fonts/map/dvips/notomath
%dir %{_texmfdistdir}/fonts/map/dvips/nunito
%dir %{_texmfdistdir}/fonts/map/dvips/ocherokee
%dir %{_texmfdistdir}/fonts/map/dvips/ocr-b-outline
%dir %{_texmfdistdir}/fonts/map/dvips/oinuit
%dir %{_texmfdistdir}/fonts/map/dvips/old-arrows
%dir %{_texmfdistdir}/fonts/map/dvips/oldstandard
%dir %{_texmfdistdir}/fonts/map/dvips/omega
%dir %{_texmfdistdir}/fonts/map/dvips/opensans
%dir %{_texmfdistdir}/fonts/map/dvips/oswald
%dir %{_texmfdistdir}/fonts/map/dvips/overlock
%dir %{_texmfdistdir}/fonts/map/dvips/palatino
%dir %{_texmfdistdir}/fonts/map/dvips/paratype
%dir %{_texmfdistdir}/fonts/map/dvips/phaistos
%dir %{_texmfdistdir}/fonts/map/dvips/pigpen
%dir %{_texmfdistdir}/fonts/map/dvips/pl
%dir %{_texmfdistdir}/fonts/map/dvips/playfair
%dir %{_texmfdistdir}/fonts/map/dvips/plex
%dir %{_texmfdistdir}/fonts/map/dvips/plimsoll
%dir %{_texmfdistdir}/fonts/map/dvips/poiretone
%dir %{_texmfdistdir}/fonts/map/dvips/poltawski
%dir %{_texmfdistdir}/fonts/map/dvips/prodint
%dir %{_texmfdistdir}/fonts/map/dvips/pslatex
%dir %{_texmfdistdir}/fonts/map/dvips/psnfss
%dir %{_texmfdistdir}/fonts/map/dvips/pxfonts
%dir %{_texmfdistdir}/fonts/map/dvips/quattrocento
%dir %{_texmfdistdir}/fonts/map/dvips/raleway
%dir %{_texmfdistdir}/fonts/map/dvips/recycle
%dir %{_texmfdistdir}/fonts/map/dvips/roboto
%dir %{_texmfdistdir}/fonts/map/dvips/rojud
%dir %{_texmfdistdir}/fonts/map/dvips/romande
%dir %{_texmfdistdir}/fonts/map/dvips/rosario
%dir %{_texmfdistdir}/fonts/map/dvips/rsfs
%dir %{_texmfdistdir}/fonts/map/dvips/rsfso
%dir %{_texmfdistdir}/fonts/map/dvips/sanskrit-t1
%dir %{_texmfdistdir}/fonts/map/dvips/sansmathaccent
%dir %{_texmfdistdir}/fonts/map/dvips/sansmathfonts
%dir %{_texmfdistdir}/fonts/map/dvips/scanpages
%dir %{_texmfdistdir}/fonts/map/dvips/scholax
%dir %{_texmfdistdir}/fonts/map/dvips/semaphor
%dir %{_texmfdistdir}/fonts/map/dvips/simpleicons
%dir %{_texmfdistdir}/fonts/map/dvips/skaknew
%dir %{_texmfdistdir}/fonts/map/dvips/sourcecodepro
%dir %{_texmfdistdir}/fonts/map/dvips/sourcesanspro
%dir %{_texmfdistdir}/fonts/map/dvips/sourceserifpro
%dir %{_texmfdistdir}/fonts/map/dvips/spectral
%dir %{_texmfdistdir}/fonts/map/dvips/srbtiks
%dir %{_texmfdistdir}/fonts/map/dvips/starfont
%dir %{_texmfdistdir}/fonts/map/dvips/staves
%dir %{_texmfdistdir}/fonts/map/dvips/step
%dir %{_texmfdistdir}/fonts/map/dvips/stepgreek
%dir %{_texmfdistdir}/fonts/map/dvips/stickstoo
%dir %{_texmfdistdir}/fonts/map/dvips/stix
%dir %{_texmfdistdir}/fonts/map/dvips/stix2-type1
%dir %{_texmfdistdir}/fonts/map/dvips/stmaryrd
%dir %{_texmfdistdir}/fonts/map/dvips/superiors
%dir %{_texmfdistdir}/fonts/map/dvips/svrsymbols
%dir %{_texmfdistdir}/fonts/map/dvips/symbol
%dir %{_texmfdistdir}/fonts/map/dvips/tabvar
%dir %{_texmfdistdir}/fonts/map/dvips/tempora
%dir %{_texmfdistdir}/fonts/map/dvips/tengwarscript
%dir %{_texmfdistdir}/fonts/map/dvips/tetex
%dir %{_texmfdistdir}/fonts/map/dvips/tex-gyre
%dir %{_texmfdistdir}/fonts/map/dvips/tfrupee
%dir %{_texmfdistdir}/fonts/map/dvips/theanodidot
%dir %{_texmfdistdir}/fonts/map/dvips/theanomodern
%dir %{_texmfdistdir}/fonts/map/dvips/theanooldstyle
%dir %{_texmfdistdir}/fonts/map/dvips/times
%dir %{_texmfdistdir}/fonts/map/dvips/tinos
%dir %{_texmfdistdir}/fonts/map/dvips/tipa
%dir %{_texmfdistdir}/fonts/map/dvips/trajan
%dir %{_texmfdistdir}/fonts/map/dvips/txfonts
%dir %{_texmfdistdir}/fonts/map/dvips/txfontsb
%dir %{_texmfdistdir}/fonts/map/dvips/txuprcal
%dir %{_texmfdistdir}/fonts/map/dvips/uhc
%dir %{_texmfdistdir}/fonts/map/dvips/universalis
%dir %{_texmfdistdir}/fonts/map/dvips/velthuis
%dir %{_texmfdistdir}/fonts/map/dvips/venturis
%dir %{_texmfdistdir}/fonts/map/dvips/venturis2
%dir %{_texmfdistdir}/fonts/map/dvips/venturisold
%dir %{_texmfdistdir}/fonts/map/dvips/venturissans
%dir %{_texmfdistdir}/fonts/map/dvips/venturissans2
%dir %{_texmfdistdir}/fonts/map/dvips/vntex
%dir %{_texmfdistdir}/fonts/map/dvips/wadalab
%dir %{_texmfdistdir}/fonts/map/dvips/wasy-type1
%dir %{_texmfdistdir}/fonts/map/dvips/xcharter
%dir %{_texmfdistdir}/fonts/map/dvips/xypic
%dir %{_texmfdistdir}/fonts/map/dvips/yfonts-t1
%dir %{_texmfdistdir}/fonts/map/dvips/yhmath
%dir %{_texmfdistdir}/fonts/map/dvips/zapfchan
%dir %{_texmfdistdir}/fonts/map/dvips/zapfding
%dir %{_texmfdistdir}/fonts/map/fontname
%dir %{_texmfdistdir}/fonts/map/glyphlist
%dir %{_texmfdistdir}/fonts/map/luatex
%dir %{_texmfdistdir}/fonts/map/luatex/context
%dir %{_texmfdistdir}/fonts/map/pdftex
%dir %{_texmfdistdir}/fonts/map/pdftex/context
%dir %{_texmfdistdir}/fonts/map/pdftex/gentium-tug
%dir %{_texmfdistdir}/fonts/map/vtex
%dir %{_texmfdistdir}/fonts/map/vtex/antiqua
%dir %{_texmfdistdir}/fonts/map/vtex/cm-super
%dir %{_texmfdistdir}/fonts/map/vtex/mnsymbol
%dir %{_texmfdistdir}/fonts/misc
%dir %{_texmfdistdir}/fonts/misc/cjk-gs-integrate
%dir %{_texmfdistdir}/fonts/misc/cns
%dir %{_texmfdistdir}/fonts/misc/ptex-fontmaps
%dir %{_texmfdistdir}/fonts/misc/xetex
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/arabxetex
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/base
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/context
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/polyglossia
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/unimath-plain-xetex
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/xecjk
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/xepersian
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-devanagari
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-itrans
%dir %{_texmfdistdir}/fonts/misc/xetex/fontmapping/xetex-tibetan
%dir %{_texmfdistdir}/fonts/ofm
%dir %{_texmfdistdir}/fonts/ofm/public
%dir %{_texmfdistdir}/fonts/ofm/public/cm-lgc
%dir %{_texmfdistdir}/fonts/ofm/public/dad
%dir %{_texmfdistdir}/fonts/ofm/public/ethiop
%dir %{_texmfdistdir}/fonts/ofm/public/japanese-otf
%dir %{_texmfdistdir}/fonts/ofm/public/ocherokee
%dir %{_texmfdistdir}/fonts/ofm/public/oinuit
%dir %{_texmfdistdir}/fonts/ofm/public/omega
%dir %{_texmfdistdir}/fonts/ofm/public/otibet
%dir %{_texmfdistdir}/fonts/opentype
%dir %{_texmfdistdir}/fonts/opentype/adobe
%dir %{_texmfdistdir}/fonts/opentype/adobe/sourcecodepro
%dir %{_texmfdistdir}/fonts/opentype/adobe/sourcesanspro
%dir %{_texmfdistdir}/fonts/opentype/adobe/sourceserifpro
%dir %{_texmfdistdir}/fonts/opentype/arkandis
%dir %{_texmfdistdir}/fonts/opentype/arkandis/accanthis
%dir %{_texmfdistdir}/fonts/opentype/arkandis/berenisadf
%dir %{_texmfdistdir}/fonts/opentype/arkandis/gillius
%dir %{_texmfdistdir}/fonts/opentype/arkandis/mintspirit
%dir %{_texmfdistdir}/fonts/opentype/arkandis/universalis
%dir %{_texmfdistdir}/fonts/opentype/gnome
%dir %{_texmfdistdir}/fonts/opentype/gnome/cantarell
%dir %{_texmfdistdir}/fonts/opentype/google
%dir %{_texmfdistdir}/fonts/opentype/google/roboto
%dir %{_texmfdistdir}/fonts/opentype/gust
%dir %{_texmfdistdir}/fonts/opentype/gust/poltawski
%dir %{_texmfdistdir}/fonts/opentype/huerta
%dir %{_texmfdistdir}/fonts/opentype/huerta/alegreya
%dir %{_texmfdistdir}/fonts/opentype/ibm
%dir %{_texmfdistdir}/fonts/opentype/ibm/plex
%dir %{_texmfdistdir}/fonts/opentype/iginomarini
%dir %{_texmfdistdir}/fonts/opentype/iginomarini/imfellenglish
%dir %{_texmfdistdir}/fonts/opentype/impallari
%dir %{_texmfdistdir}/fonts/opentype/impallari/cabin
%dir %{_texmfdistdir}/fonts/opentype/impallari/librebodoni
%dir %{_texmfdistdir}/fonts/opentype/impallari/librecaslon
%dir %{_texmfdistdir}/fonts/opentype/impallari/librefranklin
%dir %{_texmfdistdir}/fonts/opentype/impallari/lobster2
%dir %{_texmfdistdir}/fonts/opentype/impallari/raleway
%dir %{_texmfdistdir}/fonts/opentype/kosch
%dir %{_texmfdistdir}/fonts/opentype/kosch/crimson
%dir %{_texmfdistdir}/fonts/opentype/novel
%dir %{_texmfdistdir}/fonts/opentype/nowacki
%dir %{_texmfdistdir}/fonts/opentype/nowacki/iwona
%dir %{_texmfdistdir}/fonts/opentype/nowacki/kurier
%dir %{_texmfdistdir}/fonts/opentype/omnibus-type
%dir %{_texmfdistdir}/fonts/opentype/omnibus-type/asapsym
%dir %{_texmfdistdir}/fonts/opentype/public
%dir %{_texmfdistdir}/fonts/opentype/public/aboensis
%dir %{_texmfdistdir}/fonts/opentype/public/aesupp
%dir %{_texmfdistdir}/fonts/opentype/public/alfaslabone
%dir %{_texmfdistdir}/fonts/opentype/public/algolrevived
%dir %{_texmfdistdir}/fonts/opentype/public/almfixed
%dir %{_texmfdistdir}/fonts/opentype/public/antt
%dir %{_texmfdistdir}/fonts/opentype/public/archivo
%dir %{_texmfdistdir}/fonts/opentype/public/asana-math
%dir %{_texmfdistdir}/fonts/opentype/public/atkinson
%dir %{_texmfdistdir}/fonts/opentype/public/baskervaldx
%dir %{_texmfdistdir}/fonts/opentype/public/baskervillef
%dir %{_texmfdistdir}/fonts/opentype/public/beuron
%dir %{_texmfdistdir}/fonts/opentype/public/cascadia-code
%dir %{_texmfdistdir}/fonts/opentype/public/ccicons
%dir %{_texmfdistdir}/fonts/opentype/public/chivo
%dir %{_texmfdistdir}/fonts/opentype/public/clara
%dir %{_texmfdistdir}/fonts/opentype/public/cm-unicode
%dir %{_texmfdistdir}/fonts/opentype/public/cochineal
%dir %{_texmfdistdir}/fonts/opentype/public/coelacanth
%dir %{_texmfdistdir}/fonts/opentype/public/concmath-otf
%dir %{_texmfdistdir}/fonts/opentype/public/cooperhewitt
%dir %{_texmfdistdir}/fonts/opentype/public/countriesofeurope
%dir %{_texmfdistdir}/fonts/opentype/public/courierten
%dir %{_texmfdistdir}/fonts/opentype/public/cyklop
%dir %{_texmfdistdir}/fonts/opentype/public/dantelogo
%dir %{_texmfdistdir}/fonts/opentype/public/domitian
%dir %{_texmfdistdir}/fonts/opentype/public/drm
%dir %{_texmfdistdir}/fonts/opentype/public/ebgaramond
%dir %{_texmfdistdir}/fonts/opentype/public/eczar
%dir %{_texmfdistdir}/fonts/opentype/public/erewhon
%dir %{_texmfdistdir}/fonts/opentype/public/erewhon-math
%dir %{_texmfdistdir}/fonts/opentype/public/etbb
%dir %{_texmfdistdir}/fonts/opentype/public/euler-math
%dir %{_texmfdistdir}/fonts/opentype/public/fandol
%dir %{_texmfdistdir}/fonts/opentype/public/fbb
%dir %{_texmfdistdir}/fonts/opentype/public/fdsymbol
%dir %{_texmfdistdir}/fonts/opentype/public/fetamont
%dir %{_texmfdistdir}/fonts/opentype/public/fira
%dir %{_texmfdistdir}/fonts/opentype/public/firamath
%dir %{_texmfdistdir}/fonts/opentype/public/fontawesome
%dir %{_texmfdistdir}/fonts/opentype/public/fontawesome5
%dir %{_texmfdistdir}/fonts/opentype/public/fonts-churchslavonic
%dir %{_texmfdistdir}/fonts/opentype/public/fonts-tlwg
%dir %{_texmfdistdir}/fonts/opentype/public/forum
%dir %{_texmfdistdir}/fonts/opentype/public/fourier
%dir %{_texmfdistdir}/fonts/opentype/public/frederika2016
%dir %{_texmfdistdir}/fonts/opentype/public/garamond-libre
%dir %{_texmfdistdir}/fonts/opentype/public/garamond-math
%dir %{_texmfdistdir}/fonts/opentype/public/gfsartemisia
%dir %{_texmfdistdir}/fonts/opentype/public/gfsbaskerville
%dir %{_texmfdistdir}/fonts/opentype/public/gfsbodoni
%dir %{_texmfdistdir}/fonts/opentype/public/gfscomplutum
%dir %{_texmfdistdir}/fonts/opentype/public/gfsdidot
%dir %{_texmfdistdir}/fonts/opentype/public/gfsdidotclassic
%dir %{_texmfdistdir}/fonts/opentype/public/gfsneohellenic
%dir %{_texmfdistdir}/fonts/opentype/public/gfsneohellenicmath
%dir %{_texmfdistdir}/fonts/opentype/public/gfsporson
%dir %{_texmfdistdir}/fonts/opentype/public/gfssolomos
%dir %{_texmfdistdir}/fonts/opentype/public/gnu-freefont
%dir %{_texmfdistdir}/fonts/opentype/public/haranoaji
%dir %{_texmfdistdir}/fonts/opentype/public/haranoaji-extra
%dir %{_texmfdistdir}/fonts/opentype/public/helmholtz-ellis-ji-notation
%dir %{_texmfdistdir}/fonts/opentype/public/heuristica
%dir %{_texmfdistdir}/fonts/opentype/public/hindmadurai
%dir %{_texmfdistdir}/fonts/opentype/public/ibarra
%dir %{_texmfdistdir}/fonts/opentype/public/inconsolata
%dir %{_texmfdistdir}/fonts/opentype/public/inriafonts
%dir %{_texmfdistdir}/fonts/opentype/public/inter
%dir %{_texmfdistdir}/fonts/opentype/public/kerkis
%dir %{_texmfdistdir}/fonts/opentype/public/kpfonts-otf
%dir %{_texmfdistdir}/fonts/opentype/public/libertine
%dir %{_texmfdistdir}/fonts/opentype/public/libertinus-fonts
%dir %{_texmfdistdir}/fonts/opentype/public/lilyglyphs
%dir %{_texmfdistdir}/fonts/opentype/public/linguisticspro
%dir %{_texmfdistdir}/fonts/opentype/public/lm
%dir %{_texmfdistdir}/fonts/opentype/public/lm-math
%dir %{_texmfdistdir}/fonts/opentype/public/logix
%dir %{_texmfdistdir}/fonts/opentype/public/luapstricks
%dir %{_texmfdistdir}/fonts/opentype/public/mdsymbol
%dir %{_texmfdistdir}/fonts/opentype/public/miama
%dir %{_texmfdistdir}/fonts/opentype/public/missaali
%dir %{_texmfdistdir}/fonts/opentype/public/mnsymbol
%dir %{_texmfdistdir}/fonts/opentype/public/montserrat
%dir %{_texmfdistdir}/fonts/opentype/public/musixtex-fonts
%dir %{_texmfdistdir}/fonts/opentype/public/newcomputermodern
%dir %{_texmfdistdir}/fonts/opentype/public/newpx
%dir %{_texmfdistdir}/fonts/opentype/public/newtx
%dir %{_texmfdistdir}/fonts/opentype/public/nimbus15
%dir %{_texmfdistdir}/fonts/opentype/public/nunito
%dir %{_texmfdistdir}/fonts/opentype/public/ocr-b-outline
%dir %{_texmfdistdir}/fonts/opentype/public/oldstandard
%dir %{_texmfdistdir}/fonts/opentype/public/phaistos
%dir %{_texmfdistdir}/fonts/opentype/public/philokalia
%dir %{_texmfdistdir}/fonts/opentype/public/playfair
%dir %{_texmfdistdir}/fonts/opentype/public/punknova
%dir %{_texmfdistdir}/fonts/opentype/public/qualitype
%dir %{_texmfdistdir}/fonts/opentype/public/rosario
%dir %{_texmfdistdir}/fonts/opentype/public/scholax
%dir %{_texmfdistdir}/fonts/opentype/public/semaphor
%dir %{_texmfdistdir}/fonts/opentype/public/shobhika
%dir %{_texmfdistdir}/fonts/opentype/public/simpleicons
%dir %{_texmfdistdir}/fonts/opentype/public/skaknew
%dir %{_texmfdistdir}/fonts/opentype/public/spark-otf
%dir %{_texmfdistdir}/fonts/opentype/public/step
%dir %{_texmfdistdir}/fonts/opentype/public/stix
%dir %{_texmfdistdir}/fonts/opentype/public/stix2-otf
%dir %{_texmfdistdir}/fonts/opentype/public/svrsymbols
%dir %{_texmfdistdir}/fonts/opentype/public/talos
%dir %{_texmfdistdir}/fonts/opentype/public/tempora
%dir %{_texmfdistdir}/fonts/opentype/public/tex-gyre
%dir %{_texmfdistdir}/fonts/opentype/public/tex-gyre-math
%dir %{_texmfdistdir}/fonts/opentype/public/txfontsb
%dir %{_texmfdistdir}/fonts/opentype/public/umtypewriter
%dir %{_texmfdistdir}/fonts/opentype/public/xcharter
%dir %{_texmfdistdir}/fonts/opentype/public/xcharter-math
%dir %{_texmfdistdir}/fonts/opentype/public/xits
%dir %{_texmfdistdir}/fonts/opentype/public/yfonts-otf
%dir %{_texmfdistdir}/fonts/opentype/public/yinit-otf
%dir %{_texmfdistdir}/fonts/opentype/rozynski
%dir %{_texmfdistdir}/fonts/opentype/rozynski/comicneue
%dir %{_texmfdistdir}/fonts/opentype/sorkin
%dir %{_texmfdistdir}/fonts/opentype/sorkin/merriweather
%dir %{_texmfdistdir}/fonts/opentype/tipo
%dir %{_texmfdistdir}/fonts/opentype/tipo/overlock
%dir %{_texmfdistdir}/fonts/ovf
%dir %{_texmfdistdir}/fonts/ovf/public
%dir %{_texmfdistdir}/fonts/ovf/public/cm-lgc
%dir %{_texmfdistdir}/fonts/ovf/public/dad
%dir %{_texmfdistdir}/fonts/ovf/public/ethiop
%dir %{_texmfdistdir}/fonts/ovf/public/ocherokee
%dir %{_texmfdistdir}/fonts/ovf/public/oinuit
%dir %{_texmfdistdir}/fonts/ovf/public/omega
%dir %{_texmfdistdir}/fonts/ovf/public/otibet
%dir %{_texmfdistdir}/fonts/ovp
%dir %{_texmfdistdir}/fonts/ovp/public
%dir %{_texmfdistdir}/fonts/ovp/public/ethiop
%dir %{_texmfdistdir}/fonts/ovp/public/ocherokee
%dir %{_texmfdistdir}/fonts/ovp/public/omega
%dir %{_texmfdistdir}/fonts/ovp/public/otibet
%dir %{_texmfdistdir}/fonts/pk
%dir %{_texmfdistdir}/fonts/pk/ljfour
%dir %{_texmfdistdir}/fonts/pk/ljfour/public
%dir %{_texmfdistdir}/fonts/pk/ljfour/public/cm
%dir %{_texmfdistdir}/fonts/pk/ljfour/public/cm/dpi600
%dir %{_texmfdistdir}/fonts/sfd
%dir %{_texmfdistdir}/fonts/sfd/dnp
%dir %{_texmfdistdir}/fonts/sfd/pxchfon
%dir %{_texmfdistdir}/fonts/sfd/ttf2pk
%dir %{_texmfdistdir}/fonts/source
%dir %{_texmfdistdir}/fonts/source/gregoriotex
%dir %{_texmfdistdir}/fonts/source/jknappen
%dir %{_texmfdistdir}/fonts/source/jknappen/ec
%dir %{_texmfdistdir}/fonts/source/jknappen/fc
%dir %{_texmfdistdir}/fonts/source/lh
%dir %{_texmfdistdir}/fonts/source/lh/base
%dir %{_texmfdistdir}/fonts/source/lh/lh-XSlav
%dir %{_texmfdistdir}/fonts/source/lh/lh-conc
%dir %{_texmfdistdir}/fonts/source/lh/lh-lcy
%dir %{_texmfdistdir}/fonts/source/lh/lh-ot2
%dir %{_texmfdistdir}/fonts/source/lh/lh-t2a
%dir %{_texmfdistdir}/fonts/source/lh/lh-t2b
%dir %{_texmfdistdir}/fonts/source/lh/lh-t2c
%dir %{_texmfdistdir}/fonts/source/lh/lh-t2d
%dir %{_texmfdistdir}/fonts/source/lh/lh-x2
%dir %{_texmfdistdir}/fonts/source/lh/nont2
%dir %{_texmfdistdir}/fonts/source/lh/specific
%dir %{_texmfdistdir}/fonts/source/ptex-fonts
%dir %{_texmfdistdir}/fonts/source/ptex-fonts/jis
%dir %{_texmfdistdir}/fonts/source/ptex-fonts/nmin-ngoth
%dir %{_texmfdistdir}/fonts/source/ptex-fonts/standard
%dir %{_texmfdistdir}/fonts/source/public
%dir %{_texmfdistdir}/fonts/source/public/allrunes
%dir %{_texmfdistdir}/fonts/source/public/amsfonts
%dir %{_texmfdistdir}/fonts/source/public/amsfonts/cmextra
%dir %{_texmfdistdir}/fonts/source/public/amsfonts/cyrillic
%dir %{_texmfdistdir}/fonts/source/public/amsfonts/dummy
%dir %{_texmfdistdir}/fonts/source/public/amsfonts/symbols
%dir %{_texmfdistdir}/fonts/source/public/arabtex
%dir %{_texmfdistdir}/fonts/source/public/aramaic-serto
%dir %{_texmfdistdir}/fonts/source/public/archaic
%dir %{_texmfdistdir}/fonts/source/public/armenian
%dir %{_texmfdistdir}/fonts/source/public/ascmac
%dir %{_texmfdistdir}/fonts/source/public/aspectratio
%dir %{_texmfdistdir}/fonts/source/public/astro
%dir %{_texmfdistdir}/fonts/source/public/aurical
%dir %{_texmfdistdir}/fonts/source/public/bangtex
%dir %{_texmfdistdir}/fonts/source/public/barcodes
%dir %{_texmfdistdir}/fonts/source/public/bartel-chess-fonts
%dir %{_texmfdistdir}/fonts/source/public/bbding
%dir %{_texmfdistdir}/fonts/source/public/bbm
%dir %{_texmfdistdir}/fonts/source/public/bbold
%dir %{_texmfdistdir}/fonts/source/public/bengali
%dir %{_texmfdistdir}/fonts/source/public/beuron
%dir %{_texmfdistdir}/fonts/source/public/bguq
%dir %{_texmfdistdir}/fonts/source/public/boisik
%dir %{_texmfdistdir}/fonts/source/public/bookhands
%dir %{_texmfdistdir}/fonts/source/public/calligra
%dir %{_texmfdistdir}/fonts/source/public/casyl
%dir %{_texmfdistdir}/fonts/source/public/cbcoptic
%dir %{_texmfdistdir}/fonts/source/public/cbfonts
%dir %{_texmfdistdir}/fonts/source/public/cc-pl
%dir %{_texmfdistdir}/fonts/source/public/chemarrow
%dir %{_texmfdistdir}/fonts/source/public/cherokee
%dir %{_texmfdistdir}/fonts/source/public/chess
%dir %{_texmfdistdir}/fonts/source/public/circ
%dir %{_texmfdistdir}/fonts/source/public/clock
%dir %{_texmfdistdir}/fonts/source/public/cm
%dir %{_texmfdistdir}/fonts/source/public/cm-mf-extra-bold
%dir %{_texmfdistdir}/fonts/source/public/cmbright
%dir %{_texmfdistdir}/fonts/source/public/cmcyr
%dir %{_texmfdistdir}/fonts/source/public/cmextra
%dir %{_texmfdistdir}/fonts/source/public/cmll
%dir %{_texmfdistdir}/fonts/source/public/cmpica
%dir %{_texmfdistdir}/fonts/source/public/cmtiup
%dir %{_texmfdistdir}/fonts/source/public/cmupint
%dir %{_texmfdistdir}/fonts/source/public/concmath-fonts
%dir %{_texmfdistdir}/fonts/source/public/concrete
%dir %{_texmfdistdir}/fonts/source/public/cookingsymbols
%dir %{_texmfdistdir}/fonts/source/public/cryst
%dir %{_texmfdistdir}/fonts/source/public/cs
%dir %{_texmfdistdir}/fonts/source/public/ctib
%dir %{_texmfdistdir}/fonts/source/public/dancers
%dir %{_texmfdistdir}/fonts/source/public/dice
%dir %{_texmfdistdir}/fonts/source/public/dingbat
%dir %{_texmfdistdir}/fonts/source/public/doublestroke
%dir %{_texmfdistdir}/fonts/source/public/dozenal
%dir %{_texmfdistdir}/fonts/source/public/drm
%dir %{_texmfdistdir}/fonts/source/public/duerer
%dir %{_texmfdistdir}/fonts/source/public/ecc
%dir %{_texmfdistdir}/fonts/source/public/eiad
%dir %{_texmfdistdir}/fonts/source/public/eiad-ltx
%dir %{_texmfdistdir}/fonts/source/public/elvish
%dir %{_texmfdistdir}/fonts/source/public/esint
%dir %{_texmfdistdir}/fonts/source/public/esrelation
%dir %{_texmfdistdir}/fonts/source/public/esvect
%dir %{_texmfdistdir}/fonts/source/public/etex
%dir %{_texmfdistdir}/fonts/source/public/ethiop
%dir %{_texmfdistdir}/fonts/source/public/euro-ce
%dir %{_texmfdistdir}/fonts/source/public/eurosym
%dir %{_texmfdistdir}/fonts/source/public/euxm
%dir %{_texmfdistdir}/fonts/source/public/fdsymbol
%dir %{_texmfdistdir}/fonts/source/public/fetamont
%dir %{_texmfdistdir}/fonts/source/public/feyn
%dir %{_texmfdistdir}/fonts/source/public/fge
%dir %{_texmfdistdir}/fonts/source/public/frcursive
%dir %{_texmfdistdir}/fonts/source/public/genealogy
%dir %{_texmfdistdir}/fonts/source/public/ghab
%dir %{_texmfdistdir}/fonts/source/public/go
%dir %{_texmfdistdir}/fonts/source/public/gothic
%dir %{_texmfdistdir}/fonts/source/public/greenpoint
%dir %{_texmfdistdir}/fonts/source/public/hands
%dir %{_texmfdistdir}/fonts/source/public/ibygrk
%dir %{_texmfdistdir}/fonts/source/public/ifsym
%dir %{_texmfdistdir}/fonts/source/public/jablantile
%dir %{_texmfdistdir}/fonts/source/public/kixfont
%dir %{_texmfdistdir}/fonts/source/public/knitting
%dir %{_texmfdistdir}/fonts/source/public/knuth-lib
%dir %{_texmfdistdir}/fonts/source/public/knuth-local
%dir %{_texmfdistdir}/fonts/source/public/latex-fonts
%dir %{_texmfdistdir}/fonts/source/public/levy
%dir %{_texmfdistdir}/fonts/source/public/lfb
%dir %{_texmfdistdir}/fonts/source/public/lxfonts
%dir %{_texmfdistdir}/fonts/source/public/mathabx
%dir %{_texmfdistdir}/fonts/source/public/mdsymbol
%dir %{_texmfdistdir}/fonts/source/public/mflogo
%dir %{_texmfdistdir}/fonts/source/public/mnsymbol
%dir %{_texmfdistdir}/fonts/source/public/modes
%dir %{_texmfdistdir}/fonts/source/public/montex
%dir %{_texmfdistdir}/fonts/source/public/musixtex-fonts
%dir %{_texmfdistdir}/fonts/source/public/mxedruli
%dir %{_texmfdistdir}/fonts/source/public/niceframe
%dir %{_texmfdistdir}/fonts/source/public/nkarta
%dir %{_texmfdistdir}/fonts/source/public/obnov
%dir %{_texmfdistdir}/fonts/source/public/ocr-b
%dir %{_texmfdistdir}/fonts/source/public/ogham
%dir %{_texmfdistdir}/fonts/source/public/oldlatin
%dir %{_texmfdistdir}/fonts/source/public/orkhun
%dir %{_texmfdistdir}/fonts/source/public/othello
%dir %{_texmfdistdir}/fonts/source/public/otibet
%dir %{_texmfdistdir}/fonts/source/public/pacioli
%dir %{_texmfdistdir}/fonts/source/public/phonetic
%dir %{_texmfdistdir}/fonts/source/public/pigpen
%dir %{_texmfdistdir}/fonts/source/public/pl
%dir %{_texmfdistdir}/fonts/source/public/punk
%dir %{_texmfdistdir}/fonts/source/public/recycle
%dir %{_texmfdistdir}/fonts/source/public/rsfs
%dir %{_texmfdistdir}/fonts/source/public/sanskrit
%dir %{_texmfdistdir}/fonts/source/public/sansmathfonts
%dir %{_texmfdistdir}/fonts/source/public/sauter
%dir %{_texmfdistdir}/fonts/source/public/schulschriften
%dir %{_texmfdistdir}/fonts/source/public/semaphor
%dir %{_texmfdistdir}/fonts/source/public/semaphor/metafont
%dir %{_texmfdistdir}/fonts/source/public/shade
%dir %{_texmfdistdir}/fonts/source/public/shuffle
%dir %{_texmfdistdir}/fonts/source/public/skak
%dir %{_texmfdistdir}/fonts/source/public/skull
%dir %{_texmfdistdir}/fonts/source/public/stmaryrd
%dir %{_texmfdistdir}/fonts/source/public/tapir
%dir %{_texmfdistdir}/fonts/source/public/tipa
%dir %{_texmfdistdir}/fonts/source/public/tram
%dir %{_texmfdistdir}/fonts/source/public/trsym
%dir %{_texmfdistdir}/fonts/source/public/universa
%dir %{_texmfdistdir}/fonts/source/public/velthuis
%dir %{_texmfdistdir}/fonts/source/public/wasy
%dir %{_texmfdistdir}/fonts/source/public/wnri
%dir %{_texmfdistdir}/fonts/source/public/wsuipa
%dir %{_texmfdistdir}/fonts/source/public/xq
%dir %{_texmfdistdir}/fonts/source/public/xypic
%dir %{_texmfdistdir}/fonts/source/public/yannisgr
%dir %{_texmfdistdir}/fonts/source/public/yhmath
%dir %{_texmfdistdir}/fonts/source/uptex-fonts
%dir %{_texmfdistdir}/fonts/source/vntex
%dir %{_texmfdistdir}/fonts/source/vntex/vnr
%dir %{_texmfdistdir}/fonts/tfm
%dir %{_texmfdistdir}/fonts/tfm/SIL
%dir %{_texmfdistdir}/fonts/tfm/SIL/andika
%dir %{_texmfdistdir}/fonts/tfm/SIL/charissil
%dir %{_texmfdistdir}/fonts/tfm/aajohan
%dir %{_texmfdistdir}/fonts/tfm/aajohan/comfortaa
%dir %{_texmfdistdir}/fonts/tfm/adobe
%dir %{_texmfdistdir}/fonts/tfm/adobe/avantgar
%dir %{_texmfdistdir}/fonts/tfm/adobe/bookman
%dir %{_texmfdistdir}/fonts/tfm/adobe/courier
%dir %{_texmfdistdir}/fonts/tfm/adobe/helvetic
%dir %{_texmfdistdir}/fonts/tfm/adobe/ly1
%dir %{_texmfdistdir}/fonts/tfm/adobe/ncntrsbk
%dir %{_texmfdistdir}/fonts/tfm/adobe/palatino
%dir %{_texmfdistdir}/fonts/tfm/adobe/sourcecodepro
%dir %{_texmfdistdir}/fonts/tfm/adobe/sourcesanspro
%dir %{_texmfdistdir}/fonts/tfm/adobe/sourceserifpro
%dir %{_texmfdistdir}/fonts/tfm/adobe/symbol
%dir %{_texmfdistdir}/fonts/tfm/adobe/times
%dir %{_texmfdistdir}/fonts/tfm/adobe/utopia
%dir %{_texmfdistdir}/fonts/tfm/adobe/zapfchan
%dir %{_texmfdistdir}/fonts/tfm/adobe/zapfding
%dir %{_texmfdistdir}/fonts/tfm/arabi
%dir %{_texmfdistdir}/fonts/tfm/arabi/arabeyes
%dir %{_texmfdistdir}/fonts/tfm/arabi/farsiweb
%dir %{_texmfdistdir}/fonts/tfm/arkandis
%dir %{_texmfdistdir}/fonts/tfm/arkandis/accanthis
%dir %{_texmfdistdir}/fonts/tfm/arkandis/adforn
%dir %{_texmfdistdir}/fonts/tfm/arkandis/adfsymbols
%dir %{_texmfdistdir}/fonts/tfm/arkandis/baskervald
%dir %{_texmfdistdir}/fonts/tfm/arkandis/berenisadf
%dir %{_texmfdistdir}/fonts/tfm/arkandis/electrum
%dir %{_texmfdistdir}/fonts/tfm/arkandis/gillius
%dir %{_texmfdistdir}/fonts/tfm/arkandis/libris
%dir %{_texmfdistdir}/fonts/tfm/arkandis/mintspirit
%dir %{_texmfdistdir}/fonts/tfm/arkandis/romande
%dir %{_texmfdistdir}/fonts/tfm/arkandis/universalis
%dir %{_texmfdistdir}/fonts/tfm/arkandis/venturis
%dir %{_texmfdistdir}/fonts/tfm/arkandis/venturis2
%dir %{_texmfdistdir}/fonts/tfm/arkandis/venturisold
%dir %{_texmfdistdir}/fonts/tfm/arkandis/venturissans
%dir %{_texmfdistdir}/fonts/tfm/arkandis/venturissans2
%dir %{_texmfdistdir}/fonts/tfm/arphic
%dir %{_texmfdistdir}/fonts/tfm/arphic/bkaimp
%dir %{_texmfdistdir}/fonts/tfm/arphic/bkaiu
%dir %{_texmfdistdir}/fonts/tfm/arphic/bsmilp
%dir %{_texmfdistdir}/fonts/tfm/arphic/bsmiu
%dir %{_texmfdistdir}/fonts/tfm/arphic/gbsnlp
%dir %{_texmfdistdir}/fonts/tfm/arphic/gbsnu
%dir %{_texmfdistdir}/fonts/tfm/arphic/gkaimp
%dir %{_texmfdistdir}/fonts/tfm/arphic/gkaiu
%dir %{_texmfdistdir}/fonts/tfm/ascender
%dir %{_texmfdistdir}/fonts/tfm/ascender/droid
%dir %{_texmfdistdir}/fonts/tfm/ascender/droid/droidsans
%dir %{_texmfdistdir}/fonts/tfm/ascender/droid/droidsansmono
%dir %{_texmfdistdir}/fonts/tfm/ascender/droid/droidserif
%dir %{_texmfdistdir}/fonts/tfm/ascender/opensans
%dir %{_texmfdistdir}/fonts/tfm/bh
%dir %{_texmfdistdir}/fonts/tfm/bh/gofonts
%dir %{_texmfdistdir}/fonts/tfm/bitstrea
%dir %{_texmfdistdir}/fonts/tfm/bitstrea/charter
%dir %{_texmfdistdir}/fonts/tfm/catharsis
%dir %{_texmfdistdir}/fonts/tfm/catharsis/cormorantgaramond
%dir %{_texmfdistdir}/fonts/tfm/cns
%dir %{_texmfdistdir}/fonts/tfm/cns/c0so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c1so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c2so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c3so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c4so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c5so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c6so12
%dir %{_texmfdistdir}/fonts/tfm/cns/c7so12
%dir %{_texmfdistdir}/fonts/tfm/cs
%dir %{_texmfdistdir}/fonts/tfm/cs/cs-a35
%dir %{_texmfdistdir}/fonts/tfm/cs/cs-charter
%dir %{_texmfdistdir}/fonts/tfm/gnome
%dir %{_texmfdistdir}/fonts/tfm/gnome/cantarell
%dir %{_texmfdistdir}/fonts/tfm/google
%dir %{_texmfdistdir}/fonts/tfm/google/arimo
%dir %{_texmfdistdir}/fonts/tfm/google/carlito
%dir %{_texmfdistdir}/fonts/tfm/google/noto
%dir %{_texmfdistdir}/fonts/tfm/google/roboto
%dir %{_texmfdistdir}/fonts/tfm/google/tinos
%dir %{_texmfdistdir}/fonts/tfm/gust
%dir %{_texmfdistdir}/fonts/tfm/gust/poltawski
%dir %{_texmfdistdir}/fonts/tfm/hoekwater
%dir %{_texmfdistdir}/fonts/tfm/hoekwater/context
%dir %{_texmfdistdir}/fonts/tfm/huerta
%dir %{_texmfdistdir}/fonts/tfm/huerta/alegreya
%dir %{_texmfdistdir}/fonts/tfm/huerta/bitter
%dir %{_texmfdistdir}/fonts/tfm/huerta/caladea
%dir %{_texmfdistdir}/fonts/tfm/ibm
%dir %{_texmfdistdir}/fonts/tfm/ibm/plex
%dir %{_texmfdistdir}/fonts/tfm/iginomarini
%dir %{_texmfdistdir}/fonts/tfm/iginomarini/imfellenglish
%dir %{_texmfdistdir}/fonts/tfm/impallari
%dir %{_texmfdistdir}/fonts/tfm/impallari/cabin
%dir %{_texmfdistdir}/fonts/tfm/impallari/librebaskerville
%dir %{_texmfdistdir}/fonts/tfm/impallari/librebodoni
%dir %{_texmfdistdir}/fonts/tfm/impallari/librecaslon
%dir %{_texmfdistdir}/fonts/tfm/impallari/librefranklin
%dir %{_texmfdistdir}/fonts/tfm/impallari/lobster2
%dir %{_texmfdistdir}/fonts/tfm/impallari/quattrocento
%dir %{_texmfdistdir}/fonts/tfm/impallari/raleway
%dir %{_texmfdistdir}/fonts/tfm/intel
%dir %{_texmfdistdir}/fonts/tfm/intel/clearsans
%dir %{_texmfdistdir}/fonts/tfm/jknappen
%dir %{_texmfdistdir}/fonts/tfm/jknappen/ec
%dir %{_texmfdistdir}/fonts/tfm/jknappen/fc
%dir %{_texmfdistdir}/fonts/tfm/jmn
%dir %{_texmfdistdir}/fonts/tfm/jmn/hans
%dir %{_texmfdistdir}/fonts/tfm/kosch
%dir %{_texmfdistdir}/fonts/tfm/kosch/crimson
%dir %{_texmfdistdir}/fonts/tfm/metapost
%dir %{_texmfdistdir}/fonts/tfm/monotype
%dir %{_texmfdistdir}/fonts/tfm/monotype/helvetic
%dir %{_texmfdistdir}/fonts/tfm/monotype/symbol
%dir %{_texmfdistdir}/fonts/tfm/ndiscovered
%dir %{_texmfdistdir}/fonts/tfm/ndiscovered/cinzel
%dir %{_texmfdistdir}/fonts/tfm/nowacki
%dir %{_texmfdistdir}/fonts/tfm/nowacki/iwona
%dir %{_texmfdistdir}/fonts/tfm/nowacki/kurier
%dir %{_texmfdistdir}/fonts/tfm/paratype
%dir %{_texmfdistdir}/fonts/tfm/paratype/ptmono
%dir %{_texmfdistdir}/fonts/tfm/paratype/ptsans
%dir %{_texmfdistdir}/fonts/tfm/paratype/ptserif
%dir %{_texmfdistdir}/fonts/tfm/production
%dir %{_texmfdistdir}/fonts/tfm/production/spectral
%dir %{_texmfdistdir}/fonts/tfm/ptex-fonts
%dir %{_texmfdistdir}/fonts/tfm/ptex-fonts/dvips
%dir %{_texmfdistdir}/fonts/tfm/ptex-fonts/jis
%dir %{_texmfdistdir}/fonts/tfm/ptex-fonts/nmin-ngoth
%dir %{_texmfdistdir}/fonts/tfm/ptex-fonts/standard
%dir %{_texmfdistdir}/fonts/tfm/public
%dir %{_texmfdistdir}/fonts/tfm/public/ae
%dir %{_texmfdistdir}/fonts/tfm/public/aesupp
%dir %{_texmfdistdir}/fonts/tfm/public/alfaslabone
%dir %{_texmfdistdir}/fonts/tfm/public/algolrevived
%dir %{_texmfdistdir}/fonts/tfm/public/almendra
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts/cmextra
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts/cyrillic
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts/dummy
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts/euler
%dir %{_texmfdistdir}/fonts/tfm/public/amsfonts/symbols
%dir %{_texmfdistdir}/fonts/tfm/public/anonymouspro
%dir %{_texmfdistdir}/fonts/tfm/public/antt
%dir %{_texmfdistdir}/fonts/tfm/public/arabtex
%dir %{_texmfdistdir}/fonts/tfm/public/aramaic-serto
%dir %{_texmfdistdir}/fonts/tfm/public/archaic
%dir %{_texmfdistdir}/fonts/tfm/public/archivo
%dir %{_texmfdistdir}/fonts/tfm/public/arev
%dir %{_texmfdistdir}/fonts/tfm/public/armenian
%dir %{_texmfdistdir}/fonts/tfm/public/arvo
%dir %{_texmfdistdir}/fonts/tfm/public/ascii-font
%dir %{_texmfdistdir}/fonts/tfm/public/ascmac
%dir %{_texmfdistdir}/fonts/tfm/public/aspectratio
%dir %{_texmfdistdir}/fonts/tfm/public/astro
%dir %{_texmfdistdir}/fonts/tfm/public/atkinson
%dir %{_texmfdistdir}/fonts/tfm/public/augie
%dir %{_texmfdistdir}/fonts/tfm/public/auncial-new
%dir %{_texmfdistdir}/fonts/tfm/public/aurical
%dir %{_texmfdistdir}/fonts/tfm/public/bangtex
%dir %{_texmfdistdir}/fonts/tfm/public/barcodes
%dir %{_texmfdistdir}/fonts/tfm/public/bartel-chess-fonts
%dir %{_texmfdistdir}/fonts/tfm/public/baskervaldx
%dir %{_texmfdistdir}/fonts/tfm/public/baskervillef
%dir %{_texmfdistdir}/fonts/tfm/public/bbding
%dir %{_texmfdistdir}/fonts/tfm/public/bbm
%dir %{_texmfdistdir}/fonts/tfm/public/bbold
%dir %{_texmfdistdir}/fonts/tfm/public/bboldx
%dir %{_texmfdistdir}/fonts/tfm/public/bengali
%dir %{_texmfdistdir}/fonts/tfm/public/bera
%dir %{_texmfdistdir}/fonts/tfm/public/beuron
%dir %{_texmfdistdir}/fonts/tfm/public/bguq
%dir %{_texmfdistdir}/fonts/tfm/public/blacklettert1
%dir %{_texmfdistdir}/fonts/tfm/public/boisik
%dir %{_texmfdistdir}/fonts/tfm/public/bookhands
%dir %{_texmfdistdir}/fonts/tfm/public/boondox
%dir %{_texmfdistdir}/fonts/tfm/public/brushscr
%dir %{_texmfdistdir}/fonts/tfm/public/burmese
%dir %{_texmfdistdir}/fonts/tfm/public/bxjatoucs
%dir %{_texmfdistdir}/fonts/tfm/public/calligra
%dir %{_texmfdistdir}/fonts/tfm/public/cascadia-code
%dir %{_texmfdistdir}/fonts/tfm/public/casyl
%dir %{_texmfdistdir}/fonts/tfm/public/cbcoptic
%dir %{_texmfdistdir}/fonts/tfm/public/cbfonts
%dir %{_texmfdistdir}/fonts/tfm/public/cc-pl
%dir %{_texmfdistdir}/fonts/tfm/public/ccicons
%dir %{_texmfdistdir}/fonts/tfm/public/cfr-lm
%dir %{_texmfdistdir}/fonts/tfm/public/chemarrow
%dir %{_texmfdistdir}/fonts/tfm/public/cherokee
%dir %{_texmfdistdir}/fonts/tfm/public/chess
%dir %{_texmfdistdir}/fonts/tfm/public/chivo
%dir %{_texmfdistdir}/fonts/tfm/public/circ
%dir %{_texmfdistdir}/fonts/tfm/public/cjhebrew
%dir %{_texmfdistdir}/fonts/tfm/public/clara
%dir %{_texmfdistdir}/fonts/tfm/public/clock
%dir %{_texmfdistdir}/fonts/tfm/public/cm
%dir %{_texmfdistdir}/fonts/tfm/public/cm-lgc
%dir %{_texmfdistdir}/fonts/tfm/public/cm-mf-extra-bold
%dir %{_texmfdistdir}/fonts/tfm/public/cmathbb
%dir %{_texmfdistdir}/fonts/tfm/public/cmbright
%dir %{_texmfdistdir}/fonts/tfm/public/cmcyr
%dir %{_texmfdistdir}/fonts/tfm/public/cmexb
%dir %{_texmfdistdir}/fonts/tfm/public/cmextra
%dir %{_texmfdistdir}/fonts/tfm/public/cmll
%dir %{_texmfdistdir}/fonts/tfm/public/cmpica
%dir %{_texmfdistdir}/fonts/tfm/public/cmsrb
%dir %{_texmfdistdir}/fonts/tfm/public/cmtiup
%dir %{_texmfdistdir}/fonts/tfm/public/cmupint
%dir %{_texmfdistdir}/fonts/tfm/public/cochineal
%dir %{_texmfdistdir}/fonts/tfm/public/coelacanth
%dir %{_texmfdistdir}/fonts/tfm/public/concmath-fonts
%dir %{_texmfdistdir}/fonts/tfm/public/concrete
%dir %{_texmfdistdir}/fonts/tfm/public/cookingsymbols
%dir %{_texmfdistdir}/fonts/tfm/public/cooperhewitt
%dir %{_texmfdistdir}/fonts/tfm/public/countriesofeurope
%dir %{_texmfdistdir}/fonts/tfm/public/courierten
%dir %{_texmfdistdir}/fonts/tfm/public/crimsonpro
%dir %{_texmfdistdir}/fonts/tfm/public/cryst
%dir %{_texmfdistdir}/fonts/tfm/public/cs
%dir %{_texmfdistdir}/fonts/tfm/public/ctib
%dir %{_texmfdistdir}/fonts/tfm/public/cuprum
%dir %{_texmfdistdir}/fonts/tfm/public/cyklop
%dir %{_texmfdistdir}/fonts/tfm/public/dad
%dir %{_texmfdistdir}/fonts/tfm/public/dancers
%dir %{_texmfdistdir}/fonts/tfm/public/dantelogo
%dir %{_texmfdistdir}/fonts/tfm/public/dejavu
%dir %{_texmfdistdir}/fonts/tfm/public/dice
%dir %{_texmfdistdir}/fonts/tfm/public/dictsym
%dir %{_texmfdistdir}/fonts/tfm/public/dingbat
%dir %{_texmfdistdir}/fonts/tfm/public/domitian
%dir %{_texmfdistdir}/fonts/tfm/public/doublestroke
%dir %{_texmfdistdir}/fonts/tfm/public/dozenal
%dir %{_texmfdistdir}/fonts/tfm/public/drm
%dir %{_texmfdistdir}/fonts/tfm/public/dsserif
%dir %{_texmfdistdir}/fonts/tfm/public/duerer
%dir %{_texmfdistdir}/fonts/tfm/public/dutchcal
%dir %{_texmfdistdir}/fonts/tfm/public/ebgaramond
%dir %{_texmfdistdir}/fonts/tfm/public/ebgaramond-maths
%dir %{_texmfdistdir}/fonts/tfm/public/ecc
%dir %{_texmfdistdir}/fonts/tfm/public/eco
%dir %{_texmfdistdir}/fonts/tfm/public/eiad
%dir %{_texmfdistdir}/fonts/tfm/public/elvish
%dir %{_texmfdistdir}/fonts/tfm/public/epigrafica
%dir %{_texmfdistdir}/fonts/tfm/public/epiolmec
%dir %{_texmfdistdir}/fonts/tfm/public/erewhon
%dir %{_texmfdistdir}/fonts/tfm/public/esint
%dir %{_texmfdistdir}/fonts/tfm/public/esrelation
%dir %{_texmfdistdir}/fonts/tfm/public/esstix
%dir %{_texmfdistdir}/fonts/tfm/public/esvect
%dir %{_texmfdistdir}/fonts/tfm/public/etbb
%dir %{_texmfdistdir}/fonts/tfm/public/etex
%dir %{_texmfdistdir}/fonts/tfm/public/ethiop
%dir %{_texmfdistdir}/fonts/tfm/public/eulervm
%dir %{_texmfdistdir}/fonts/tfm/public/euro-ce
%dir %{_texmfdistdir}/fonts/tfm/public/eurosym
%dir %{_texmfdistdir}/fonts/tfm/public/euxm
%dir %{_texmfdistdir}/fonts/tfm/public/fbb
%dir %{_texmfdistdir}/fonts/tfm/public/fdsymbol
%dir %{_texmfdistdir}/fonts/tfm/public/fetamont
%dir %{_texmfdistdir}/fonts/tfm/public/feyn
%dir %{_texmfdistdir}/fonts/tfm/public/fge
%dir %{_texmfdistdir}/fonts/tfm/public/figbas
%dir %{_texmfdistdir}/fonts/tfm/public/fira
%dir %{_texmfdistdir}/fonts/tfm/public/foekfont
%dir %{_texmfdistdir}/fonts/tfm/public/fonetika
%dir %{_texmfdistdir}/fonts/tfm/public/fontawesome
%dir %{_texmfdistdir}/fonts/tfm/public/fontawesome5
%dir %{_texmfdistdir}/fonts/tfm/public/fonts-tlwg
%dir %{_texmfdistdir}/fonts/tfm/public/forum
%dir %{_texmfdistdir}/fonts/tfm/public/fourier
%dir %{_texmfdistdir}/fonts/tfm/public/fouriernc
%dir %{_texmfdistdir}/fonts/tfm/public/frcursive
%dir %{_texmfdistdir}/fonts/tfm/public/frimurer
%dir %{_texmfdistdir}/fonts/tfm/public/garamond-libre
%dir %{_texmfdistdir}/fonts/tfm/public/garuda-c90
%dir %{_texmfdistdir}/fonts/tfm/public/genealogy
%dir %{_texmfdistdir}/fonts/tfm/public/gentium-tug
%dir %{_texmfdistdir}/fonts/tfm/public/gfsartemisia
%dir %{_texmfdistdir}/fonts/tfm/public/gfsbaskerville
%dir %{_texmfdistdir}/fonts/tfm/public/gfsbodoni
%dir %{_texmfdistdir}/fonts/tfm/public/gfscomplutum
%dir %{_texmfdistdir}/fonts/tfm/public/gfsdidot
%dir %{_texmfdistdir}/fonts/tfm/public/gfsneohellenic
%dir %{_texmfdistdir}/fonts/tfm/public/gfsporson
%dir %{_texmfdistdir}/fonts/tfm/public/gfssolomos
%dir %{_texmfdistdir}/fonts/tfm/public/gillcm
%dir %{_texmfdistdir}/fonts/tfm/public/go
%dir %{_texmfdistdir}/fonts/tfm/public/gothic
%dir %{_texmfdistdir}/fonts/tfm/public/greenpoint
%dir %{_texmfdistdir}/fonts/tfm/public/gudea
%dir %{_texmfdistdir}/fonts/tfm/public/hacm
%dir %{_texmfdistdir}/fonts/tfm/public/hands
%dir %{_texmfdistdir}/fonts/tfm/public/heuristica
%dir %{_texmfdistdir}/fonts/tfm/public/hfoldsty
%dir %{_texmfdistdir}/fonts/tfm/public/hindmadurai
%dir %{_texmfdistdir}/fonts/tfm/public/ibarra
%dir %{_texmfdistdir}/fonts/tfm/public/ibygrk
%dir %{_texmfdistdir}/fonts/tfm/public/ifsym
%dir %{_texmfdistdir}/fonts/tfm/public/inconsolata
%dir %{_texmfdistdir}/fonts/tfm/public/initials
%dir %{_texmfdistdir}/fonts/tfm/public/inriafonts
%dir %{_texmfdistdir}/fonts/tfm/public/inter
%dir %{_texmfdistdir}/fonts/tfm/public/ipaex-type1
%dir %{_texmfdistdir}/fonts/tfm/public/jamtimes
%dir %{_texmfdistdir}/fonts/tfm/public/japanese-otf
%dir %{_texmfdistdir}/fonts/tfm/public/jlreq
%dir %{_texmfdistdir}/fonts/tfm/public/jlreq-deluxe
%dir %{_texmfdistdir}/fonts/tfm/public/josefin
%dir %{_texmfdistdir}/fonts/tfm/public/junicode
%dir %{_texmfdistdir}/fonts/tfm/public/kerkis
%dir %{_texmfdistdir}/fonts/tfm/public/kixfont
%dir %{_texmfdistdir}/fonts/tfm/public/knitting
%dir %{_texmfdistdir}/fonts/tfm/public/knuth-lib
%dir %{_texmfdistdir}/fonts/tfm/public/knuth-local
%dir %{_texmfdistdir}/fonts/tfm/public/kpfonts
%dir %{_texmfdistdir}/fonts/tfm/public/latex-fonts
%dir %{_texmfdistdir}/fonts/tfm/public/levy
%dir %{_texmfdistdir}/fonts/tfm/public/lfb
%dir %{_texmfdistdir}/fonts/tfm/public/libertine
%dir %{_texmfdistdir}/fonts/tfm/public/libertinegc
%dir %{_texmfdistdir}/fonts/tfm/public/libertinus-type1
%dir %{_texmfdistdir}/fonts/tfm/public/libertinust1math
%dir %{_texmfdistdir}/fonts/tfm/public/lineara
%dir %{_texmfdistdir}/fonts/tfm/public/linguisticspro
%dir %{_texmfdistdir}/fonts/tfm/public/lithuanian
%dir %{_texmfdistdir}/fonts/tfm/public/lm
%dir %{_texmfdistdir}/fonts/tfm/public/lxfonts
%dir %{_texmfdistdir}/fonts/tfm/public/magra
%dir %{_texmfdistdir}/fonts/tfm/public/marcellus
%dir %{_texmfdistdir}/fonts/tfm/public/marvosym
%dir %{_texmfdistdir}/fonts/tfm/public/mathabx
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdbch
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdgreek
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdici
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdpgd
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdpus
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdput
%dir %{_texmfdistdir}/fonts/tfm/public/mathdesign/mdugm
%dir %{_texmfdistdir}/fonts/tfm/public/mathpazo
%dir %{_texmfdistdir}/fonts/tfm/public/mdputu
%dir %{_texmfdistdir}/fonts/tfm/public/mdsymbol
%dir %{_texmfdistdir}/fonts/tfm/public/mflogo
%dir %{_texmfdistdir}/fonts/tfm/public/miama
%dir %{_texmfdistdir}/fonts/tfm/public/mlmodern
%dir %{_texmfdistdir}/fonts/tfm/public/mnsymbol
%dir %{_texmfdistdir}/fonts/tfm/public/montex
%dir %{_texmfdistdir}/fonts/tfm/public/montserrat
%dir %{_texmfdistdir}/fonts/tfm/public/morisawa
%dir %{_texmfdistdir}/fonts/tfm/public/musixtex-fonts
%dir %{_texmfdistdir}/fonts/tfm/public/mxedruli
%dir %{_texmfdistdir}/fonts/tfm/public/nanumtype1
%dir %{_texmfdistdir}/fonts/tfm/public/newpx
%dir %{_texmfdistdir}/fonts/tfm/public/newtx
%dir %{_texmfdistdir}/fonts/tfm/public/newtxsf
%dir %{_texmfdistdir}/fonts/tfm/public/newtxtt
%dir %{_texmfdistdir}/fonts/tfm/public/niceframe
%dir %{_texmfdistdir}/fonts/tfm/public/nimbus15
%dir %{_texmfdistdir}/fonts/tfm/public/nkarta
%dir %{_texmfdistdir}/fonts/tfm/public/norasi-c90
%dir %{_texmfdistdir}/fonts/tfm/public/notomath
%dir %{_texmfdistdir}/fonts/tfm/public/nunito
%dir %{_texmfdistdir}/fonts/tfm/public/obnov
%dir %{_texmfdistdir}/fonts/tfm/public/ocherokee
%dir %{_texmfdistdir}/fonts/tfm/public/ocr-b
%dir %{_texmfdistdir}/fonts/tfm/public/ogham
%dir %{_texmfdistdir}/fonts/tfm/public/oinuit
%dir %{_texmfdistdir}/fonts/tfm/public/old-arrows
%dir %{_texmfdistdir}/fonts/tfm/public/oldlatin
%dir %{_texmfdistdir}/fonts/tfm/public/oldstandard
%dir %{_texmfdistdir}/fonts/tfm/public/omega
%dir %{_texmfdistdir}/fonts/tfm/public/orkhun
%dir %{_texmfdistdir}/fonts/tfm/public/oswald
%dir %{_texmfdistdir}/fonts/tfm/public/othello
%dir %{_texmfdistdir}/fonts/tfm/public/otibet
%dir %{_texmfdistdir}/fonts/tfm/public/pacioli
%dir %{_texmfdistdir}/fonts/tfm/public/pdftex
%dir %{_texmfdistdir}/fonts/tfm/public/phaistos
%dir %{_texmfdistdir}/fonts/tfm/public/phonetic
%dir %{_texmfdistdir}/fonts/tfm/public/pigpen
%dir %{_texmfdistdir}/fonts/tfm/public/pl
%dir %{_texmfdistdir}/fonts/tfm/public/playfair
%dir %{_texmfdistdir}/fonts/tfm/public/plimsoll
%dir %{_texmfdistdir}/fonts/tfm/public/poiretone
%dir %{_texmfdistdir}/fonts/tfm/public/prodint
%dir %{_texmfdistdir}/fonts/tfm/public/pslatex
%dir %{_texmfdistdir}/fonts/tfm/public/punk
%dir %{_texmfdistdir}/fonts/tfm/public/pxchfon
%dir %{_texmfdistdir}/fonts/tfm/public/pxfonts
%dir %{_texmfdistdir}/fonts/tfm/public/pxjodel
%dir %{_texmfdistdir}/fonts/tfm/public/pxtxalfa
%dir %{_texmfdistdir}/fonts/tfm/public/pxufont
%dir %{_texmfdistdir}/fonts/tfm/public/qpxqtx
%dir %{_texmfdistdir}/fonts/tfm/public/recycle
%dir %{_texmfdistdir}/fonts/tfm/public/relenc
%dir %{_texmfdistdir}/fonts/tfm/public/rojud
%dir %{_texmfdistdir}/fonts/tfm/public/rosario
%dir %{_texmfdistdir}/fonts/tfm/public/rsfs
%dir %{_texmfdistdir}/fonts/tfm/public/rsfso
%dir %{_texmfdistdir}/fonts/tfm/public/sanskrit
%dir %{_texmfdistdir}/fonts/tfm/public/sansmathaccent
%dir %{_texmfdistdir}/fonts/tfm/public/sansmathfonts
%dir %{_texmfdistdir}/fonts/tfm/public/scanpages
%dir %{_texmfdistdir}/fonts/tfm/public/scholax
%dir %{_texmfdistdir}/fonts/tfm/public/schulschriften
%dir %{_texmfdistdir}/fonts/tfm/public/semaphor
%dir %{_texmfdistdir}/fonts/tfm/public/shuffle
%dir %{_texmfdistdir}/fonts/tfm/public/simpleicons
%dir %{_texmfdistdir}/fonts/tfm/public/skak
%dir %{_texmfdistdir}/fonts/tfm/public/skaknew
%dir %{_texmfdistdir}/fonts/tfm/public/skull
%dir %{_texmfdistdir}/fonts/tfm/public/srbtiks
%dir %{_texmfdistdir}/fonts/tfm/public/starfont
%dir %{_texmfdistdir}/fonts/tfm/public/staves
%dir %{_texmfdistdir}/fonts/tfm/public/step
%dir %{_texmfdistdir}/fonts/tfm/public/stepgreek
%dir %{_texmfdistdir}/fonts/tfm/public/stickstoo
%dir %{_texmfdistdir}/fonts/tfm/public/stix
%dir %{_texmfdistdir}/fonts/tfm/public/stix2-type1
%dir %{_texmfdistdir}/fonts/tfm/public/stmaryrd
%dir %{_texmfdistdir}/fonts/tfm/public/superiors
%dir %{_texmfdistdir}/fonts/tfm/public/svrsymbols
%dir %{_texmfdistdir}/fonts/tfm/public/tabvar
%dir %{_texmfdistdir}/fonts/tfm/public/tempora
%dir %{_texmfdistdir}/fonts/tfm/public/tengwarscript
%dir %{_texmfdistdir}/fonts/tfm/public/tex-gyre
%dir %{_texmfdistdir}/fonts/tfm/public/tfrupee
%dir %{_texmfdistdir}/fonts/tfm/public/theanodidot
%dir %{_texmfdistdir}/fonts/tfm/public/theanomodern
%dir %{_texmfdistdir}/fonts/tfm/public/theanooldstyle
%dir %{_texmfdistdir}/fonts/tfm/public/tipa
%dir %{_texmfdistdir}/fonts/tfm/public/trajan
%dir %{_texmfdistdir}/fonts/tfm/public/trsym
%dir %{_texmfdistdir}/fonts/tfm/public/txfonts
%dir %{_texmfdistdir}/fonts/tfm/public/txfontsb
%dir %{_texmfdistdir}/fonts/tfm/public/txuprcal
%dir %{_texmfdistdir}/fonts/tfm/public/universa
%dir %{_texmfdistdir}/fonts/tfm/public/uppunctlm
%dir %{_texmfdistdir}/fonts/tfm/public/velthuis
%dir %{_texmfdistdir}/fonts/tfm/public/wasy
%dir %{_texmfdistdir}/fonts/tfm/public/wnri
%dir %{_texmfdistdir}/fonts/tfm/public/wsuipa
%dir %{_texmfdistdir}/fonts/tfm/public/xcharter
%dir %{_texmfdistdir}/fonts/tfm/public/xq
%dir %{_texmfdistdir}/fonts/tfm/public/xypic
%dir %{_texmfdistdir}/fonts/tfm/public/yannisgr
%dir %{_texmfdistdir}/fonts/tfm/public/yhmath
%dir %{_texmfdistdir}/fonts/tfm/public/zhmetrics-uptex
%dir %{_texmfdistdir}/fonts/tfm/rozynski
%dir %{_texmfdistdir}/fonts/tfm/rozynski/comicneue
%dir %{_texmfdistdir}/fonts/tfm/sorkin
%dir %{_texmfdistdir}/fonts/tfm/sorkin/merriweather
%dir %{_texmfdistdir}/fonts/tfm/tipo
%dir %{_texmfdistdir}/fonts/tfm/tipo/overlock
%dir %{_texmfdistdir}/fonts/tfm/typoland
%dir %{_texmfdistdir}/fonts/tfm/typoland/lato
%dir %{_texmfdistdir}/fonts/tfm/uhc
%dir %{_texmfdistdir}/fonts/tfm/uhc/umj
%dir %{_texmfdistdir}/fonts/tfm/uhc/uwmj
%dir %{_texmfdistdir}/fonts/tfm/uhc/wmj
%dir %{_texmfdistdir}/fonts/tfm/uptex-fonts
%dir %{_texmfdistdir}/fonts/tfm/uptex-fonts/jis
%dir %{_texmfdistdir}/fonts/tfm/uptex-fonts/min
%dir %{_texmfdistdir}/fonts/tfm/urw
%dir %{_texmfdistdir}/fonts/tfm/urw/antiqua
%dir %{_texmfdistdir}/fonts/tfm/urw/grotesq
%dir %{_texmfdistdir}/fonts/tfm/urw/urwchancal
%dir %{_texmfdistdir}/fonts/tfm/urw35vf
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/avantgar
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/bookman
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/courier
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/helvetic
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/ncntrsbk
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/palatino
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/symbol
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/times
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/zapfchan
%dir %{_texmfdistdir}/fonts/tfm/urw35vf/zapfding
%dir %{_texmfdistdir}/fonts/tfm/vntex
%dir %{_texmfdistdir}/fonts/tfm/vntex/arevvn
%dir %{_texmfdistdir}/fonts/tfm/vntex/chartervn
%dir %{_texmfdistdir}/fonts/tfm/vntex/cmbrightvn
%dir %{_texmfdistdir}/fonts/tfm/vntex/concretevn
%dir %{_texmfdistdir}/fonts/tfm/vntex/grotesqvn
%dir %{_texmfdistdir}/fonts/tfm/vntex/txttvn
%dir %{_texmfdistdir}/fonts/tfm/vntex/urwvn
%dir %{_texmfdistdir}/fonts/tfm/vntex/vnr
%dir %{_texmfdistdir}/fonts/tfm/vntex/vntopia
%dir %{_texmfdistdir}/fonts/tfm/wadalab
%dir %{_texmfdistdir}/fonts/tfm/wadalab/dgj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/dmj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/mc2j
%dir %{_texmfdistdir}/fonts/tfm/wadalab/mcj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/mr2j
%dir %{_texmfdistdir}/fonts/tfm/wadalab/mrj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/udgj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/udmj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/umcj
%dir %{_texmfdistdir}/fonts/tfm/wadalab/umrj
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/cyberb
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbk
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbkfs
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbkhei
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbkkai
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbkli
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbksong
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/gbkyou
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/unifs
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/unihei
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/unikai
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/unili
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/unisong
%dir %{_texmfdistdir}/fonts/tfm/zhmetrics/uniyou
%dir %{_texmfdistdir}/fonts/truetype
%dir %{_texmfdistdir}/fonts/truetype/SIL
%dir %{_texmfdistdir}/fonts/truetype/SIL/andika
%dir %{_texmfdistdir}/fonts/truetype/SIL/charissil
%dir %{_texmfdistdir}/fonts/truetype/aajohan
%dir %{_texmfdistdir}/fonts/truetype/aajohan/comfortaa
%dir %{_texmfdistdir}/fonts/truetype/ascender
%dir %{_texmfdistdir}/fonts/truetype/ascender/droid
%dir %{_texmfdistdir}/fonts/truetype/ascender/droid/droidsans
%dir %{_texmfdistdir}/fonts/truetype/ascender/droid/droidsansmono
%dir %{_texmfdistdir}/fonts/truetype/ascender/droid/droidserif
%dir %{_texmfdistdir}/fonts/truetype/ascender/opensans
%dir %{_texmfdistdir}/fonts/truetype/bh
%dir %{_texmfdistdir}/fonts/truetype/bh/gofonts
%dir %{_texmfdistdir}/fonts/truetype/catharsis
%dir %{_texmfdistdir}/fonts/truetype/catharsis/cormorantgaramond
%dir %{_texmfdistdir}/fonts/truetype/google
%dir %{_texmfdistdir}/fonts/truetype/google/arimo
%dir %{_texmfdistdir}/fonts/truetype/google/carlito
%dir %{_texmfdistdir}/fonts/truetype/google/noto
%dir %{_texmfdistdir}/fonts/truetype/google/noto-emoji
%dir %{_texmfdistdir}/fonts/truetype/google/tinos
%dir %{_texmfdistdir}/fonts/truetype/huerta
%dir %{_texmfdistdir}/fonts/truetype/huerta/bitter
%dir %{_texmfdistdir}/fonts/truetype/huerta/caladea
%dir %{_texmfdistdir}/fonts/truetype/impallari
%dir %{_texmfdistdir}/fonts/truetype/impallari/librebaskerville
%dir %{_texmfdistdir}/fonts/truetype/impallari/quattrocento
%dir %{_texmfdistdir}/fonts/truetype/intel
%dir %{_texmfdistdir}/fonts/truetype/intel/clearsans
%dir %{_texmfdistdir}/fonts/truetype/ndiscovered
%dir %{_texmfdistdir}/fonts/truetype/ndiscovered/cinzel
%dir %{_texmfdistdir}/fonts/truetype/paratype
%dir %{_texmfdistdir}/fonts/truetype/paratype/ptmono
%dir %{_texmfdistdir}/fonts/truetype/paratype/ptsans
%dir %{_texmfdistdir}/fonts/truetype/paratype/ptserif
%dir %{_texmfdistdir}/fonts/truetype/production
%dir %{_texmfdistdir}/fonts/truetype/production/spectral
%dir %{_texmfdistdir}/fonts/truetype/public
%dir %{_texmfdistdir}/fonts/truetype/public/academicons
%dir %{_texmfdistdir}/fonts/truetype/public/alkalami
%dir %{_texmfdistdir}/fonts/truetype/public/almendra
%dir %{_texmfdistdir}/fonts/truetype/public/almfixed
%dir %{_texmfdistdir}/fonts/truetype/public/amiri
%dir %{_texmfdistdir}/fonts/truetype/public/anonymouspro
%dir %{_texmfdistdir}/fonts/truetype/public/arphic-ttf
%dir %{_texmfdistdir}/fonts/truetype/public/arvo
%dir %{_texmfdistdir}/fonts/truetype/public/asana-math
%dir %{_texmfdistdir}/fonts/truetype/public/baekmuk
%dir %{_texmfdistdir}/fonts/truetype/public/bangla
%dir %{_texmfdistdir}/fonts/truetype/public/belleek
%dir %{_texmfdistdir}/fonts/truetype/public/crimsonpro
%dir %{_texmfdistdir}/fonts/truetype/public/cuprum
%dir %{_texmfdistdir}/fonts/truetype/public/dejavu
%dir %{_texmfdistdir}/fonts/truetype/public/doulossil
%dir %{_texmfdistdir}/fonts/truetype/public/ektype-tanka
%dir %{_texmfdistdir}/fonts/truetype/public/fonetika
%dir %{_texmfdistdir}/fonts/truetype/public/fontmfizz
%dir %{_texmfdistdir}/fonts/truetype/public/gentium-tug
%dir %{_texmfdistdir}/fonts/truetype/public/gnu-freefont
%dir %{_texmfdistdir}/fonts/truetype/public/gregoriotex
%dir %{_texmfdistdir}/fonts/truetype/public/hamnosys
%dir %{_texmfdistdir}/fonts/truetype/public/hmtrump
%dir %{_texmfdistdir}/fonts/truetype/public/inriafonts
%dir %{_texmfdistdir}/fonts/truetype/public/ipaex
%dir %{_texmfdistdir}/fonts/truetype/public/josefin
%dir %{_texmfdistdir}/fonts/truetype/public/junicode
%dir %{_texmfdistdir}/fonts/truetype/public/lexend
%dir %{_texmfdistdir}/fonts/truetype/public/logix
%dir %{_texmfdistdir}/fonts/truetype/public/marcellus
%dir %{_texmfdistdir}/fonts/truetype/public/marvosym
%dir %{_texmfdistdir}/fonts/truetype/public/padauk
%dir %{_texmfdistdir}/fonts/truetype/public/poiretone
%dir %{_texmfdistdir}/fonts/truetype/public/theanodidot
%dir %{_texmfdistdir}/fonts/truetype/public/theanomodern
%dir %{_texmfdistdir}/fonts/truetype/public/theanooldstyle
%dir %{_texmfdistdir}/fonts/truetype/public/twemoji-colr
%dir %{_texmfdistdir}/fonts/truetype/public/typicons
%dir %{_texmfdistdir}/fonts/truetype/public/unfonts-core
%dir %{_texmfdistdir}/fonts/truetype/public/unfonts-extra
%dir %{_texmfdistdir}/fonts/truetype/typoland
%dir %{_texmfdistdir}/fonts/truetype/typoland/lato
%dir %{_texmfdistdir}/fonts/type1
%dir %{_texmfdistdir}/fonts/type1/SIL
%dir %{_texmfdistdir}/fonts/type1/SIL/andika
%dir %{_texmfdistdir}/fonts/type1/SIL/charissil
%dir %{_texmfdistdir}/fonts/type1/aajohan
%dir %{_texmfdistdir}/fonts/type1/aajohan/comfortaa
%dir %{_texmfdistdir}/fonts/type1/adobe
%dir %{_texmfdistdir}/fonts/type1/adobe/courier
%dir %{_texmfdistdir}/fonts/type1/adobe/sourcecodepro
%dir %{_texmfdistdir}/fonts/type1/adobe/sourcesanspro
%dir %{_texmfdistdir}/fonts/type1/adobe/sourceserifpro
%dir %{_texmfdistdir}/fonts/type1/adobe/utopia
%dir %{_texmfdistdir}/fonts/type1/arabi
%dir %{_texmfdistdir}/fonts/type1/arabi/arabeyes
%dir %{_texmfdistdir}/fonts/type1/arabi/farsiweb
%dir %{_texmfdistdir}/fonts/type1/arkandis
%dir %{_texmfdistdir}/fonts/type1/arkandis/accanthis
%dir %{_texmfdistdir}/fonts/type1/arkandis/adforn
%dir %{_texmfdistdir}/fonts/type1/arkandis/adfsymbols
%dir %{_texmfdistdir}/fonts/type1/arkandis/baskervald
%dir %{_texmfdistdir}/fonts/type1/arkandis/berenisadf
%dir %{_texmfdistdir}/fonts/type1/arkandis/electrum
%dir %{_texmfdistdir}/fonts/type1/arkandis/gillius
%dir %{_texmfdistdir}/fonts/type1/arkandis/libris
%dir %{_texmfdistdir}/fonts/type1/arkandis/mintspirit
%dir %{_texmfdistdir}/fonts/type1/arkandis/romande
%dir %{_texmfdistdir}/fonts/type1/arkandis/universalis
%dir %{_texmfdistdir}/fonts/type1/arkandis/venturis
%dir %{_texmfdistdir}/fonts/type1/arkandis/venturis2
%dir %{_texmfdistdir}/fonts/type1/arkandis/venturisold
%dir %{_texmfdistdir}/fonts/type1/arkandis/venturissans
%dir %{_texmfdistdir}/fonts/type1/arkandis/venturissans2
%dir %{_texmfdistdir}/fonts/type1/arphic
%dir %{_texmfdistdir}/fonts/type1/arphic/bkaiu
%dir %{_texmfdistdir}/fonts/type1/arphic/bsmiu
%dir %{_texmfdistdir}/fonts/type1/arphic/gbsnu
%dir %{_texmfdistdir}/fonts/type1/arphic/gkaiu
%dir %{_texmfdistdir}/fonts/type1/ascender
%dir %{_texmfdistdir}/fonts/type1/ascender/droid
%dir %{_texmfdistdir}/fonts/type1/ascender/droid/droidsans
%dir %{_texmfdistdir}/fonts/type1/ascender/droid/droidsansmono
%dir %{_texmfdistdir}/fonts/type1/ascender/droid/droidserif
%dir %{_texmfdistdir}/fonts/type1/ascender/opensans
%dir %{_texmfdistdir}/fonts/type1/bh
%dir %{_texmfdistdir}/fonts/type1/bh/gofonts
%dir %{_texmfdistdir}/fonts/type1/bitstrea
%dir %{_texmfdistdir}/fonts/type1/bitstrea/charter
%dir %{_texmfdistdir}/fonts/type1/catharsis
%dir %{_texmfdistdir}/fonts/type1/catharsis/cormorantgaramond
%dir %{_texmfdistdir}/fonts/type1/gnome
%dir %{_texmfdistdir}/fonts/type1/gnome/cantarell
%dir %{_texmfdistdir}/fonts/type1/google
%dir %{_texmfdistdir}/fonts/type1/google/arimo
%dir %{_texmfdistdir}/fonts/type1/google/carlito
%dir %{_texmfdistdir}/fonts/type1/google/noto
%dir %{_texmfdistdir}/fonts/type1/google/roboto
%dir %{_texmfdistdir}/fonts/type1/google/tinos
%dir %{_texmfdistdir}/fonts/type1/gust
%dir %{_texmfdistdir}/fonts/type1/gust/poltawski
%dir %{_texmfdistdir}/fonts/type1/hoekwater
%dir %{_texmfdistdir}/fonts/type1/hoekwater/context
%dir %{_texmfdistdir}/fonts/type1/hoekwater/manfnt-font
%dir %{_texmfdistdir}/fonts/type1/hoekwater/mflogo-font
%dir %{_texmfdistdir}/fonts/type1/huerta
%dir %{_texmfdistdir}/fonts/type1/huerta/alegreya
%dir %{_texmfdistdir}/fonts/type1/huerta/bitter
%dir %{_texmfdistdir}/fonts/type1/huerta/caladea
%dir %{_texmfdistdir}/fonts/type1/ibm
%dir %{_texmfdistdir}/fonts/type1/ibm/plex
%dir %{_texmfdistdir}/fonts/type1/iginomarini
%dir %{_texmfdistdir}/fonts/type1/iginomarini/imfellenglish
%dir %{_texmfdistdir}/fonts/type1/impallari
%dir %{_texmfdistdir}/fonts/type1/impallari/cabin
%dir %{_texmfdistdir}/fonts/type1/impallari/librebaskerville
%dir %{_texmfdistdir}/fonts/type1/impallari/librebodoni
%dir %{_texmfdistdir}/fonts/type1/impallari/librecaslon
%dir %{_texmfdistdir}/fonts/type1/impallari/librefranklin
%dir %{_texmfdistdir}/fonts/type1/impallari/lobster2
%dir %{_texmfdistdir}/fonts/type1/impallari/quattrocento
%dir %{_texmfdistdir}/fonts/type1/impallari/raleway
%dir %{_texmfdistdir}/fonts/type1/intel
%dir %{_texmfdistdir}/fonts/type1/intel/clearsans
%dir %{_texmfdistdir}/fonts/type1/jmn
%dir %{_texmfdistdir}/fonts/type1/jmn/hans
%dir %{_texmfdistdir}/fonts/type1/kosch
%dir %{_texmfdistdir}/fonts/type1/kosch/crimson
%dir %{_texmfdistdir}/fonts/type1/metapost
%dir %{_texmfdistdir}/fonts/type1/ndiscovered
%dir %{_texmfdistdir}/fonts/type1/ndiscovered/cinzel
%dir %{_texmfdistdir}/fonts/type1/nowacki
%dir %{_texmfdistdir}/fonts/type1/nowacki/iwona
%dir %{_texmfdistdir}/fonts/type1/nowacki/kurier
%dir %{_texmfdistdir}/fonts/type1/paratype
%dir %{_texmfdistdir}/fonts/type1/paratype/ptmono
%dir %{_texmfdistdir}/fonts/type1/paratype/ptsans
%dir %{_texmfdistdir}/fonts/type1/paratype/ptserif
%dir %{_texmfdistdir}/fonts/type1/production
%dir %{_texmfdistdir}/fonts/type1/production/spectral
%dir %{_texmfdistdir}/fonts/type1/public
%dir %{_texmfdistdir}/fonts/type1/public/aesupp
%dir %{_texmfdistdir}/fonts/type1/public/alfaslabone
%dir %{_texmfdistdir}/fonts/type1/public/algolrevived
%dir %{_texmfdistdir}/fonts/type1/public/allrunes
%dir %{_texmfdistdir}/fonts/type1/public/almendra
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/cm
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/cmextra
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/cyrillic
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/euler
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/latxfont
%dir %{_texmfdistdir}/fonts/type1/public/amsfonts/symbols
%dir %{_texmfdistdir}/fonts/type1/public/anonymouspro
%dir %{_texmfdistdir}/fonts/type1/public/antt
%dir %{_texmfdistdir}/fonts/type1/public/arabtex
%dir %{_texmfdistdir}/fonts/type1/public/aramaic-serto
%dir %{_texmfdistdir}/fonts/type1/public/archaic
%dir %{_texmfdistdir}/fonts/type1/public/archivo
%dir %{_texmfdistdir}/fonts/type1/public/arev
%dir %{_texmfdistdir}/fonts/type1/public/armenian
%dir %{_texmfdistdir}/fonts/type1/public/ascii-font
%dir %{_texmfdistdir}/fonts/type1/public/ascmac
%dir %{_texmfdistdir}/fonts/type1/public/aspectratio
%dir %{_texmfdistdir}/fonts/type1/public/atkinson
%dir %{_texmfdistdir}/fonts/type1/public/augie
%dir %{_texmfdistdir}/fonts/type1/public/auncial-new
%dir %{_texmfdistdir}/fonts/type1/public/aurical
%dir %{_texmfdistdir}/fonts/type1/public/baskervaldx
%dir %{_texmfdistdir}/fonts/type1/public/baskervillef
%dir %{_texmfdistdir}/fonts/type1/public/bbold-type1
%dir %{_texmfdistdir}/fonts/type1/public/bboldx
%dir %{_texmfdistdir}/fonts/type1/public/belleek
%dir %{_texmfdistdir}/fonts/type1/public/bera
%dir %{_texmfdistdir}/fonts/type1/public/beuron
%dir %{_texmfdistdir}/fonts/type1/public/bguq
%dir %{_texmfdistdir}/fonts/type1/public/bookhands
%dir %{_texmfdistdir}/fonts/type1/public/boondox
%dir %{_texmfdistdir}/fonts/type1/public/brushscr
%dir %{_texmfdistdir}/fonts/type1/public/burmese
%dir %{_texmfdistdir}/fonts/type1/public/calligra-type1
%dir %{_texmfdistdir}/fonts/type1/public/carolmin-ps
%dir %{_texmfdistdir}/fonts/type1/public/cascadia-code
%dir %{_texmfdistdir}/fonts/type1/public/cbcoptic
%dir %{_texmfdistdir}/fonts/type1/public/cbfonts
%dir %{_texmfdistdir}/fonts/type1/public/cc-pl
%dir %{_texmfdistdir}/fonts/type1/public/ccicons
%dir %{_texmfdistdir}/fonts/type1/public/chemarrow
%dir %{_texmfdistdir}/fonts/type1/public/chivo
%dir %{_texmfdistdir}/fonts/type1/public/cjhebrew
%dir %{_texmfdistdir}/fonts/type1/public/clara
%dir %{_texmfdistdir}/fonts/type1/public/cm-lgc
%dir %{_texmfdistdir}/fonts/type1/public/cm-super
%dir %{_texmfdistdir}/fonts/type1/public/cm-unicode
%dir %{_texmfdistdir}/fonts/type1/public/cmathbb
%dir %{_texmfdistdir}/fonts/type1/public/cmcyr
%dir %{_texmfdistdir}/fonts/type1/public/cmexb
%dir %{_texmfdistdir}/fonts/type1/public/cmll
%dir %{_texmfdistdir}/fonts/type1/public/cmsrb
%dir %{_texmfdistdir}/fonts/type1/public/cmupint
%dir %{_texmfdistdir}/fonts/type1/public/cochineal
%dir %{_texmfdistdir}/fonts/type1/public/coelacanth
%dir %{_texmfdistdir}/fonts/type1/public/cooperhewitt
%dir %{_texmfdistdir}/fonts/type1/public/countriesofeurope
%dir %{_texmfdistdir}/fonts/type1/public/courierten
%dir %{_texmfdistdir}/fonts/type1/public/crimsonpro
%dir %{_texmfdistdir}/fonts/type1/public/cryst
%dir %{_texmfdistdir}/fonts/type1/public/cs
%dir %{_texmfdistdir}/fonts/type1/public/cyklop
%dir %{_texmfdistdir}/fonts/type1/public/dad
%dir %{_texmfdistdir}/fonts/type1/public/dantelogo
%dir %{_texmfdistdir}/fonts/type1/public/dejavu
%dir %{_texmfdistdir}/fonts/type1/public/dictsym
%dir %{_texmfdistdir}/fonts/type1/public/domitian
%dir %{_texmfdistdir}/fonts/type1/public/doublestroke
%dir %{_texmfdistdir}/fonts/type1/public/dozenal
%dir %{_texmfdistdir}/fonts/type1/public/drm
%dir %{_texmfdistdir}/fonts/type1/public/dsserif
%dir %{_texmfdistdir}/fonts/type1/public/dutchcal
%dir %{_texmfdistdir}/fonts/type1/public/ebgaramond
%dir %{_texmfdistdir}/fonts/type1/public/epigrafica
%dir %{_texmfdistdir}/fonts/type1/public/epiolmec
%dir %{_texmfdistdir}/fonts/type1/public/erewhon
%dir %{_texmfdistdir}/fonts/type1/public/esint-type1
%dir %{_texmfdistdir}/fonts/type1/public/esrelation
%dir %{_texmfdistdir}/fonts/type1/public/esstix
%dir %{_texmfdistdir}/fonts/type1/public/esvect
%dir %{_texmfdistdir}/fonts/type1/public/etbb
%dir %{_texmfdistdir}/fonts/type1/public/ethiop-t1
%dir %{_texmfdistdir}/fonts/type1/public/eurosym
%dir %{_texmfdistdir}/fonts/type1/public/fbb
%dir %{_texmfdistdir}/fonts/type1/public/fdsymbol
%dir %{_texmfdistdir}/fonts/type1/public/fetamont
%dir %{_texmfdistdir}/fonts/type1/public/fge
%dir %{_texmfdistdir}/fonts/type1/public/figbas
%dir %{_texmfdistdir}/fonts/type1/public/fira
%dir %{_texmfdistdir}/fonts/type1/public/foekfont
%dir %{_texmfdistdir}/fonts/type1/public/fonetika
%dir %{_texmfdistdir}/fonts/type1/public/fontawesome
%dir %{_texmfdistdir}/fonts/type1/public/fontawesome5
%dir %{_texmfdistdir}/fonts/type1/public/fonts-tlwg
%dir %{_texmfdistdir}/fonts/type1/public/forum
%dir %{_texmfdistdir}/fonts/type1/public/fourier
%dir %{_texmfdistdir}/fonts/type1/public/fpl
%dir %{_texmfdistdir}/fonts/type1/public/frcursive
%dir %{_texmfdistdir}/fonts/type1/public/frimurer
%dir %{_texmfdistdir}/fonts/type1/public/garamond-libre
%dir %{_texmfdistdir}/fonts/type1/public/gentium-tug
%dir %{_texmfdistdir}/fonts/type1/public/gfsartemisia
%dir %{_texmfdistdir}/fonts/type1/public/gfsbaskerville
%dir %{_texmfdistdir}/fonts/type1/public/gfsbodoni
%dir %{_texmfdistdir}/fonts/type1/public/gfscomplutum
%dir %{_texmfdistdir}/fonts/type1/public/gfsdidot
%dir %{_texmfdistdir}/fonts/type1/public/gfsneohellenic
%dir %{_texmfdistdir}/fonts/type1/public/gfsporson
%dir %{_texmfdistdir}/fonts/type1/public/gfssolomos
%dir %{_texmfdistdir}/fonts/type1/public/gudea
%dir %{_texmfdistdir}/fonts/type1/public/hacm
%dir %{_texmfdistdir}/fonts/type1/public/heuristica
%dir %{_texmfdistdir}/fonts/type1/public/hfbright
%dir %{_texmfdistdir}/fonts/type1/public/hindmadurai
%dir %{_texmfdistdir}/fonts/type1/public/ibarra
%dir %{_texmfdistdir}/fonts/type1/public/ibygrk
%dir %{_texmfdistdir}/fonts/type1/public/inconsolata
%dir %{_texmfdistdir}/fonts/type1/public/initials
%dir %{_texmfdistdir}/fonts/type1/public/inriafonts
%dir %{_texmfdistdir}/fonts/type1/public/inter
%dir %{_texmfdistdir}/fonts/type1/public/ipaex-type1
%dir %{_texmfdistdir}/fonts/type1/public/josefin
%dir %{_texmfdistdir}/fonts/type1/public/kerkis
%dir %{_texmfdistdir}/fonts/type1/public/knitting
%dir %{_texmfdistdir}/fonts/type1/public/kpfonts
%dir %{_texmfdistdir}/fonts/type1/public/libertine
%dir %{_texmfdistdir}/fonts/type1/public/libertinus-type1
%dir %{_texmfdistdir}/fonts/type1/public/libertinust1math
%dir %{_texmfdistdir}/fonts/type1/public/lineara
%dir %{_texmfdistdir}/fonts/type1/public/linguisticspro
%dir %{_texmfdistdir}/fonts/type1/public/lm
%dir %{_texmfdistdir}/fonts/type1/public/lxfonts
%dir %{_texmfdistdir}/fonts/type1/public/magra
%dir %{_texmfdistdir}/fonts/type1/public/marcellus
%dir %{_texmfdistdir}/fonts/type1/public/marvosym
%dir %{_texmfdistdir}/fonts/type1/public/mathabx-type1
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdbch
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdici
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdpgd
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdpus
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdput
%dir %{_texmfdistdir}/fonts/type1/public/mathdesign/mdugm
%dir %{_texmfdistdir}/fonts/type1/public/mathpazo
%dir %{_texmfdistdir}/fonts/type1/public/mdsymbol
%dir %{_texmfdistdir}/fonts/type1/public/miama
%dir %{_texmfdistdir}/fonts/type1/public/mlmodern
%dir %{_texmfdistdir}/fonts/type1/public/mnsymbol
%dir %{_texmfdistdir}/fonts/type1/public/montex
%dir %{_texmfdistdir}/fonts/type1/public/montserrat
%dir %{_texmfdistdir}/fonts/type1/public/musixtex-fonts
%dir %{_texmfdistdir}/fonts/type1/public/mxedruli
%dir %{_texmfdistdir}/fonts/type1/public/nanumtype1
%dir %{_texmfdistdir}/fonts/type1/public/newpx
%dir %{_texmfdistdir}/fonts/type1/public/newtx
%dir %{_texmfdistdir}/fonts/type1/public/newtxsf
%dir %{_texmfdistdir}/fonts/type1/public/newtxtt
%dir %{_texmfdistdir}/fonts/type1/public/niceframe-type1
%dir %{_texmfdistdir}/fonts/type1/public/nimbus15
%dir %{_texmfdistdir}/fonts/type1/public/notomath
%dir %{_texmfdistdir}/fonts/type1/public/nunito
%dir %{_texmfdistdir}/fonts/type1/public/ocherokee
%dir %{_texmfdistdir}/fonts/type1/public/ocr-b-outline
%dir %{_texmfdistdir}/fonts/type1/public/oinuit
%dir %{_texmfdistdir}/fonts/type1/public/old-arrows
%dir %{_texmfdistdir}/fonts/type1/public/oldstandard
%dir %{_texmfdistdir}/fonts/type1/public/omega
%dir %{_texmfdistdir}/fonts/type1/public/oswald
%dir %{_texmfdistdir}/fonts/type1/public/pdftex
%dir %{_texmfdistdir}/fonts/type1/public/phaistos
%dir %{_texmfdistdir}/fonts/type1/public/pigpen
%dir %{_texmfdistdir}/fonts/type1/public/pl
%dir %{_texmfdistdir}/fonts/type1/public/playfair
%dir %{_texmfdistdir}/fonts/type1/public/plimsoll
%dir %{_texmfdistdir}/fonts/type1/public/poiretone
%dir %{_texmfdistdir}/fonts/type1/public/prodint
%dir %{_texmfdistdir}/fonts/type1/public/pxfonts
%dir %{_texmfdistdir}/fonts/type1/public/recycle
%dir %{_texmfdistdir}/fonts/type1/public/rojud
%dir %{_texmfdistdir}/fonts/type1/public/rosario
%dir %{_texmfdistdir}/fonts/type1/public/rsfs
%dir %{_texmfdistdir}/fonts/type1/public/sanskrit-t1
%dir %{_texmfdistdir}/fonts/type1/public/sansmathfonts
%dir %{_texmfdistdir}/fonts/type1/public/scanpages
%dir %{_texmfdistdir}/fonts/type1/public/scholax
%dir %{_texmfdistdir}/fonts/type1/public/semaphor
%dir %{_texmfdistdir}/fonts/type1/public/simpleicons
%dir %{_texmfdistdir}/fonts/type1/public/skaknew
%dir %{_texmfdistdir}/fonts/type1/public/starfont
%dir %{_texmfdistdir}/fonts/type1/public/staves
%dir %{_texmfdistdir}/fonts/type1/public/step
%dir %{_texmfdistdir}/fonts/type1/public/stepgreek
%dir %{_texmfdistdir}/fonts/type1/public/stickstoo
%dir %{_texmfdistdir}/fonts/type1/public/stix
%dir %{_texmfdistdir}/fonts/type1/public/stix2-type1
%dir %{_texmfdistdir}/fonts/type1/public/stmaryrd
%dir %{_texmfdistdir}/fonts/type1/public/superiors
%dir %{_texmfdistdir}/fonts/type1/public/svrsymbols
%dir %{_texmfdistdir}/fonts/type1/public/tabvar
%dir %{_texmfdistdir}/fonts/type1/public/tapir
%dir %{_texmfdistdir}/fonts/type1/public/tempora
%dir %{_texmfdistdir}/fonts/type1/public/tex-gyre
%dir %{_texmfdistdir}/fonts/type1/public/tfrupee
%dir %{_texmfdistdir}/fonts/type1/public/theanodidot
%dir %{_texmfdistdir}/fonts/type1/public/theanomodern
%dir %{_texmfdistdir}/fonts/type1/public/theanooldstyle
%dir %{_texmfdistdir}/fonts/type1/public/tipa
%dir %{_texmfdistdir}/fonts/type1/public/trajan
%dir %{_texmfdistdir}/fonts/type1/public/txfonts
%dir %{_texmfdistdir}/fonts/type1/public/txfontsb
%dir %{_texmfdistdir}/fonts/type1/public/txuprcal
%dir %{_texmfdistdir}/fonts/type1/public/velthuis
%dir %{_texmfdistdir}/fonts/type1/public/wasy-type1
%dir %{_texmfdistdir}/fonts/type1/public/xcharter
%dir %{_texmfdistdir}/fonts/type1/public/xypic
%dir %{_texmfdistdir}/fonts/type1/public/yfonts-t1
%dir %{_texmfdistdir}/fonts/type1/public/yhmath
%dir %{_texmfdistdir}/fonts/type1/rozynski
%dir %{_texmfdistdir}/fonts/type1/rozynski/comicneue
%dir %{_texmfdistdir}/fonts/type1/sorkin
%dir %{_texmfdistdir}/fonts/type1/sorkin/merriweather
%dir %{_texmfdistdir}/fonts/type1/tipo
%dir %{_texmfdistdir}/fonts/type1/tipo/overlock
%dir %{_texmfdistdir}/fonts/type1/typoland
%dir %{_texmfdistdir}/fonts/type1/typoland/lato
%dir %{_texmfdistdir}/fonts/type1/uhc
%dir %{_texmfdistdir}/fonts/type1/uhc/umj
%dir %{_texmfdistdir}/fonts/type1/urw
%dir %{_texmfdistdir}/fonts/type1/urw/antiqua
%dir %{_texmfdistdir}/fonts/type1/urw/avantgar
%dir %{_texmfdistdir}/fonts/type1/urw/bookman
%dir %{_texmfdistdir}/fonts/type1/urw/courier
%dir %{_texmfdistdir}/fonts/type1/urw/grotesq
%dir %{_texmfdistdir}/fonts/type1/urw/helvetic
%dir %{_texmfdistdir}/fonts/type1/urw/ncntrsbk
%dir %{_texmfdistdir}/fonts/type1/urw/palatino
%dir %{_texmfdistdir}/fonts/type1/urw/symbol
%dir %{_texmfdistdir}/fonts/type1/urw/times
%dir %{_texmfdistdir}/fonts/type1/urw/zapfchan
%dir %{_texmfdistdir}/fonts/type1/urw/zapfding
%dir %{_texmfdistdir}/fonts/type1/vntex
%dir %{_texmfdistdir}/fonts/type1/vntex/arevvn
%dir %{_texmfdistdir}/fonts/type1/vntex/chartervn
%dir %{_texmfdistdir}/fonts/type1/vntex/cmbrightvn
%dir %{_texmfdistdir}/fonts/type1/vntex/concretevn
%dir %{_texmfdistdir}/fonts/type1/vntex/grotesqvn
%dir %{_texmfdistdir}/fonts/type1/vntex/txttvn
%dir %{_texmfdistdir}/fonts/type1/vntex/urwvn
%dir %{_texmfdistdir}/fonts/type1/vntex/vnr
%dir %{_texmfdistdir}/fonts/type1/vntex/vntopia
%dir %{_texmfdistdir}/fonts/type1/wadalab
%dir %{_texmfdistdir}/fonts/type1/wadalab/dgj
%dir %{_texmfdistdir}/fonts/type1/wadalab/dmj
%dir %{_texmfdistdir}/fonts/type1/wadalab/mc2j
%dir %{_texmfdistdir}/fonts/type1/wadalab/mcj
%dir %{_texmfdistdir}/fonts/type1/wadalab/mr2j
%dir %{_texmfdistdir}/fonts/type1/wadalab/mrj
%dir %{_texmfdistdir}/fonts/type3
%dir %{_texmfdistdir}/fonts/type3/mpfonts
%dir %{_texmfdistdir}/fonts/vf
%dir %{_texmfdistdir}/fonts/vf/SIL
%dir %{_texmfdistdir}/fonts/vf/SIL/andika
%dir %{_texmfdistdir}/fonts/vf/SIL/charissil
%dir %{_texmfdistdir}/fonts/vf/aajohan
%dir %{_texmfdistdir}/fonts/vf/aajohan/comfortaa
%dir %{_texmfdistdir}/fonts/vf/adobe
%dir %{_texmfdistdir}/fonts/vf/adobe/avantgar
%dir %{_texmfdistdir}/fonts/vf/adobe/bookman
%dir %{_texmfdistdir}/fonts/vf/adobe/courier
%dir %{_texmfdistdir}/fonts/vf/adobe/helvetic
%dir %{_texmfdistdir}/fonts/vf/adobe/ly1
%dir %{_texmfdistdir}/fonts/vf/adobe/ncntrsbk
%dir %{_texmfdistdir}/fonts/vf/adobe/palatino
%dir %{_texmfdistdir}/fonts/vf/adobe/sourcecodepro
%dir %{_texmfdistdir}/fonts/vf/adobe/sourcesanspro
%dir %{_texmfdistdir}/fonts/vf/adobe/sourceserifpro
%dir %{_texmfdistdir}/fonts/vf/adobe/times
%dir %{_texmfdistdir}/fonts/vf/adobe/utopia
%dir %{_texmfdistdir}/fonts/vf/adobe/zapfchan
%dir %{_texmfdistdir}/fonts/vf/arkandis
%dir %{_texmfdistdir}/fonts/vf/arkandis/accanthis
%dir %{_texmfdistdir}/fonts/vf/arkandis/baskervald
%dir %{_texmfdistdir}/fonts/vf/arkandis/electrum
%dir %{_texmfdistdir}/fonts/vf/arkandis/gillius
%dir %{_texmfdistdir}/fonts/vf/arkandis/libris
%dir %{_texmfdistdir}/fonts/vf/arkandis/mintspirit
%dir %{_texmfdistdir}/fonts/vf/arkandis/romande
%dir %{_texmfdistdir}/fonts/vf/arkandis/universalis
%dir %{_texmfdistdir}/fonts/vf/arkandis/venturis
%dir %{_texmfdistdir}/fonts/vf/arkandis/venturis2
%dir %{_texmfdistdir}/fonts/vf/arkandis/venturisold
%dir %{_texmfdistdir}/fonts/vf/arkandis/venturissans
%dir %{_texmfdistdir}/fonts/vf/arkandis/venturissans2
%dir %{_texmfdistdir}/fonts/vf/arphic
%dir %{_texmfdistdir}/fonts/vf/arphic/bkaimp
%dir %{_texmfdistdir}/fonts/vf/arphic/bsmilp
%dir %{_texmfdistdir}/fonts/vf/arphic/gbsnlp
%dir %{_texmfdistdir}/fonts/vf/arphic/gkaimp
%dir %{_texmfdistdir}/fonts/vf/ascender
%dir %{_texmfdistdir}/fonts/vf/ascender/droid
%dir %{_texmfdistdir}/fonts/vf/ascender/droid/droidsans
%dir %{_texmfdistdir}/fonts/vf/ascender/droid/droidsansmono
%dir %{_texmfdistdir}/fonts/vf/ascender/droid/droidserif
%dir %{_texmfdistdir}/fonts/vf/ascender/opensans
%dir %{_texmfdistdir}/fonts/vf/bh
%dir %{_texmfdistdir}/fonts/vf/bh/gofonts
%dir %{_texmfdistdir}/fonts/vf/bitstrea
%dir %{_texmfdistdir}/fonts/vf/bitstrea/charter
%dir %{_texmfdistdir}/fonts/vf/catharsis
%dir %{_texmfdistdir}/fonts/vf/catharsis/cormorantgaramond
%dir %{_texmfdistdir}/fonts/vf/cs
%dir %{_texmfdistdir}/fonts/vf/cs/cs-a35
%dir %{_texmfdistdir}/fonts/vf/cs/cs-charter
%dir %{_texmfdistdir}/fonts/vf/gnome
%dir %{_texmfdistdir}/fonts/vf/gnome/cantarell
%dir %{_texmfdistdir}/fonts/vf/google
%dir %{_texmfdistdir}/fonts/vf/google/arimo
%dir %{_texmfdistdir}/fonts/vf/google/carlito
%dir %{_texmfdistdir}/fonts/vf/google/noto
%dir %{_texmfdistdir}/fonts/vf/google/roboto
%dir %{_texmfdistdir}/fonts/vf/google/tinos
%dir %{_texmfdistdir}/fonts/vf/huerta
%dir %{_texmfdistdir}/fonts/vf/huerta/alegreya
%dir %{_texmfdistdir}/fonts/vf/huerta/bitter
%dir %{_texmfdistdir}/fonts/vf/huerta/caladea
%dir %{_texmfdistdir}/fonts/vf/ibm
%dir %{_texmfdistdir}/fonts/vf/ibm/plex
%dir %{_texmfdistdir}/fonts/vf/iginomarini
%dir %{_texmfdistdir}/fonts/vf/iginomarini/imfellenglish
%dir %{_texmfdistdir}/fonts/vf/impallari
%dir %{_texmfdistdir}/fonts/vf/impallari/cabin
%dir %{_texmfdistdir}/fonts/vf/impallari/librebaskerville
%dir %{_texmfdistdir}/fonts/vf/impallari/librebodoni
%dir %{_texmfdistdir}/fonts/vf/impallari/librecaslon
%dir %{_texmfdistdir}/fonts/vf/impallari/librefranklin
%dir %{_texmfdistdir}/fonts/vf/impallari/lobster2
%dir %{_texmfdistdir}/fonts/vf/impallari/quattrocento
%dir %{_texmfdistdir}/fonts/vf/impallari/raleway
%dir %{_texmfdistdir}/fonts/vf/intel
%dir %{_texmfdistdir}/fonts/vf/intel/clearsans
%dir %{_texmfdistdir}/fonts/vf/kosch
%dir %{_texmfdistdir}/fonts/vf/kosch/crimson
%dir %{_texmfdistdir}/fonts/vf/monotype
%dir %{_texmfdistdir}/fonts/vf/monotype/helvetic
%dir %{_texmfdistdir}/fonts/vf/ndiscovered
%dir %{_texmfdistdir}/fonts/vf/ndiscovered/cinzel
%dir %{_texmfdistdir}/fonts/vf/paratype
%dir %{_texmfdistdir}/fonts/vf/paratype/ptmono
%dir %{_texmfdistdir}/fonts/vf/paratype/ptsans
%dir %{_texmfdistdir}/fonts/vf/paratype/ptserif
%dir %{_texmfdistdir}/fonts/vf/production
%dir %{_texmfdistdir}/fonts/vf/production/spectral
%dir %{_texmfdistdir}/fonts/vf/ptex-fonts
%dir %{_texmfdistdir}/fonts/vf/ptex-fonts/jis
%dir %{_texmfdistdir}/fonts/vf/ptex-fonts/nmin-ngoth
%dir %{_texmfdistdir}/fonts/vf/ptex-fonts/standard
%dir %{_texmfdistdir}/fonts/vf/public
%dir %{_texmfdistdir}/fonts/vf/public/ae
%dir %{_texmfdistdir}/fonts/vf/public/alfaslabone
%dir %{_texmfdistdir}/fonts/vf/public/algolrevived
%dir %{_texmfdistdir}/fonts/vf/public/almendra
%dir %{_texmfdistdir}/fonts/vf/public/anonymouspro
%dir %{_texmfdistdir}/fonts/vf/public/archivo
%dir %{_texmfdistdir}/fonts/vf/public/arev
%dir %{_texmfdistdir}/fonts/vf/public/arvo
%dir %{_texmfdistdir}/fonts/vf/public/atkinson
%dir %{_texmfdistdir}/fonts/vf/public/augie
%dir %{_texmfdistdir}/fonts/vf/public/baskervaldx
%dir %{_texmfdistdir}/fonts/vf/public/baskervillef
%dir %{_texmfdistdir}/fonts/vf/public/bera
%dir %{_texmfdistdir}/fonts/vf/public/blacklettert1
%dir %{_texmfdistdir}/fonts/vf/public/boondox
%dir %{_texmfdistdir}/fonts/vf/public/brushscr
%dir %{_texmfdistdir}/fonts/vf/public/cascadia-code
%dir %{_texmfdistdir}/fonts/vf/public/cfr-lm
%dir %{_texmfdistdir}/fonts/vf/public/chivo
%dir %{_texmfdistdir}/fonts/vf/public/cjhebrew
%dir %{_texmfdistdir}/fonts/vf/public/clara
%dir %{_texmfdistdir}/fonts/vf/public/cm-lgc
%dir %{_texmfdistdir}/fonts/vf/public/cmathbb
%dir %{_texmfdistdir}/fonts/vf/public/cmcyr
%dir %{_texmfdistdir}/fonts/vf/public/cmsrb
%dir %{_texmfdistdir}/fonts/vf/public/cmtiup
%dir %{_texmfdistdir}/fonts/vf/public/cochineal
%dir %{_texmfdistdir}/fonts/vf/public/coelacanth
%dir %{_texmfdistdir}/fonts/vf/public/cooperhewitt
%dir %{_texmfdistdir}/fonts/vf/public/courierten
%dir %{_texmfdistdir}/fonts/vf/public/crimsonpro
%dir %{_texmfdistdir}/fonts/vf/public/dantelogo
%dir %{_texmfdistdir}/fonts/vf/public/dejavu
%dir %{_texmfdistdir}/fonts/vf/public/domitian
%dir %{_texmfdistdir}/fonts/vf/public/dutchcal
%dir %{_texmfdistdir}/fonts/vf/public/ebgaramond
%dir %{_texmfdistdir}/fonts/vf/public/eco
%dir %{_texmfdistdir}/fonts/vf/public/epigrafica
%dir %{_texmfdistdir}/fonts/vf/public/erewhon
%dir %{_texmfdistdir}/fonts/vf/public/esstix
%dir %{_texmfdistdir}/fonts/vf/public/etbb
%dir %{_texmfdistdir}/fonts/vf/public/eulervm
%dir %{_texmfdistdir}/fonts/vf/public/fbb
%dir %{_texmfdistdir}/fonts/vf/public/fira
%dir %{_texmfdistdir}/fonts/vf/public/fonts-tlwg
%dir %{_texmfdistdir}/fonts/vf/public/forum
%dir %{_texmfdistdir}/fonts/vf/public/fourier
%dir %{_texmfdistdir}/fonts/vf/public/fouriernc
%dir %{_texmfdistdir}/fonts/vf/public/garamond-libre
%dir %{_texmfdistdir}/fonts/vf/public/gfsartemisia
%dir %{_texmfdistdir}/fonts/vf/public/gfsbaskerville
%dir %{_texmfdistdir}/fonts/vf/public/gfsbodoni
%dir %{_texmfdistdir}/fonts/vf/public/gfscomplutum
%dir %{_texmfdistdir}/fonts/vf/public/gfsdidot
%dir %{_texmfdistdir}/fonts/vf/public/gfsneohellenic
%dir %{_texmfdistdir}/fonts/vf/public/gfsporson
%dir %{_texmfdistdir}/fonts/vf/public/gfssolomos
%dir %{_texmfdistdir}/fonts/vf/public/gillcm
%dir %{_texmfdistdir}/fonts/vf/public/gudea
%dir %{_texmfdistdir}/fonts/vf/public/hacm
%dir %{_texmfdistdir}/fonts/vf/public/heuristica
%dir %{_texmfdistdir}/fonts/vf/public/hfoldsty
%dir %{_texmfdistdir}/fonts/vf/public/hindmadurai
%dir %{_texmfdistdir}/fonts/vf/public/ibarra
%dir %{_texmfdistdir}/fonts/vf/public/inriafonts
%dir %{_texmfdistdir}/fonts/vf/public/inter
%dir %{_texmfdistdir}/fonts/vf/public/jamtimes
%dir %{_texmfdistdir}/fonts/vf/public/japanese-otf
%dir %{_texmfdistdir}/fonts/vf/public/jlreq
%dir %{_texmfdistdir}/fonts/vf/public/jlreq-deluxe
%dir %{_texmfdistdir}/fonts/vf/public/josefin
%dir %{_texmfdistdir}/fonts/vf/public/junicode
%dir %{_texmfdistdir}/fonts/vf/public/kerkis
%dir %{_texmfdistdir}/fonts/vf/public/kpfonts
%dir %{_texmfdistdir}/fonts/vf/public/libertine
%dir %{_texmfdistdir}/fonts/vf/public/libertinus-type1
%dir %{_texmfdistdir}/fonts/vf/public/libertinust1math
%dir %{_texmfdistdir}/fonts/vf/public/linguisticspro
%dir %{_texmfdistdir}/fonts/vf/public/magra
%dir %{_texmfdistdir}/fonts/vf/public/marcellus
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdbch
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdgreek
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdici
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdpgd
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdpus
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdput
%dir %{_texmfdistdir}/fonts/vf/public/mathdesign/mdugm
%dir %{_texmfdistdir}/fonts/vf/public/mathpazo
%dir %{_texmfdistdir}/fonts/vf/public/mdputu
%dir %{_texmfdistdir}/fonts/vf/public/montserrat
%dir %{_texmfdistdir}/fonts/vf/public/morisawa
%dir %{_texmfdistdir}/fonts/vf/public/nanumtype1
%dir %{_texmfdistdir}/fonts/vf/public/newpx
%dir %{_texmfdistdir}/fonts/vf/public/newtx
%dir %{_texmfdistdir}/fonts/vf/public/newtxsf
%dir %{_texmfdistdir}/fonts/vf/public/nimbus15
%dir %{_texmfdistdir}/fonts/vf/public/notomath
%dir %{_texmfdistdir}/fonts/vf/public/nunito
%dir %{_texmfdistdir}/fonts/vf/public/oldstandard
%dir %{_texmfdistdir}/fonts/vf/public/oswald
%dir %{_texmfdistdir}/fonts/vf/public/playfair
%dir %{_texmfdistdir}/fonts/vf/public/poiretone
%dir %{_texmfdistdir}/fonts/vf/public/pslatex
%dir %{_texmfdistdir}/fonts/vf/public/pxchfon
%dir %{_texmfdistdir}/fonts/vf/public/pxfonts
%dir %{_texmfdistdir}/fonts/vf/public/pxjodel
%dir %{_texmfdistdir}/fonts/vf/public/pxtxalfa
%dir %{_texmfdistdir}/fonts/vf/public/pxufont
%dir %{_texmfdistdir}/fonts/vf/public/qpxqtx
%dir %{_texmfdistdir}/fonts/vf/public/relenc
%dir %{_texmfdistdir}/fonts/vf/public/rosario
%dir %{_texmfdistdir}/fonts/vf/public/rsfso
%dir %{_texmfdistdir}/fonts/vf/public/sansmathaccent
%dir %{_texmfdistdir}/fonts/vf/public/sansmathfonts
%dir %{_texmfdistdir}/fonts/vf/public/scholax
%dir %{_texmfdistdir}/fonts/vf/public/srbtiks
%dir %{_texmfdistdir}/fonts/vf/public/step
%dir %{_texmfdistdir}/fonts/vf/public/stepgreek
%dir %{_texmfdistdir}/fonts/vf/public/stickstoo
%dir %{_texmfdistdir}/fonts/vf/public/stix
%dir %{_texmfdistdir}/fonts/vf/public/tempora
%dir %{_texmfdistdir}/fonts/vf/public/tengwarscript
%dir %{_texmfdistdir}/fonts/vf/public/theanodidot
%dir %{_texmfdistdir}/fonts/vf/public/theanomodern
%dir %{_texmfdistdir}/fonts/vf/public/theanooldstyle
%dir %{_texmfdistdir}/fonts/vf/public/txfonts
%dir %{_texmfdistdir}/fonts/vf/public/txfontsb
%dir %{_texmfdistdir}/fonts/vf/public/uppunctlm
%dir %{_texmfdistdir}/fonts/vf/public/xcharter
%dir %{_texmfdistdir}/fonts/vf/public/yhmath
%dir %{_texmfdistdir}/fonts/vf/public/zhmetrics-uptex
%dir %{_texmfdistdir}/fonts/vf/rozynski
%dir %{_texmfdistdir}/fonts/vf/rozynski/comicneue
%dir %{_texmfdistdir}/fonts/vf/sorkin
%dir %{_texmfdistdir}/fonts/vf/sorkin/merriweather
%dir %{_texmfdistdir}/fonts/vf/tipo
%dir %{_texmfdistdir}/fonts/vf/tipo/overlock
%dir %{_texmfdistdir}/fonts/vf/typoland
%dir %{_texmfdistdir}/fonts/vf/typoland/lato
%dir %{_texmfdistdir}/fonts/vf/uhc
%dir %{_texmfdistdir}/fonts/vf/uhc/uwmj
%dir %{_texmfdistdir}/fonts/vf/uhc/wmj
%dir %{_texmfdistdir}/fonts/vf/uptex-fonts
%dir %{_texmfdistdir}/fonts/vf/uptex-fonts/jis
%dir %{_texmfdistdir}/fonts/vf/uptex-fonts/min
%dir %{_texmfdistdir}/fonts/vf/urw
%dir %{_texmfdistdir}/fonts/vf/urw/antiqua
%dir %{_texmfdistdir}/fonts/vf/urw/grotesq
%dir %{_texmfdistdir}/fonts/vf/urw/urwchancal
%dir %{_texmfdistdir}/fonts/vf/urw35vf
%dir %{_texmfdistdir}/fonts/vf/urw35vf/avantgar
%dir %{_texmfdistdir}/fonts/vf/urw35vf/bookman
%dir %{_texmfdistdir}/fonts/vf/urw35vf/courier
%dir %{_texmfdistdir}/fonts/vf/urw35vf/helvetic
%dir %{_texmfdistdir}/fonts/vf/urw35vf/ncntrsbk
%dir %{_texmfdistdir}/fonts/vf/urw35vf/palatino
%dir %{_texmfdistdir}/fonts/vf/urw35vf/times
%dir %{_texmfdistdir}/fonts/vf/urw35vf/zapfchan
%dir %{_texmfdistdir}/fonts/vf/vntex
%dir %{_texmfdistdir}/fonts/vf/vntex/chartervn
%dir %{_texmfdistdir}/fonts/vf/vntex/urwvn
%dir %{_texmfdistdir}/fonts/vf/vntex/vntopia
%dir %{_texmfdistdir}/fonts/vf/wadalab
%dir %{_texmfdistdir}/fonts/vf/wadalab/udgj
%dir %{_texmfdistdir}/fonts/vf/wadalab/udmj
%dir %{_texmfdistdir}/fonts/vf/wadalab/umcj
%dir %{_texmfdistdir}/fonts/vf/wadalab/umrj
%dir %{_texmfdistdir}/hbf2gf
%dir %{_texmfdistdir}/makeindex
%dir %{_texmfdistdir}/makeindex/babel
%dir %{_texmfdistdir}/makeindex/base
%dir %{_texmfdistdir}/makeindex/bgteubner
%dir %{_texmfdistdir}/makeindex/biblatex-sbl
%dir %{_texmfdistdir}/makeindex/cnbwp
%dir %{_texmfdistdir}/makeindex/cnltx
%dir %{_texmfdistdir}/makeindex/confproc
%dir %{_texmfdistdir}/makeindex/disser
%dir %{_texmfdistdir}/makeindex/e-french
%dir %{_texmfdistdir}/makeindex/fixlatvian
%dir %{_texmfdistdir}/makeindex/forest
%dir %{_texmfdistdir}/makeindex/gindex
%dir %{_texmfdistdir}/makeindex/gmdoc
%dir %{_texmfdistdir}/makeindex/hitex
%dir %{_texmfdistdir}/makeindex/hithesis
%dir %{_texmfdistdir}/makeindex/hitszthesis
%dir %{_texmfdistdir}/makeindex/index
%dir %{_texmfdistdir}/makeindex/iso
%dir %{_texmfdistdir}/makeindex/juraabbrev
%dir %{_texmfdistdir}/makeindex/kotex-utils
%dir %{_texmfdistdir}/makeindex/latex
%dir %{_texmfdistdir}/makeindex/leipzig
%dir %{_texmfdistdir}/makeindex/memoir
%dir %{_texmfdistdir}/makeindex/mendex-doc
%dir %{_texmfdistdir}/makeindex/mkgrkindex
%dir %{_texmfdistdir}/makeindex/multibib
%dir %{_texmfdistdir}/makeindex/nomencl
%dir %{_texmfdistdir}/makeindex/nomentbl
%dir %{_texmfdistdir}/makeindex/nostarch
%dir %{_texmfdistdir}/makeindex/oscola
%dir %{_texmfdistdir}/makeindex/plain
%dir %{_texmfdistdir}/makeindex/pst-optexp
%dir %{_texmfdistdir}/makeindex/repeatindex
%dir %{_texmfdistdir}/makeindex/songbook
%dir %{_texmfdistdir}/makeindex/startex
%dir %{_texmfdistdir}/makeindex/tikzpingus
%dir %{_texmfdistdir}/makeindex/xdoc
%dir %{_texmfdistdir}/metafont
%dir %{_texmfdistdir}/metafont/base
%dir %{_texmfdistdir}/metafont/config
%dir %{_texmfdistdir}/metafont/feynmf
%dir %{_texmfdistdir}/metafont/mflua
%dir %{_texmfdistdir}/metafont/mfpic
%dir %{_texmfdistdir}/metafont/misc
%dir %{_texmfdistdir}/metafont/roex
%dir %{_texmfdistdir}/metapost
%dir %{_texmfdistdir}/metapost/automata
%dir %{_texmfdistdir}/metapost/base
%dir %{_texmfdistdir}/metapost/bbcard
%dir %{_texmfdistdir}/metapost/bclogo
%dir %{_texmfdistdir}/metapost/blockdraw_mp
%dir %{_texmfdistdir}/metapost/bpolynomial
%dir %{_texmfdistdir}/metapost/byrne
%dir %{_texmfdistdir}/metapost/cmarrows
%dir %{_texmfdistdir}/metapost/config
%dir %{_texmfdistdir}/metapost/context
%dir %{_texmfdistdir}/metapost/context/base
%dir %{_texmfdistdir}/metapost/context/base/common
%dir %{_texmfdistdir}/metapost/context/base/mpiv
%dir %{_texmfdistdir}/metapost/context/base/mpxl
%dir %{_texmfdistdir}/metapost/context/fonts
%dir %{_texmfdistdir}/metapost/context/fonts/mpiv
%dir %{_texmfdistdir}/metapost/context/third
%dir %{_texmfdistdir}/metapost/context/third/gnuplot
%dir %{_texmfdistdir}/metapost/drv
%dir %{_texmfdistdir}/metapost/dviincl
%dir %{_texmfdistdir}/metapost/epsincl
%dir %{_texmfdistdir}/metapost/expressg
%dir %{_texmfdistdir}/metapost/exteps
%dir %{_texmfdistdir}/metapost/featpost
%dir %{_texmfdistdir}/metapost/fetamont
%dir %{_texmfdistdir}/metapost/feynmf
%dir %{_texmfdistdir}/metapost/fiziko
%dir %{_texmfdistdir}/metapost/garrigues
%dir %{_texmfdistdir}/metapost/hatching
%dir %{_texmfdistdir}/metapost/hershey-mp
%dir %{_texmfdistdir}/metapost/latexmp
%dir %{_texmfdistdir}/metapost/luamesh
%dir %{_texmfdistdir}/metapost/makecirc
%dir %{_texmfdistdir}/metapost/metago
%dir %{_texmfdistdir}/metapost/metaobj
%dir %{_texmfdistdir}/metapost/metaplot
%dir %{_texmfdistdir}/metapost/metapost-colorbrewer
%dir %{_texmfdistdir}/metapost/metauml
%dir %{_texmfdistdir}/metapost/mf2pt1
%dir %{_texmfdistdir}/metapost/mfpic
%dir %{_texmfdistdir}/metapost/minim-hatching
%dir %{_texmfdistdir}/metapost/minim-mp
%dir %{_texmfdistdir}/metapost/misc
%dir %{_texmfdistdir}/metapost/mp3d
%dir %{_texmfdistdir}/metapost/mparrows
%dir %{_texmfdistdir}/metapost/mpattern
%dir %{_texmfdistdir}/metapost/mpcolornames
%dir %{_texmfdistdir}/metapost/mptrees
%dir %{_texmfdistdir}/metapost/nkarta
%dir %{_texmfdistdir}/metapost/piechartmp
%dir %{_texmfdistdir}/metapost/profcollege
%dir %{_texmfdistdir}/metapost/repere
%dir %{_texmfdistdir}/metapost/roundrect
%dir %{_texmfdistdir}/metapost/shapes
%dir %{_texmfdistdir}/metapost/slideshow
%dir %{_texmfdistdir}/metapost/splines
%dir %{_texmfdistdir}/metapost/suanpan
%dir %{_texmfdistdir}/metapost/support
%dir %{_texmfdistdir}/metapost/support/charlib
%dir %{_texmfdistdir}/metapost/tabvar
%dir %{_texmfdistdir}/metapost/textpath
%dir %{_texmfdistdir}/metapost/threeddice
%dir %{_texmfdistdir}/metapost/venn
%dir %{_texmfdistdir}/mft
%dir %{_texmfdistdir}/mft/base
%dir %{_texmfdistdir}/mft/knuth-local
%dir %{_texmfdistdir}/omega
%dir %{_texmfdistdir}/omega/ocp
%dir %{_texmfdistdir}/omega/ocp/antomega
%dir %{_texmfdistdir}/omega/ocp/antomega/latin
%dir %{_texmfdistdir}/omega/ocp/char2uni
%dir %{_texmfdistdir}/omega/ocp/ethiop
%dir %{_texmfdistdir}/omega/ocp/misc
%dir %{_texmfdistdir}/omega/ocp/ocherokee
%dir %{_texmfdistdir}/omega/ocp/oinuit
%dir %{_texmfdistdir}/omega/ocp/omega
%dir %{_texmfdistdir}/omega/ocp/otibet
%dir %{_texmfdistdir}/omega/ocp/uni2char
%dir %{_texmfdistdir}/omega/otp
%dir %{_texmfdistdir}/omega/otp/antomega
%dir %{_texmfdistdir}/omega/otp/antomega/latin
%dir %{_texmfdistdir}/omega/otp/char2uni
%dir %{_texmfdistdir}/omega/otp/ethiop
%dir %{_texmfdistdir}/omega/otp/misc
%dir %{_texmfdistdir}/omega/otp/ocherokee
%dir %{_texmfdistdir}/omega/otp/oinuit
%dir %{_texmfdistdir}/omega/otp/omega
%dir %{_texmfdistdir}/omega/otp/otibet
%dir %{_texmfdistdir}/omega/otp/uni2char
%dir %{_texmfdistdir}/pbibtex
%dir %{_texmfdistdir}/pbibtex/bib
%dir %{_texmfdistdir}/pbibtex/bst
%dir %{_texmfdistdir}/scripts
%dir %{_texmfdistdir}/scripts/a2ping
%dir %{_texmfdistdir}/scripts/accfonts
%dir %{_texmfdistdir}/scripts/adhocfilelist
%dir %{_texmfdistdir}/scripts/albatross
%dir %{_texmfdistdir}/scripts/arara
%dir %{_texmfdistdir}/scripts/arara/rules
%dir %{_texmfdistdir}/scripts/attachfile2
%dir %{_texmfdistdir}/scripts/authorindex
%dir %{_texmfdistdir}/scripts/barracuda
%dir %{_texmfdistdir}/scripts/barracuda/lib-barcode
%dir %{_texmfdistdir}/scripts/barracuda/lib-driver
%dir %{_texmfdistdir}/scripts/barracuda/lib-geo
%dir %{_texmfdistdir}/scripts/bib2gls
%dir %{_texmfdistdir}/scripts/bib2gls/resources
%dir %{_texmfdistdir}/scripts/bibcop
%dir %{_texmfdistdir}/scripts/bibexport
%dir %{_texmfdistdir}/scripts/bibtexperllibs
%dir %{_texmfdistdir}/scripts/bibtexperllibs/BibTeX
%dir %{_texmfdistdir}/scripts/bibtexperllibs/BibTeX/Parser
%dir %{_texmfdistdir}/scripts/bibtexperllibs/LaTeX
%dir %{_texmfdistdir}/scripts/bibtexperllibs/LaTeX/ToUnicode
%dir %{_texmfdistdir}/scripts/bundledoc
%dir %{_texmfdistdir}/scripts/cachepic
%dir %{_texmfdistdir}/scripts/changes
%dir %{_texmfdistdir}/scripts/checkcites
%dir %{_texmfdistdir}/scripts/checklistings
%dir %{_texmfdistdir}/scripts/chklref
%dir %{_texmfdistdir}/scripts/chktex
%dir %{_texmfdistdir}/scripts/citation-style-language
%dir %{_texmfdistdir}/scripts/cjk-gs-integrate
%dir %{_texmfdistdir}/scripts/clojure-pamphlet
%dir %{_texmfdistdir}/scripts/cloze
%dir %{_texmfdistdir}/scripts/cluttex
%dir %{_texmfdistdir}/scripts/context
%dir %{_texmfdistdir}/scripts/context/lua
%dir %{_texmfdistdir}/scripts/context/lua/third
%dir %{_texmfdistdir}/scripts/context/lua/third/enigma
%dir %{_texmfdistdir}/scripts/context/lua/third/enigma/mtx-t-enigma.lua
%dir %{_texmfdistdir}/scripts/context/lua/third/rst
%dir %{_texmfdistdir}/scripts/context/lua/third/simpleslides
%dir %{_texmfdistdir}/scripts/context/lua/third/transliterator
%dir %{_texmfdistdir}/scripts/context/perl
%dir %{_texmfdistdir}/scripts/convbkmk
%dir %{_texmfdistdir}/scripts/crossrefware
%dir %{_texmfdistdir}/scripts/ctan-o-mat
%dir %{_texmfdistdir}/scripts/ctanbib
%dir %{_texmfdistdir}/scripts/ctanify
%dir %{_texmfdistdir}/scripts/ctanupload
%dir %{_texmfdistdir}/scripts/de-macro
%dir %{_texmfdistdir}/scripts/diadia
%dir %{_texmfdistdir}/scripts/digestif
%dir %{_texmfdistdir}/scripts/dosepsbin
%dir %{_texmfdistdir}/scripts/dtxgen
%dir %{_texmfdistdir}/scripts/dviasm
%dir %{_texmfdistdir}/scripts/dviinfox
%dir %{_texmfdistdir}/scripts/epspdf
%dir %{_texmfdistdir}/scripts/epstopdf
%dir %{_texmfdistdir}/scripts/exceltex
%dir %{_texmfdistdir}/scripts/fig4latex
%dir %{_texmfdistdir}/scripts/findhyph
%dir %{_texmfdistdir}/scripts/flowfram
%dir %{_texmfdistdir}/scripts/fmtcount
%dir %{_texmfdistdir}/scripts/fontools
%dir %{_texmfdistdir}/scripts/fragmaster
%dir %{_texmfdistdir}/scripts/getmap
%dir %{_texmfdistdir}/scripts/git-latexdiff
%dir %{_texmfdistdir}/scripts/glossaries
%dir %{_texmfdistdir}/scripts/gregoriotex
%dir %{_texmfdistdir}/scripts/hyperxmp
%dir %{_texmfdistdir}/scripts/jfmutil
%dir %{_texmfdistdir}/scripts/ketcindy
%dir %{_texmfdistdir}/scripts/ketcindy/data
%dir %{_texmfdistdir}/scripts/ketcindy/data/fontF
%dir %{_texmfdistdir}/scripts/ketcindy/data/polyhedrons_obj
%dir %{_texmfdistdir}/scripts/ketcindy/ketjava
%dir %{_texmfdistdir}/scripts/ketcindy/ketlib
%dir %{_texmfdistdir}/scripts/ketcindy/ketlib/ketpicR
%dir %{_texmfdistdir}/scripts/ketcindy/ketlib/maximaL
%dir %{_texmfdistdir}/scripts/ketcindy/ketlib/oshima
%dir %{_texmfdistdir}/scripts/ketcindy/ketlibC
%dir %{_texmfdistdir}/scripts/kotex-utils
%dir %{_texmfdistdir}/scripts/l3build
%dir %{_texmfdistdir}/scripts/latex-git-log
%dir %{_texmfdistdir}/scripts/latex-make
%dir %{_texmfdistdir}/scripts/latex-papersize
%dir %{_texmfdistdir}/scripts/latex2man
%dir %{_texmfdistdir}/scripts/latex2nemeth
%dir %{_texmfdistdir}/scripts/latexdiff
%dir %{_texmfdistdir}/scripts/latexfileversion
%dir %{_texmfdistdir}/scripts/latexindent
%dir %{_texmfdistdir}/scripts/latexindent/LatexIndent
%dir %{_texmfdistdir}/scripts/latexmk
%dir %{_texmfdistdir}/scripts/latexpand
%dir %{_texmfdistdir}/scripts/light-latex-make
%dir %{_texmfdistdir}/scripts/lilyglyphs
%dir %{_texmfdistdir}/scripts/listbib
%dir %{_texmfdistdir}/scripts/listings-ext
%dir %{_texmfdistdir}/scripts/logicpuzzle
%dir %{_texmfdistdir}/scripts/ltxfileinfo
%dir %{_texmfdistdir}/scripts/ltximg
%dir %{_texmfdistdir}/scripts/lua-alt-getopt
%dir %{_texmfdistdir}/scripts/lua-physical
%dir %{_texmfdistdir}/scripts/lua-uca
%dir %{_texmfdistdir}/scripts/luafindfont
%dir %{_texmfdistdir}/scripts/luaindex
%dir %{_texmfdistdir}/scripts/luamesh
%dir %{_texmfdistdir}/scripts/luaotfload
%dir %{_texmfdistdir}/scripts/luasseq
%dir %{_texmfdistdir}/scripts/lwarp
%dir %{_texmfdistdir}/scripts/lyluatex
%dir %{_texmfdistdir}/scripts/m-tx
%dir %{_texmfdistdir}/scripts/magicnum
%dir %{_texmfdistdir}/scripts/make4ht
%dir %{_texmfdistdir}/scripts/make4ht/domfilters
%dir %{_texmfdistdir}/scripts/make4ht/extensions
%dir %{_texmfdistdir}/scripts/make4ht/filters
%dir %{_texmfdistdir}/scripts/make4ht/formats
%dir %{_texmfdistdir}/scripts/makedtx
%dir %{_texmfdistdir}/scripts/markdown
%dir %{_texmfdistdir}/scripts/match_parens
%dir %{_texmfdistdir}/scripts/mathspic
%dir %{_texmfdistdir}/scripts/mf2pt1
%dir %{_texmfdistdir}/scripts/mfirstuc
%dir %{_texmfdistdir}/scripts/mflua
%dir %{_texmfdistdir}/scripts/mkgrkindex
%dir %{_texmfdistdir}/scripts/mkjobtexmf
%dir %{_texmfdistdir}/scripts/mkpic
%dir %{_texmfdistdir}/scripts/multibibliography
%dir %{_texmfdistdir}/scripts/musixtex
%dir %{_texmfdistdir}/scripts/mycv
%dir %{_texmfdistdir}/scripts/optexcount
%dir %{_texmfdistdir}/scripts/pagelayout
%dir %{_texmfdistdir}/scripts/pax
%dir %{_texmfdistdir}/scripts/pdfbook2
%dir %{_texmfdistdir}/scripts/pdfcrop
%dir %{_texmfdistdir}/scripts/pdfjam
%dir %{_texmfdistdir}/scripts/pdflatexpicscale
%dir %{_texmfdistdir}/scripts/pdftex-quiet
%dir %{_texmfdistdir}/scripts/pdfxup
%dir %{_texmfdistdir}/scripts/pedigree-perl
%dir %{_texmfdistdir}/scripts/pedigree-perl/Pedigree
%dir %{_texmfdistdir}/scripts/perltex
%dir %{_texmfdistdir}/scripts/petri-nets
%dir %{_texmfdistdir}/scripts/pfarrei
%dir %{_texmfdistdir}/scripts/pgfmolbio
%dir %{_texmfdistdir}/scripts/pgfplots
%dir %{_texmfdistdir}/scripts/pkfix
%dir %{_texmfdistdir}/scripts/pkfix-helper
%dir %{_texmfdistdir}/scripts/placeat
%dir %{_texmfdistdir}/scripts/pmxchords
%dir %{_texmfdistdir}/scripts/ps2eps
%dir %{_texmfdistdir}/scripts/pst-pdf
%dir %{_texmfdistdir}/scripts/pst2pdf
%dir %{_texmfdistdir}/scripts/ptex-fontmaps
%dir %{_texmfdistdir}/scripts/ptex2pdf
%dir %{_texmfdistdir}/scripts/purifyeps
%dir %{_texmfdistdir}/scripts/puyotikz
%dir %{_texmfdistdir}/scripts/pygmentex
%dir %{_texmfdistdir}/scripts/pythontex
%dir %{_texmfdistdir}/scripts/qrbill
%dir %{_texmfdistdir}/scripts/rubik
%dir %{_texmfdistdir}/scripts/simpdftex
%dir %{_texmfdistdir}/scripts/spelling
%dir %{_texmfdistdir}/scripts/spix
%dir %{_texmfdistdir}/scripts/splitindex
%dir %{_texmfdistdir}/scripts/srcredact
%dir %{_texmfdistdir}/scripts/sty2dtx
%dir %{_texmfdistdir}/scripts/svn-multi
%dir %{_texmfdistdir}/scripts/tex4ebook
%dir %{_texmfdistdir}/scripts/tex4ht
%dir %{_texmfdistdir}/scripts/texaccents
%dir %{_texmfdistdir}/scripts/texcount
%dir %{_texmfdistdir}/scripts/texdef
%dir %{_texmfdistdir}/scripts/texdiff
%dir %{_texmfdistdir}/scripts/texdirflatten
%dir %{_texmfdistdir}/scripts/texdoc
%dir %{_texmfdistdir}/scripts/texdoctk
%dir %{_texmfdistdir}/scripts/texfot
%dir %{_texmfdistdir}/scripts/texlive
%dir %{_texmfdistdir}/scripts/texlive-extra
%dir %{_texmfdistdir}/scripts/texliveonfly
%dir %{_texmfdistdir}/scripts/texloganalyser
%dir %{_texmfdistdir}/scripts/texlogfilter
%dir %{_texmfdistdir}/scripts/texlogsieve
%dir %{_texmfdistdir}/scripts/texosquery
%dir %{_texmfdistdir}/scripts/texplate
%dir %{_texmfdistdir}/scripts/thumbpdf
%dir %{_texmfdistdir}/scripts/tikztosvg
%dir %{_texmfdistdir}/scripts/typeoutfileinfo
%dir %{_texmfdistdir}/scripts/ulqda
%dir %{_texmfdistdir}/scripts/urlbst
%dir %{_texmfdistdir}/scripts/vpe
%dir %{_texmfdistdir}/scripts/webquiz
%dir %{_texmfdistdir}/scripts/wordcount
%dir %{_texmfdistdir}/scripts/xindex
%dir %{_texmfdistdir}/scripts/yplan
%dir %{_texmfdistdir}/source
%dir %{_texmfdistdir}/source/bibtex
%dir %{_texmfdistdir}/source/bibtex/biber-ms
%dir %{_texmfdistdir}/source/generic
%dir %{_texmfdistdir}/source/generic/patch
%dir %{_texmfdistdir}/source/latex
%dir %{_texmfdistdir}/source/latex/fifinddo-info
%dir %{_texmfdistdir}/source/latex/fifinddo-info/makeelse
%dir %{_texmfdistdir}/source/latex/fifinddo-info/makeone
%dir %{_texmfdistdir}/source/latex/fifinddo-info/makevars
%dir %{_texmfdistdir}/source/latex/formation-latex-ul
%dir %{_texmfdistdir}/source/latex/formation-latex-ul/auxdoc
%dir %{_texmfdistdir}/source/latex/formation-latex-ul/images
%dir %{_texmfdistdir}/source/latex/formation-latex-ul/listings
%dir %{_texmfdistdir}/source/latex/gloss-occitan
%dir %{_texmfdistdir}/source/metapost
%dir %{_texmfdistdir}/source/metapost/metatype1
%dir %{_texmfdistdir}/tex
%dir %{_texmfdistdir}/tex/amstex
%dir %{_texmfdistdir}/tex/amstex/base
%dir %{_texmfdistdir}/tex/amstex/config
%dir %{_texmfdistdir}/tex/context
%dir %{_texmfdistdir}/tex/context/base
%dir %{_texmfdistdir}/tex/context/base/mkii
%dir %{_texmfdistdir}/tex/context/base/mkiv
%dir %{_texmfdistdir}/tex/context/base/mkxl
%dir %{_texmfdistdir}/tex/context/bib
%dir %{_texmfdistdir}/tex/context/bib/common
%dir %{_texmfdistdir}/tex/context/colors
%dir %{_texmfdistdir}/tex/context/colors/icc
%dir %{_texmfdistdir}/tex/context/colors/icc/context
%dir %{_texmfdistdir}/tex/context/colors/icc/profiles
%dir %{_texmfdistdir}/tex/context/fonts
%dir %{_texmfdistdir}/tex/context/fonts/mkiv
%dir %{_texmfdistdir}/tex/context/fonts/mkxl
%dir %{_texmfdistdir}/tex/context/interface
%dir %{_texmfdistdir}/tex/context/interface/mkiv
%dir %{_texmfdistdir}/tex/context/interface/third
%dir %{_texmfdistdir}/tex/context/modules
%dir %{_texmfdistdir}/tex/context/modules/common
%dir %{_texmfdistdir}/tex/context/modules/mkiv
%dir %{_texmfdistdir}/tex/context/modules/mkxl
%dir %{_texmfdistdir}/tex/context/patterns
%dir %{_texmfdistdir}/tex/context/patterns/common
%dir %{_texmfdistdir}/tex/context/patterns/mkiv
%dir %{_texmfdistdir}/tex/context/patterns/mkxl
%dir %{_texmfdistdir}/tex/context/sample
%dir %{_texmfdistdir}/tex/context/sample/common
%dir %{_texmfdistdir}/tex/context/sample/third
%dir %{_texmfdistdir}/tex/context/test
%dir %{_texmfdistdir}/tex/context/test/mkiv
%dir %{_texmfdistdir}/tex/context/third
%dir %{_texmfdistdir}/tex/context/third/account
%dir %{_texmfdistdir}/tex/context/third/algorithmic
%dir %{_texmfdistdir}/tex/context/third/animation
%dir %{_texmfdistdir}/tex/context/third/annotation
%dir %{_texmfdistdir}/tex/context/third/asymptote
%dir %{_texmfdistdir}/tex/context/third/bnf
%dir %{_texmfdistdir}/tex/context/third/chromato
%dir %{_texmfdistdir}/tex/context/third/circuitikz
%dir %{_texmfdistdir}/tex/context/third/cmscbf
%dir %{_texmfdistdir}/tex/context/third/cmttbf
%dir %{_texmfdistdir}/tex/context/third/commutative-diagrams
%dir %{_texmfdistdir}/tex/context/third/construction-plan
%dir %{_texmfdistdir}/tex/context/third/cyrillicnumbers
%dir %{_texmfdistdir}/tex/context/third/degrade
%dir %{_texmfdistdir}/tex/context/third/enigma
%dir %{_texmfdistdir}/tex/context/third/enigma/t-enigma.mkv
%dir %{_texmfdistdir}/tex/context/third/expkv-bundle
%dir %{_texmfdistdir}/tex/context/third/fancybreak
%dir %{_texmfdistdir}/tex/context/third/filter
%dir %{_texmfdistdir}/tex/context/third/french
%dir %{_texmfdistdir}/tex/context/third/fullpage
%dir %{_texmfdistdir}/tex/context/third/gantt
%dir %{_texmfdistdir}/tex/context/third/gnuplot
%dir %{_texmfdistdir}/tex/context/third/handlecsv
%dir %{_texmfdistdir}/tex/context/third/layout
%dir %{_texmfdistdir}/tex/context/third/letter
%dir %{_texmfdistdir}/tex/context/third/letter/base
%dir %{_texmfdistdir}/tex/context/third/letter/style
%dir %{_texmfdistdir}/tex/context/third/lettrine
%dir %{_texmfdistdir}/tex/context/third/lua-widow-control
%dir %{_texmfdistdir}/tex/context/third/markdown
%dir %{_texmfdistdir}/tex/context/third/mathsets
%dir %{_texmfdistdir}/tex/context/third/pgf
%dir %{_texmfdistdir}/tex/context/third/pgf/basiclayer
%dir %{_texmfdistdir}/tex/context/third/pgf/frontendlayer
%dir %{_texmfdistdir}/tex/context/third/pgf/math
%dir %{_texmfdistdir}/tex/context/third/pgf/systemlayer
%dir %{_texmfdistdir}/tex/context/third/pgf/utilities
%dir %{_texmfdistdir}/tex/context/third/pgfplots
%dir %{_texmfdistdir}/tex/context/third/rst
%dir %{_texmfdistdir}/tex/context/third/ruby
%dir %{_texmfdistdir}/tex/context/third/scontents
%dir %{_texmfdistdir}/tex/context/third/semaphor
%dir %{_texmfdistdir}/tex/context/third/simplefonts
%dir %{_texmfdistdir}/tex/context/third/simpleslides
%dir %{_texmfdistdir}/tex/context/third/title
%dir %{_texmfdistdir}/tex/context/third/transliterator
%dir %{_texmfdistdir}/tex/context/third/typearea
%dir %{_texmfdistdir}/tex/context/third/typescripts
%dir %{_texmfdistdir}/tex/context/third/vim
%dir %{_texmfdistdir}/tex/context/third/visualcounter
%dir %{_texmfdistdir}/tex/context/third/zhspacing
%dir %{_texmfdistdir}/tex/cslatex
%dir %{_texmfdistdir}/tex/cslatex/base
%dir %{_texmfdistdir}/tex/cslatex/cspsfonts
%dir %{_texmfdistdir}/tex/csplain
%dir %{_texmfdistdir}/tex/csplain/base
%dir %{_texmfdistdir}/tex/csplain/fonts
%dir %{_texmfdistdir}/tex/csplain/opmac
%dir %{_texmfdistdir}/tex/eplain
%dir %{_texmfdistdir}/tex/fontinst
%dir %{_texmfdistdir}/tex/fontinst/afm2pl
%dir %{_texmfdistdir}/tex/fontinst/base
%dir %{_texmfdistdir}/tex/fontinst/latinetx
%dir %{_texmfdistdir}/tex/fontinst/latinmtx
%dir %{_texmfdistdir}/tex/fontinst/mathetx
%dir %{_texmfdistdir}/tex/fontinst/mathmtx
%dir %{_texmfdistdir}/tex/fontinst/misc
%dir %{_texmfdistdir}/tex/fontinst/smbletx
%dir %{_texmfdistdir}/tex/fontinst/smblmtx
%dir %{_texmfdistdir}/tex/generic
%dir %{_texmfdistdir}/tex/generic/2up
%dir %{_texmfdistdir}/tex/generic/abbr
%dir %{_texmfdistdir}/tex/generic/abstyles
%dir %{_texmfdistdir}/tex/generic/alphalph
%dir %{_texmfdistdir}/tex/generic/apnum
%dir %{_texmfdistdir}/tex/generic/arrayjobx
%dir %{_texmfdistdir}/tex/generic/asapsym
%dir %{_texmfdistdir}/tex/generic/atbegshi
%dir %{_texmfdistdir}/tex/generic/autoaligne
%dir %{_texmfdistdir}/tex/generic/babel
%dir %{_texmfdistdir}/tex/generic/babel-albanian
%dir %{_texmfdistdir}/tex/generic/babel-azerbaijani
%dir %{_texmfdistdir}/tex/generic/babel-basque
%dir %{_texmfdistdir}/tex/generic/babel-belarusian
%dir %{_texmfdistdir}/tex/generic/babel-bosnian
%dir %{_texmfdistdir}/tex/generic/babel-breton
%dir %{_texmfdistdir}/tex/generic/babel-bulgarian
%dir %{_texmfdistdir}/tex/generic/babel-catalan
%dir %{_texmfdistdir}/tex/generic/babel-croatian
%dir %{_texmfdistdir}/tex/generic/babel-czech
%dir %{_texmfdistdir}/tex/generic/babel-danish
%dir %{_texmfdistdir}/tex/generic/babel-dutch
%dir %{_texmfdistdir}/tex/generic/babel-english
%dir %{_texmfdistdir}/tex/generic/babel-esperanto
%dir %{_texmfdistdir}/tex/generic/babel-estonian
%dir %{_texmfdistdir}/tex/generic/babel-finnish
%dir %{_texmfdistdir}/tex/generic/babel-french
%dir %{_texmfdistdir}/tex/generic/babel-friulan
%dir %{_texmfdistdir}/tex/generic/babel-galician
%dir %{_texmfdistdir}/tex/generic/babel-georgian
%dir %{_texmfdistdir}/tex/generic/babel-german
%dir %{_texmfdistdir}/tex/generic/babel-greek
%dir %{_texmfdistdir}/tex/generic/babel-hebrew
%dir %{_texmfdistdir}/tex/generic/babel-hungarian
%dir %{_texmfdistdir}/tex/generic/babel-icelandic
%dir %{_texmfdistdir}/tex/generic/babel-indonesian
%dir %{_texmfdistdir}/tex/generic/babel-interlingua
%dir %{_texmfdistdir}/tex/generic/babel-irish
%dir %{_texmfdistdir}/tex/generic/babel-italian
%dir %{_texmfdistdir}/tex/generic/babel-japanese
%dir %{_texmfdistdir}/tex/generic/babel-kurmanji
%dir %{_texmfdistdir}/tex/generic/babel-latin
%dir %{_texmfdistdir}/tex/generic/babel-latvian
%dir %{_texmfdistdir}/tex/generic/babel-lithuanian
%dir %{_texmfdistdir}/tex/generic/babel-macedonian
%dir %{_texmfdistdir}/tex/generic/babel-malay
%dir %{_texmfdistdir}/tex/generic/babel-norsk
%dir %{_texmfdistdir}/tex/generic/babel-occitan
%dir %{_texmfdistdir}/tex/generic/babel-piedmontese
%dir %{_texmfdistdir}/tex/generic/babel-polish
%dir %{_texmfdistdir}/tex/generic/babel-portuges
%dir %{_texmfdistdir}/tex/generic/babel-romanian
%dir %{_texmfdistdir}/tex/generic/babel-romansh
%dir %{_texmfdistdir}/tex/generic/babel-russian
%dir %{_texmfdistdir}/tex/generic/babel-samin
%dir %{_texmfdistdir}/tex/generic/babel-scottish
%dir %{_texmfdistdir}/tex/generic/babel-serbian
%dir %{_texmfdistdir}/tex/generic/babel-serbianc
%dir %{_texmfdistdir}/tex/generic/babel-slovak
%dir %{_texmfdistdir}/tex/generic/babel-slovenian
%dir %{_texmfdistdir}/tex/generic/babel-sorbian
%dir %{_texmfdistdir}/tex/generic/babel-spanish
%dir %{_texmfdistdir}/tex/generic/babel-swedish
%dir %{_texmfdistdir}/tex/generic/babel-thai
%dir %{_texmfdistdir}/tex/generic/babel-turkish
%dir %{_texmfdistdir}/tex/generic/babel-ukrainian
%dir %{_texmfdistdir}/tex/generic/babel-vietnamese
%dir %{_texmfdistdir}/tex/generic/babel-welsh
%dir %{_texmfdistdir}/tex/generic/babel/locale
%dir %{_texmfdistdir}/tex/generic/babel/locale/af
%dir %{_texmfdistdir}/tex/generic/babel/locale/agq
%dir %{_texmfdistdir}/tex/generic/babel/locale/ak
%dir %{_texmfdistdir}/tex/generic/babel/locale/am
%dir %{_texmfdistdir}/tex/generic/babel/locale/ar
%dir %{_texmfdistdir}/tex/generic/babel/locale/as
%dir %{_texmfdistdir}/tex/generic/babel/locale/asa
%dir %{_texmfdistdir}/tex/generic/babel/locale/ast
%dir %{_texmfdistdir}/tex/generic/babel/locale/az
%dir %{_texmfdistdir}/tex/generic/babel/locale/bas
%dir %{_texmfdistdir}/tex/generic/babel/locale/be
%dir %{_texmfdistdir}/tex/generic/babel/locale/bem
%dir %{_texmfdistdir}/tex/generic/babel/locale/bez
%dir %{_texmfdistdir}/tex/generic/babel/locale/bg
%dir %{_texmfdistdir}/tex/generic/babel/locale/bm
%dir %{_texmfdistdir}/tex/generic/babel/locale/bn
%dir %{_texmfdistdir}/tex/generic/babel/locale/bo
%dir %{_texmfdistdir}/tex/generic/babel/locale/br
%dir %{_texmfdistdir}/tex/generic/babel/locale/brx
%dir %{_texmfdistdir}/tex/generic/babel/locale/bs
%dir %{_texmfdistdir}/tex/generic/babel/locale/ca
%dir %{_texmfdistdir}/tex/generic/babel/locale/ce
%dir %{_texmfdistdir}/tex/generic/babel/locale/cgg
%dir %{_texmfdistdir}/tex/generic/babel/locale/chr
%dir %{_texmfdistdir}/tex/generic/babel/locale/ckb
%dir %{_texmfdistdir}/tex/generic/babel/locale/cop
%dir %{_texmfdistdir}/tex/generic/babel/locale/cs
%dir %{_texmfdistdir}/tex/generic/babel/locale/cu
%dir %{_texmfdistdir}/tex/generic/babel/locale/cy
%dir %{_texmfdistdir}/tex/generic/babel/locale/da
%dir %{_texmfdistdir}/tex/generic/babel/locale/dav
%dir %{_texmfdistdir}/tex/generic/babel/locale/de
%dir %{_texmfdistdir}/tex/generic/babel/locale/dje
%dir %{_texmfdistdir}/tex/generic/babel/locale/dsb
%dir %{_texmfdistdir}/tex/generic/babel/locale/dua
%dir %{_texmfdistdir}/tex/generic/babel/locale/dyo
%dir %{_texmfdistdir}/tex/generic/babel/locale/dz
%dir %{_texmfdistdir}/tex/generic/babel/locale/ebu
%dir %{_texmfdistdir}/tex/generic/babel/locale/ee
%dir %{_texmfdistdir}/tex/generic/babel/locale/el
%dir %{_texmfdistdir}/tex/generic/babel/locale/en
%dir %{_texmfdistdir}/tex/generic/babel/locale/eo
%dir %{_texmfdistdir}/tex/generic/babel/locale/es
%dir %{_texmfdistdir}/tex/generic/babel/locale/et
%dir %{_texmfdistdir}/tex/generic/babel/locale/eu
%dir %{_texmfdistdir}/tex/generic/babel/locale/ewo
%dir %{_texmfdistdir}/tex/generic/babel/locale/fa
%dir %{_texmfdistdir}/tex/generic/babel/locale/ff
%dir %{_texmfdistdir}/tex/generic/babel/locale/fi
%dir %{_texmfdistdir}/tex/generic/babel/locale/fil
%dir %{_texmfdistdir}/tex/generic/babel/locale/fo
%dir %{_texmfdistdir}/tex/generic/babel/locale/fr
%dir %{_texmfdistdir}/tex/generic/babel/locale/fur
%dir %{_texmfdistdir}/tex/generic/babel/locale/fy
%dir %{_texmfdistdir}/tex/generic/babel/locale/ga
%dir %{_texmfdistdir}/tex/generic/babel/locale/gd
%dir %{_texmfdistdir}/tex/generic/babel/locale/gl
%dir %{_texmfdistdir}/tex/generic/babel/locale/grc
%dir %{_texmfdistdir}/tex/generic/babel/locale/gsw
%dir %{_texmfdistdir}/tex/generic/babel/locale/gu
%dir %{_texmfdistdir}/tex/generic/babel/locale/guz
%dir %{_texmfdistdir}/tex/generic/babel/locale/gv
%dir %{_texmfdistdir}/tex/generic/babel/locale/ha
%dir %{_texmfdistdir}/tex/generic/babel/locale/haw
%dir %{_texmfdistdir}/tex/generic/babel/locale/he
%dir %{_texmfdistdir}/tex/generic/babel/locale/hi
%dir %{_texmfdistdir}/tex/generic/babel/locale/hr
%dir %{_texmfdistdir}/tex/generic/babel/locale/hsb
%dir %{_texmfdistdir}/tex/generic/babel/locale/hu
%dir %{_texmfdistdir}/tex/generic/babel/locale/hy
%dir %{_texmfdistdir}/tex/generic/babel/locale/ia
%dir %{_texmfdistdir}/tex/generic/babel/locale/id
%dir %{_texmfdistdir}/tex/generic/babel/locale/ig
%dir %{_texmfdistdir}/tex/generic/babel/locale/ii
%dir %{_texmfdistdir}/tex/generic/babel/locale/is
%dir %{_texmfdistdir}/tex/generic/babel/locale/it
%dir %{_texmfdistdir}/tex/generic/babel/locale/ja
%dir %{_texmfdistdir}/tex/generic/babel/locale/jgo
%dir %{_texmfdistdir}/tex/generic/babel/locale/jmc
%dir %{_texmfdistdir}/tex/generic/babel/locale/ka
%dir %{_texmfdistdir}/tex/generic/babel/locale/kab
%dir %{_texmfdistdir}/tex/generic/babel/locale/kam
%dir %{_texmfdistdir}/tex/generic/babel/locale/kde
%dir %{_texmfdistdir}/tex/generic/babel/locale/kea
%dir %{_texmfdistdir}/tex/generic/babel/locale/kgp
%dir %{_texmfdistdir}/tex/generic/babel/locale/khq
%dir %{_texmfdistdir}/tex/generic/babel/locale/ki
%dir %{_texmfdistdir}/tex/generic/babel/locale/kk
%dir %{_texmfdistdir}/tex/generic/babel/locale/kkj
%dir %{_texmfdistdir}/tex/generic/babel/locale/kl
%dir %{_texmfdistdir}/tex/generic/babel/locale/kln
%dir %{_texmfdistdir}/tex/generic/babel/locale/km
%dir %{_texmfdistdir}/tex/generic/babel/locale/kmr
%dir %{_texmfdistdir}/tex/generic/babel/locale/kn
%dir %{_texmfdistdir}/tex/generic/babel/locale/ko
%dir %{_texmfdistdir}/tex/generic/babel/locale/kok
%dir %{_texmfdistdir}/tex/generic/babel/locale/ks
%dir %{_texmfdistdir}/tex/generic/babel/locale/ksb
%dir %{_texmfdistdir}/tex/generic/babel/locale/ksf
%dir %{_texmfdistdir}/tex/generic/babel/locale/ksh
%dir %{_texmfdistdir}/tex/generic/babel/locale/kw
%dir %{_texmfdistdir}/tex/generic/babel/locale/ky
%dir %{_texmfdistdir}/tex/generic/babel/locale/la
%dir %{_texmfdistdir}/tex/generic/babel/locale/lag
%dir %{_texmfdistdir}/tex/generic/babel/locale/lb
%dir %{_texmfdistdir}/tex/generic/babel/locale/lg
%dir %{_texmfdistdir}/tex/generic/babel/locale/lkt
%dir %{_texmfdistdir}/tex/generic/babel/locale/ln
%dir %{_texmfdistdir}/tex/generic/babel/locale/lo
%dir %{_texmfdistdir}/tex/generic/babel/locale/lrc
%dir %{_texmfdistdir}/tex/generic/babel/locale/lt
%dir %{_texmfdistdir}/tex/generic/babel/locale/lu
%dir %{_texmfdistdir}/tex/generic/babel/locale/luo
%dir %{_texmfdistdir}/tex/generic/babel/locale/luy
%dir %{_texmfdistdir}/tex/generic/babel/locale/lv
%dir %{_texmfdistdir}/tex/generic/babel/locale/mas
%dir %{_texmfdistdir}/tex/generic/babel/locale/mer
%dir %{_texmfdistdir}/tex/generic/babel/locale/mfe
%dir %{_texmfdistdir}/tex/generic/babel/locale/mg
%dir %{_texmfdistdir}/tex/generic/babel/locale/mgh
%dir %{_texmfdistdir}/tex/generic/babel/locale/mgo
%dir %{_texmfdistdir}/tex/generic/babel/locale/mk
%dir %{_texmfdistdir}/tex/generic/babel/locale/ml
%dir %{_texmfdistdir}/tex/generic/babel/locale/mn
%dir %{_texmfdistdir}/tex/generic/babel/locale/mr
%dir %{_texmfdistdir}/tex/generic/babel/locale/ms
%dir %{_texmfdistdir}/tex/generic/babel/locale/mt
%dir %{_texmfdistdir}/tex/generic/babel/locale/mua
%dir %{_texmfdistdir}/tex/generic/babel/locale/my
%dir %{_texmfdistdir}/tex/generic/babel/locale/mzn
%dir %{_texmfdistdir}/tex/generic/babel/locale/naq
%dir %{_texmfdistdir}/tex/generic/babel/locale/nb
%dir %{_texmfdistdir}/tex/generic/babel/locale/nd
%dir %{_texmfdistdir}/tex/generic/babel/locale/ne
%dir %{_texmfdistdir}/tex/generic/babel/locale/nl
%dir %{_texmfdistdir}/tex/generic/babel/locale/nmg
%dir %{_texmfdistdir}/tex/generic/babel/locale/nn
%dir %{_texmfdistdir}/tex/generic/babel/locale/nnh
%dir %{_texmfdistdir}/tex/generic/babel/locale/no
%dir %{_texmfdistdir}/tex/generic/babel/locale/nus
%dir %{_texmfdistdir}/tex/generic/babel/locale/nyn
%dir %{_texmfdistdir}/tex/generic/babel/locale/oc
%dir %{_texmfdistdir}/tex/generic/babel/locale/om
%dir %{_texmfdistdir}/tex/generic/babel/locale/or
%dir %{_texmfdistdir}/tex/generic/babel/locale/os
%dir %{_texmfdistdir}/tex/generic/babel/locale/pa
%dir %{_texmfdistdir}/tex/generic/babel/locale/pl
%dir %{_texmfdistdir}/tex/generic/babel/locale/pms
%dir %{_texmfdistdir}/tex/generic/babel/locale/ps
%dir %{_texmfdistdir}/tex/generic/babel/locale/pt
%dir %{_texmfdistdir}/tex/generic/babel/locale/qu
%dir %{_texmfdistdir}/tex/generic/babel/locale/rm
%dir %{_texmfdistdir}/tex/generic/babel/locale/rn
%dir %{_texmfdistdir}/tex/generic/babel/locale/ro
%dir %{_texmfdistdir}/tex/generic/babel/locale/rof
%dir %{_texmfdistdir}/tex/generic/babel/locale/ru
%dir %{_texmfdistdir}/tex/generic/babel/locale/rw
%dir %{_texmfdistdir}/tex/generic/babel/locale/rwk
%dir %{_texmfdistdir}/tex/generic/babel/locale/sa
%dir %{_texmfdistdir}/tex/generic/babel/locale/sah
%dir %{_texmfdistdir}/tex/generic/babel/locale/saq
%dir %{_texmfdistdir}/tex/generic/babel/locale/sbp
%dir %{_texmfdistdir}/tex/generic/babel/locale/sc
%dir %{_texmfdistdir}/tex/generic/babel/locale/se
%dir %{_texmfdistdir}/tex/generic/babel/locale/seh
%dir %{_texmfdistdir}/tex/generic/babel/locale/ses
%dir %{_texmfdistdir}/tex/generic/babel/locale/sg
%dir %{_texmfdistdir}/tex/generic/babel/locale/shi
%dir %{_texmfdistdir}/tex/generic/babel/locale/si
%dir %{_texmfdistdir}/tex/generic/babel/locale/sk
%dir %{_texmfdistdir}/tex/generic/babel/locale/sl
%dir %{_texmfdistdir}/tex/generic/babel/locale/smn
%dir %{_texmfdistdir}/tex/generic/babel/locale/sn
%dir %{_texmfdistdir}/tex/generic/babel/locale/so
%dir %{_texmfdistdir}/tex/generic/babel/locale/sq
%dir %{_texmfdistdir}/tex/generic/babel/locale/sr
%dir %{_texmfdistdir}/tex/generic/babel/locale/sv
%dir %{_texmfdistdir}/tex/generic/babel/locale/sw
%dir %{_texmfdistdir}/tex/generic/babel/locale/syr
%dir %{_texmfdistdir}/tex/generic/babel/locale/ta
%dir %{_texmfdistdir}/tex/generic/babel/locale/te
%dir %{_texmfdistdir}/tex/generic/babel/locale/teo
%dir %{_texmfdistdir}/tex/generic/babel/locale/th
%dir %{_texmfdistdir}/tex/generic/babel/locale/ti
%dir %{_texmfdistdir}/tex/generic/babel/locale/tk
%dir %{_texmfdistdir}/tex/generic/babel/locale/to
%dir %{_texmfdistdir}/tex/generic/babel/locale/tr
%dir %{_texmfdistdir}/tex/generic/babel/locale/twq
%dir %{_texmfdistdir}/tex/generic/babel/locale/tzm
%dir %{_texmfdistdir}/tex/generic/babel/locale/ug
%dir %{_texmfdistdir}/tex/generic/babel/locale/uk
%dir %{_texmfdistdir}/tex/generic/babel/locale/ur
%dir %{_texmfdistdir}/tex/generic/babel/locale/uz
%dir %{_texmfdistdir}/tex/generic/babel/locale/vai
%dir %{_texmfdistdir}/tex/generic/babel/locale/vi
%dir %{_texmfdistdir}/tex/generic/babel/locale/vun
%dir %{_texmfdistdir}/tex/generic/babel/locale/wae
%dir %{_texmfdistdir}/tex/generic/babel/locale/xog
%dir %{_texmfdistdir}/tex/generic/babel/locale/yav
%dir %{_texmfdistdir}/tex/generic/babel/locale/yi
%dir %{_texmfdistdir}/tex/generic/babel/locale/yo
%dir %{_texmfdistdir}/tex/generic/babel/locale/yrl
%dir %{_texmfdistdir}/tex/generic/babel/locale/yue
%dir %{_texmfdistdir}/tex/generic/babel/locale/zgh
%dir %{_texmfdistdir}/tex/generic/babel/locale/zh
%dir %{_texmfdistdir}/tex/generic/babel/locale/zu
%dir %{_texmfdistdir}/tex/generic/bagpipe
%dir %{_texmfdistdir}/tex/generic/barr
%dir %{_texmfdistdir}/tex/generic/beebe
%dir %{_texmfdistdir}/tex/generic/bibtex
%dir %{_texmfdistdir}/tex/generic/bigintcalc
%dir %{_texmfdistdir}/tex/generic/bitelist
%dir %{_texmfdistdir}/tex/generic/bitset
%dir %{_texmfdistdir}/tex/generic/borceux
%dir %{_texmfdistdir}/tex/generic/c-pascal
%dir %{_texmfdistdir}/tex/generic/catchfile
%dir %{_texmfdistdir}/tex/generic/catcodes
%dir %{_texmfdistdir}/tex/generic/chemfig
%dir %{_texmfdistdir}/tex/generic/chronosys
%dir %{_texmfdistdir}/tex/generic/circuitikz
%dir %{_texmfdistdir}/tex/generic/colorprofiles
%dir %{_texmfdistdir}/tex/generic/colortab
%dir %{_texmfdistdir}/tex/generic/commado
%dir %{_texmfdistdir}/tex/generic/commutative-diagrams
%dir %{_texmfdistdir}/tex/generic/compare
%dir %{_texmfdistdir}/tex/generic/config
%dir %{_texmfdistdir}/tex/generic/context
%dir %{_texmfdistdir}/tex/generic/context/luatex
%dir %{_texmfdistdir}/tex/generic/context/mptopdf
%dir %{_texmfdistdir}/tex/generic/crossrefenum
%dir %{_texmfdistdir}/tex/generic/ctex
%dir %{_texmfdistdir}/tex/generic/ctex/zhmap
%dir %{_texmfdistdir}/tex/generic/dcpic
%dir %{_texmfdistdir}/tex/generic/dehyph
%dir %{_texmfdistdir}/tex/generic/dehyph-exptl
%dir %{_texmfdistdir}/tex/generic/dirtree
%dir %{_texmfdistdir}/tex/generic/docbytex
%dir %{_texmfdistdir}/tex/generic/dowith
%dir %{_texmfdistdir}/tex/generic/dratex
%dir %{_texmfdistdir}/tex/generic/dvips
%dir %{_texmfdistdir}/tex/generic/e-french
%dir %{_texmfdistdir}/tex/generic/ean
%dir %{_texmfdistdir}/tex/generic/edmac
%dir %{_texmfdistdir}/tex/generic/eijkhout
%dir %{_texmfdistdir}/tex/generic/embedfile
%dir %{_texmfdistdir}/tex/generic/encodings
%dir %{_texmfdistdir}/tex/generic/enctex
%dir %{_texmfdistdir}/tex/generic/enigma
%dir %{_texmfdistdir}/tex/generic/epigram
%dir %{_texmfdistdir}/tex/generic/epsf
%dir %{_texmfdistdir}/tex/generic/etexcmds
%dir %{_texmfdistdir}/tex/generic/expex
%dir %{_texmfdistdir}/tex/generic/expex-acro
%dir %{_texmfdistdir}/tex/generic/expkv-bundle
%dir %{_texmfdistdir}/tex/generic/fenixpar
%dir %{_texmfdistdir}/tex/generic/filemod
%dir %{_texmfdistdir}/tex/generic/fixjfm
%dir %{_texmfdistdir}/tex/generic/fltpoint
%dir %{_texmfdistdir}/tex/generic/fntproof
%dir %{_texmfdistdir}/tex/generic/formlett
%dir %{_texmfdistdir}/tex/generic/frame
%dir %{_texmfdistdir}/tex/generic/gates
%dir %{_texmfdistdir}/tex/generic/german
%dir %{_texmfdistdir}/tex/generic/gettitlestring
%dir %{_texmfdistdir}/tex/generic/gobble
%dir %{_texmfdistdir}/tex/generic/gtl
%dir %{_texmfdistdir}/tex/generic/hlist
%dir %{_texmfdistdir}/tex/generic/hologo
%dir %{_texmfdistdir}/tex/generic/hyph-utf8
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/conversions
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/loadhyph
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns/ptex
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns/quote
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns/tex
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns/tex-8bit
%dir %{_texmfdistdir}/tex/generic/hyph-utf8/patterns/txt
%dir %{_texmfdistdir}/tex/generic/hyphen
%dir %{_texmfdistdir}/tex/generic/hyphenex
%dir %{_texmfdistdir}/tex/generic/ibygrk
%dir %{_texmfdistdir}/tex/generic/ifptex
%dir %{_texmfdistdir}/tex/generic/iftex
%dir %{_texmfdistdir}/tex/generic/ifxptex
%dir %{_texmfdistdir}/tex/generic/infwarerr
%dir %{_texmfdistdir}/tex/generic/insbox
%dir %{_texmfdistdir}/tex/generic/intcalc
%dir %{_texmfdistdir}/tex/generic/kastrup
%dir %{_texmfdistdir}/tex/generic/knuth-lib
%dir %{_texmfdistdir}/tex/generic/kvdefinekeys
%dir %{_texmfdistdir}/tex/generic/langcode
%dir %{_texmfdistdir}/tex/generic/lecturer
%dir %{_texmfdistdir}/tex/generic/letterspacing
%dir %{_texmfdistdir}/tex/generic/levy
%dir %{_texmfdistdir}/tex/generic/librarian
%dir %{_texmfdistdir}/tex/generic/listofitems
%dir %{_texmfdistdir}/tex/generic/localloc
%dir %{_texmfdistdir}/tex/generic/lpform
%dir %{_texmfdistdir}/tex/generic/lt3luabridge
%dir %{_texmfdistdir}/tex/generic/ltxcmds
%dir %{_texmfdistdir}/tex/generic/luatex85
%dir %{_texmfdistdir}/tex/generic/m-tx
%dir %{_texmfdistdir}/tex/generic/magicnum
%dir %{_texmfdistdir}/tex/generic/markdown
%dir %{_texmfdistdir}/tex/generic/mathabx
%dir %{_texmfdistdir}/tex/generic/mathdots
%dir %{_texmfdistdir}/tex/generic/mathlig
%dir %{_texmfdistdir}/tex/generic/metapost
%dir %{_texmfdistdir}/tex/generic/mfpic
%dir %{_texmfdistdir}/tex/generic/midnight
%dir %{_texmfdistdir}/tex/generic/minifp
%dir %{_texmfdistdir}/tex/generic/mleftright
%dir %{_texmfdistdir}/tex/generic/modulus
%dir %{_texmfdistdir}/tex/generic/multido
%dir %{_texmfdistdir}/tex/generic/multiexpand
%dir %{_texmfdistdir}/tex/generic/musixtex
%dir %{_texmfdistdir}/tex/generic/musixtnt
%dir %{_texmfdistdir}/tex/generic/namedef
%dir %{_texmfdistdir}/tex/generic/navigator
%dir %{_texmfdistdir}/tex/generic/nth
%dir %{_texmfdistdir}/tex/generic/oberdiek
%dir %{_texmfdistdir}/tex/generic/ofs
%dir %{_texmfdistdir}/tex/generic/olsak-misc
%dir %{_texmfdistdir}/tex/generic/omegahyph
%dir %{_texmfdistdir}/tex/generic/outerhbox
%dir %{_texmfdistdir}/tex/generic/path
%dir %{_texmfdistdir}/tex/generic/pdf-trans
%dir %{_texmfdistdir}/tex/generic/pdfescape
%dir %{_texmfdistdir}/tex/generic/pdfmsym
%dir %{_texmfdistdir}/tex/generic/pdftex
%dir %{_texmfdistdir}/tex/generic/pdftexcmds
%dir %{_texmfdistdir}/tex/generic/petri-nets
%dir %{_texmfdistdir}/tex/generic/pgf
%dir %{_texmfdistdir}/tex/generic/pgf/basiclayer
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/circuits
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/datavisualization
%dir %{_texmfdistdir}/tex/generic/pgf/frontendlayer/tikz/libraries/graphs
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/bindings
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/circular
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/control
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/deprecated
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/energybased
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/energybased/multilevelmixer
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/layered
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/misclayout
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/module
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/doc/ogdf/planarity
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/examples
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/experimental
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/experimental/evolving
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/algorithms
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/base
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/forcetypes
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/force/jedi/initialpositioning
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/interface
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/layered
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/lib
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/model
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/ogdf
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/pedigrees
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/phylogenetics
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/planar
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/routing
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/tools
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/lua/pgf/gd/trees
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/tex
%dir %{_texmfdistdir}/tex/generic/pgf/graphdrawing/tex/experimental
%dir %{_texmfdistdir}/tex/generic/pgf/libraries
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/datavisualization
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/decorations
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/luamath
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/luamath/pgf
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/luamath/pgf/luamath
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/shapes
%dir %{_texmfdistdir}/tex/generic/pgf/libraries/shapes/circuits
%dir %{_texmfdistdir}/tex/generic/pgf/lua
%dir %{_texmfdistdir}/tex/generic/pgf/lua/pgf
%dir %{_texmfdistdir}/tex/generic/pgf/lua/pgf/manual
%dir %{_texmfdistdir}/tex/generic/pgf/math
%dir %{_texmfdistdir}/tex/generic/pgf/modules
%dir %{_texmfdistdir}/tex/generic/pgf/systemlayer
%dir %{_texmfdistdir}/tex/generic/pgf/utilities
%dir %{_texmfdistdir}/tex/generic/pgfornament
%dir %{_texmfdistdir}/tex/generic/pgfornament/am
%dir %{_texmfdistdir}/tex/generic/pgfornament/pgfhan
%dir %{_texmfdistdir}/tex/generic/pgfornament/vectorian
%dir %{_texmfdistdir}/tex/generic/pgfplots
%dir %{_texmfdistdir}/tex/generic/pgfplots/libs
%dir %{_texmfdistdir}/tex/generic/pgfplots/liststructure
%dir %{_texmfdistdir}/tex/generic/pgfplots/lua
%dir %{_texmfdistdir}/tex/generic/pgfplots/lua/pgfplots
%dir %{_texmfdistdir}/tex/generic/pgfplots/lua/pgfplotsoldpgfsupp
%dir %{_texmfdistdir}/tex/generic/pgfplots/lua/pgfplotsoldpgfsupp/luamath
%dir %{_texmfdistdir}/tex/generic/pgfplots/numtable
%dir %{_texmfdistdir}/tex/generic/pgfplots/oldpgfcompatib
%dir %{_texmfdistdir}/tex/generic/pgfplots/oldpgfplotscompatib
%dir %{_texmfdistdir}/tex/generic/pgfplots/pgfcontrib
%dir %{_texmfdistdir}/tex/generic/pgfplots/sys
%dir %{_texmfdistdir}/tex/generic/pgfplots/test
%dir %{_texmfdistdir}/tex/generic/pgfplots/util
%dir %{_texmfdistdir}/tex/generic/pictex
%dir %{_texmfdistdir}/tex/generic/plainpkg
%dir %{_texmfdistdir}/tex/generic/pmx
%dir %{_texmfdistdir}/tex/generic/pmxchords
%dir %{_texmfdistdir}/tex/generic/polexpr
%dir %{_texmfdistdir}/tex/generic/poormanlog
%dir %{_texmfdistdir}/tex/generic/poster-mac
%dir %{_texmfdistdir}/tex/generic/pst-3d
%dir %{_texmfdistdir}/tex/generic/pst-3dplot
%dir %{_texmfdistdir}/tex/generic/pst-abspos
%dir %{_texmfdistdir}/tex/generic/pst-antiprism
%dir %{_texmfdistdir}/tex/generic/pst-arrow
%dir %{_texmfdistdir}/tex/generic/pst-asr
%dir %{_texmfdistdir}/tex/generic/pst-bar
%dir %{_texmfdistdir}/tex/generic/pst-barcode
%dir %{_texmfdistdir}/tex/generic/pst-bezier
%dir %{_texmfdistdir}/tex/generic/pst-blur
%dir %{_texmfdistdir}/tex/generic/pst-bspline
%dir %{_texmfdistdir}/tex/generic/pst-cie
%dir %{_texmfdistdir}/tex/generic/pst-circ
%dir %{_texmfdistdir}/tex/generic/pst-coil
%dir %{_texmfdistdir}/tex/generic/pst-contourplot
%dir %{_texmfdistdir}/tex/generic/pst-cox
%dir %{_texmfdistdir}/tex/generic/pst-dart
%dir %{_texmfdistdir}/tex/generic/pst-diffraction
%dir %{_texmfdistdir}/tex/generic/pst-electricfield
%dir %{_texmfdistdir}/tex/generic/pst-eps
%dir %{_texmfdistdir}/tex/generic/pst-eucl
%dir %{_texmfdistdir}/tex/generic/pst-feyn
%dir %{_texmfdistdir}/tex/generic/pst-fill
%dir %{_texmfdistdir}/tex/generic/pst-fit
%dir %{_texmfdistdir}/tex/generic/pst-fr3d
%dir %{_texmfdistdir}/tex/generic/pst-fractal
%dir %{_texmfdistdir}/tex/generic/pst-fun
%dir %{_texmfdistdir}/tex/generic/pst-func
%dir %{_texmfdistdir}/tex/generic/pst-gantt
%dir %{_texmfdistdir}/tex/generic/pst-geo
%dir %{_texmfdistdir}/tex/generic/pst-geo/data
%dir %{_texmfdistdir}/tex/generic/pst-geometrictools
%dir %{_texmfdistdir}/tex/generic/pst-gr3d
%dir %{_texmfdistdir}/tex/generic/pst-grad
%dir %{_texmfdistdir}/tex/generic/pst-graphicx
%dir %{_texmfdistdir}/tex/generic/pst-hsb
%dir %{_texmfdistdir}/tex/generic/pst-infixplot
%dir %{_texmfdistdir}/tex/generic/pst-intersect
%dir %{_texmfdistdir}/tex/generic/pst-jtree
%dir %{_texmfdistdir}/tex/generic/pst-knot
%dir %{_texmfdistdir}/tex/generic/pst-labo
%dir %{_texmfdistdir}/tex/generic/pst-lens
%dir %{_texmfdistdir}/tex/generic/pst-light3d
%dir %{_texmfdistdir}/tex/generic/pst-lsystem
%dir %{_texmfdistdir}/tex/generic/pst-magneticfield
%dir %{_texmfdistdir}/tex/generic/pst-marble
%dir %{_texmfdistdir}/tex/generic/pst-math
%dir %{_texmfdistdir}/tex/generic/pst-mirror
%dir %{_texmfdistdir}/tex/generic/pst-moire
%dir %{_texmfdistdir}/tex/generic/pst-node
%dir %{_texmfdistdir}/tex/generic/pst-ob3d
%dir %{_texmfdistdir}/tex/generic/pst-ode
%dir %{_texmfdistdir}/tex/generic/pst-optic
%dir %{_texmfdistdir}/tex/generic/pst-osci
%dir %{_texmfdistdir}/tex/generic/pst-ovl
%dir %{_texmfdistdir}/tex/generic/pst-pad
%dir %{_texmfdistdir}/tex/generic/pst-pdgr
%dir %{_texmfdistdir}/tex/generic/pst-perspective
%dir %{_texmfdistdir}/tex/generic/pst-plot
%dir %{_texmfdistdir}/tex/generic/pst-poly
%dir %{_texmfdistdir}/tex/generic/pst-pulley
%dir %{_texmfdistdir}/tex/generic/pst-qtree
%dir %{_texmfdistdir}/tex/generic/pst-rputover
%dir %{_texmfdistdir}/tex/generic/pst-rubans
%dir %{_texmfdistdir}/tex/generic/pst-shell
%dir %{_texmfdistdir}/tex/generic/pst-sigsys
%dir %{_texmfdistdir}/tex/generic/pst-slpe
%dir %{_texmfdistdir}/tex/generic/pst-solarsystem
%dir %{_texmfdistdir}/tex/generic/pst-solides3d
%dir %{_texmfdistdir}/tex/generic/pst-spectra
%dir %{_texmfdistdir}/tex/generic/pst-spinner
%dir %{_texmfdistdir}/tex/generic/pst-stru
%dir %{_texmfdistdir}/tex/generic/pst-text
%dir %{_texmfdistdir}/tex/generic/pst-thick
%dir %{_texmfdistdir}/tex/generic/pst-tools
%dir %{_texmfdistdir}/tex/generic/pst-tree
%dir %{_texmfdistdir}/tex/generic/pst-turtle
%dir %{_texmfdistdir}/tex/generic/pst-tvz
%dir %{_texmfdistdir}/tex/generic/pst-vehicle
%dir %{_texmfdistdir}/tex/generic/pstricks
%dir %{_texmfdistdir}/tex/generic/pstricks-add
%dir %{_texmfdistdir}/tex/generic/pstricks/config
%dir %{_texmfdistdir}/tex/generic/qpxqtx
%dir %{_texmfdistdir}/tex/generic/random
%dir %{_texmfdistdir}/tex/generic/randomlist
%dir %{_texmfdistdir}/tex/generic/reverxii
%dir %{_texmfdistdir}/tex/generic/rlepsf
%dir %{_texmfdistdir}/tex/generic/ruhyphen
%dir %{_texmfdistdir}/tex/generic/ruler
%dir %{_texmfdistdir}/tex/generic/schemata
%dir %{_texmfdistdir}/tex/generic/scontents
%dir %{_texmfdistdir}/tex/generic/shade
%dir %{_texmfdistdir}/tex/generic/shapepar
%dir %{_texmfdistdir}/tex/generic/simplekv
%dir %{_texmfdistdir}/tex/generic/soul
%dir %{_texmfdistdir}/tex/generic/splitindex
%dir %{_texmfdistdir}/tex/generic/stringenc
%dir %{_texmfdistdir}/tex/generic/swrule
%dir %{_texmfdistdir}/tex/generic/systeme
%dir %{_texmfdistdir}/tex/generic/t2
%dir %{_texmfdistdir}/tex/generic/t2/cyrfinst
%dir %{_texmfdistdir}/tex/generic/t2/cyrfinst/derivatives
%dir %{_texmfdistdir}/tex/generic/t2/cyrfinst/etc
%dir %{_texmfdistdir}/tex/generic/tabto-generic
%dir %{_texmfdistdir}/tex/generic/tap
%dir %{_texmfdistdir}/tex/generic/termmenu
%dir %{_texmfdistdir}/tex/generic/tex-ewd
%dir %{_texmfdistdir}/tex/generic/tex-ini-files
%dir %{_texmfdistdir}/tex/generic/tex-locale
%dir %{_texmfdistdir}/tex/generic/tex-ps
%dir %{_texmfdistdir}/tex/generic/tex4ht
%dir %{_texmfdistdir}/tex/generic/texapi
%dir %{_texmfdistdir}/tex/generic/texdate
%dir %{_texmfdistdir}/tex/generic/texdimens
%dir %{_texmfdistdir}/tex/generic/texdraw
%dir %{_texmfdistdir}/tex/generic/textmerg
%dir %{_texmfdistdir}/tex/generic/thumbpdf
%dir %{_texmfdistdir}/tex/generic/tikz-cd
%dir %{_texmfdistdir}/tex/generic/tikz-ext
%dir %{_texmfdistdir}/tex/generic/tikzducks
%dir %{_texmfdistdir}/tex/generic/tokcycle
%dir %{_texmfdistdir}/tex/generic/tracklang
%dir %{_texmfdistdir}/tex/generic/trigonometry
%dir %{_texmfdistdir}/tex/generic/ukrhyph
%dir %{_texmfdistdir}/tex/generic/ulem
%dir %{_texmfdistdir}/tex/generic/unicode-data
%dir %{_texmfdistdir}/tex/generic/uniquecounter
%dir %{_texmfdistdir}/tex/generic/upca
%dir %{_texmfdistdir}/tex/generic/upzhkinsoku
%dir %{_texmfdistdir}/tex/generic/variations
%dir %{_texmfdistdir}/tex/generic/vaucanson-g
%dir %{_texmfdistdir}/tex/generic/velthuis
%dir %{_texmfdistdir}/tex/generic/witharrows
%dir %{_texmfdistdir}/tex/generic/xcomment
%dir %{_texmfdistdir}/tex/generic/xint
%dir %{_texmfdistdir}/tex/generic/xkeyval
%dir %{_texmfdistdir}/tex/generic/xlop
%dir %{_texmfdistdir}/tex/generic/xstring
%dir %{_texmfdistdir}/tex/generic/xypic
%dir %{_texmfdistdir}/tex/generic/yax
%dir %{_texmfdistdir}/tex/generic/ydoc
%dir %{_texmfdistdir}/tex/generic/youngtab
%dir %{_texmfdistdir}/tex/generic/zhmetrics
%dir %{_texmfdistdir}/tex/generic/zhspacing
%dir %{_texmfdistdir}/tex/hitex
%dir %{_texmfdistdir}/tex/hitex/base
%dir %{_texmfdistdir}/tex/jadetex
%dir %{_texmfdistdir}/tex/jadetex/base
%dir %{_texmfdistdir}/tex/lambda
%dir %{_texmfdistdir}/tex/lambda/antomega
%dir %{_texmfdistdir}/tex/lambda/base
%dir %{_texmfdistdir}/tex/lambda/config
%dir %{_texmfdistdir}/tex/lambda/ocherokee
%dir %{_texmfdistdir}/tex/lambda/oinuit
%dir %{_texmfdistdir}/tex/latex
%dir %{_texmfdistdir}/tex/latex-dev
%dir %{_texmfdistdir}/tex/latex-dev/amsmath
%dir %{_texmfdistdir}/tex/latex-dev/base
%dir %{_texmfdistdir}/tex/latex-dev/firstaid
%dir %{_texmfdistdir}/tex/latex-dev/graphics
%dir %{_texmfdistdir}/tex/latex-dev/latex-lab
%dir %{_texmfdistdir}/tex/latex-dev/tools
%dir %{_texmfdistdir}/tex/latex/12many
%dir %{_texmfdistdir}/tex/latex/a0poster
%dir %{_texmfdistdir}/tex/latex/a4wide
%dir %{_texmfdistdir}/tex/latex/a5comb
%dir %{_texmfdistdir}/tex/latex/aalok
%dir %{_texmfdistdir}/tex/latex/aastex
%dir %{_texmfdistdir}/tex/latex/abc
%dir %{_texmfdistdir}/tex/latex/abnt
%dir %{_texmfdistdir}/tex/latex/abntex2
%dir %{_texmfdistdir}/tex/latex/abntexto
%dir %{_texmfdistdir}/tex/latex/aboensis
%dir %{_texmfdistdir}/tex/latex/abraces
%dir %{_texmfdistdir}/tex/latex/abspos
%dir %{_texmfdistdir}/tex/latex/abstract
%dir %{_texmfdistdir}/tex/latex/academicons
%dir %{_texmfdistdir}/tex/latex/accanthis
%dir %{_texmfdistdir}/tex/latex/accents
%dir %{_texmfdistdir}/tex/latex/accessibility
%dir %{_texmfdistdir}/tex/latex/accfonts
%dir %{_texmfdistdir}/tex/latex/accsupp
%dir %{_texmfdistdir}/tex/latex/achemso
%dir %{_texmfdistdir}/tex/latex/acmart
%dir %{_texmfdistdir}/tex/latex/acmconf
%dir %{_texmfdistdir}/tex/latex/acro
%dir %{_texmfdistdir}/tex/latex/acronym
%dir %{_texmfdistdir}/tex/latex/acroterm
%dir %{_texmfdistdir}/tex/latex/active-conf
%dir %{_texmfdistdir}/tex/latex/actuarialangle
%dir %{_texmfdistdir}/tex/latex/actuarialsymbol
%dir %{_texmfdistdir}/tex/latex/addfont
%dir %{_texmfdistdir}/tex/latex/addlines
%dir %{_texmfdistdir}/tex/latex/adfathesis
%dir %{_texmfdistdir}/tex/latex/adforn
%dir %{_texmfdistdir}/tex/latex/adfsymbols
%dir %{_texmfdistdir}/tex/latex/adigraph
%dir %{_texmfdistdir}/tex/latex/adjmulticol
%dir %{_texmfdistdir}/tex/latex/adjustbox
%dir %{_texmfdistdir}/tex/latex/adrconv
%dir %{_texmfdistdir}/tex/latex/adtrees
%dir %{_texmfdistdir}/tex/latex/advdate
%dir %{_texmfdistdir}/tex/latex/ae
%dir %{_texmfdistdir}/tex/latex/aeguill
%dir %{_texmfdistdir}/tex/latex/aesupp
%dir %{_texmfdistdir}/tex/latex/afparticle
%dir %{_texmfdistdir}/tex/latex/afthesis
%dir %{_texmfdistdir}/tex/latex/aguplus
%dir %{_texmfdistdir}/tex/latex/aiaa
%dir %{_texmfdistdir}/tex/latex/akktex
%dir %{_texmfdistdir}/tex/latex/akletter
%dir %{_texmfdistdir}/tex/latex/akshar
%dir %{_texmfdistdir}/tex/latex/alchemist
%dir %{_texmfdistdir}/tex/latex/alegreya
%dir %{_texmfdistdir}/tex/latex/alertmessage
%dir %{_texmfdistdir}/tex/latex/alertmessage/img
%dir %{_texmfdistdir}/tex/latex/alfaslabone
%dir %{_texmfdistdir}/tex/latex/alg
%dir %{_texmfdistdir}/tex/latex/algobox
%dir %{_texmfdistdir}/tex/latex/algolrevived
%dir %{_texmfdistdir}/tex/latex/algorithm2e
%dir %{_texmfdistdir}/tex/latex/algorithmicx
%dir %{_texmfdistdir}/tex/latex/algorithms
%dir %{_texmfdistdir}/tex/latex/algpseudocodex
%dir %{_texmfdistdir}/tex/latex/algxpar
%dir %{_texmfdistdir}/tex/latex/aligned-overset
%dir %{_texmfdistdir}/tex/latex/allrunes
%dir %{_texmfdistdir}/tex/latex/almendra
%dir %{_texmfdistdir}/tex/latex/alnumsec
%dir %{_texmfdistdir}/tex/latex/alterqcm
%dir %{_texmfdistdir}/tex/latex/altfont
%dir %{_texmfdistdir}/tex/latex/altsubsup
%dir %{_texmfdistdir}/tex/latex/amsaddr
%dir %{_texmfdistdir}/tex/latex/amscdx
%dir %{_texmfdistdir}/tex/latex/amscls
%dir %{_texmfdistdir}/tex/latex/amsfonts
%dir %{_texmfdistdir}/tex/latex/amsmath
%dir %{_texmfdistdir}/tex/latex/amsrefs
%dir %{_texmfdistdir}/tex/latex/andika
%dir %{_texmfdistdir}/tex/latex/animate
%dir %{_texmfdistdir}/tex/latex/annee-scolaire
%dir %{_texmfdistdir}/tex/latex/annotate-equations
%dir %{_texmfdistdir}/tex/latex/anonchap
%dir %{_texmfdistdir}/tex/latex/anonymous-acm
%dir %{_texmfdistdir}/tex/latex/anonymouspro
%dir %{_texmfdistdir}/tex/latex/answers
%dir %{_texmfdistdir}/tex/latex/antanilipsum
%dir %{_texmfdistdir}/tex/latex/antiqua
%dir %{_texmfdistdir}/tex/latex/antt
%dir %{_texmfdistdir}/tex/latex/anyfontsize
%dir %{_texmfdistdir}/tex/latex/anysize
%dir %{_texmfdistdir}/tex/latex/aobs-tikz
%dir %{_texmfdistdir}/tex/latex/aomart
%dir %{_texmfdistdir}/tex/latex/apa
%dir %{_texmfdistdir}/tex/latex/apa6
%dir %{_texmfdistdir}/tex/latex/apa6/config
%dir %{_texmfdistdir}/tex/latex/apa6e
%dir %{_texmfdistdir}/tex/latex/apa7
%dir %{_texmfdistdir}/tex/latex/apa7/config
%dir %{_texmfdistdir}/tex/latex/apacite
%dir %{_texmfdistdir}/tex/latex/appendix
%dir %{_texmfdistdir}/tex/latex/appendixnumberbeamer
%dir %{_texmfdistdir}/tex/latex/apptools
%dir %{_texmfdistdir}/tex/latex/apxproof
%dir %{_texmfdistdir}/tex/latex/arabi
%dir %{_texmfdistdir}/tex/latex/arabi-add
%dir %{_texmfdistdir}/tex/latex/arabicfront
%dir %{_texmfdistdir}/tex/latex/arabtex
%dir %{_texmfdistdir}/tex/latex/aramaic-serto
%dir %{_texmfdistdir}/tex/latex/archaeologie
%dir %{_texmfdistdir}/tex/latex/archaic
%dir %{_texmfdistdir}/tex/latex/archivo
%dir %{_texmfdistdir}/tex/latex/arcs
%dir %{_texmfdistdir}/tex/latex/arev
%dir %{_texmfdistdir}/tex/latex/arimo
%dir %{_texmfdistdir}/tex/latex/armenian
%dir %{_texmfdistdir}/tex/latex/arraycols
%dir %{_texmfdistdir}/tex/latex/arraysort
%dir %{_texmfdistdir}/tex/latex/arsclassica
%dir %{_texmfdistdir}/tex/latex/articleingud
%dir %{_texmfdistdir}/tex/latex/arvo
%dir %{_texmfdistdir}/tex/latex/arydshln
%dir %{_texmfdistdir}/tex/latex/asaetr
%dir %{_texmfdistdir}/tex/latex/asapsym
%dir %{_texmfdistdir}/tex/latex/ascelike
%dir %{_texmfdistdir}/tex/latex/ascii-font
%dir %{_texmfdistdir}/tex/latex/asciilist
%dir %{_texmfdistdir}/tex/latex/ascmac
%dir %{_texmfdistdir}/tex/latex/askinclude
%dir %{_texmfdistdir}/tex/latex/askmaps
%dir %{_texmfdistdir}/tex/latex/asmeconf
%dir %{_texmfdistdir}/tex/latex/asmejour
%dir %{_texmfdistdir}/tex/latex/aspectratio
%dir %{_texmfdistdir}/tex/latex/assignment
%dir %{_texmfdistdir}/tex/latex/assoccnt
%dir %{_texmfdistdir}/tex/latex/association-matrix
%dir %{_texmfdistdir}/tex/latex/asternote
%dir %{_texmfdistdir}/tex/latex/asyfig
%dir %{_texmfdistdir}/tex/latex/asymptote
%dir %{_texmfdistdir}/tex/latex/asypictureb
%dir %{_texmfdistdir}/tex/latex/atenddvi
%dir %{_texmfdistdir}/tex/latex/atendofenv
%dir %{_texmfdistdir}/tex/latex/atkinson
%dir %{_texmfdistdir}/tex/latex/attachfile
%dir %{_texmfdistdir}/tex/latex/attachfile2
%dir %{_texmfdistdir}/tex/latex/atveryend
%dir %{_texmfdistdir}/tex/latex/aucklandthesis
%dir %{_texmfdistdir}/tex/latex/augie
%dir %{_texmfdistdir}/tex/latex/auncial-new
%dir %{_texmfdistdir}/tex/latex/aurical
%dir %{_texmfdistdir}/tex/latex/aurl
%dir %{_texmfdistdir}/tex/latex/authoraftertitle
%dir %{_texmfdistdir}/tex/latex/authorarchive
%dir %{_texmfdistdir}/tex/latex/authordate
%dir %{_texmfdistdir}/tex/latex/authorindex
%dir %{_texmfdistdir}/tex/latex/auto-pst-pdf
%dir %{_texmfdistdir}/tex/latex/auto-pst-pdf-lua
%dir %{_texmfdistdir}/tex/latex/autoarea
%dir %{_texmfdistdir}/tex/latex/autobreak
%dir %{_texmfdistdir}/tex/latex/autofancyhdr
%dir %{_texmfdistdir}/tex/latex/autonum
%dir %{_texmfdistdir}/tex/latex/autopdf
%dir %{_texmfdistdir}/tex/latex/auxhook
%dir %{_texmfdistdir}/tex/latex/avantgar
%dir %{_texmfdistdir}/tex/latex/avremu
%dir %{_texmfdistdir}/tex/latex/awesomebox
%dir %{_texmfdistdir}/tex/latex/axessibility
%dir %{_texmfdistdir}/tex/latex/axodraw2
%dir %{_texmfdistdir}/tex/latex/b1encoding
%dir %{_texmfdistdir}/tex/latex/babelbib
%dir %{_texmfdistdir}/tex/latex/background
%dir %{_texmfdistdir}/tex/latex/backnaur
%dir %{_texmfdistdir}/tex/latex/bangla
%dir %{_texmfdistdir}/tex/latex/bangorcsthesis
%dir %{_texmfdistdir}/tex/latex/bangorexam
%dir %{_texmfdistdir}/tex/latex/bangtex
%dir %{_texmfdistdir}/tex/latex/bankstatement
%dir %{_texmfdistdir}/tex/latex/barcodes
%dir %{_texmfdistdir}/tex/latex/bardiag
%dir %{_texmfdistdir}/tex/latex/base
%dir %{_texmfdistdir}/tex/latex/bashful
%dir %{_texmfdistdir}/tex/latex/basicarith
%dir %{_texmfdistdir}/tex/latex/baskervald
%dir %{_texmfdistdir}/tex/latex/baskervaldx
%dir %{_texmfdistdir}/tex/latex/baskervillef
%dir %{_texmfdistdir}/tex/latex/basque-book
%dir %{_texmfdistdir}/tex/latex/basque-date
%dir %{_texmfdistdir}/tex/latex/bbding
%dir %{_texmfdistdir}/tex/latex/bbm-macros
%dir %{_texmfdistdir}/tex/latex/bbold
%dir %{_texmfdistdir}/tex/latex/bboldx
%dir %{_texmfdistdir}/tex/latex/bchart
%dir %{_texmfdistdir}/tex/latex/bclogo
%dir %{_texmfdistdir}/tex/latex/beamer
%dir %{_texmfdistdir}/tex/latex/beamer-fuberlin
%dir %{_texmfdistdir}/tex/latex/beamer-verona
%dir %{_texmfdistdir}/tex/latex/beamer2thesis
%dir %{_texmfdistdir}/tex/latex/beamerappendixnote
%dir %{_texmfdistdir}/tex/latex/beameraudience
%dir %{_texmfdistdir}/tex/latex/beamerauxtheme
%dir %{_texmfdistdir}/tex/latex/beamercolorthemeowl
%dir %{_texmfdistdir}/tex/latex/beamerdarkthemes
%dir %{_texmfdistdir}/tex/latex/beamerposter
%dir %{_texmfdistdir}/tex/latex/beamersubframe
%dir %{_texmfdistdir}/tex/latex/beamerswitch
%dir %{_texmfdistdir}/tex/latex/beamertheme-arguelles
%dir %{_texmfdistdir}/tex/latex/beamertheme-cuerna
%dir %{_texmfdistdir}/tex/latex/beamertheme-detlevcm
%dir %{_texmfdistdir}/tex/latex/beamertheme-epyt
%dir %{_texmfdistdir}/tex/latex/beamertheme-focus
%dir %{_texmfdistdir}/tex/latex/beamertheme-light
%dir %{_texmfdistdir}/tex/latex/beamertheme-metropolis
%dir %{_texmfdistdir}/tex/latex/beamertheme-npbt
%dir %{_texmfdistdir}/tex/latex/beamertheme-npbt/images
%dir %{_texmfdistdir}/tex/latex/beamertheme-phnompenh
%dir %{_texmfdistdir}/tex/latex/beamertheme-pure-minimalistic
%dir %{_texmfdistdir}/tex/latex/beamertheme-saintpetersburg
%dir %{_texmfdistdir}/tex/latex/beamertheme-simpledarkblue
%dir %{_texmfdistdir}/tex/latex/beamertheme-simpleplus
%dir %{_texmfdistdir}/tex/latex/beamertheme-tcolorbox
%dir %{_texmfdistdir}/tex/latex/beamertheme-trigon
%dir %{_texmfdistdir}/tex/latex/beamertheme-upenn-bc
%dir %{_texmfdistdir}/tex/latex/beamerthemeamurmaple
%dir %{_texmfdistdir}/tex/latex/beamerthemejltree
%dir %{_texmfdistdir}/tex/latex/beamerthemelalic
%dir %{_texmfdistdir}/tex/latex/beamerthemenirma
%dir %{_texmfdistdir}/tex/latex/beamerthemenord
%dir %{_texmfdistdir}/tex/latex/bearwear
%dir %{_texmfdistdir}/tex/latex/beaulivre
%dir %{_texmfdistdir}/tex/latex/begingreek
%dir %{_texmfdistdir}/tex/latex/begriff
%dir %{_texmfdistdir}/tex/latex/beilstein
%dir %{_texmfdistdir}/tex/latex/bengali
%dir %{_texmfdistdir}/tex/latex/bera
%dir %{_texmfdistdir}/tex/latex/berenisadf
%dir %{_texmfdistdir}/tex/latex/betababel
%dir %{_texmfdistdir}/tex/latex/beton
%dir %{_texmfdistdir}/tex/latex/beuron
%dir %{_texmfdistdir}/tex/latex/bewerbung
%dir %{_texmfdistdir}/tex/latex/bez123
%dir %{_texmfdistdir}/tex/latex/bfh-ci
%dir %{_texmfdistdir}/tex/latex/bgteubner
%dir %{_texmfdistdir}/tex/latex/bguq
%dir %{_texmfdistdir}/tex/latex/bibarts
%dir %{_texmfdistdir}/tex/latex/bibcop
%dir %{_texmfdistdir}/tex/latex/biblatex
%dir %{_texmfdistdir}/tex/latex/biblatex-abnt
%dir %{_texmfdistdir}/tex/latex/biblatex-ajc2020unofficial
%dir %{_texmfdistdir}/tex/latex/biblatex-anonymous
%dir %{_texmfdistdir}/tex/latex/biblatex-apa
%dir %{_texmfdistdir}/tex/latex/biblatex-apa6
%dir %{_texmfdistdir}/tex/latex/biblatex-archaeology
%dir %{_texmfdistdir}/tex/latex/biblatex-arthistory-bonn
%dir %{_texmfdistdir}/tex/latex/biblatex-bath
%dir %{_texmfdistdir}/tex/latex/biblatex-bookinarticle
%dir %{_texmfdistdir}/tex/latex/biblatex-bookinother
%dir %{_texmfdistdir}/tex/latex/biblatex-bwl
%dir %{_texmfdistdir}/tex/latex/biblatex-caspervector
%dir %{_texmfdistdir}/tex/latex/biblatex-chem
%dir %{_texmfdistdir}/tex/latex/biblatex-chicago
%dir %{_texmfdistdir}/tex/latex/biblatex-claves
%dir %{_texmfdistdir}/tex/latex/biblatex-cv
%dir %{_texmfdistdir}/tex/latex/biblatex-dw
%dir %{_texmfdistdir}/tex/latex/biblatex-dw/bbx
%dir %{_texmfdistdir}/tex/latex/biblatex-dw/cbx
%dir %{_texmfdistdir}/tex/latex/biblatex-dw/lbx
%dir %{_texmfdistdir}/tex/latex/biblatex-enc
%dir %{_texmfdistdir}/tex/latex/biblatex-ext
%dir %{_texmfdistdir}/tex/latex/biblatex-fiwi
%dir %{_texmfdistdir}/tex/latex/biblatex-gb7714-2015
%dir %{_texmfdistdir}/tex/latex/biblatex-german-legal
%dir %{_texmfdistdir}/tex/latex/biblatex-gost
%dir %{_texmfdistdir}/tex/latex/biblatex-historian
%dir %{_texmfdistdir}/tex/latex/biblatex-ieee
%dir %{_texmfdistdir}/tex/latex/biblatex-ijsra
%dir %{_texmfdistdir}/tex/latex/biblatex-iso690
%dir %{_texmfdistdir}/tex/latex/biblatex-jura2
%dir %{_texmfdistdir}/tex/latex/biblatex-juradiss
%dir %{_texmfdistdir}/tex/latex/biblatex-license
%dir %{_texmfdistdir}/tex/latex/biblatex-lncs
%dir %{_texmfdistdir}/tex/latex/biblatex-lni
%dir %{_texmfdistdir}/tex/latex/biblatex-luh-ipw
%dir %{_texmfdistdir}/tex/latex/biblatex-luh-ipw/bbx
%dir %{_texmfdistdir}/tex/latex/biblatex-luh-ipw/cbx
%dir %{_texmfdistdir}/tex/latex/biblatex-luh-ipw/lbx
%dir %{_texmfdistdir}/tex/latex/biblatex-manuscripts-philology
%dir %{_texmfdistdir}/tex/latex/biblatex-mla
%dir %{_texmfdistdir}/tex/latex/biblatex-morenames
%dir %{_texmfdistdir}/tex/latex/biblatex-ms
%dir %{_texmfdistdir}/tex/latex/biblatex-ms/bbx
%dir %{_texmfdistdir}/tex/latex/biblatex-ms/cbx
%dir %{_texmfdistdir}/tex/latex/biblatex-ms/lbx
%dir %{_texmfdistdir}/tex/latex/biblatex-multiple-dm
%dir %{_texmfdistdir}/tex/latex/biblatex-musuos
%dir %{_texmfdistdir}/tex/latex/biblatex-nature
%dir %{_texmfdistdir}/tex/latex/biblatex-nejm
%dir %{_texmfdistdir}/tex/latex/biblatex-nottsclassic
%dir %{_texmfdistdir}/tex/latex/biblatex-opcit-booktitle
%dir %{_texmfdistdir}/tex/latex/biblatex-oxref
%dir %{_texmfdistdir}/tex/latex/biblatex-philosophy
%dir %{_texmfdistdir}/tex/latex/biblatex-phys
%dir %{_texmfdistdir}/tex/latex/biblatex-publist
%dir %{_texmfdistdir}/tex/latex/biblatex-readbbl
%dir %{_texmfdistdir}/tex/latex/biblatex-realauthor
%dir %{_texmfdistdir}/tex/latex/biblatex-sbl
%dir %{_texmfdistdir}/tex/latex/biblatex-science
%dir %{_texmfdistdir}/tex/latex/biblatex-shortfields
%dir %{_texmfdistdir}/tex/latex/biblatex-socialscienceshuberlin
%dir %{_texmfdistdir}/tex/latex/biblatex-software
%dir %{_texmfdistdir}/tex/latex/biblatex-source-division
%dir %{_texmfdistdir}/tex/latex/biblatex-spbasic
%dir %{_texmfdistdir}/tex/latex/biblatex-subseries
%dir %{_texmfdistdir}/tex/latex/biblatex-swiss-legal
%dir %{_texmfdistdir}/tex/latex/biblatex-trad
%dir %{_texmfdistdir}/tex/latex/biblatex-true-citepages-omit
%dir %{_texmfdistdir}/tex/latex/biblatex-unified
%dir %{_texmfdistdir}/tex/latex/biblatex-vancouver
%dir %{_texmfdistdir}/tex/latex/biblatex/bbx
%dir %{_texmfdistdir}/tex/latex/biblatex/cbx
%dir %{_texmfdistdir}/tex/latex/biblatex/lbx
%dir %{_texmfdistdir}/tex/latex/biblatex2bibitem
%dir %{_texmfdistdir}/tex/latex/bibleref
%dir %{_texmfdistdir}/tex/latex/bibleref-french
%dir %{_texmfdistdir}/tex/latex/bibleref-german
%dir %{_texmfdistdir}/tex/latex/bibleref-lds
%dir %{_texmfdistdir}/tex/latex/bibleref-mouth
%dir %{_texmfdistdir}/tex/latex/bibleref-parse
%dir %{_texmfdistdir}/tex/latex/bibletext
%dir %{_texmfdistdir}/tex/latex/biblist
%dir %{_texmfdistdir}/tex/latex/bibtopic
%dir %{_texmfdistdir}/tex/latex/bibtopicprefix
%dir %{_texmfdistdir}/tex/latex/bibunits
%dir %{_texmfdistdir}/tex/latex/bigfoot
%dir %{_texmfdistdir}/tex/latex/bigints
%dir %{_texmfdistdir}/tex/latex/bilingualpages
%dir %{_texmfdistdir}/tex/latex/binarytree
%dir %{_texmfdistdir}/tex/latex/binomexp
%dir %{_texmfdistdir}/tex/latex/biochemistry-colors
%dir %{_texmfdistdir}/tex/latex/biocon
%dir %{_texmfdistdir}/tex/latex/bithesis
%dir %{_texmfdistdir}/tex/latex/bitpattern
%dir %{_texmfdistdir}/tex/latex/bitter
%dir %{_texmfdistdir}/tex/latex/bizcard
%dir %{_texmfdistdir}/tex/latex/bjfuthesis
%dir %{_texmfdistdir}/tex/latex/blacklettert1
%dir %{_texmfdistdir}/tex/latex/blindtext
%dir %{_texmfdistdir}/tex/latex/blkarray
%dir %{_texmfdistdir}/tex/latex/blochsphere
%dir %{_texmfdistdir}/tex/latex/block
%dir %{_texmfdistdir}/tex/latex/bloques
%dir %{_texmfdistdir}/tex/latex/blowup
%dir %{_texmfdistdir}/tex/latex/blox
%dir %{_texmfdistdir}/tex/latex/bmstu
%dir %{_texmfdistdir}/tex/latex/bmstu-iu8
%dir %{_texmfdistdir}/tex/latex/bnumexpr
%dir %{_texmfdistdir}/tex/latex/bodegraph
%dir %{_texmfdistdir}/tex/latex/bodeplot
%dir %{_texmfdistdir}/tex/latex/bohr
%dir %{_texmfdistdir}/tex/latex/boisik
%dir %{_texmfdistdir}/tex/latex/boites
%dir %{_texmfdistdir}/tex/latex/bold-extra
%dir %{_texmfdistdir}/tex/latex/boldtensors
%dir %{_texmfdistdir}/tex/latex/bondgraph
%dir %{_texmfdistdir}/tex/latex/bondgraphs
%dir %{_texmfdistdir}/tex/latex/book-of-common-prayer
%dir %{_texmfdistdir}/tex/latex/bookcover
%dir %{_texmfdistdir}/tex/latex/bookest
%dir %{_texmfdistdir}/tex/latex/bookhands
%dir %{_texmfdistdir}/tex/latex/booklet
%dir %{_texmfdistdir}/tex/latex/bookman
%dir %{_texmfdistdir}/tex/latex/bookmark
%dir %{_texmfdistdir}/tex/latex/bookshelf
%dir %{_texmfdistdir}/tex/latex/booktabs
%dir %{_texmfdistdir}/tex/latex/boolexpr
%dir %{_texmfdistdir}/tex/latex/boondox
%dir %{_texmfdistdir}/tex/latex/bophook
%dir %{_texmfdistdir}/tex/latex/bosisio
%dir %{_texmfdistdir}/tex/latex/boxedminipage
%dir %{_texmfdistdir}/tex/latex/boxhandler
%dir %{_texmfdistdir}/tex/latex/bpchem
%dir %{_texmfdistdir}/tex/latex/br-lex
%dir %{_texmfdistdir}/tex/latex/bracketkey
%dir %{_texmfdistdir}/tex/latex/braids
%dir %{_texmfdistdir}/tex/latex/braille
%dir %{_texmfdistdir}/tex/latex/braket
%dir %{_texmfdistdir}/tex/latex/brandeis-dissertation
%dir %{_texmfdistdir}/tex/latex/brandeis-problemset
%dir %{_texmfdistdir}/tex/latex/brandeis-thesis
%dir %{_texmfdistdir}/tex/latex/breakcites
%dir %{_texmfdistdir}/tex/latex/breakurl
%dir %{_texmfdistdir}/tex/latex/bredzenie
%dir %{_texmfdistdir}/tex/latex/breqn
%dir %{_texmfdistdir}/tex/latex/bropd
%dir %{_texmfdistdir}/tex/latex/brushscr
%dir %{_texmfdistdir}/tex/latex/bubblesort
%dir %{_texmfdistdir}/tex/latex/bullcntr
%dir %{_texmfdistdir}/tex/latex/bundledoc
%dir %{_texmfdistdir}/tex/latex/burmese
%dir %{_texmfdistdir}/tex/latex/bussproofs
%dir %{_texmfdistdir}/tex/latex/bussproofs-extra
%dir %{_texmfdistdir}/tex/latex/bxbase
%dir %{_texmfdistdir}/tex/latex/bxcalc
%dir %{_texmfdistdir}/tex/latex/bxcjkjatype
%dir %{_texmfdistdir}/tex/latex/bxdpx-beamer
%dir %{_texmfdistdir}/tex/latex/bxdvidriver
%dir %{_texmfdistdir}/tex/latex/bxeepic
%dir %{_texmfdistdir}/tex/latex/bxenclose
%dir %{_texmfdistdir}/tex/latex/bxghost
%dir %{_texmfdistdir}/tex/latex/bxjaholiday
%dir %{_texmfdistdir}/tex/latex/bxjalipsum
%dir %{_texmfdistdir}/tex/latex/bxjaprnind
%dir %{_texmfdistdir}/tex/latex/bxjatoucs
%dir %{_texmfdistdir}/tex/latex/bxjscls
%dir %{_texmfdistdir}/tex/latex/bxnewfont
%dir %{_texmfdistdir}/tex/latex/bxorigcapt
%dir %{_texmfdistdir}/tex/latex/bxpapersize
%dir %{_texmfdistdir}/tex/latex/bxpdfver
%dir %{_texmfdistdir}/tex/latex/bxtexlogo
%dir %{_texmfdistdir}/tex/latex/bxwareki
%dir %{_texmfdistdir}/tex/latex/byo-twemojis
%dir %{_texmfdistdir}/tex/latex/byrne
%dir %{_texmfdistdir}/tex/latex/bytefield
%dir %{_texmfdistdir}/tex/latex/cabin
%dir %{_texmfdistdir}/tex/latex/cachepic
%dir %{_texmfdistdir}/tex/latex/caladea
%dir %{_texmfdistdir}/tex/latex/calcage
%dir %{_texmfdistdir}/tex/latex/calctab
%dir %{_texmfdistdir}/tex/latex/calculation
%dir %{_texmfdistdir}/tex/latex/calculator
%dir %{_texmfdistdir}/tex/latex/callouts
%dir %{_texmfdistdir}/tex/latex/calrsfs
%dir %{_texmfdistdir}/tex/latex/cals
%dir %{_texmfdistdir}/tex/latex/calxxxx-yyyy
%dir %{_texmfdistdir}/tex/latex/cancel
%dir %{_texmfdistdir}/tex/latex/canoniclayout
%dir %{_texmfdistdir}/tex/latex/cantarell
%dir %{_texmfdistdir}/tex/latex/capt-of
%dir %{_texmfdistdir}/tex/latex/captcont
%dir %{_texmfdistdir}/tex/latex/captdef
%dir %{_texmfdistdir}/tex/latex/caption
%dir %{_texmfdistdir}/tex/latex/carbohydrates
%dir %{_texmfdistdir}/tex/latex/carlisle
%dir %{_texmfdistdir}/tex/latex/carlito
%dir %{_texmfdistdir}/tex/latex/cartonaugh
%dir %{_texmfdistdir}/tex/latex/cascade
%dir %{_texmfdistdir}/tex/latex/cascadia-code
%dir %{_texmfdistdir}/tex/latex/cascadilla
%dir %{_texmfdistdir}/tex/latex/cases
%dir %{_texmfdistdir}/tex/latex/casyl
%dir %{_texmfdistdir}/tex/latex/catchfilebetweentags
%dir %{_texmfdistdir}/tex/latex/catechis
%dir %{_texmfdistdir}/tex/latex/catoptions
%dir %{_texmfdistdir}/tex/latex/causets
%dir %{_texmfdistdir}/tex/latex/cbcoptic
%dir %{_texmfdistdir}/tex/latex/cbfonts-fd
%dir %{_texmfdistdir}/tex/latex/ccaption
%dir %{_texmfdistdir}/tex/latex/ccfonts
%dir %{_texmfdistdir}/tex/latex/ccicons
%dir %{_texmfdistdir}/tex/latex/cclicenses
%dir %{_texmfdistdir}/tex/latex/ccool
%dir %{_texmfdistdir}/tex/latex/cd
%dir %{_texmfdistdir}/tex/latex/cd-cover
%dir %{_texmfdistdir}/tex/latex/cdcmd
%dir %{_texmfdistdir}/tex/latex/cdpbundl
%dir %{_texmfdistdir}/tex/latex/cell
%dir %{_texmfdistdir}/tex/latex/cellprops
%dir %{_texmfdistdir}/tex/latex/cellspace
%dir %{_texmfdistdir}/tex/latex/celtic
%dir %{_texmfdistdir}/tex/latex/censor
%dir %{_texmfdistdir}/tex/latex/centeredline
%dir %{_texmfdistdir}/tex/latex/centerlastline
%dir %{_texmfdistdir}/tex/latex/cesenaexam
%dir %{_texmfdistdir}/tex/latex/cfr-initials
%dir %{_texmfdistdir}/tex/latex/cfr-lm
%dir %{_texmfdistdir}/tex/latex/changebar
%dir %{_texmfdistdir}/tex/latex/changelayout
%dir %{_texmfdistdir}/tex/latex/changelog
%dir %{_texmfdistdir}/tex/latex/changepage
%dir %{_texmfdistdir}/tex/latex/changes
%dir %{_texmfdistdir}/tex/latex/chappg
%dir %{_texmfdistdir}/tex/latex/chapterfolder
%dir %{_texmfdistdir}/tex/latex/charissil
%dir %{_texmfdistdir}/tex/latex/chbibref
%dir %{_texmfdistdir}/tex/latex/cheatsheet
%dir %{_texmfdistdir}/tex/latex/checkend
%dir %{_texmfdistdir}/tex/latex/checklistings
%dir %{_texmfdistdir}/tex/latex/chemarrow
%dir %{_texmfdistdir}/tex/latex/chemcompounds
%dir %{_texmfdistdir}/tex/latex/chemcono
%dir %{_texmfdistdir}/tex/latex/chemexec
%dir %{_texmfdistdir}/tex/latex/chemformula
%dir %{_texmfdistdir}/tex/latex/chemgreek
%dir %{_texmfdistdir}/tex/latex/chemmacros
%dir %{_texmfdistdir}/tex/latex/chemnum
%dir %{_texmfdistdir}/tex/latex/chemobabel
%dir %{_texmfdistdir}/tex/latex/chemplants
%dir %{_texmfdistdir}/tex/latex/chemschemex
%dir %{_texmfdistdir}/tex/latex/chemsec
%dir %{_texmfdistdir}/tex/latex/chemstyle
%dir %{_texmfdistdir}/tex/latex/chemstyle/config
%dir %{_texmfdistdir}/tex/latex/cherokee
%dir %{_texmfdistdir}/tex/latex/chess
%dir %{_texmfdistdir}/tex/latex/chess-problem-diagrams
%dir %{_texmfdistdir}/tex/latex/chessboard
%dir %{_texmfdistdir}/tex/latex/chessfss
%dir %{_texmfdistdir}/tex/latex/chet
%dir %{_texmfdistdir}/tex/latex/chextras
%dir %{_texmfdistdir}/tex/latex/chhaya
%dir %{_texmfdistdir}/tex/latex/chicago
%dir %{_texmfdistdir}/tex/latex/chifoot
%dir %{_texmfdistdir}/tex/latex/childdoc
%dir %{_texmfdistdir}/tex/latex/chinesechess
%dir %{_texmfdistdir}/tex/latex/chivo
%dir %{_texmfdistdir}/tex/latex/chkfloat
%dir %{_texmfdistdir}/tex/latex/chklref
%dir %{_texmfdistdir}/tex/latex/chletter
%dir %{_texmfdistdir}/tex/latex/chngcntr
%dir %{_texmfdistdir}/tex/latex/chordbars
%dir %{_texmfdistdir}/tex/latex/chordbox
%dir %{_texmfdistdir}/tex/latex/chronology
%dir %{_texmfdistdir}/tex/latex/chs-physics-report
%dir %{_texmfdistdir}/tex/latex/chscite
%dir %{_texmfdistdir}/tex/latex/churchslavonic
%dir %{_texmfdistdir}/tex/latex/cinzel
%dir %{_texmfdistdir}/tex/latex/circ
%dir %{_texmfdistdir}/tex/latex/circledsteps
%dir %{_texmfdistdir}/tex/latex/circledtext
%dir %{_texmfdistdir}/tex/latex/circuit-macros
%dir %{_texmfdistdir}/tex/latex/circuitikz
%dir %{_texmfdistdir}/tex/latex/citation-style-language
%dir %{_texmfdistdir}/tex/latex/citation-style-language/locales
%dir %{_texmfdistdir}/tex/latex/citation-style-language/styles
%dir %{_texmfdistdir}/tex/latex/cite
%dir %{_texmfdistdir}/tex/latex/citeall
%dir %{_texmfdistdir}/tex/latex/citeref
%dir %{_texmfdistdir}/tex/latex/cje
%dir %{_texmfdistdir}/tex/latex/cjhebrew
%dir %{_texmfdistdir}/tex/latex/cjk
%dir %{_texmfdistdir}/tex/latex/cjk-ko
%dir %{_texmfdistdir}/tex/latex/cjk/contrib
%dir %{_texmfdistdir}/tex/latex/cjk/contrib/wadalab
%dir %{_texmfdistdir}/tex/latex/cjk/texinput
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/Bg5
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/CEF
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/CNS
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/GB
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/JIS
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/KS
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/KS/HLaTeX
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/SJIS
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/UTF8
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/mule
%dir %{_texmfdistdir}/tex/latex/cjk/texinput/thai
%dir %{_texmfdistdir}/tex/latex/cjk/utils
%dir %{_texmfdistdir}/tex/latex/cjk/utils/pyhyphen
%dir %{_texmfdistdir}/tex/latex/cjkpunct
%dir %{_texmfdistdir}/tex/latex/clara
%dir %{_texmfdistdir}/tex/latex/classics
%dir %{_texmfdistdir}/tex/latex/classicthesis
%dir %{_texmfdistdir}/tex/latex/classpack
%dir %{_texmfdistdir}/tex/latex/cleanthesis
%dir %{_texmfdistdir}/tex/latex/clearsans
%dir %{_texmfdistdir}/tex/latex/clefval
%dir %{_texmfdistdir}/tex/latex/cleveref
%dir %{_texmfdistdir}/tex/latex/clicks
%dir %{_texmfdistdir}/tex/latex/clipboard
%dir %{_texmfdistdir}/tex/latex/clistmap
%dir %{_texmfdistdir}/tex/latex/clock
%dir %{_texmfdistdir}/tex/latex/clojure-pamphlet
%dir %{_texmfdistdir}/tex/latex/clrdblpg
%dir %{_texmfdistdir}/tex/latex/clrscode
%dir %{_texmfdistdir}/tex/latex/clrscode3e
%dir %{_texmfdistdir}/tex/latex/clrstrip
%dir %{_texmfdistdir}/tex/latex/cm-lgc
%dir %{_texmfdistdir}/tex/latex/cm-super
%dir %{_texmfdistdir}/tex/latex/cmap
%dir %{_texmfdistdir}/tex/latex/cmathbb
%dir %{_texmfdistdir}/tex/latex/cmbright
%dir %{_texmfdistdir}/tex/latex/cmdstring
%dir %{_texmfdistdir}/tex/latex/cmdtrack
%dir %{_texmfdistdir}/tex/latex/cmll
%dir %{_texmfdistdir}/tex/latex/cmpj
%dir %{_texmfdistdir}/tex/latex/cmsd
%dir %{_texmfdistdir}/tex/latex/cmsrb
%dir %{_texmfdistdir}/tex/latex/cmtiup
%dir %{_texmfdistdir}/tex/latex/cmupint
%dir %{_texmfdistdir}/tex/latex/cnbwp
%dir %{_texmfdistdir}/tex/latex/cnltx
%dir %{_texmfdistdir}/tex/latex/cntformats
%dir %{_texmfdistdir}/tex/latex/cntperchap
%dir %{_texmfdistdir}/tex/latex/cochineal
%dir %{_texmfdistdir}/tex/latex/codeanatomy
%dir %{_texmfdistdir}/tex/latex/codebox
%dir %{_texmfdistdir}/tex/latex/codedoc
%dir %{_texmfdistdir}/tex/latex/codehigh
%dir %{_texmfdistdir}/tex/latex/codepage
%dir %{_texmfdistdir}/tex/latex/codesection
%dir %{_texmfdistdir}/tex/latex/codicefiscaleitaliano
%dir %{_texmfdistdir}/tex/latex/coelacanth
%dir %{_texmfdistdir}/tex/latex/coffeestains
%dir %{_texmfdistdir}/tex/latex/collcell
%dir %{_texmfdistdir}/tex/latex/collectbox
%dir %{_texmfdistdir}/tex/latex/collref
%dir %{_texmfdistdir}/tex/latex/colophon
%dir %{_texmfdistdir}/tex/latex/color-edits
%dir %{_texmfdistdir}/tex/latex/colordoc
%dir %{_texmfdistdir}/tex/latex/colorframed
%dir %{_texmfdistdir}/tex/latex/colorinfo
%dir %{_texmfdistdir}/tex/latex/coloring
%dir %{_texmfdistdir}/tex/latex/colorist
%dir %{_texmfdistdir}/tex/latex/colorspace
%dir %{_texmfdistdir}/tex/latex/colortbl
%dir %{_texmfdistdir}/tex/latex/colorwav
%dir %{_texmfdistdir}/tex/latex/colorweb
%dir %{_texmfdistdir}/tex/latex/colourchange
%dir %{_texmfdistdir}/tex/latex/combelow
%dir %{_texmfdistdir}/tex/latex/combine
%dir %{_texmfdistdir}/tex/latex/combinedgraphics
%dir %{_texmfdistdir}/tex/latex/comfortaa
%dir %{_texmfdistdir}/tex/latex/comicneue
%dir %{_texmfdistdir}/tex/latex/comma
%dir %{_texmfdistdir}/tex/latex/commath
%dir %{_texmfdistdir}/tex/latex/commedit
%dir %{_texmfdistdir}/tex/latex/comment
%dir %{_texmfdistdir}/tex/latex/commonunicode
%dir %{_texmfdistdir}/tex/latex/commutative-diagrams
%dir %{_texmfdistdir}/tex/latex/compactbib
%dir %{_texmfdistdir}/tex/latex/competences
%dir %{_texmfdistdir}/tex/latex/complexity
%dir %{_texmfdistdir}/tex/latex/computational-complexity
%dir %{_texmfdistdir}/tex/latex/concepts
%dir %{_texmfdistdir}/tex/latex/concmath
%dir %{_texmfdistdir}/tex/latex/concmath-otf
%dir %{_texmfdistdir}/tex/latex/concprog
%dir %{_texmfdistdir}/tex/latex/conditext
%dir %{_texmfdistdir}/tex/latex/confproc
%dir %{_texmfdistdir}/tex/latex/constants
%dir %{_texmfdistdir}/tex/latex/conteq
%dir %{_texmfdistdir}/tex/latex/context
%dir %{_texmfdistdir}/tex/latex/context/ppchtex
%dir %{_texmfdistdir}/tex/latex/continue
%dir %{_texmfdistdir}/tex/latex/contour
%dir %{_texmfdistdir}/tex/latex/contracard
%dir %{_texmfdistdir}/tex/latex/conv-xkv
%dir %{_texmfdistdir}/tex/latex/cooking
%dir %{_texmfdistdir}/tex/latex/cooking-units
%dir %{_texmfdistdir}/tex/latex/cookingsymbols
%dir %{_texmfdistdir}/tex/latex/cool
%dir %{_texmfdistdir}/tex/latex/coolfn
%dir %{_texmfdistdir}/tex/latex/coollist
%dir %{_texmfdistdir}/tex/latex/coolstr
%dir %{_texmfdistdir}/tex/latex/coolthms
%dir %{_texmfdistdir}/tex/latex/cooltooltips
%dir %{_texmfdistdir}/tex/latex/coop-writing
%dir %{_texmfdistdir}/tex/latex/cooperhewitt
%dir %{_texmfdistdir}/tex/latex/coordsys
%dir %{_texmfdistdir}/tex/latex/copyedit
%dir %{_texmfdistdir}/tex/latex/copyrightbox
%dir %{_texmfdistdir}/tex/latex/cormorantgaramond
%dir %{_texmfdistdir}/tex/latex/correctmathalign
%dir %{_texmfdistdir}/tex/latex/coseoul
%dir %{_texmfdistdir}/tex/latex/countriesofeurope
%dir %{_texmfdistdir}/tex/latex/counttexruns
%dir %{_texmfdistdir}/tex/latex/courier
%dir %{_texmfdistdir}/tex/latex/courier-scaled
%dir %{_texmfdistdir}/tex/latex/courierten
%dir %{_texmfdistdir}/tex/latex/courseoutline
%dir %{_texmfdistdir}/tex/latex/coursepaper
%dir %{_texmfdistdir}/tex/latex/coverpage
%dir %{_texmfdistdir}/tex/latex/covington
%dir %{_texmfdistdir}/tex/latex/cprotect
%dir %{_texmfdistdir}/tex/latex/cprotectinside
%dir %{_texmfdistdir}/tex/latex/cquthesis
%dir %{_texmfdistdir}/tex/latex/crbox
%dir %{_texmfdistdir}/tex/latex/create-theorem
%dir %{_texmfdistdir}/tex/latex/crefthe
%dir %{_texmfdistdir}/tex/latex/crimson
%dir %{_texmfdistdir}/tex/latex/crimsonpro
%dir %{_texmfdistdir}/tex/latex/crop
%dir %{_texmfdistdir}/tex/latex/crossreference
%dir %{_texmfdistdir}/tex/latex/crossreftools
%dir %{_texmfdistdir}/tex/latex/crossrefware
%dir %{_texmfdistdir}/tex/latex/crossword
%dir %{_texmfdistdir}/tex/latex/crosswrd
%dir %{_texmfdistdir}/tex/latex/crumbs
%dir %{_texmfdistdir}/tex/latex/cryptocode
%dir %{_texmfdistdir}/tex/latex/csassignments
%dir %{_texmfdistdir}/tex/latex/csbulletin
%dir %{_texmfdistdir}/tex/latex/csquotes
%dir %{_texmfdistdir}/tex/latex/css-colors
%dir %{_texmfdistdir}/tex/latex/csvmerge
%dir %{_texmfdistdir}/tex/latex/csvsimple
%dir %{_texmfdistdir}/tex/latex/ctable
%dir %{_texmfdistdir}/tex/latex/ctex
%dir %{_texmfdistdir}/tex/latex/ctex/config
%dir %{_texmfdistdir}/tex/latex/ctex/dictionary
%dir %{_texmfdistdir}/tex/latex/ctex/engine
%dir %{_texmfdistdir}/tex/latex/ctex/fd
%dir %{_texmfdistdir}/tex/latex/ctex/fontset
%dir %{_texmfdistdir}/tex/latex/ctex/heading
%dir %{_texmfdistdir}/tex/latex/ctex/scheme
%dir %{_texmfdistdir}/tex/latex/ctib
%dir %{_texmfdistdir}/tex/latex/cuisine
%dir %{_texmfdistdir}/tex/latex/cuprum
%dir %{_texmfdistdir}/tex/latex/currency
%dir %{_texmfdistdir}/tex/latex/currfile
%dir %{_texmfdistdir}/tex/latex/currvita
%dir %{_texmfdistdir}/tex/latex/curve
%dir %{_texmfdistdir}/tex/latex/curve2e
%dir %{_texmfdistdir}/tex/latex/curves
%dir %{_texmfdistdir}/tex/latex/custom-bib
%dir %{_texmfdistdir}/tex/latex/customdice
%dir %{_texmfdistdir}/tex/latex/cutwin
%dir %{_texmfdistdir}/tex/latex/cv
%dir %{_texmfdistdir}/tex/latex/cv4tw
%dir %{_texmfdistdir}/tex/latex/cvss
%dir %{_texmfdistdir}/tex/latex/cweb-latex
%dir %{_texmfdistdir}/tex/latex/cyber
%dir %{_texmfdistdir}/tex/latex/cybercic
%dir %{_texmfdistdir}/tex/latex/cyklop
%dir %{_texmfdistdir}/tex/latex/cyrillic
%dir %{_texmfdistdir}/tex/latex/dantelogo
%dir %{_texmfdistdir}/tex/latex/darkmode
%dir %{_texmfdistdir}/tex/latex/dashbox
%dir %{_texmfdistdir}/tex/latex/dashrule
%dir %{_texmfdistdir}/tex/latex/dashundergaps
%dir %{_texmfdistdir}/tex/latex/dataref
%dir %{_texmfdistdir}/tex/latex/datatool
%dir %{_texmfdistdir}/tex/latex/datax
%dir %{_texmfdistdir}/tex/latex/dateiliste
%dir %{_texmfdistdir}/tex/latex/datenumber
%dir %{_texmfdistdir}/tex/latex/datetime
%dir %{_texmfdistdir}/tex/latex/datetime2
%dir %{_texmfdistdir}/tex/latex/datetime2-bahasai
%dir %{_texmfdistdir}/tex/latex/datetime2-basque
%dir %{_texmfdistdir}/tex/latex/datetime2-breton
%dir %{_texmfdistdir}/tex/latex/datetime2-bulgarian
%dir %{_texmfdistdir}/tex/latex/datetime2-catalan
%dir %{_texmfdistdir}/tex/latex/datetime2-croatian
%dir %{_texmfdistdir}/tex/latex/datetime2-czech
%dir %{_texmfdistdir}/tex/latex/datetime2-danish
%dir %{_texmfdistdir}/tex/latex/datetime2-dutch
%dir %{_texmfdistdir}/tex/latex/datetime2-en-fulltext
%dir %{_texmfdistdir}/tex/latex/datetime2-english
%dir %{_texmfdistdir}/tex/latex/datetime2-esperanto
%dir %{_texmfdistdir}/tex/latex/datetime2-estonian
%dir %{_texmfdistdir}/tex/latex/datetime2-finnish
%dir %{_texmfdistdir}/tex/latex/datetime2-french
%dir %{_texmfdistdir}/tex/latex/datetime2-galician
%dir %{_texmfdistdir}/tex/latex/datetime2-german
%dir %{_texmfdistdir}/tex/latex/datetime2-greek
%dir %{_texmfdistdir}/tex/latex/datetime2-hebrew
%dir %{_texmfdistdir}/tex/latex/datetime2-icelandic
%dir %{_texmfdistdir}/tex/latex/datetime2-irish
%dir %{_texmfdistdir}/tex/latex/datetime2-it-fulltext
%dir %{_texmfdistdir}/tex/latex/datetime2-italian
%dir %{_texmfdistdir}/tex/latex/datetime2-latin
%dir %{_texmfdistdir}/tex/latex/datetime2-lsorbian
%dir %{_texmfdistdir}/tex/latex/datetime2-magyar
%dir %{_texmfdistdir}/tex/latex/datetime2-norsk
%dir %{_texmfdistdir}/tex/latex/datetime2-polish
%dir %{_texmfdistdir}/tex/latex/datetime2-portuges
%dir %{_texmfdistdir}/tex/latex/datetime2-romanian
%dir %{_texmfdistdir}/tex/latex/datetime2-russian
%dir %{_texmfdistdir}/tex/latex/datetime2-samin
%dir %{_texmfdistdir}/tex/latex/datetime2-scottish
%dir %{_texmfdistdir}/tex/latex/datetime2-serbian
%dir %{_texmfdistdir}/tex/latex/datetime2-slovak
%dir %{_texmfdistdir}/tex/latex/datetime2-slovene
%dir %{_texmfdistdir}/tex/latex/datetime2-spanish
%dir %{_texmfdistdir}/tex/latex/datetime2-swedish
%dir %{_texmfdistdir}/tex/latex/datetime2-turkish
%dir %{_texmfdistdir}/tex/latex/datetime2-ukrainian
%dir %{_texmfdistdir}/tex/latex/datetime2-usorbian
%dir %{_texmfdistdir}/tex/latex/datetime2-welsh
%dir %{_texmfdistdir}/tex/latex/dblfloatfix
%dir %{_texmfdistdir}/tex/latex/dbshow
%dir %{_texmfdistdir}/tex/latex/dccpaper
%dir %{_texmfdistdir}/tex/latex/ddphonism
%dir %{_texmfdistdir}/tex/latex/debate
%dir %{_texmfdistdir}/tex/latex/decimal
%dir %{_texmfdistdir}/tex/latex/decision-table
%dir %{_texmfdistdir}/tex/latex/decorule
%dir %{_texmfdistdir}/tex/latex/dejavu
%dir %{_texmfdistdir}/tex/latex/dejavu-otf
%dir %{_texmfdistdir}/tex/latex/delim
%dir %{_texmfdistdir}/tex/latex/delimseasy
%dir %{_texmfdistdir}/tex/latex/delimset
%dir %{_texmfdistdir}/tex/latex/delimtxt
%dir %{_texmfdistdir}/tex/latex/democodetools
%dir %{_texmfdistdir}/tex/latex/denisbdoc
%dir %{_texmfdistdir}/tex/latex/derivative
%dir %{_texmfdistdir}/tex/latex/dhua
%dir %{_texmfdistdir}/tex/latex/diabetes-logbook
%dir %{_texmfdistdir}/tex/latex/diadia
%dir %{_texmfdistdir}/tex/latex/diagbox
%dir %{_texmfdistdir}/tex/latex/diagmac2
%dir %{_texmfdistdir}/tex/latex/diagnose
%dir %{_texmfdistdir}/tex/latex/dialogl
%dir %{_texmfdistdir}/tex/latex/dichokey
%dir %{_texmfdistdir}/tex/latex/dictsym
%dir %{_texmfdistdir}/tex/latex/diffcoeff
%dir %{_texmfdistdir}/tex/latex/digiconfigs
%dir %{_texmfdistdir}/tex/latex/dijkstra
%dir %{_texmfdistdir}/tex/latex/dimnum
%dir %{_texmfdistdir}/tex/latex/dinbrief
%dir %{_texmfdistdir}/tex/latex/dingbat
%dir %{_texmfdistdir}/tex/latex/directory
%dir %{_texmfdistdir}/tex/latex/dirtytalk
%dir %{_texmfdistdir}/tex/latex/disser
%dir %{_texmfdistdir}/tex/latex/ditaa
%dir %{_texmfdistdir}/tex/latex/dithesis
%dir %{_texmfdistdir}/tex/latex/dk-bib
%dir %{_texmfdistdir}/tex/latex/dlfltxb
%dir %{_texmfdistdir}/tex/latex/dnaseq
%dir %{_texmfdistdir}/tex/latex/doclicense
%dir %{_texmfdistdir}/tex/latex/doclicense/images
%dir %{_texmfdistdir}/tex/latex/doclicense/license-texts
%dir %{_texmfdistdir}/tex/latex/docmfp
%dir %{_texmfdistdir}/tex/latex/docmute
%dir %{_texmfdistdir}/tex/latex/docshots
%dir %{_texmfdistdir}/tex/latex/doctools
%dir %{_texmfdistdir}/tex/latex/documentation
%dir %{_texmfdistdir}/tex/latex/docutils
%dir %{_texmfdistdir}/tex/latex/doi
%dir %{_texmfdistdir}/tex/latex/doipubmed
%dir %{_texmfdistdir}/tex/latex/domitian
%dir %{_texmfdistdir}/tex/latex/dot2texi
%dir %{_texmfdistdir}/tex/latex/dotarrow
%dir %{_texmfdistdir}/tex/latex/dotlessi
%dir %{_texmfdistdir}/tex/latex/dotseqn
%dir %{_texmfdistdir}/tex/latex/dottex
%dir %{_texmfdistdir}/tex/latex/doublestroke
%dir %{_texmfdistdir}/tex/latex/download
%dir %{_texmfdistdir}/tex/latex/dox
%dir %{_texmfdistdir}/tex/latex/dozenal
%dir %{_texmfdistdir}/tex/latex/dpcircling
%dir %{_texmfdistdir}/tex/latex/dpfloat
%dir %{_texmfdistdir}/tex/latex/dprogress
%dir %{_texmfdistdir}/tex/latex/drac
%dir %{_texmfdistdir}/tex/latex/draftcopy
%dir %{_texmfdistdir}/tex/latex/draftfigure
%dir %{_texmfdistdir}/tex/latex/draftwatermark
%dir %{_texmfdistdir}/tex/latex/dramatist
%dir %{_texmfdistdir}/tex/latex/drawmatrix
%dir %{_texmfdistdir}/tex/latex/drawstack
%dir %{_texmfdistdir}/tex/latex/drm
%dir %{_texmfdistdir}/tex/latex/droid
%dir %{_texmfdistdir}/tex/latex/droit-fr
%dir %{_texmfdistdir}/tex/latex/drs
%dir %{_texmfdistdir}/tex/latex/dsptricks
%dir %{_texmfdistdir}/tex/latex/dsserif
%dir %{_texmfdistdir}/tex/latex/dtk
%dir %{_texmfdistdir}/tex/latex/dtk-bibliography
%dir %{_texmfdistdir}/tex/latex/dtxdescribe
%dir %{_texmfdistdir}/tex/latex/ducksay
%dir %{_texmfdistdir}/tex/latex/duckuments
%dir %{_texmfdistdir}/tex/latex/duerer-latex
%dir %{_texmfdistdir}/tex/latex/duotenzor
%dir %{_texmfdistdir}/tex/latex/dutchcal
%dir %{_texmfdistdir}/tex/latex/dvdcoll
%dir %{_texmfdistdir}/tex/latex/dvdcoll/dcl
%dir %{_texmfdistdir}/tex/latex/dvgloss
%dir %{_texmfdistdir}/tex/latex/dynamicnumber
%dir %{_texmfdistdir}/tex/latex/dynblocks
%dir %{_texmfdistdir}/tex/latex/dynkin-diagrams
%dir %{_texmfdistdir}/tex/latex/dyntree
%dir %{_texmfdistdir}/tex/latex/ean13isbn
%dir %{_texmfdistdir}/tex/latex/easing
%dir %{_texmfdistdir}/tex/latex/easy
%dir %{_texmfdistdir}/tex/latex/easy-todo
%dir %{_texmfdistdir}/tex/latex/easybook
%dir %{_texmfdistdir}/tex/latex/easyfig
%dir %{_texmfdistdir}/tex/latex/easyfloats
%dir %{_texmfdistdir}/tex/latex/easyformat
%dir %{_texmfdistdir}/tex/latex/easylist
%dir %{_texmfdistdir}/tex/latex/easyreview
%dir %{_texmfdistdir}/tex/latex/ebezier
%dir %{_texmfdistdir}/tex/latex/ebgaramond
%dir %{_texmfdistdir}/tex/latex/ebgaramond-maths
%dir %{_texmfdistdir}/tex/latex/ebook
%dir %{_texmfdistdir}/tex/latex/ebproof
%dir %{_texmfdistdir}/tex/latex/ebsthesis
%dir %{_texmfdistdir}/tex/latex/ecclesiastic
%dir %{_texmfdistdir}/tex/latex/ecgdraw
%dir %{_texmfdistdir}/tex/latex/ecltree
%dir %{_texmfdistdir}/tex/latex/eco
%dir %{_texmfdistdir}/tex/latex/ecobiblatex
%dir %{_texmfdistdir}/tex/latex/econlipsum
%dir %{_texmfdistdir}/tex/latex/econometrics
%dir %{_texmfdistdir}/tex/latex/economic
%dir %{_texmfdistdir}/tex/latex/ecv
%dir %{_texmfdistdir}/tex/latex/ed
%dir %{_texmfdistdir}/tex/latex/edfnotes
%dir %{_texmfdistdir}/tex/latex/edichokey
%dir %{_texmfdistdir}/tex/latex/edmargin
%dir %{_texmfdistdir}/tex/latex/eemeir
%dir %{_texmfdistdir}/tex/latex/eepic
%dir %{_texmfdistdir}/tex/latex/efbox
%dir %{_texmfdistdir}/tex/latex/egameps
%dir %{_texmfdistdir}/tex/latex/egplot
%dir %{_texmfdistdir}/tex/latex/ehhline
%dir %{_texmfdistdir}/tex/latex/eiad
%dir %{_texmfdistdir}/tex/latex/eiad-ltx
%dir %{_texmfdistdir}/tex/latex/einfart
%dir %{_texmfdistdir}/tex/latex/ejpecp
%dir %{_texmfdistdir}/tex/latex/ekaia
%dir %{_texmfdistdir}/tex/latex/elbioimp
%dir %{_texmfdistdir}/tex/latex/electrum
%dir %{_texmfdistdir}/tex/latex/eledform
%dir %{_texmfdistdir}/tex/latex/eledmac
%dir %{_texmfdistdir}/tex/latex/elements
%dir %{_texmfdistdir}/tex/latex/ellipse
%dir %{_texmfdistdir}/tex/latex/ellipsis
%dir %{_texmfdistdir}/tex/latex/elmath
%dir %{_texmfdistdir}/tex/latex/elocalloc
%dir %{_texmfdistdir}/tex/latex/elpres
%dir %{_texmfdistdir}/tex/latex/els-cas-templates
%dir %{_texmfdistdir}/tex/latex/els-cas-templates/thumbnails
%dir %{_texmfdistdir}/tex/latex/elsarticle
%dir %{_texmfdistdir}/tex/latex/elteikthesis
%dir %{_texmfdistdir}/tex/latex/eltex
%dir %{_texmfdistdir}/tex/latex/elzcards
%dir %{_texmfdistdir}/tex/latex/emarks
%dir %{_texmfdistdir}/tex/latex/embedall
%dir %{_texmfdistdir}/tex/latex/embedfile
%dir %{_texmfdistdir}/tex/latex/embrac
%dir %{_texmfdistdir}/tex/latex/emf
%dir %{_texmfdistdir}/tex/latex/emisa
%dir %{_texmfdistdir}/tex/latex/emoji
%dir %{_texmfdistdir}/tex/latex/emp
%dir %{_texmfdistdir}/tex/latex/emptypage
%dir %{_texmfdistdir}/tex/latex/emulateapj
%dir %{_texmfdistdir}/tex/latex/encxvlna
%dir %{_texmfdistdir}/tex/latex/endfloat
%dir %{_texmfdistdir}/tex/latex/endheads
%dir %{_texmfdistdir}/tex/latex/endiagram
%dir %{_texmfdistdir}/tex/latex/endnotes
%dir %{_texmfdistdir}/tex/latex/endnotes-hy
%dir %{_texmfdistdir}/tex/latex/endnotesj
%dir %{_texmfdistdir}/tex/latex/endofproofwd
%dir %{_texmfdistdir}/tex/latex/endofproofwd/common
%dir %{_texmfdistdir}/tex/latex/engpron
%dir %{_texmfdistdir}/tex/latex/engrec
%dir %{_texmfdistdir}/tex/latex/engtlc
%dir %{_texmfdistdir}/tex/latex/enigma
%dir %{_texmfdistdir}/tex/latex/enotez
%dir %{_texmfdistdir}/tex/latex/enumitem
%dir %{_texmfdistdir}/tex/latex/enumitem-zref
%dir %{_texmfdistdir}/tex/latex/envbig
%dir %{_texmfdistdir}/tex/latex/environ
%dir %{_texmfdistdir}/tex/latex/envlab
%dir %{_texmfdistdir}/tex/latex/eolang
%dir %{_texmfdistdir}/tex/latex/epigrafica
%dir %{_texmfdistdir}/tex/latex/epigraph
%dir %{_texmfdistdir}/tex/latex/epigraph-keys
%dir %{_texmfdistdir}/tex/latex/epiolmec
%dir %{_texmfdistdir}/tex/latex/epsdice
%dir %{_texmfdistdir}/tex/latex/epspdfconversion
%dir %{_texmfdistdir}/tex/latex/epstopdf-pkg
%dir %{_texmfdistdir}/tex/latex/eq-pin2corr
%dir %{_texmfdistdir}/tex/latex/eqell
%dir %{_texmfdistdir}/tex/latex/eqexpl
%dir %{_texmfdistdir}/tex/latex/eqlist
%dir %{_texmfdistdir}/tex/latex/eqnalign
%dir %{_texmfdistdir}/tex/latex/eqname
%dir %{_texmfdistdir}/tex/latex/eqnarray
%dir %{_texmfdistdir}/tex/latex/eqnnumwarn
%dir %{_texmfdistdir}/tex/latex/eqparbox
%dir %{_texmfdistdir}/tex/latex/erdc
%dir %{_texmfdistdir}/tex/latex/erewhon
%dir %{_texmfdistdir}/tex/latex/erewhon-math
%dir %{_texmfdistdir}/tex/latex/errata
%dir %{_texmfdistdir}/tex/latex/erw-l3
%dir %{_texmfdistdir}/tex/latex/esami
%dir %{_texmfdistdir}/tex/latex/esdiff
%dir %{_texmfdistdir}/tex/latex/esieecv
%dir %{_texmfdistdir}/tex/latex/esindex
%dir %{_texmfdistdir}/tex/latex/esint
%dir %{_texmfdistdir}/tex/latex/esk
%dir %{_texmfdistdir}/tex/latex/eskd
%dir %{_texmfdistdir}/tex/latex/eskdx
%dir %{_texmfdistdir}/tex/latex/eso-pic
%dir %{_texmfdistdir}/tex/latex/esrelation
%dir %{_texmfdistdir}/tex/latex/esstix
%dir %{_texmfdistdir}/tex/latex/estcpmm
%dir %{_texmfdistdir}/tex/latex/esvect
%dir %{_texmfdistdir}/tex/latex/etaremune
%dir %{_texmfdistdir}/tex/latex/etbb
%dir %{_texmfdistdir}/tex/latex/etex-pkg
%dir %{_texmfdistdir}/tex/latex/etextools
%dir %{_texmfdistdir}/tex/latex/ethiop
%dir %{_texmfdistdir}/tex/latex/etl
%dir %{_texmfdistdir}/tex/latex/etoc
%dir %{_texmfdistdir}/tex/latex/etoolbox
%dir %{_texmfdistdir}/tex/latex/etsvthor
%dir %{_texmfdistdir}/tex/latex/euclideangeometry
%dir %{_texmfdistdir}/tex/latex/euenc
%dir %{_texmfdistdir}/tex/latex/euflag
%dir %{_texmfdistdir}/tex/latex/eukdate
%dir %{_texmfdistdir}/tex/latex/euler
%dir %{_texmfdistdir}/tex/latex/euler-math
%dir %{_texmfdistdir}/tex/latex/eulerpx
%dir %{_texmfdistdir}/tex/latex/eulervm
%dir %{_texmfdistdir}/tex/latex/euro
%dir %{_texmfdistdir}/tex/latex/europasscv
%dir %{_texmfdistdir}/tex/latex/europasscv/def
%dir %{_texmfdistdir}/tex/latex/europasscv/icons
%dir %{_texmfdistdir}/tex/latex/europecv
%dir %{_texmfdistdir}/tex/latex/eurosym
%dir %{_texmfdistdir}/tex/latex/everyhook
%dir %{_texmfdistdir}/tex/latex/everypage
%dir %{_texmfdistdir}/tex/latex/everysel
%dir %{_texmfdistdir}/tex/latex/everyshi
%dir %{_texmfdistdir}/tex/latex/exam
%dir %{_texmfdistdir}/tex/latex/exam-lite
%dir %{_texmfdistdir}/tex/latex/exam-n
%dir %{_texmfdistdir}/tex/latex/exam-randomizechoices
%dir %{_texmfdistdir}/tex/latex/exam-zh
%dir %{_texmfdistdir}/tex/latex/examdesign
%dir %{_texmfdistdir}/tex/latex/example
%dir %{_texmfdistdir}/tex/latex/examplep
%dir %{_texmfdistdir}/tex/latex/exceltex
%dir %{_texmfdistdir}/tex/latex/excludeonly
%dir %{_texmfdistdir}/tex/latex/exercise
%dir %{_texmfdistdir}/tex/latex/exercisebank
%dir %{_texmfdistdir}/tex/latex/exercisepoints
%dir %{_texmfdistdir}/tex/latex/exercises
%dir %{_texmfdistdir}/tex/latex/exesheet
%dir %{_texmfdistdir}/tex/latex/exframe
%dir %{_texmfdistdir}/tex/latex/exp-testopt
%dir %{_texmfdistdir}/tex/latex/expdlist
%dir %{_texmfdistdir}/tex/latex/expkv-bundle
%dir %{_texmfdistdir}/tex/latex/export
%dir %{_texmfdistdir}/tex/latex/exsheets
%dir %{_texmfdistdir}/tex/latex/exsol
%dir %{_texmfdistdir}/tex/latex/extarrows
%dir %{_texmfdistdir}/tex/latex/extpfeil
%dir %{_texmfdistdir}/tex/latex/extract
%dir %{_texmfdistdir}/tex/latex/extsizes
%dir %{_texmfdistdir}/tex/latex/facsimile
%dir %{_texmfdistdir}/tex/latex/factura
%dir %{_texmfdistdir}/tex/latex/faktor
%dir %{_texmfdistdir}/tex/latex/familytree
%dir %{_texmfdistdir}/tex/latex/fancybox
%dir %{_texmfdistdir}/tex/latex/fancyhandout
%dir %{_texmfdistdir}/tex/latex/fancyhdr
%dir %{_texmfdistdir}/tex/latex/fancylabel
%dir %{_texmfdistdir}/tex/latex/fancynum
%dir %{_texmfdistdir}/tex/latex/fancypar
%dir %{_texmfdistdir}/tex/latex/fancyqr
%dir %{_texmfdistdir}/tex/latex/fancyref
%dir %{_texmfdistdir}/tex/latex/fancyslides
%dir %{_texmfdistdir}/tex/latex/fancytabs
%dir %{_texmfdistdir}/tex/latex/fancytooltips
%dir %{_texmfdistdir}/tex/latex/fancyvrb
%dir %{_texmfdistdir}/tex/latex/fascicules
%dir %{_texmfdistdir}/tex/latex/fast-diagram
%dir %{_texmfdistdir}/tex/latex/fbb
%dir %{_texmfdistdir}/tex/latex/fbithesis
%dir %{_texmfdistdir}/tex/latex/fbox
%dir %{_texmfdistdir}/tex/latex/fc
%dir %{_texmfdistdir}/tex/latex/fcavtex
%dir %{_texmfdistdir}/tex/latex/fcltxdoc
%dir %{_texmfdistdir}/tex/latex/fcolumn
%dir %{_texmfdistdir}/tex/latex/fdsymbol
%dir %{_texmfdistdir}/tex/latex/fduthesis
%dir %{_texmfdistdir}/tex/latex/fei
%dir %{_texmfdistdir}/tex/latex/fetamont
%dir %{_texmfdistdir}/tex/latex/fetchcls
%dir %{_texmfdistdir}/tex/latex/feupphdteses
%dir %{_texmfdistdir}/tex/latex/fewerfloatpages
%dir %{_texmfdistdir}/tex/latex/feyn
%dir %{_texmfdistdir}/tex/latex/feynmf
%dir %{_texmfdistdir}/tex/latex/feynmp-auto
%dir %{_texmfdistdir}/tex/latex/ffcode
%dir %{_texmfdistdir}/tex/latex/ffslides
%dir %{_texmfdistdir}/tex/latex/fge
%dir %{_texmfdistdir}/tex/latex/fgruler
%dir %{_texmfdistdir}/tex/latex/fifo-stack
%dir %{_texmfdistdir}/tex/latex/figbib
%dir %{_texmfdistdir}/tex/latex/figchild
%dir %{_texmfdistdir}/tex/latex/figput
%dir %{_texmfdistdir}/tex/latex/figsize
%dir %{_texmfdistdir}/tex/latex/filecontents
%dir %{_texmfdistdir}/tex/latex/filecontentsdef
%dir %{_texmfdistdir}/tex/latex/filedate
%dir %{_texmfdistdir}/tex/latex/filehook
%dir %{_texmfdistdir}/tex/latex/fileinfo
%dir %{_texmfdistdir}/tex/latex/filemod
%dir %{_texmfdistdir}/tex/latex/fink
%dir %{_texmfdistdir}/tex/latex/finstrut
%dir %{_texmfdistdir}/tex/latex/fira
%dir %{_texmfdistdir}/tex/latex/firamath-otf
%dir %{_texmfdistdir}/tex/latex/firstaid
%dir %{_texmfdistdir}/tex/latex/fistrum
%dir %{_texmfdistdir}/tex/latex/fitbox
%dir %{_texmfdistdir}/tex/latex/fithesis
%dir %{_texmfdistdir}/tex/latex/fithesis/locale
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/econ
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/fi
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/fsps
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/fss
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/law
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/med
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/ped
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/pharm
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/phil
%dir %{_texmfdistdir}/tex/latex/fithesis/locale/mu/sci
%dir %{_texmfdistdir}/tex/latex/fithesis/logo
%dir %{_texmfdistdir}/tex/latex/fithesis/logo/mu
%dir %{_texmfdistdir}/tex/latex/fithesis/style
%dir %{_texmfdistdir}/tex/latex/fithesis/style/mu
%dir %{_texmfdistdir}/tex/latex/fix2col
%dir %{_texmfdistdir}/tex/latex/fixcmex
%dir %{_texmfdistdir}/tex/latex/fixdif
%dir %{_texmfdistdir}/tex/latex/fixfoot
%dir %{_texmfdistdir}/tex/latex/fixltxhyph
%dir %{_texmfdistdir}/tex/latex/fixmath
%dir %{_texmfdistdir}/tex/latex/fixme
%dir %{_texmfdistdir}/tex/latex/fixme/layouts
%dir %{_texmfdistdir}/tex/latex/fixme/layouts/env
%dir %{_texmfdistdir}/tex/latex/fixme/layouts/target
%dir %{_texmfdistdir}/tex/latex/fixme/themes
%dir %{_texmfdistdir}/tex/latex/fixmetodonotes
%dir %{_texmfdistdir}/tex/latex/fjodor
%dir %{_texmfdistdir}/tex/latex/flabels
%dir %{_texmfdistdir}/tex/latex/flacards
%dir %{_texmfdistdir}/tex/latex/flagderiv
%dir %{_texmfdistdir}/tex/latex/flashcards
%dir %{_texmfdistdir}/tex/latex/flashmovie
%dir %{_texmfdistdir}/tex/latex/flexipage
%dir %{_texmfdistdir}/tex/latex/flipbook
%dir %{_texmfdistdir}/tex/latex/flippdf
%dir %{_texmfdistdir}/tex/latex/float
%dir %{_texmfdistdir}/tex/latex/floatrow
%dir %{_texmfdistdir}/tex/latex/flowchart
%dir %{_texmfdistdir}/tex/latex/flowfram
%dir %{_texmfdistdir}/tex/latex/fmp
%dir %{_texmfdistdir}/tex/latex/fmtcount
%dir %{_texmfdistdir}/tex/latex/fn2end
%dir %{_texmfdistdir}/tex/latex/fnbreak
%dir %{_texmfdistdir}/tex/latex/fncychap
%dir %{_texmfdistdir}/tex/latex/fncylab
%dir %{_texmfdistdir}/tex/latex/fnpara
%dir %{_texmfdistdir}/tex/latex/fnpct
%dir %{_texmfdistdir}/tex/latex/fnspe
%dir %{_texmfdistdir}/tex/latex/fnumprint
%dir %{_texmfdistdir}/tex/latex/foekfont
%dir %{_texmfdistdir}/tex/latex/foilhtml
%dir %{_texmfdistdir}/tex/latex/foliono
%dir %{_texmfdistdir}/tex/latex/fonetika
%dir %{_texmfdistdir}/tex/latex/fontawesome
%dir %{_texmfdistdir}/tex/latex/fontawesome5
%dir %{_texmfdistdir}/tex/latex/fontaxes
%dir %{_texmfdistdir}/tex/latex/fontinst
%dir %{_texmfdistdir}/tex/latex/fontmfizz
%dir %{_texmfdistdir}/tex/latex/fonts-tlwg
%dir %{_texmfdistdir}/tex/latex/fontsetup
%dir %{_texmfdistdir}/tex/latex/fontsize
%dir %{_texmfdistdir}/tex/latex/fontspec
%dir %{_texmfdistdir}/tex/latex/fonttable
%dir %{_texmfdistdir}/tex/latex/footbib
%dir %{_texmfdistdir}/tex/latex/footmisc
%dir %{_texmfdistdir}/tex/latex/footmisx
%dir %{_texmfdistdir}/tex/latex/footnotebackref
%dir %{_texmfdistdir}/tex/latex/footnotehyper
%dir %{_texmfdistdir}/tex/latex/footnoterange
%dir %{_texmfdistdir}/tex/latex/footnpag
%dir %{_texmfdistdir}/tex/latex/forarray
%dir %{_texmfdistdir}/tex/latex/foreign
%dir %{_texmfdistdir}/tex/latex/forest
%dir %{_texmfdistdir}/tex/latex/forloop
%dir %{_texmfdistdir}/tex/latex/formal-grammar
%dir %{_texmfdistdir}/tex/latex/forms16be
%dir %{_texmfdistdir}/tex/latex/formular
%dir %{_texmfdistdir}/tex/latex/forum
%dir %{_texmfdistdir}/tex/latex/fouridx
%dir %{_texmfdistdir}/tex/latex/fourier
%dir %{_texmfdistdir}/tex/latex/fouriernc
%dir %{_texmfdistdir}/tex/latex/fp
%dir %{_texmfdistdir}/tex/latex/fragments
%dir %{_texmfdistdir}/tex/latex/framed
%dir %{_texmfdistdir}/tex/latex/francais-bst
%dir %{_texmfdistdir}/tex/latex/frankenstein
%dir %{_texmfdistdir}/tex/latex/frcursive
%dir %{_texmfdistdir}/tex/latex/frege
%dir %{_texmfdistdir}/tex/latex/frenchmath
%dir %{_texmfdistdir}/tex/latex/frimurer
%dir %{_texmfdistdir}/tex/latex/frletter
%dir %{_texmfdistdir}/tex/latex/frontespizio
%dir %{_texmfdistdir}/tex/latex/froufrou
%dir %{_texmfdistdir}/tex/latex/frpseudocode
%dir %{_texmfdistdir}/tex/latex/ftc-notebook
%dir %{_texmfdistdir}/tex/latex/ftcap
%dir %{_texmfdistdir}/tex/latex/ftnxtra
%dir %{_texmfdistdir}/tex/latex/fullblck
%dir %{_texmfdistdir}/tex/latex/fullminipage
%dir %{_texmfdistdir}/tex/latex/fullwidth
%dir %{_texmfdistdir}/tex/latex/functan
%dir %{_texmfdistdir}/tex/latex/functional
%dir %{_texmfdistdir}/tex/latex/fundus-calligra
%dir %{_texmfdistdir}/tex/latex/fundus-cyr
%dir %{_texmfdistdir}/tex/latex/fundus-sueterlin
%dir %{_texmfdistdir}/tex/latex/fvextra
%dir %{_texmfdistdir}/tex/latex/fwlw
%dir %{_texmfdistdir}/tex/latex/g-brief
%dir %{_texmfdistdir}/tex/latex/gaceta
%dir %{_texmfdistdir}/tex/latex/galois
%dir %{_texmfdistdir}/tex/latex/gamebook
%dir %{_texmfdistdir}/tex/latex/gamebooklib
%dir %{_texmfdistdir}/tex/latex/gammas
%dir %{_texmfdistdir}/tex/latex/garamond-libre
%dir %{_texmfdistdir}/tex/latex/gastex
%dir %{_texmfdistdir}/tex/latex/gatherenum
%dir %{_texmfdistdir}/tex/latex/gauss
%dir %{_texmfdistdir}/tex/latex/gb4e
%dir %{_texmfdistdir}/tex/latex/gbt7714
%dir %{_texmfdistdir}/tex/latex/gcard
%dir %{_texmfdistdir}/tex/latex/gchords
%dir %{_texmfdistdir}/tex/latex/gcite
%dir %{_texmfdistdir}/tex/latex/gckanbun
%dir %{_texmfdistdir}/tex/latex/gender
%dir %{_texmfdistdir}/tex/latex/gene-logic
%dir %{_texmfdistdir}/tex/latex/genealogytree
%dir %{_texmfdistdir}/tex/latex/genmpage
%dir %{_texmfdistdir}/tex/latex/gensymb
%dir %{_texmfdistdir}/tex/latex/gentium-tug
%dir %{_texmfdistdir}/tex/latex/gentombow
%dir %{_texmfdistdir}/tex/latex/geometry
%dir %{_texmfdistdir}/tex/latex/geradwp
%dir %{_texmfdistdir}/tex/latex/germbib
%dir %{_texmfdistdir}/tex/latex/germkorr
%dir %{_texmfdistdir}/tex/latex/geschichtsfrkl
%dir %{_texmfdistdir}/tex/latex/getfiledate
%dir %{_texmfdistdir}/tex/latex/getitems
%dir %{_texmfdistdir}/tex/latex/getmap
%dir %{_texmfdistdir}/tex/latex/gfdl
%dir %{_texmfdistdir}/tex/latex/gfsartemisia
%dir %{_texmfdistdir}/tex/latex/gfsbaskerville
%dir %{_texmfdistdir}/tex/latex/gfsbodoni
%dir %{_texmfdistdir}/tex/latex/gfscomplutum
%dir %{_texmfdistdir}/tex/latex/gfsdidot
%dir %{_texmfdistdir}/tex/latex/gfsneohellenic
%dir %{_texmfdistdir}/tex/latex/gfsneohellenicmath
%dir %{_texmfdistdir}/tex/latex/gfsporson
%dir %{_texmfdistdir}/tex/latex/gfssolomos
%dir %{_texmfdistdir}/tex/latex/ghab
%dir %{_texmfdistdir}/tex/latex/ghsystem
%dir %{_texmfdistdir}/tex/latex/ghsystem/language
%dir %{_texmfdistdir}/tex/latex/ghsystem/pictures
%dir %{_texmfdistdir}/tex/latex/gillcm
%dir %{_texmfdistdir}/tex/latex/gillius
%dir %{_texmfdistdir}/tex/latex/gincltex
%dir %{_texmfdistdir}/tex/latex/gindex
%dir %{_texmfdistdir}/tex/latex/ginpenc
%dir %{_texmfdistdir}/tex/latex/gitfile-info
%dir %{_texmfdistdir}/tex/latex/gitinfo
%dir %{_texmfdistdir}/tex/latex/gitinfo2
%dir %{_texmfdistdir}/tex/latex/gitlog
%dir %{_texmfdistdir}/tex/latex/gitstatus
%dir %{_texmfdistdir}/tex/latex/gitver
%dir %{_texmfdistdir}/tex/latex/globalvals
%dir %{_texmfdistdir}/tex/latex/glosmathtools
%dir %{_texmfdistdir}/tex/latex/gloss
%dir %{_texmfdistdir}/tex/latex/glossaries
%dir %{_texmfdistdir}/tex/latex/glossaries-danish
%dir %{_texmfdistdir}/tex/latex/glossaries-dutch
%dir %{_texmfdistdir}/tex/latex/glossaries-english
%dir %{_texmfdistdir}/tex/latex/glossaries-estonian
%dir %{_texmfdistdir}/tex/latex/glossaries-extra
%dir %{_texmfdistdir}/tex/latex/glossaries-finnish
%dir %{_texmfdistdir}/tex/latex/glossaries-french
%dir %{_texmfdistdir}/tex/latex/glossaries-german
%dir %{_texmfdistdir}/tex/latex/glossaries-irish
%dir %{_texmfdistdir}/tex/latex/glossaries-italian
%dir %{_texmfdistdir}/tex/latex/glossaries-magyar
%dir %{_texmfdistdir}/tex/latex/glossaries-nynorsk
%dir %{_texmfdistdir}/tex/latex/glossaries-polish
%dir %{_texmfdistdir}/tex/latex/glossaries-portuges
%dir %{_texmfdistdir}/tex/latex/glossaries-serbian
%dir %{_texmfdistdir}/tex/latex/glossaries-slovene
%dir %{_texmfdistdir}/tex/latex/glossaries-spanish
%dir %{_texmfdistdir}/tex/latex/glossaries/base
%dir %{_texmfdistdir}/tex/latex/glossaries/expl
%dir %{_texmfdistdir}/tex/latex/glossaries/rollback
%dir %{_texmfdistdir}/tex/latex/glossaries/styles
%dir %{_texmfdistdir}/tex/latex/glossaries/test-entries
%dir %{_texmfdistdir}/tex/latex/gmdoc
%dir %{_texmfdistdir}/tex/latex/gmdoc-enhance
%dir %{_texmfdistdir}/tex/latex/gmiflink
%dir %{_texmfdistdir}/tex/latex/gmp
%dir %{_texmfdistdir}/tex/latex/gmutils
%dir %{_texmfdistdir}/tex/latex/gmverb
%dir %{_texmfdistdir}/tex/latex/gmverse
%dir %{_texmfdistdir}/tex/latex/gnuplottex
%dir %{_texmfdistdir}/tex/latex/go
%dir %{_texmfdistdir}/tex/latex/gofonts
%dir %{_texmfdistdir}/tex/latex/gotoh
%dir %{_texmfdistdir}/tex/latex/grabbox
%dir %{_texmfdistdir}/tex/latex/gradient-text
%dir %{_texmfdistdir}/tex/latex/gradientframe
%dir %{_texmfdistdir}/tex/latex/grading-scheme
%dir %{_texmfdistdir}/tex/latex/gradstudentresume
%dir %{_texmfdistdir}/tex/latex/grafcet
%dir %{_texmfdistdir}/tex/latex/grant
%dir %{_texmfdistdir}/tex/latex/graph35
%dir %{_texmfdistdir}/tex/latex/graphbox
%dir %{_texmfdistdir}/tex/latex/graphics
%dir %{_texmfdistdir}/tex/latex/graphics-cfg
%dir %{_texmfdistdir}/tex/latex/graphics-def
%dir %{_texmfdistdir}/tex/latex/graphicscache
%dir %{_texmfdistdir}/tex/latex/graphicx-psmin
%dir %{_texmfdistdir}/tex/latex/graphicxbox
%dir %{_texmfdistdir}/tex/latex/graphicxpsd
%dir %{_texmfdistdir}/tex/latex/graphpaper
%dir %{_texmfdistdir}/tex/latex/graphviz
%dir %{_texmfdistdir}/tex/latex/grayhints
%dir %{_texmfdistdir}/tex/latex/greek-fontenc
%dir %{_texmfdistdir}/tex/latex/greek-inputenc
%dir %{_texmfdistdir}/tex/latex/greekdates
%dir %{_texmfdistdir}/tex/latex/greektex
%dir %{_texmfdistdir}/tex/latex/greektonoi
%dir %{_texmfdistdir}/tex/latex/grfext
%dir %{_texmfdistdir}/tex/latex/grffile
%dir %{_texmfdistdir}/tex/latex/grfpaste
%dir %{_texmfdistdir}/tex/latex/grid
%dir %{_texmfdistdir}/tex/latex/grid-system
%dir %{_texmfdistdir}/tex/latex/gridpapers
%dir %{_texmfdistdir}/tex/latex/gridset
%dir %{_texmfdistdir}/tex/latex/gridslides
%dir %{_texmfdistdir}/tex/latex/grotesq
%dir %{_texmfdistdir}/tex/latex/grundgesetze
%dir %{_texmfdistdir}/tex/latex/gs1
%dir %{_texmfdistdir}/tex/latex/gsemthesis
%dir %{_texmfdistdir}/tex/latex/gtrcrd
%dir %{_texmfdistdir}/tex/latex/gtrlib-largetrees
%dir %{_texmfdistdir}/tex/latex/gu
%dir %{_texmfdistdir}/tex/latex/gudea
%dir %{_texmfdistdir}/tex/latex/guitar
%dir %{_texmfdistdir}/tex/latex/guitarchordschemes
%dir %{_texmfdistdir}/tex/latex/guitartabs
%dir %{_texmfdistdir}/tex/latex/guitlogo
%dir %{_texmfdistdir}/tex/latex/gzt
%dir %{_texmfdistdir}/tex/latex/gzt/images
%dir %{_texmfdistdir}/tex/latex/h2020proposal
%dir %{_texmfdistdir}/tex/latex/ha-prosper
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Aggie
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Capsules
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Ciment
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Fyma
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/HA
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Lakar
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Simple
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/TCS
%dir %{_texmfdistdir}/tex/latex/ha-prosper/Styles/Tycja
%dir %{_texmfdistdir}/tex/latex/hackthefootline
%dir %{_texmfdistdir}/tex/latex/hacm
%dir %{_texmfdistdir}/tex/latex/hagenberg-thesis
%dir %{_texmfdistdir}/tex/latex/halloweenmath
%dir %{_texmfdistdir}/tex/latex/hamnosys
%dir %{_texmfdistdir}/tex/latex/handin
%dir %{_texmfdistdir}/tex/latex/handout
%dir %{_texmfdistdir}/tex/latex/handoutwithnotes
%dir %{_texmfdistdir}/tex/latex/hang
%dir %{_texmfdistdir}/tex/latex/hanging
%dir %{_texmfdistdir}/tex/latex/har2nat
%dir %{_texmfdistdir}/tex/latex/hardwrap
%dir %{_texmfdistdir}/tex/latex/harmony
%dir %{_texmfdistdir}/tex/latex/harnon-cv
%dir %{_texmfdistdir}/tex/latex/harpoon
%dir %{_texmfdistdir}/tex/latex/harvard
%dir %{_texmfdistdir}/tex/latex/harveyballs
%dir %{_texmfdistdir}/tex/latex/hausarbeit-jura
%dir %{_texmfdistdir}/tex/latex/havannah
%dir %{_texmfdistdir}/tex/latex/hc
%dir %{_texmfdistdir}/tex/latex/he-she
%dir %{_texmfdistdir}/tex/latex/hecthese
%dir %{_texmfdistdir}/tex/latex/helmholtz-ellis-ji-notation
%dir %{_texmfdistdir}/tex/latex/helvetic
%dir %{_texmfdistdir}/tex/latex/hep
%dir %{_texmfdistdir}/tex/latex/hep-acronym
%dir %{_texmfdistdir}/tex/latex/hep-bibliography
%dir %{_texmfdistdir}/tex/latex/hep-float
%dir %{_texmfdistdir}/tex/latex/hep-font
%dir %{_texmfdistdir}/tex/latex/hep-math
%dir %{_texmfdistdir}/tex/latex/hep-math-font
%dir %{_texmfdistdir}/tex/latex/hep-paper
%dir %{_texmfdistdir}/tex/latex/hep-reference
%dir %{_texmfdistdir}/tex/latex/hep-text
%dir %{_texmfdistdir}/tex/latex/hep-title
%dir %{_texmfdistdir}/tex/latex/hepnames
%dir %{_texmfdistdir}/tex/latex/hepparticles
%dir %{_texmfdistdir}/tex/latex/hepthesis
%dir %{_texmfdistdir}/tex/latex/hepunits
%dir %{_texmfdistdir}/tex/latex/here
%dir %{_texmfdistdir}/tex/latex/hereapplies
%dir %{_texmfdistdir}/tex/latex/heros-otf
%dir %{_texmfdistdir}/tex/latex/heuristica
%dir %{_texmfdistdir}/tex/latex/hexboard
%dir %{_texmfdistdir}/tex/latex/hexgame
%dir %{_texmfdistdir}/tex/latex/hf-tikz
%dir %{_texmfdistdir}/tex/latex/hfoldsty
%dir %{_texmfdistdir}/tex/latex/hfutexam
%dir %{_texmfdistdir}/tex/latex/hhtensor
%dir %{_texmfdistdir}/tex/latex/hideanswer
%dir %{_texmfdistdir}/tex/latex/highlightlatex
%dir %{_texmfdistdir}/tex/latex/hindmadurai
%dir %{_texmfdistdir}/tex/latex/histogr
%dir %{_texmfdistdir}/tex/latex/historische-zeitschrift
%dir %{_texmfdistdir}/tex/latex/hitec
%dir %{_texmfdistdir}/tex/latex/hitreport
%dir %{_texmfdistdir}/tex/latex/hitszbeamer
%dir %{_texmfdistdir}/tex/latex/hitszthesis
%dir %{_texmfdistdir}/tex/latex/hletter
%dir %{_texmfdistdir}/tex/latex/hobby
%dir %{_texmfdistdir}/tex/latex/hobete
%dir %{_texmfdistdir}/tex/latex/hobsub
%dir %{_texmfdistdir}/tex/latex/hopatch
%dir %{_texmfdistdir}/tex/latex/horoscop
%dir %{_texmfdistdir}/tex/latex/hpsdiss
%dir %{_texmfdistdir}/tex/latex/href-ul
%dir %{_texmfdistdir}/tex/latex/hrefhide
%dir %{_texmfdistdir}/tex/latex/hrlatex
%dir %{_texmfdistdir}/tex/latex/huawei
%dir %{_texmfdistdir}/tex/latex/huaz
%dir %{_texmfdistdir}/tex/latex/hulipsum
%dir %{_texmfdistdir}/tex/latex/hustthesis
%dir %{_texmfdistdir}/tex/latex/hvarabic
%dir %{_texmfdistdir}/tex/latex/hvextern
%dir %{_texmfdistdir}/tex/latex/hvfloat
%dir %{_texmfdistdir}/tex/latex/hvindex
%dir %{_texmfdistdir}/tex/latex/hvlogos
%dir %{_texmfdistdir}/tex/latex/hvpygmentex
%dir %{_texmfdistdir}/tex/latex/hvqrurl
%dir %{_texmfdistdir}/tex/latex/hwemoji
%dir %{_texmfdistdir}/tex/latex/hycolor
%dir %{_texmfdistdir}/tex/latex/hypdestopt
%dir %{_texmfdistdir}/tex/latex/hypdoc
%dir %{_texmfdistdir}/tex/latex/hypdvips
%dir %{_texmfdistdir}/tex/latex/hyper
%dir %{_texmfdistdir}/tex/latex/hyperbar
%dir %{_texmfdistdir}/tex/latex/hypernat
%dir %{_texmfdistdir}/tex/latex/hyperref
%dir %{_texmfdistdir}/tex/latex/hyperxmp
%dir %{_texmfdistdir}/tex/latex/hyphenat
%dir %{_texmfdistdir}/tex/latex/ibarra
%dir %{_texmfdistdir}/tex/latex/ibrackets
%dir %{_texmfdistdir}/tex/latex/ibycus-babel
%dir %{_texmfdistdir}/tex/latex/icite
%dir %{_texmfdistdir}/tex/latex/icsv
%dir %{_texmfdistdir}/tex/latex/identkey
%dir %{_texmfdistdir}/tex/latex/idxcmds
%dir %{_texmfdistdir}/tex/latex/idxlayout
%dir %{_texmfdistdir}/tex/latex/ieeeconf
%dir %{_texmfdistdir}/tex/latex/ieeepes
%dir %{_texmfdistdir}/tex/latex/ieeetran
%dir %{_texmfdistdir}/tex/latex/iexec
%dir %{_texmfdistdir}/tex/latex/ifallfalse
%dir %{_texmfdistdir}/tex/latex/iffont
%dir %{_texmfdistdir}/tex/latex/ifmslide
%dir %{_texmfdistdir}/tex/latex/ifmtarg
%dir %{_texmfdistdir}/tex/latex/ifnextok
%dir %{_texmfdistdir}/tex/latex/ifoddpage
%dir %{_texmfdistdir}/tex/latex/ifplatform
%dir %{_texmfdistdir}/tex/latex/ifsym
%dir %{_texmfdistdir}/tex/latex/ifthenx
%dir %{_texmfdistdir}/tex/latex/iitem
%dir %{_texmfdistdir}/tex/latex/ijmart
%dir %{_texmfdistdir}/tex/latex/ijsra
%dir %{_texmfdistdir}/tex/latex/imac
%dir %{_texmfdistdir}/tex/latex/image-gallery
%dir %{_texmfdistdir}/tex/latex/imakeidx
%dir %{_texmfdistdir}/tex/latex/imfellenglish
%dir %{_texmfdistdir}/tex/latex/impnattypo
%dir %{_texmfdistdir}/tex/latex/import
%dir %{_texmfdistdir}/tex/latex/imtekda
%dir %{_texmfdistdir}/tex/latex/incgraph
%dir %{_texmfdistdir}/tex/latex/includernw
%dir %{_texmfdistdir}/tex/latex/inconsolata
%dir %{_texmfdistdir}/tex/latex/index
%dir %{_texmfdistdir}/tex/latex/indextools
%dir %{_texmfdistdir}/tex/latex/initials
%dir %{_texmfdistdir}/tex/latex/inkpaper
%dir %{_texmfdistdir}/tex/latex/inline-images
%dir %{_texmfdistdir}/tex/latex/inlinebib
%dir %{_texmfdistdir}/tex/latex/inlinedef
%dir %{_texmfdistdir}/tex/latex/inlinelabel
%dir %{_texmfdistdir}/tex/latex/inputenx
%dir %{_texmfdistdir}/tex/latex/inputnormalization
%dir %{_texmfdistdir}/tex/latex/inputtrc
%dir %{_texmfdistdir}/tex/latex/inriafonts
%dir %{_texmfdistdir}/tex/latex/inter
%dir %{_texmfdistdir}/tex/latex/interactiveworkbook
%dir %{_texmfdistdir}/tex/latex/interfaces
%dir %{_texmfdistdir}/tex/latex/interval
%dir %{_texmfdistdir}/tex/latex/intopdf
%dir %{_texmfdistdir}/tex/latex/inversepath
%dir %{_texmfdistdir}/tex/latex/invoice
%dir %{_texmfdistdir}/tex/latex/invoice-class
%dir %{_texmfdistdir}/tex/latex/invoice2
%dir %{_texmfdistdir}/tex/latex/iodhbwm
%dir %{_texmfdistdir}/tex/latex/ionumbers
%dir %{_texmfdistdir}/tex/latex/ipaex-type1
%dir %{_texmfdistdir}/tex/latex/iscram
%dir %{_texmfdistdir}/tex/latex/iso
%dir %{_texmfdistdir}/tex/latex/iso10303
%dir %{_texmfdistdir}/tex/latex/isodate
%dir %{_texmfdistdir}/tex/latex/isodoc
%dir %{_texmfdistdir}/tex/latex/isomath
%dir %{_texmfdistdir}/tex/latex/isonums
%dir %{_texmfdistdir}/tex/latex/isopt
%dir %{_texmfdistdir}/tex/latex/isorot
%dir %{_texmfdistdir}/tex/latex/isotope
%dir %{_texmfdistdir}/tex/latex/issuulinks
%dir %{_texmfdistdir}/tex/latex/istgame
%dir %{_texmfdistdir}/tex/latex/itnumpar
%dir %{_texmfdistdir}/tex/latex/iwhdp
%dir %{_texmfdistdir}/tex/latex/iwona
%dir %{_texmfdistdir}/tex/latex/jacow
%dir %{_texmfdistdir}/tex/latex/jamtimes
%dir %{_texmfdistdir}/tex/latex/jeuxcartes
%dir %{_texmfdistdir}/tex/latex/jigsaw
%dir %{_texmfdistdir}/tex/latex/jkmath
%dir %{_texmfdistdir}/tex/latex/jknapltx
%dir %{_texmfdistdir}/tex/latex/jlabels
%dir %{_texmfdistdir}/tex/latex/jlreq
%dir %{_texmfdistdir}/tex/latex/jmb
%dir %{_texmfdistdir}/tex/latex/jmlr
%dir %{_texmfdistdir}/tex/latex/jmsdelim
%dir %{_texmfdistdir}/tex/latex/jneurosci
%dir %{_texmfdistdir}/tex/latex/jnuexam
%dir %{_texmfdistdir}/tex/latex/jobname-suffix
%dir %{_texmfdistdir}/tex/latex/josefin
%dir %{_texmfdistdir}/tex/latex/jourcl
%dir %{_texmfdistdir}/tex/latex/jpneduenumerate
%dir %{_texmfdistdir}/tex/latex/jpnedumathsymbols
%dir %{_texmfdistdir}/tex/latex/jpsj
%dir %{_texmfdistdir}/tex/latex/jslectureplanner
%dir %{_texmfdistdir}/tex/latex/jumplines
%dir %{_texmfdistdir}/tex/latex/junicode
%dir %{_texmfdistdir}/tex/latex/jupynotex
%dir %{_texmfdistdir}/tex/latex/jura
%dir %{_texmfdistdir}/tex/latex/juraabbrev
%dir %{_texmfdistdir}/tex/latex/jurabib
%dir %{_texmfdistdir}/tex/latex/juramisc
%dir %{_texmfdistdir}/tex/latex/jurarsp
%dir %{_texmfdistdir}/tex/latex/jvlisting
%dir %{_texmfdistdir}/tex/latex/jwjournal
%dir %{_texmfdistdir}/tex/latex/kalendarium
%dir %{_texmfdistdir}/tex/latex/kanbun
%dir %{_texmfdistdir}/tex/latex/kantlipsum
%dir %{_texmfdistdir}/tex/latex/karnaugh
%dir %{_texmfdistdir}/tex/latex/karnaugh-map
%dir %{_texmfdistdir}/tex/latex/karnaughmap
%dir %{_texmfdistdir}/tex/latex/kblocks
%dir %{_texmfdistdir}/tex/latex/kdgdocs
%dir %{_texmfdistdir}/tex/latex/kdpcover
%dir %{_texmfdistdir}/tex/latex/kerkis
%dir %{_texmfdistdir}/tex/latex/kerntest
%dir %{_texmfdistdir}/tex/latex/ketcindy
%dir %{_texmfdistdir}/tex/latex/keycommand
%dir %{_texmfdistdir}/tex/latex/keyfloat
%dir %{_texmfdistdir}/tex/latex/keyindex
%dir %{_texmfdistdir}/tex/latex/keyparse
%dir %{_texmfdistdir}/tex/latex/keyreader
%dir %{_texmfdistdir}/tex/latex/keystroke
%dir %{_texmfdistdir}/tex/latex/keyval2e
%dir %{_texmfdistdir}/tex/latex/keyvaltable
%dir %{_texmfdistdir}/tex/latex/kfupm-math-exam
%dir %{_texmfdistdir}/tex/latex/kinematikz
%dir %{_texmfdistdir}/tex/latex/kix
%dir %{_texmfdistdir}/tex/latex/kluwer
%dir %{_texmfdistdir}/tex/latex/knitting
%dir %{_texmfdistdir}/tex/latex/knittingpattern
%dir %{_texmfdistdir}/tex/latex/knowledge
%dir %{_texmfdistdir}/tex/latex/koma-moderncvclassic
%dir %{_texmfdistdir}/tex/latex/koma-script
%dir %{_texmfdistdir}/tex/latex/koma-script-sfs
%dir %{_texmfdistdir}/tex/latex/komacv
%dir %{_texmfdistdir}/tex/latex/komacv-rg
%dir %{_texmfdistdir}/tex/latex/kotex-oblivoir
%dir %{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-common
%dir %{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-ucs
%dir %{_texmfdistdir}/tex/latex/kotex-oblivoir/memhangul-x
%dir %{_texmfdistdir}/tex/latex/kotex-utf
%dir %{_texmfdistdir}/tex/latex/kotex-utf/contrib
%dir %{_texmfdistdir}/tex/latex/kotex-utf/tex4ht
%dir %{_texmfdistdir}/tex/latex/kpfonts
%dir %{_texmfdistdir}/tex/latex/kpfonts-otf
%dir %{_texmfdistdir}/tex/latex/ksp-thesis
%dir %{_texmfdistdir}/tex/latex/ktv-texdata
%dir %{_texmfdistdir}/tex/latex/ku-template
%dir %{_texmfdistdir}/tex/latex/kurier
%dir %{_texmfdistdir}/tex/latex/kvmap
%dir %{_texmfdistdir}/tex/latex/kvoptions
%dir %{_texmfdistdir}/tex/latex/kvsetkeys
%dir %{_texmfdistdir}/tex/latex/l3backend
%dir %{_texmfdistdir}/tex/latex/l3build
%dir %{_texmfdistdir}/tex/latex/l3experimental
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3benchmark
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3bitset
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3draw
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3graphics
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3opacity
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3str
%dir %{_texmfdistdir}/tex/latex/l3experimental/l3sys-shell
%dir %{_texmfdistdir}/tex/latex/l3experimental/xcoffins
%dir %{_texmfdistdir}/tex/latex/l3experimental/xgalley
%dir %{_texmfdistdir}/tex/latex/l3kernel
%dir %{_texmfdistdir}/tex/latex/l3packages
%dir %{_texmfdistdir}/tex/latex/l3packages/l3keys2e
%dir %{_texmfdistdir}/tex/latex/l3packages/xfp
%dir %{_texmfdistdir}/tex/latex/l3packages/xfrac
%dir %{_texmfdistdir}/tex/latex/l3packages/xparse
%dir %{_texmfdistdir}/tex/latex/l3packages/xtemplate
%dir %{_texmfdistdir}/tex/latex/labbook
%dir %{_texmfdistdir}/tex/latex/labels
%dir %{_texmfdistdir}/tex/latex/labels4easylist
%dir %{_texmfdistdir}/tex/latex/labelschanged
%dir %{_texmfdistdir}/tex/latex/labyrinth
%dir %{_texmfdistdir}/tex/latex/ladder
%dir %{_texmfdistdir}/tex/latex/lambdax
%dir %{_texmfdistdir}/tex/latex/langnames
%dir %{_texmfdistdir}/tex/latex/langsci-avm
%dir %{_texmfdistdir}/tex/latex/lapdf
%dir %{_texmfdistdir}/tex/latex/lastpackage
%dir %{_texmfdistdir}/tex/latex/lastpage
%dir %{_texmfdistdir}/tex/latex/latex-lab
%dir %{_texmfdistdir}/tex/latex/latex-make
%dir %{_texmfdistdir}/tex/latex/latex-uni8
%dir %{_texmfdistdir}/tex/latex/latex2man
%dir %{_texmfdistdir}/tex/latex/latexbangla
%dir %{_texmfdistdir}/tex/latex/latexbug
%dir %{_texmfdistdir}/tex/latex/latexcolors
%dir %{_texmfdistdir}/tex/latex/latexconfig
%dir %{_texmfdistdir}/tex/latex/latexdemo
%dir %{_texmfdistdir}/tex/latex/latexfileinfo-pkgs
%dir %{_texmfdistdir}/tex/latex/latexgit
%dir %{_texmfdistdir}/tex/latex/latino-sine-flexione
%dir %{_texmfdistdir}/tex/latex/lato
%dir %{_texmfdistdir}/tex/latex/layaureo
%dir %{_texmfdistdir}/tex/latex/layouts
%dir %{_texmfdistdir}/tex/latex/lazylist
%dir %{_texmfdistdir}/tex/latex/lccaps
%dir %{_texmfdistdir}/tex/latex/lcd
%dir %{_texmfdistdir}/tex/latex/lcg
%dir %{_texmfdistdir}/tex/latex/lcyw
%dir %{_texmfdistdir}/tex/latex/leading
%dir %{_texmfdistdir}/tex/latex/leadsheets
%dir %{_texmfdistdir}/tex/latex/leaflet
%dir %{_texmfdistdir}/tex/latex/lebhart
%dir %{_texmfdistdir}/tex/latex/lectures
%dir %{_texmfdistdir}/tex/latex/lectureslides
%dir %{_texmfdistdir}/tex/latex/ledmac
%dir %{_texmfdistdir}/tex/latex/leftidx
%dir %{_texmfdistdir}/tex/latex/leftindex
%dir %{_texmfdistdir}/tex/latex/leipzig
%dir %{_texmfdistdir}/tex/latex/lengthconvert
%dir %{_texmfdistdir}/tex/latex/letltxmacro
%dir %{_texmfdistdir}/tex/latex/letterswitharrows
%dir %{_texmfdistdir}/tex/latex/lettre
%dir %{_texmfdistdir}/tex/latex/lettrine
%dir %{_texmfdistdir}/tex/latex/lewis
%dir %{_texmfdistdir}/tex/latex/lexend
%dir %{_texmfdistdir}/tex/latex/lexikon
%dir %{_texmfdistdir}/tex/latex/lexref
%dir %{_texmfdistdir}/tex/latex/lgreek
%dir %{_texmfdistdir}/tex/latex/lgrmath
%dir %{_texmfdistdir}/tex/latex/lh
%dir %{_texmfdistdir}/tex/latex/lhcyr
%dir %{_texmfdistdir}/tex/latex/lhcyr/lhcyralt
%dir %{_texmfdistdir}/tex/latex/lhcyr/lhcyrkoi
%dir %{_texmfdistdir}/tex/latex/lhcyr/lhcyrwin
%dir %{_texmfdistdir}/tex/latex/lhelp
%dir %{_texmfdistdir}/tex/latex/libertine
%dir %{_texmfdistdir}/tex/latex/libertinegc
%dir %{_texmfdistdir}/tex/latex/libertinus
%dir %{_texmfdistdir}/tex/latex/libertinus-otf
%dir %{_texmfdistdir}/tex/latex/libertinus-type1
%dir %{_texmfdistdir}/tex/latex/libertinust1math
%dir %{_texmfdistdir}/tex/latex/libgreek
%dir %{_texmfdistdir}/tex/latex/librebaskerville
%dir %{_texmfdistdir}/tex/latex/librebodoni
%dir %{_texmfdistdir}/tex/latex/librecaslon
%dir %{_texmfdistdir}/tex/latex/librefranklin
%dir %{_texmfdistdir}/tex/latex/libris
%dir %{_texmfdistdir}/tex/latex/lie-hasse
%dir %{_texmfdistdir}/tex/latex/liftarm
%dir %{_texmfdistdir}/tex/latex/lilyglyphs
%dir %{_texmfdistdir}/tex/latex/lilyglyphs/commands
%dir %{_texmfdistdir}/tex/latex/lilyglyphs/core
%dir %{_texmfdistdir}/tex/latex/lilyglyphs/pdfs
%dir %{_texmfdistdir}/tex/latex/limap
%dir %{_texmfdistdir}/tex/latex/limecv
%dir %{_texmfdistdir}/tex/latex/lineara
%dir %{_texmfdistdir}/tex/latex/linegoal
%dir %{_texmfdistdir}/tex/latex/lineno
%dir %{_texmfdistdir}/tex/latex/ling-macros
%dir %{_texmfdistdir}/tex/latex/linguex
%dir %{_texmfdistdir}/tex/latex/linguisticspro
%dir %{_texmfdistdir}/tex/latex/linop
%dir %{_texmfdistdir}/tex/latex/lion-msc
%dir %{_texmfdistdir}/tex/latex/lipsum
%dir %{_texmfdistdir}/tex/latex/lisp-on-tex
%dir %{_texmfdistdir}/tex/latex/listbib
%dir %{_texmfdistdir}/tex/latex/listing
%dir %{_texmfdistdir}/tex/latex/listings
%dir %{_texmfdistdir}/tex/latex/listings-ext
%dir %{_texmfdistdir}/tex/latex/listingsutf8
%dir %{_texmfdistdir}/tex/latex/listlbls
%dir %{_texmfdistdir}/tex/latex/listliketab
%dir %{_texmfdistdir}/tex/latex/listofsymbols
%dir %{_texmfdistdir}/tex/latex/lithuanian
%dir %{_texmfdistdir}/tex/latex/liturg
%dir %{_texmfdistdir}/tex/latex/lkproof
%dir %{_texmfdistdir}/tex/latex/llncs
%dir %{_texmfdistdir}/tex/latex/llncsconf
%dir %{_texmfdistdir}/tex/latex/lm
%dir %{_texmfdistdir}/tex/latex/lmake
%dir %{_texmfdistdir}/tex/latex/lni
%dir %{_texmfdistdir}/tex/latex/lobster2
%dir %{_texmfdistdir}/tex/latex/locality
%dir %{_texmfdistdir}/tex/latex/logbox
%dir %{_texmfdistdir}/tex/latex/logical-markup-utils
%dir %{_texmfdistdir}/tex/latex/logicproof
%dir %{_texmfdistdir}/tex/latex/logicpuzzle
%dir %{_texmfdistdir}/tex/latex/logix
%dir %{_texmfdistdir}/tex/latex/logpap
%dir %{_texmfdistdir}/tex/latex/logreq
%dir %{_texmfdistdir}/tex/latex/longdivision
%dir %{_texmfdistdir}/tex/latex/longfbox
%dir %{_texmfdistdir}/tex/latex/longfigure
%dir %{_texmfdistdir}/tex/latex/longnamefilelist
%dir %{_texmfdistdir}/tex/latex/loops
%dir %{_texmfdistdir}/tex/latex/lpic
%dir %{_texmfdistdir}/tex/latex/lplfitch
%dir %{_texmfdistdir}/tex/latex/lps
%dir %{_texmfdistdir}/tex/latex/lroundrect
%dir %{_texmfdistdir}/tex/latex/lsc
%dir %{_texmfdistdir}/tex/latex/lstaddons
%dir %{_texmfdistdir}/tex/latex/lstbayes
%dir %{_texmfdistdir}/tex/latex/lstfiracode
%dir %{_texmfdistdir}/tex/latex/lt3graph
%dir %{_texmfdistdir}/tex/latex/lt3rawobjects
%dir %{_texmfdistdir}/tex/latex/ltablex
%dir %{_texmfdistdir}/tex/latex/ltabptch
%dir %{_texmfdistdir}/tex/latex/ltb2bib
%dir %{_texmfdistdir}/tex/latex/ltxdockit
%dir %{_texmfdistdir}/tex/latex/ltxguidex
%dir %{_texmfdistdir}/tex/latex/ltxkeys
%dir %{_texmfdistdir}/tex/latex/ltxmisc
%dir %{_texmfdistdir}/tex/latex/ltxnew
%dir %{_texmfdistdir}/tex/latex/ltxtools
%dir %{_texmfdistdir}/tex/latex/luacolor
%dir %{_texmfdistdir}/tex/latex/lwarp
%dir %{_texmfdistdir}/tex/latex/lxfonts
%dir %{_texmfdistdir}/tex/latex/ly1
%dir %{_texmfdistdir}/tex/latex/m-tx
%dir %{_texmfdistdir}/tex/latex/macrolist
%dir %{_texmfdistdir}/tex/latex/macros2e
%dir %{_texmfdistdir}/tex/latex/macroswap
%dir %{_texmfdistdir}/tex/latex/mafr
%dir %{_texmfdistdir}/tex/latex/magaz
%dir %{_texmfdistdir}/tex/latex/magicwatermark
%dir %{_texmfdistdir}/tex/latex/magra
%dir %{_texmfdistdir}/tex/latex/mahjong
%dir %{_texmfdistdir}/tex/latex/mahjong/tiles
%dir %{_texmfdistdir}/tex/latex/mailing
%dir %{_texmfdistdir}/tex/latex/mailmerge
%dir %{_texmfdistdir}/tex/latex/makebarcode
%dir %{_texmfdistdir}/tex/latex/makebase
%dir %{_texmfdistdir}/tex/latex/makebox
%dir %{_texmfdistdir}/tex/latex/makecell
%dir %{_texmfdistdir}/tex/latex/makecmds
%dir %{_texmfdistdir}/tex/latex/makedtx
%dir %{_texmfdistdir}/tex/latex/makeglos
%dir %{_texmfdistdir}/tex/latex/makelabels
%dir %{_texmfdistdir}/tex/latex/makeplot
%dir %{_texmfdistdir}/tex/latex/maker
%dir %{_texmfdistdir}/tex/latex/makerobust
%dir %{_texmfdistdir}/tex/latex/makeshape
%dir %{_texmfdistdir}/tex/latex/mandi
%dir %{_texmfdistdir}/tex/latex/manfnt
%dir %{_texmfdistdir}/tex/latex/manuscript
%dir %{_texmfdistdir}/tex/latex/manyind
%dir %{_texmfdistdir}/tex/latex/marathi
%dir %{_texmfdistdir}/tex/latex/marcellus
%dir %{_texmfdistdir}/tex/latex/margbib
%dir %{_texmfdistdir}/tex/latex/marginfit
%dir %{_texmfdistdir}/tex/latex/marginfix
%dir %{_texmfdistdir}/tex/latex/marginnote
%dir %{_texmfdistdir}/tex/latex/markdown
%dir %{_texmfdistdir}/tex/latex/marvosym
%dir %{_texmfdistdir}/tex/latex/matapli
%dir %{_texmfdistdir}/tex/latex/matc3
%dir %{_texmfdistdir}/tex/latex/matc3mem
%dir %{_texmfdistdir}/tex/latex/mathalpha
%dir %{_texmfdistdir}/tex/latex/mathastext
%dir %{_texmfdistdir}/tex/latex/mathcommand
%dir %{_texmfdistdir}/tex/latex/mathcomp
%dir %{_texmfdistdir}/tex/latex/mathdesign
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdbch
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdici
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdpgd
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdpus
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdput
%dir %{_texmfdistdir}/tex/latex/mathdesign/mdugm
%dir %{_texmfdistdir}/tex/latex/mathexam
%dir %{_texmfdistdir}/tex/latex/mathfam256
%dir %{_texmfdistdir}/tex/latex/mathfixs
%dir %{_texmfdistdir}/tex/latex/mathfont
%dir %{_texmfdistdir}/tex/latex/mathpartir
%dir %{_texmfdistdir}/tex/latex/mathpunctspace
%dir %{_texmfdistdir}/tex/latex/mathsemantics
%dir %{_texmfdistdir}/tex/latex/mathspic
%dir %{_texmfdistdir}/tex/latex/mathtools
%dir %{_texmfdistdir}/tex/latex/matlab-prettifier
%dir %{_texmfdistdir}/tex/latex/matrix-skeleton
%dir %{_texmfdistdir}/tex/latex/mattens
%dir %{_texmfdistdir}/tex/latex/maybemath
%dir %{_texmfdistdir}/tex/latex/maze
%dir %{_texmfdistdir}/tex/latex/mcaption
%dir %{_texmfdistdir}/tex/latex/mceinleger
%dir %{_texmfdistdir}/tex/latex/mcexam
%dir %{_texmfdistdir}/tex/latex/mcite
%dir %{_texmfdistdir}/tex/latex/mciteplus
%dir %{_texmfdistdir}/tex/latex/mcmthesis
%dir %{_texmfdistdir}/tex/latex/mdframed
%dir %{_texmfdistdir}/tex/latex/mdputu
%dir %{_texmfdistdir}/tex/latex/mdsymbol
%dir %{_texmfdistdir}/tex/latex/mdwtools
%dir %{_texmfdistdir}/tex/latex/mecaso
%dir %{_texmfdistdir}/tex/latex/media4svg
%dir %{_texmfdistdir}/tex/latex/media9
%dir %{_texmfdistdir}/tex/latex/media9/javascript
%dir %{_texmfdistdir}/tex/latex/media9/players
%dir %{_texmfdistdir}/tex/latex/medstarbeamer
%dir %{_texmfdistdir}/tex/latex/meetingmins
%dir %{_texmfdistdir}/tex/latex/membranecomputing
%dir %{_texmfdistdir}/tex/latex/memexsupp
%dir %{_texmfdistdir}/tex/latex/memoir
%dir %{_texmfdistdir}/tex/latex/memory
%dir %{_texmfdistdir}/tex/latex/memorygraphs
%dir %{_texmfdistdir}/tex/latex/mensa-tex
%dir %{_texmfdistdir}/tex/latex/mentis
%dir %{_texmfdistdir}/tex/latex/menu
%dir %{_texmfdistdir}/tex/latex/menucard
%dir %{_texmfdistdir}/tex/latex/menukeys
%dir %{_texmfdistdir}/tex/latex/mercatormap
%dir %{_texmfdistdir}/tex/latex/merriweather
%dir %{_texmfdistdir}/tex/latex/messagepassing
%dir %{_texmfdistdir}/tex/latex/metalogo
%dir %{_texmfdistdir}/tex/latex/metalogox
%dir %{_texmfdistdir}/tex/latex/metanorma
%dir %{_texmfdistdir}/tex/latex/metastr
%dir %{_texmfdistdir}/tex/latex/method
%dir %{_texmfdistdir}/tex/latex/metre
%dir %{_texmfdistdir}/tex/latex/metrix
%dir %{_texmfdistdir}/tex/latex/mfirstuc
%dir %{_texmfdistdir}/tex/latex/mflogo
%dir %{_texmfdistdir}/tex/latex/mfnfss
%dir %{_texmfdistdir}/tex/latex/mfpic4ode
%dir %{_texmfdistdir}/tex/latex/mftinc
%dir %{_texmfdistdir}/tex/latex/mgltex
%dir %{_texmfdistdir}/tex/latex/mhchem
%dir %{_texmfdistdir}/tex/latex/mhchem/hpstatement.inc
%dir %{_texmfdistdir}/tex/latex/mhequ
%dir %{_texmfdistdir}/tex/latex/mi-solns
%dir %{_texmfdistdir}/tex/latex/miama
%dir %{_texmfdistdir}/tex/latex/microtype
%dir %{_texmfdistdir}/tex/latex/midpage
%dir %{_texmfdistdir}/tex/latex/miller
%dir %{_texmfdistdir}/tex/latex/milog
%dir %{_texmfdistdir}/tex/latex/milsymb
%dir %{_texmfdistdir}/tex/latex/mindflow
%dir %{_texmfdistdir}/tex/latex/minibox
%dir %{_texmfdistdir}/tex/latex/minidocument
%dir %{_texmfdistdir}/tex/latex/minimalist
%dir %{_texmfdistdir}/tex/latex/minipage-marginpar
%dir %{_texmfdistdir}/tex/latex/miniplot
%dir %{_texmfdistdir}/tex/latex/minitoc
%dir %{_texmfdistdir}/tex/latex/minorrevision
%dir %{_texmfdistdir}/tex/latex/minted
%dir %{_texmfdistdir}/tex/latex/mintspirit
%dir %{_texmfdistdir}/tex/latex/minutes
%dir %{_texmfdistdir}/tex/latex/mismath
%dir %{_texmfdistdir}/tex/latex/missaali
%dir %{_texmfdistdir}/tex/latex/mla-paper
%dir %{_texmfdistdir}/tex/latex/mlacls
%dir %{_texmfdistdir}/tex/latex/mlist
%dir %{_texmfdistdir}/tex/latex/mlmodern
%dir %{_texmfdistdir}/tex/latex/mltex
%dir %{_texmfdistdir}/tex/latex/mluexercise
%dir %{_texmfdistdir}/tex/latex/mmap
%dir %{_texmfdistdir}/tex/latex/mnotes
%dir %{_texmfdistdir}/tex/latex/mnras
%dir %{_texmfdistdir}/tex/latex/mnsymbol
%dir %{_texmfdistdir}/tex/latex/modeles-factures-belges-assocs
%dir %{_texmfdistdir}/tex/latex/moderncv
%dir %{_texmfdistdir}/tex/latex/modernposter
%dir %{_texmfdistdir}/tex/latex/moderntimeline
%dir %{_texmfdistdir}/tex/latex/modiagram
%dir %{_texmfdistdir}/tex/latex/modref
%dir %{_texmfdistdir}/tex/latex/modroman
%dir %{_texmfdistdir}/tex/latex/modular
%dir %{_texmfdistdir}/tex/latex/mongolian-babel
%dir %{_texmfdistdir}/tex/latex/monofill
%dir %{_texmfdistdir}/tex/latex/montex
%dir %{_texmfdistdir}/tex/latex/montserrat
%dir %{_texmfdistdir}/tex/latex/moodle
%dir %{_texmfdistdir}/tex/latex/moreenum
%dir %{_texmfdistdir}/tex/latex/morefloats
%dir %{_texmfdistdir}/tex/latex/morehype
%dir %{_texmfdistdir}/tex/latex/moresize
%dir %{_texmfdistdir}/tex/latex/moreverb
%dir %{_texmfdistdir}/tex/latex/morewrites
%dir %{_texmfdistdir}/tex/latex/morisawa
%dir %{_texmfdistdir}/tex/latex/movie15
%dir %{_texmfdistdir}/tex/latex/mparhack
%dir %{_texmfdistdir}/tex/latex/mpgraphics
%dir %{_texmfdistdir}/tex/latex/mpostinl
%dir %{_texmfdistdir}/tex/latex/ms
%dir %{_texmfdistdir}/tex/latex/msc
%dir %{_texmfdistdir}/tex/latex/msg
%dir %{_texmfdistdir}/tex/latex/mslapa
%dir %{_texmfdistdir}/tex/latex/msu-thesis
%dir %{_texmfdistdir}/tex/latex/mtgreek
%dir %{_texmfdistdir}/tex/latex/mucproc
%dir %{_texmfdistdir}/tex/latex/mugsthesis
%dir %{_texmfdistdir}/tex/latex/muling
%dir %{_texmfdistdir}/tex/latex/multenum
%dir %{_texmfdistdir}/tex/latex/multiaudience
%dir %{_texmfdistdir}/tex/latex/multibbl
%dir %{_texmfdistdir}/tex/latex/multibib
%dir %{_texmfdistdir}/tex/latex/multibibliography
%dir %{_texmfdistdir}/tex/latex/multicap
%dir %{_texmfdistdir}/tex/latex/multicolrule
%dir %{_texmfdistdir}/tex/latex/multidef
%dir %{_texmfdistdir}/tex/latex/multido
%dir %{_texmfdistdir}/tex/latex/multienv
%dir %{_texmfdistdir}/tex/latex/multifootnote
%dir %{_texmfdistdir}/tex/latex/multilang
%dir %{_texmfdistdir}/tex/latex/multiobjective
%dir %{_texmfdistdir}/tex/latex/multiple-choice
%dir %{_texmfdistdir}/tex/latex/multirow
%dir %{_texmfdistdir}/tex/latex/musical
%dir %{_texmfdistdir}/tex/latex/musicography
%dir %{_texmfdistdir}/tex/latex/musikui
%dir %{_texmfdistdir}/tex/latex/musixguit
%dir %{_texmfdistdir}/tex/latex/musixtex
%dir %{_texmfdistdir}/tex/latex/musuos
%dir %{_texmfdistdir}/tex/latex/muthesis
%dir %{_texmfdistdir}/tex/latex/mversion
%dir %{_texmfdistdir}/tex/latex/mwcls
%dir %{_texmfdistdir}/tex/latex/mwe
%dir %{_texmfdistdir}/tex/latex/mweights
%dir %{_texmfdistdir}/tex/latex/mxedruli
%dir %{_texmfdistdir}/tex/latex/mycv
%dir %{_texmfdistdir}/tex/latex/mylatex
%dir %{_texmfdistdir}/tex/latex/mylatexformat
%dir %{_texmfdistdir}/tex/latex/nag
%dir %{_texmfdistdir}/tex/latex/naive-ebnf
%dir %{_texmfdistdir}/tex/latex/nameauth
%dir %{_texmfdistdir}/tex/latex/namedtensor
%dir %{_texmfdistdir}/tex/latex/namespc
%dir %{_texmfdistdir}/tex/latex/nanumtype1
%dir %{_texmfdistdir}/tex/latex/natbib
%dir %{_texmfdistdir}/tex/latex/natded
%dir %{_texmfdistdir}/tex/latex/nath
%dir %{_texmfdistdir}/tex/latex/nature
%dir %{_texmfdistdir}/tex/latex/navydocs
%dir %{_texmfdistdir}/tex/latex/ncclatex
%dir %{_texmfdistdir}/tex/latex/ncctools
%dir %{_texmfdistdir}/tex/latex/nchairx
%dir %{_texmfdistdir}/tex/latex/ncntrsbk
%dir %{_texmfdistdir}/tex/latex/nddiss
%dir %{_texmfdistdir}/tex/latex/ndsu-thesis
%dir %{_texmfdistdir}/tex/latex/ndsu-thesis-2022
%dir %{_texmfdistdir}/tex/latex/needspace
%dir %{_texmfdistdir}/tex/latex/nestquot
%dir %{_texmfdistdir}/tex/latex/neuralnetwork
%dir %{_texmfdistdir}/tex/latex/nevelok
%dir %{_texmfdistdir}/tex/latex/newcomputermodern
%dir %{_texmfdistdir}/tex/latex/newenviron
%dir %{_texmfdistdir}/tex/latex/newfile
%dir %{_texmfdistdir}/tex/latex/newfloat
%dir %{_texmfdistdir}/tex/latex/newlfm
%dir %{_texmfdistdir}/tex/latex/newpax
%dir %{_texmfdistdir}/tex/latex/newpx
%dir %{_texmfdistdir}/tex/latex/newspaper
%dir %{_texmfdistdir}/tex/latex/newtx
%dir %{_texmfdistdir}/tex/latex/newtxsf
%dir %{_texmfdistdir}/tex/latex/newtxtt
%dir %{_texmfdistdir}/tex/latex/newunicodechar
%dir %{_texmfdistdir}/tex/latex/newvbtm
%dir %{_texmfdistdir}/tex/latex/newverbs
%dir %{_texmfdistdir}/tex/latex/nextpage
%dir %{_texmfdistdir}/tex/latex/nfssext-cfr
%dir %{_texmfdistdir}/tex/latex/nicefilelist
%dir %{_texmfdistdir}/tex/latex/niceframe
%dir %{_texmfdistdir}/tex/latex/nicematrix
%dir %{_texmfdistdir}/tex/latex/nicetext
%dir %{_texmfdistdir}/tex/latex/nicetext/run
%dir %{_texmfdistdir}/tex/latex/nidanfloat
%dir %{_texmfdistdir}/tex/latex/nih
%dir %{_texmfdistdir}/tex/latex/nihbiosketch
%dir %{_texmfdistdir}/tex/latex/nimbus15
%dir %{_texmfdistdir}/tex/latex/nimsticks
%dir %{_texmfdistdir}/tex/latex/ninecolors
%dir %{_texmfdistdir}/tex/latex/njurepo
%dir %{_texmfdistdir}/tex/latex/njustthesis
%dir %{_texmfdistdir}/tex/latex/njuthesis
%dir %{_texmfdistdir}/tex/latex/njuvisual
%dir %{_texmfdistdir}/tex/latex/nl-interval
%dir %{_texmfdistdir}/tex/latex/nlctdoc
%dir %{_texmfdistdir}/tex/latex/nmbib
%dir %{_texmfdistdir}/tex/latex/nndraw
%dir %{_texmfdistdir}/tex/latex/nnext
%dir %{_texmfdistdir}/tex/latex/noconflict
%dir %{_texmfdistdir}/tex/latex/noindentafter
%dir %{_texmfdistdir}/tex/latex/noitcrul
%dir %{_texmfdistdir}/tex/latex/nolbreaks
%dir %{_texmfdistdir}/tex/latex/nomencl
%dir %{_texmfdistdir}/tex/latex/nomentbl
%dir %{_texmfdistdir}/tex/latex/nonfloat
%dir %{_texmfdistdir}/tex/latex/nonumonpart
%dir %{_texmfdistdir}/tex/latex/nopageno
%dir %{_texmfdistdir}/tex/latex/normalcolor
%dir %{_texmfdistdir}/tex/latex/nostarch
%dir %{_texmfdistdir}/tex/latex/notes
%dir %{_texmfdistdir}/tex/latex/notes2bib
%dir %{_texmfdistdir}/tex/latex/notespages
%dir %{_texmfdistdir}/tex/latex/notestex
%dir %{_texmfdistdir}/tex/latex/noto
%dir %{_texmfdistdir}/tex/latex/notoccite
%dir %{_texmfdistdir}/tex/latex/notomath
%dir %{_texmfdistdir}/tex/latex/nowidow
%dir %{_texmfdistdir}/tex/latex/nox
%dir %{_texmfdistdir}/tex/latex/nrc
%dir %{_texmfdistdir}/tex/latex/ntgclass
%dir %{_texmfdistdir}/tex/latex/ntheorem
%dir %{_texmfdistdir}/tex/latex/nuc
%dir %{_texmfdistdir}/tex/latex/nucleardata
%dir %{_texmfdistdir}/tex/latex/numberedblock
%dir %{_texmfdistdir}/tex/latex/numberpt
%dir %{_texmfdistdir}/tex/latex/numerica
%dir %{_texmfdistdir}/tex/latex/numerica-plus
%dir %{_texmfdistdir}/tex/latex/numerica-tables
%dir %{_texmfdistdir}/tex/latex/numericplots
%dir %{_texmfdistdir}/tex/latex/numname
%dir %{_texmfdistdir}/tex/latex/numnameru
%dir %{_texmfdistdir}/tex/latex/numprint
%dir %{_texmfdistdir}/tex/latex/numspell
%dir %{_texmfdistdir}/tex/latex/nunito
%dir %{_texmfdistdir}/tex/latex/nwafuthesis
%dir %{_texmfdistdir}/tex/latex/nwejm
%dir %{_texmfdistdir}/tex/latex/nwejm/images
%dir %{_texmfdistdir}/tex/latex/oberdiek
%dir %{_texmfdistdir}/tex/latex/objectz
%dir %{_texmfdistdir}/tex/latex/obnov
%dir %{_texmfdistdir}/tex/latex/ocg-p
%dir %{_texmfdistdir}/tex/latex/ocgx
%dir %{_texmfdistdir}/tex/latex/ocgx2
%dir %{_texmfdistdir}/tex/latex/ocr-latex
%dir %{_texmfdistdir}/tex/latex/octave
%dir %{_texmfdistdir}/tex/latex/octavo
%dir %{_texmfdistdir}/tex/latex/old-arrows
%dir %{_texmfdistdir}/tex/latex/oldstandard
%dir %{_texmfdistdir}/tex/latex/oldstyle
%dir %{_texmfdistdir}/tex/latex/onedown
%dir %{_texmfdistdir}/tex/latex/onlyamsmath
%dir %{_texmfdistdir}/tex/latex/onrannual
%dir %{_texmfdistdir}/tex/latex/opcit
%dir %{_texmfdistdir}/tex/latex/opencolor
%dir %{_texmfdistdir}/tex/latex/opensans
%dir %{_texmfdistdir}/tex/latex/oplotsymbl
%dir %{_texmfdistdir}/tex/latex/opteng
%dir %{_texmfdistdir}/tex/latex/optidef
%dir %{_texmfdistdir}/tex/latex/optional
%dir %{_texmfdistdir}/tex/latex/options
%dir %{_texmfdistdir}/tex/latex/orcidlink
%dir %{_texmfdistdir}/tex/latex/ordinalpt
%dir %{_texmfdistdir}/tex/latex/orientation
%dir %{_texmfdistdir}/tex/latex/oscola
%dir %{_texmfdistdir}/tex/latex/oswald
%dir %{_texmfdistdir}/tex/latex/ot-tableau
%dir %{_texmfdistdir}/tex/latex/othello
%dir %{_texmfdistdir}/tex/latex/othelloboard
%dir %{_texmfdistdir}/tex/latex/otibet
%dir %{_texmfdistdir}/tex/latex/oubraces
%dir %{_texmfdistdir}/tex/latex/oup-authoring-template
%dir %{_texmfdistdir}/tex/latex/outilsgeomtikz
%dir %{_texmfdistdir}/tex/latex/outline
%dir %{_texmfdistdir}/tex/latex/outliner
%dir %{_texmfdistdir}/tex/latex/outlines
%dir %{_texmfdistdir}/tex/latex/outlining
%dir %{_texmfdistdir}/tex/latex/overarrows
%dir %{_texmfdistdir}/tex/latex/overlays
%dir %{_texmfdistdir}/tex/latex/overlock
%dir %{_texmfdistdir}/tex/latex/overpic
%dir %{_texmfdistdir}/tex/latex/pacioli
%dir %{_texmfdistdir}/tex/latex/padcount
%dir %{_texmfdistdir}/tex/latex/pagecolor
%dir %{_texmfdistdir}/tex/latex/pagecont
%dir %{_texmfdistdir}/tex/latex/pagegrid
%dir %{_texmfdistdir}/tex/latex/pagelayout
%dir %{_texmfdistdir}/tex/latex/pagella-otf
%dir %{_texmfdistdir}/tex/latex/pagenote
%dir %{_texmfdistdir}/tex/latex/pagerange
%dir %{_texmfdistdir}/tex/latex/pagesel
%dir %{_texmfdistdir}/tex/latex/pageslts
%dir %{_texmfdistdir}/tex/latex/palatino
%dir %{_texmfdistdir}/tex/latex/palette
%dir %{_texmfdistdir}/tex/latex/pangram
%dir %{_texmfdistdir}/tex/latex/paper
%dir %{_texmfdistdir}/tex/latex/papercdcase
%dir %{_texmfdistdir}/tex/latex/papermas
%dir %{_texmfdistdir}/tex/latex/papertex
%dir %{_texmfdistdir}/tex/latex/paracol
%dir %{_texmfdistdir}/tex/latex/parades
%dir %{_texmfdistdir}/tex/latex/paralist
%dir %{_texmfdistdir}/tex/latex/parallel
%dir %{_texmfdistdir}/tex/latex/paratype
%dir %{_texmfdistdir}/tex/latex/paresse
%dir %{_texmfdistdir}/tex/latex/parnotes
%dir %{_texmfdistdir}/tex/latex/parrun
%dir %{_texmfdistdir}/tex/latex/parselines
%dir %{_texmfdistdir}/tex/latex/parskip
%dir %{_texmfdistdir}/tex/latex/pas-cours
%dir %{_texmfdistdir}/tex/latex/pas-crosswords
%dir %{_texmfdistdir}/tex/latex/pas-cv
%dir %{_texmfdistdir}/tex/latex/pas-tableur
%dir %{_texmfdistdir}/tex/latex/pascaltriangle
%dir %{_texmfdistdir}/tex/latex/patchcmd
%dir %{_texmfdistdir}/tex/latex/pauldoc
%dir %{_texmfdistdir}/tex/latex/pawpict
%dir %{_texmfdistdir}/tex/latex/pax
%dir %{_texmfdistdir}/tex/latex/pb-diagram
%dir %{_texmfdistdir}/tex/latex/pbalance
%dir %{_texmfdistdir}/tex/latex/pbox
%dir %{_texmfdistdir}/tex/latex/pbsheet
%dir %{_texmfdistdir}/tex/latex/pdf14
%dir %{_texmfdistdir}/tex/latex/pdfcol
%dir %{_texmfdistdir}/tex/latex/pdfcolfoot
%dir %{_texmfdistdir}/tex/latex/pdfcolmk
%dir %{_texmfdistdir}/tex/latex/pdfcomment
%dir %{_texmfdistdir}/tex/latex/pdfcprot
%dir %{_texmfdistdir}/tex/latex/pdflscape
%dir %{_texmfdistdir}/tex/latex/pdfmanagement-testphase
%dir %{_texmfdistdir}/tex/latex/pdfmarginpar
%dir %{_texmfdistdir}/tex/latex/pdfoverlay
%dir %{_texmfdistdir}/tex/latex/pdfpagediff
%dir %{_texmfdistdir}/tex/latex/pdfpages
%dir %{_texmfdistdir}/tex/latex/pdfpc
%dir %{_texmfdistdir}/tex/latex/pdfpc-movie
%dir %{_texmfdistdir}/tex/latex/pdfprivacy
%dir %{_texmfdistdir}/tex/latex/pdfreview
%dir %{_texmfdistdir}/tex/latex/pdfscreen
%dir %{_texmfdistdir}/tex/latex/pdfslide
%dir %{_texmfdistdir}/tex/latex/pdfsync
%dir %{_texmfdistdir}/tex/latex/pdftricks
%dir %{_texmfdistdir}/tex/latex/pdftricks2
%dir %{_texmfdistdir}/tex/latex/pdfwin
%dir %{_texmfdistdir}/tex/latex/pdfx
%dir %{_texmfdistdir}/tex/latex/pdfxup
%dir %{_texmfdistdir}/tex/latex/pecha
%dir %{_texmfdistdir}/tex/latex/penrose
%dir %{_texmfdistdir}/tex/latex/perfectcut
%dir %{_texmfdistdir}/tex/latex/perltex
%dir %{_texmfdistdir}/tex/latex/permute
%dir %{_texmfdistdir}/tex/latex/petiteannonce
%dir %{_texmfdistdir}/tex/latex/pfarrei
%dir %{_texmfdistdir}/tex/latex/pfdicons
%dir %{_texmfdistdir}/tex/latex/pgf
%dir %{_texmfdistdir}/tex/latex/pgf-blur
%dir %{_texmfdistdir}/tex/latex/pgf-interference
%dir %{_texmfdistdir}/tex/latex/pgf-periodictable
%dir %{_texmfdistdir}/tex/latex/pgf-periodictable/flags
%dir %{_texmfdistdir}/tex/latex/pgf-periodictable/lattice
%dir %{_texmfdistdir}/tex/latex/pgf-periodictable/spectra
%dir %{_texmfdistdir}/tex/latex/pgf-pie
%dir %{_texmfdistdir}/tex/latex/pgf-soroban
%dir %{_texmfdistdir}/tex/latex/pgf-spectra
%dir %{_texmfdistdir}/tex/latex/pgf-umlcd
%dir %{_texmfdistdir}/tex/latex/pgf-umlsd
%dir %{_texmfdistdir}/tex/latex/pgf/basiclayer
%dir %{_texmfdistdir}/tex/latex/pgf/compatibility
%dir %{_texmfdistdir}/tex/latex/pgf/doc
%dir %{_texmfdistdir}/tex/latex/pgf/frontendlayer
%dir %{_texmfdistdir}/tex/latex/pgf/frontendlayer/libraries
%dir %{_texmfdistdir}/tex/latex/pgf/math
%dir %{_texmfdistdir}/tex/latex/pgf/systemlayer
%dir %{_texmfdistdir}/tex/latex/pgf/utilities
%dir %{_texmfdistdir}/tex/latex/pgfgantt
%dir %{_texmfdistdir}/tex/latex/pgfkeyx
%dir %{_texmfdistdir}/tex/latex/pgfmath-xfp
%dir %{_texmfdistdir}/tex/latex/pgfmorepages
%dir %{_texmfdistdir}/tex/latex/pgfopts
%dir %{_texmfdistdir}/tex/latex/pgfornament
%dir %{_texmfdistdir}/tex/latex/pgfornament-han
%dir %{_texmfdistdir}/tex/latex/pgfornament-han/han
%dir %{_texmfdistdir}/tex/latex/pgfplots
%dir %{_texmfdistdir}/tex/latex/pgfplots/libs
%dir %{_texmfdistdir}/tex/latex/phaistos
%dir %{_texmfdistdir}/tex/latex/phfcc
%dir %{_texmfdistdir}/tex/latex/phfextendedabstract
%dir %{_texmfdistdir}/tex/latex/phffullpagefigure
%dir %{_texmfdistdir}/tex/latex/phfnote
%dir %{_texmfdistdir}/tex/latex/phfparen
%dir %{_texmfdistdir}/tex/latex/phfqit
%dir %{_texmfdistdir}/tex/latex/phfquotetext
%dir %{_texmfdistdir}/tex/latex/phfsvnwatermark
%dir %{_texmfdistdir}/tex/latex/phfthm
%dir %{_texmfdistdir}/tex/latex/philex
%dir %{_texmfdistdir}/tex/latex/philosophersimprint
%dir %{_texmfdistdir}/tex/latex/phonenumbers
%dir %{_texmfdistdir}/tex/latex/phonetic
%dir %{_texmfdistdir}/tex/latex/phonrule
%dir %{_texmfdistdir}/tex/latex/photo
%dir %{_texmfdistdir}/tex/latex/photobook
%dir %{_texmfdistdir}/tex/latex/physconst
%dir %{_texmfdistdir}/tex/latex/physics
%dir %{_texmfdistdir}/tex/latex/physics2
%dir %{_texmfdistdir}/tex/latex/physunits
%dir %{_texmfdistdir}/tex/latex/piano
%dir %{_texmfdistdir}/tex/latex/picinpar
%dir %{_texmfdistdir}/tex/latex/pict2e
%dir %{_texmfdistdir}/tex/latex/pictex2
%dir %{_texmfdistdir}/tex/latex/picture
%dir %{_texmfdistdir}/tex/latex/piff
%dir %{_texmfdistdir}/tex/latex/pigpen
%dir %{_texmfdistdir}/tex/latex/pinlabel
%dir %{_texmfdistdir}/tex/latex/pinoutikz
%dir %{_texmfdistdir}/tex/latex/pittetd
%dir %{_texmfdistdir}/tex/latex/pixelart
%dir %{_texmfdistdir}/tex/latex/pixelarttikz
%dir %{_texmfdistdir}/tex/latex/pkgloader
%dir %{_texmfdistdir}/tex/latex/pkuthss
%dir %{_texmfdistdir}/tex/latex/placeins
%dir %{_texmfdistdir}/tex/latex/plantslabels
%dir %{_texmfdistdir}/tex/latex/plari
%dir %{_texmfdistdir}/tex/latex/plates
%dir %{_texmfdistdir}/tex/latex/platex-tools
%dir %{_texmfdistdir}/tex/latex/plautopatch
%dir %{_texmfdistdir}/tex/latex/play
%dir %{_texmfdistdir}/tex/latex/playfair
%dir %{_texmfdistdir}/tex/latex/plex
%dir %{_texmfdistdir}/tex/latex/plex-otf
%dir %{_texmfdistdir}/tex/latex/plimsoll
%dir %{_texmfdistdir}/tex/latex/plweb
%dir %{_texmfdistdir}/tex/latex/pm-isomath
%dir %{_texmfdistdir}/tex/latex/pmboxdraw
%dir %{_texmfdistdir}/tex/latex/pmgraph
%dir %{_texmfdistdir}/tex/latex/pmhanguljamo
%dir %{_texmfdistdir}/tex/latex/poemscol
%dir %{_texmfdistdir}/tex/latex/poetry
%dir %{_texmfdistdir}/tex/latex/poetrytex
%dir %{_texmfdistdir}/tex/latex/poiretone
%dir %{_texmfdistdir}/tex/latex/polski
%dir %{_texmfdistdir}/tex/latex/poltawski
%dir %{_texmfdistdir}/tex/latex/polyglossia
%dir %{_texmfdistdir}/tex/latex/polynom
%dir %{_texmfdistdir}/tex/latex/polynomial
%dir %{_texmfdistdir}/tex/latex/polytable
%dir %{_texmfdistdir}/tex/latex/postage
%dir %{_texmfdistdir}/tex/latex/postcards
%dir %{_texmfdistdir}/tex/latex/postnotes
%dir %{_texmfdistdir}/tex/latex/powerdot
%dir %{_texmfdistdir}/tex/latex/powerdot-fuberlin
%dir %{_texmfdistdir}/tex/latex/powerdot-tuliplab
%dir %{_texmfdistdir}/tex/latex/powerdot-tuliplab/logos
%dir %{_texmfdistdir}/tex/latex/powerdot-tuliplab/logos/tulip
%dir %{_texmfdistdir}/tex/latex/ppr-prv
%dir %{_texmfdistdir}/tex/latex/ppt-slides
%dir %{_texmfdistdir}/tex/latex/ppt-slides/ppt-schemes
%dir %{_texmfdistdir}/tex/latex/ppt-slides/ppt-templates
%dir %{_texmfdistdir}/tex/latex/pracjourn
%dir %{_texmfdistdir}/tex/latex/practicalreports
%dir %{_texmfdistdir}/tex/latex/precattl
%dir %{_texmfdistdir}/tex/latex/prelim2e
%dir %{_texmfdistdir}/tex/latex/preprint
%dir %{_texmfdistdir}/tex/latex/prerex
%dir %{_texmfdistdir}/tex/latex/pressrelease
%dir %{_texmfdistdir}/tex/latex/prettyref
%dir %{_texmfdistdir}/tex/latex/prettytok
%dir %{_texmfdistdir}/tex/latex/preview
%dir %{_texmfdistdir}/tex/latex/prftree
%dir %{_texmfdistdir}/tex/latex/principia
%dir %{_texmfdistdir}/tex/latex/printlen
%dir %{_texmfdistdir}/tex/latex/proba
%dir %{_texmfdistdir}/tex/latex/probsoln
%dir %{_texmfdistdir}/tex/latex/prociagssymp
%dir %{_texmfdistdir}/tex/latex/prodint
%dir %{_texmfdistdir}/tex/latex/productbox
%dir %{_texmfdistdir}/tex/latex/profcollege
%dir %{_texmfdistdir}/tex/latex/proflabo
%dir %{_texmfdistdir}/tex/latex/proflycee
%dir %{_texmfdistdir}/tex/latex/program
%dir %{_texmfdistdir}/tex/latex/progress
%dir %{_texmfdistdir}/tex/latex/progressbar
%dir %{_texmfdistdir}/tex/latex/projlib
%dir %{_texmfdistdir}/tex/latex/proof-at-the-end
%dir %{_texmfdistdir}/tex/latex/proofread
%dir %{_texmfdistdir}/tex/latex/prooftrees
%dir %{_texmfdistdir}/tex/latex/properties
%dir %{_texmfdistdir}/tex/latex/proposal
%dir %{_texmfdistdir}/tex/latex/proposal/base
%dir %{_texmfdistdir}/tex/latex/proposal/dfg
%dir %{_texmfdistdir}/tex/latex/proposal/eu
%dir %{_texmfdistdir}/tex/latex/prosper
%dir %{_texmfdistdir}/tex/latex/protex
%dir %{_texmfdistdir}/tex/latex/protocol
%dir %{_texmfdistdir}/tex/latex/prtec
%dir %{_texmfdistdir}/tex/latex/przechlewski-book
%dir %{_texmfdistdir}/tex/latex/psbao
%dir %{_texmfdistdir}/tex/latex/pseudo
%dir %{_texmfdistdir}/tex/latex/pseudocode
%dir %{_texmfdistdir}/tex/latex/psfrag
%dir %{_texmfdistdir}/tex/latex/psfragx
%dir %{_texmfdistdir}/tex/latex/psgo
%dir %{_texmfdistdir}/tex/latex/pslatex
%dir %{_texmfdistdir}/tex/latex/psnfss
%dir %{_texmfdistdir}/tex/latex/pspicture
%dir %{_texmfdistdir}/tex/latex/pst-2dplot
%dir %{_texmfdistdir}/tex/latex/pst-3d
%dir %{_texmfdistdir}/tex/latex/pst-3dplot
%dir %{_texmfdistdir}/tex/latex/pst-abspos
%dir %{_texmfdistdir}/tex/latex/pst-am
%dir %{_texmfdistdir}/tex/latex/pst-antiprism
%dir %{_texmfdistdir}/tex/latex/pst-arrow
%dir %{_texmfdistdir}/tex/latex/pst-asr
%dir %{_texmfdistdir}/tex/latex/pst-bar
%dir %{_texmfdistdir}/tex/latex/pst-barcode
%dir %{_texmfdistdir}/tex/latex/pst-bezier
%dir %{_texmfdistdir}/tex/latex/pst-blur
%dir %{_texmfdistdir}/tex/latex/pst-bspline
%dir %{_texmfdistdir}/tex/latex/pst-calculate
%dir %{_texmfdistdir}/tex/latex/pst-calendar
%dir %{_texmfdistdir}/tex/latex/pst-cie
%dir %{_texmfdistdir}/tex/latex/pst-circ
%dir %{_texmfdistdir}/tex/latex/pst-coil
%dir %{_texmfdistdir}/tex/latex/pst-contourplot
%dir %{_texmfdistdir}/tex/latex/pst-cox
%dir %{_texmfdistdir}/tex/latex/pst-dart
%dir %{_texmfdistdir}/tex/latex/pst-dbicons
%dir %{_texmfdistdir}/tex/latex/pst-diffraction
%dir %{_texmfdistdir}/tex/latex/pst-electricfield
%dir %{_texmfdistdir}/tex/latex/pst-eps
%dir %{_texmfdistdir}/tex/latex/pst-eucl
%dir %{_texmfdistdir}/tex/latex/pst-exa
%dir %{_texmfdistdir}/tex/latex/pst-feyn
%dir %{_texmfdistdir}/tex/latex/pst-fill
%dir %{_texmfdistdir}/tex/latex/pst-fit
%dir %{_texmfdistdir}/tex/latex/pst-flags
%dir %{_texmfdistdir}/tex/latex/pst-flags/Flags
%dir %{_texmfdistdir}/tex/latex/pst-fr3d
%dir %{_texmfdistdir}/tex/latex/pst-fractal
%dir %{_texmfdistdir}/tex/latex/pst-fun
%dir %{_texmfdistdir}/tex/latex/pst-func
%dir %{_texmfdistdir}/tex/latex/pst-gantt
%dir %{_texmfdistdir}/tex/latex/pst-geo
%dir %{_texmfdistdir}/tex/latex/pst-geometrictools
%dir %{_texmfdistdir}/tex/latex/pst-gr3d
%dir %{_texmfdistdir}/tex/latex/pst-grad
%dir %{_texmfdistdir}/tex/latex/pst-hsb
%dir %{_texmfdistdir}/tex/latex/pst-infixplot
%dir %{_texmfdistdir}/tex/latex/pst-intersect
%dir %{_texmfdistdir}/tex/latex/pst-jtree
%dir %{_texmfdistdir}/tex/latex/pst-knot
%dir %{_texmfdistdir}/tex/latex/pst-labo
%dir %{_texmfdistdir}/tex/latex/pst-layout
%dir %{_texmfdistdir}/tex/latex/pst-lens
%dir %{_texmfdistdir}/tex/latex/pst-light3d
%dir %{_texmfdistdir}/tex/latex/pst-lsystem
%dir %{_texmfdistdir}/tex/latex/pst-magneticfield
%dir %{_texmfdistdir}/tex/latex/pst-marble
%dir %{_texmfdistdir}/tex/latex/pst-math
%dir %{_texmfdistdir}/tex/latex/pst-mirror
%dir %{_texmfdistdir}/tex/latex/pst-moire
%dir %{_texmfdistdir}/tex/latex/pst-node
%dir %{_texmfdistdir}/tex/latex/pst-ob3d
%dir %{_texmfdistdir}/tex/latex/pst-ode
%dir %{_texmfdistdir}/tex/latex/pst-optexp
%dir %{_texmfdistdir}/tex/latex/pst-optic
%dir %{_texmfdistdir}/tex/latex/pst-osci
%dir %{_texmfdistdir}/tex/latex/pst-ovl
%dir %{_texmfdistdir}/tex/latex/pst-pad
%dir %{_texmfdistdir}/tex/latex/pst-pdf
%dir %{_texmfdistdir}/tex/latex/pst-pdgr
%dir %{_texmfdistdir}/tex/latex/pst-perspective
%dir %{_texmfdistdir}/tex/latex/pst-platon
%dir %{_texmfdistdir}/tex/latex/pst-plot
%dir %{_texmfdistdir}/tex/latex/pst-poker
%dir %{_texmfdistdir}/tex/latex/pst-poly
%dir %{_texmfdistdir}/tex/latex/pst-pulley
%dir %{_texmfdistdir}/tex/latex/pst-qtree
%dir %{_texmfdistdir}/tex/latex/pst-rputover
%dir %{_texmfdistdir}/tex/latex/pst-rubans
%dir %{_texmfdistdir}/tex/latex/pst-shell
%dir %{_texmfdistdir}/tex/latex/pst-sigsys
%dir %{_texmfdistdir}/tex/latex/pst-slpe
%dir %{_texmfdistdir}/tex/latex/pst-solarsystem
%dir %{_texmfdistdir}/tex/latex/pst-solides3d
%dir %{_texmfdistdir}/tex/latex/pst-soroban
%dir %{_texmfdistdir}/tex/latex/pst-spectra
%dir %{_texmfdistdir}/tex/latex/pst-spinner
%dir %{_texmfdistdir}/tex/latex/pst-stru
%dir %{_texmfdistdir}/tex/latex/pst-text
%dir %{_texmfdistdir}/tex/latex/pst-thick
%dir %{_texmfdistdir}/tex/latex/pst-tools
%dir %{_texmfdistdir}/tex/latex/pst-tree
%dir %{_texmfdistdir}/tex/latex/pst-turtle
%dir %{_texmfdistdir}/tex/latex/pst-tvz
%dir %{_texmfdistdir}/tex/latex/pst-uml
%dir %{_texmfdistdir}/tex/latex/pst-vectorian
%dir %{_texmfdistdir}/tex/latex/pst-vehicle
%dir %{_texmfdistdir}/tex/latex/pst-venn
%dir %{_texmfdistdir}/tex/latex/pst-vowel
%dir %{_texmfdistdir}/tex/latex/pstool
%dir %{_texmfdistdir}/tex/latex/pstricks
%dir %{_texmfdistdir}/tex/latex/pstricks-add
%dir %{_texmfdistdir}/tex/latex/pstring
%dir %{_texmfdistdir}/tex/latex/ptolemaicastronomy
%dir %{_texmfdistdir}/tex/latex/ptptex
%dir %{_texmfdistdir}/tex/latex/punk-latex
%dir %{_texmfdistdir}/tex/latex/puyotikz
%dir %{_texmfdistdir}/tex/latex/pxcjkcat
%dir %{_texmfdistdir}/tex/latex/pxfonts
%dir %{_texmfdistdir}/tex/latex/pxgreeks
%dir %{_texmfdistdir}/tex/latex/pxjodel
%dir %{_texmfdistdir}/tex/latex/pxpgfmark
%dir %{_texmfdistdir}/tex/latex/pxpic
%dir %{_texmfdistdir}/tex/latex/pxtatescale
%dir %{_texmfdistdir}/tex/latex/pxtxalfa
%dir %{_texmfdistdir}/tex/latex/pxufont
%dir %{_texmfdistdir}/tex/latex/pygmentex
%dir %{_texmfdistdir}/tex/latex/python
%dir %{_texmfdistdir}/tex/latex/pythonhighlight
%dir %{_texmfdistdir}/tex/latex/pythonimmediate
%dir %{_texmfdistdir}/tex/latex/pythontex
%dir %{_texmfdistdir}/tex/latex/qcircuit
%dir %{_texmfdistdir}/tex/latex/qcm
%dir %{_texmfdistdir}/tex/latex/qobitree
%dir %{_texmfdistdir}/tex/latex/qrbill
%dir %{_texmfdistdir}/tex/latex/qrcode
%dir %{_texmfdistdir}/tex/latex/qsharp
%dir %{_texmfdistdir}/tex/latex/qstest
%dir %{_texmfdistdir}/tex/latex/qsymbols
%dir %{_texmfdistdir}/tex/latex/qtree
%dir %{_texmfdistdir}/tex/latex/quantikz
%dir %{_texmfdistdir}/tex/latex/quantumarticle
%dir %{_texmfdistdir}/tex/latex/quattrocento
%dir %{_texmfdistdir}/tex/latex/quicktype
%dir %{_texmfdistdir}/tex/latex/quiz2socrative
%dir %{_texmfdistdir}/tex/latex/quotchap
%dir %{_texmfdistdir}/tex/latex/quoting
%dir %{_texmfdistdir}/tex/latex/quotmark
%dir %{_texmfdistdir}/tex/latex/quran
%dir %{_texmfdistdir}/tex/latex/quran-bn
%dir %{_texmfdistdir}/tex/latex/quran-ur
%dir %{_texmfdistdir}/tex/latex/qyxf-book
%dir %{_texmfdistdir}/tex/latex/r_und_s
%dir %{_texmfdistdir}/tex/latex/ragged2e
%dir %{_texmfdistdir}/tex/latex/raleway
%dir %{_texmfdistdir}/tex/latex/ran_toks
%dir %{_texmfdistdir}/tex/latex/randbild
%dir %{_texmfdistdir}/tex/latex/randomwalk
%dir %{_texmfdistdir}/tex/latex/randtext
%dir %{_texmfdistdir}/tex/latex/rank-2-roots
%dir %{_texmfdistdir}/tex/latex/rbt-mathnotes
%dir %{_texmfdistdir}/tex/latex/rccol
%dir %{_texmfdistdir}/tex/latex/rcs
%dir %{_texmfdistdir}/tex/latex/rcs-multi
%dir %{_texmfdistdir}/tex/latex/rcsinfo
%dir %{_texmfdistdir}/tex/latex/readablecv
%dir %{_texmfdistdir}/tex/latex/readarray
%dir %{_texmfdistdir}/tex/latex/realboxes
%dir %{_texmfdistdir}/tex/latex/realhats
%dir %{_texmfdistdir}/tex/latex/realhats/hats
%dir %{_texmfdistdir}/tex/latex/realscripts
%dir %{_texmfdistdir}/tex/latex/realtranspose
%dir %{_texmfdistdir}/tex/latex/rec-thy
%dir %{_texmfdistdir}/tex/latex/recipe
%dir %{_texmfdistdir}/tex/latex/recipebook
%dir %{_texmfdistdir}/tex/latex/recipecard
%dir %{_texmfdistdir}/tex/latex/recorder-fingering
%dir %{_texmfdistdir}/tex/latex/rectopma
%dir %{_texmfdistdir}/tex/latex/recycle
%dir %{_texmfdistdir}/tex/latex/refcheck
%dir %{_texmfdistdir}/tex/latex/refcount
%dir %{_texmfdistdir}/tex/latex/refenums
%dir %{_texmfdistdir}/tex/latex/reflectgraphics
%dir %{_texmfdistdir}/tex/latex/refman
%dir %{_texmfdistdir}/tex/latex/refstyle
%dir %{_texmfdistdir}/tex/latex/regcount
%dir %{_texmfdistdir}/tex/latex/regexpatch
%dir %{_texmfdistdir}/tex/latex/register
%dir %{_texmfdistdir}/tex/latex/regstats
%dir %{_texmfdistdir}/tex/latex/reledmac
%dir %{_texmfdistdir}/tex/latex/relenc
%dir %{_texmfdistdir}/tex/latex/relsize
%dir %{_texmfdistdir}/tex/latex/reotex
%dir %{_texmfdistdir}/tex/latex/repeatindex
%dir %{_texmfdistdir}/tex/latex/repltext
%dir %{_texmfdistdir}/tex/latex/rerunfilecheck
%dir %{_texmfdistdir}/tex/latex/rescansync
%dir %{_texmfdistdir}/tex/latex/resmes
%dir %{_texmfdistdir}/tex/latex/resolsysteme
%dir %{_texmfdistdir}/tex/latex/resphilosophica
%dir %{_texmfdistdir}/tex/latex/rest-api
%dir %{_texmfdistdir}/tex/latex/returntogrid
%dir %{_texmfdistdir}/tex/latex/revquantum
%dir %{_texmfdistdir}/tex/latex/revtex
%dir %{_texmfdistdir}/tex/latex/revtex4
%dir %{_texmfdistdir}/tex/latex/revtex4-1
%dir %{_texmfdistdir}/tex/latex/rgltxdoc
%dir %{_texmfdistdir}/tex/latex/ribbonproofs
%dir %{_texmfdistdir}/tex/latex/rjlparshap
%dir %{_texmfdistdir}/tex/latex/rmathbr
%dir %{_texmfdistdir}/tex/latex/rmpage
%dir %{_texmfdistdir}/tex/latex/robotarm
%dir %{_texmfdistdir}/tex/latex/roboto
%dir %{_texmfdistdir}/tex/latex/robustcommand
%dir %{_texmfdistdir}/tex/latex/robustindex
%dir %{_texmfdistdir}/tex/latex/rojud
%dir %{_texmfdistdir}/tex/latex/romanbar
%dir %{_texmfdistdir}/tex/latex/romanbarpagenumber
%dir %{_texmfdistdir}/tex/latex/romande
%dir %{_texmfdistdir}/tex/latex/romanneg
%dir %{_texmfdistdir}/tex/latex/romannum
%dir %{_texmfdistdir}/tex/latex/rosario
%dir %{_texmfdistdir}/tex/latex/rotfloat
%dir %{_texmfdistdir}/tex/latex/rotpages
%dir %{_texmfdistdir}/tex/latex/roundbox
%dir %{_texmfdistdir}/tex/latex/rrgtrees
%dir %{_texmfdistdir}/tex/latex/rsc
%dir %{_texmfdistdir}/tex/latex/rsfso
%dir %{_texmfdistdir}/tex/latex/rterface
%dir %{_texmfdistdir}/tex/latex/rtkinenc
%dir %{_texmfdistdir}/tex/latex/rtklage
%dir %{_texmfdistdir}/tex/latex/rubik
%dir %{_texmfdistdir}/tex/latex/rulerbox
%dir %{_texmfdistdir}/tex/latex/rulercompass
%dir %{_texmfdistdir}/tex/latex/runcode
%dir %{_texmfdistdir}/tex/latex/russ
%dir %{_texmfdistdir}/tex/latex/rutitlepage
%dir %{_texmfdistdir}/tex/latex/rviewport
%dir %{_texmfdistdir}/tex/latex/rvwrite
%dir %{_texmfdistdir}/tex/latex/ryersonsgsthesis
%dir %{_texmfdistdir}/tex/latex/ryethesis
%dir %{_texmfdistdir}/tex/latex/sa-tikz
%dir %{_texmfdistdir}/tex/latex/sacsymb
%dir %{_texmfdistdir}/tex/latex/sageep
%dir %{_texmfdistdir}/tex/latex/sanitize-umlaut
%dir %{_texmfdistdir}/tex/latex/sankey
%dir %{_texmfdistdir}/tex/latex/sanskrit
%dir %{_texmfdistdir}/tex/latex/sansmath
%dir %{_texmfdistdir}/tex/latex/sansmathaccent
%dir %{_texmfdistdir}/tex/latex/sansmathfonts
%dir %{_texmfdistdir}/tex/latex/sapthesis
%dir %{_texmfdistdir}/tex/latex/sasnrdisplay
%dir %{_texmfdistdir}/tex/latex/sauerj
%dir %{_texmfdistdir}/tex/latex/sauterfonts
%dir %{_texmfdistdir}/tex/latex/saveenv
%dir %{_texmfdistdir}/tex/latex/savefnmark
%dir %{_texmfdistdir}/tex/latex/savesym
%dir %{_texmfdistdir}/tex/latex/savetrees
%dir %{_texmfdistdir}/tex/latex/scale
%dir %{_texmfdistdir}/tex/latex/scalebar
%dir %{_texmfdistdir}/tex/latex/scalerel
%dir %{_texmfdistdir}/tex/latex/scanpages
%dir %{_texmfdistdir}/tex/latex/schedule
%dir %{_texmfdistdir}/tex/latex/schemabloc
%dir %{_texmfdistdir}/tex/latex/schola-otf
%dir %{_texmfdistdir}/tex/latex/scholax
%dir %{_texmfdistdir}/tex/latex/schooldocs
%dir %{_texmfdistdir}/tex/latex/schule
%dir %{_texmfdistdir}/tex/latex/schule/xsim-style
%dir %{_texmfdistdir}/tex/latex/schulmathematik
%dir %{_texmfdistdir}/tex/latex/schulschriften
%dir %{_texmfdistdir}/tex/latex/schwalbe-chess
%dir %{_texmfdistdir}/tex/latex/scientific-thesis-cover
%dir %{_texmfdistdir}/tex/latex/sciposter
%dir %{_texmfdistdir}/tex/latex/sclang-prettifier
%dir %{_texmfdistdir}/tex/latex/scontents
%dir %{_texmfdistdir}/tex/latex/scrabble
%dir %{_texmfdistdir}/tex/latex/scrambledenvs
%dir %{_texmfdistdir}/tex/latex/scratch
%dir %{_texmfdistdir}/tex/latex/scratch3
%dir %{_texmfdistdir}/tex/latex/scratchx
%dir %{_texmfdistdir}/tex/latex/screenplay
%dir %{_texmfdistdir}/tex/latex/screenplay-pkg
%dir %{_texmfdistdir}/tex/latex/scripture
%dir %{_texmfdistdir}/tex/latex/scrjrnl
%dir %{_texmfdistdir}/tex/latex/scrlayer-fancyhdr
%dir %{_texmfdistdir}/tex/latex/scrlttr2copy
%dir %{_texmfdistdir}/tex/latex/scsnowman
%dir %{_texmfdistdir}/tex/latex/sdaps
%dir %{_texmfdistdir}/tex/latex/sdrt
%dir %{_texmfdistdir}/tex/latex/sduthesis
%dir %{_texmfdistdir}/tex/latex/sduthesis/figures
%dir %{_texmfdistdir}/tex/latex/se2thesis
%dir %{_texmfdistdir}/tex/latex/secdot
%dir %{_texmfdistdir}/tex/latex/secnum
%dir %{_texmfdistdir}/tex/latex/section
%dir %{_texmfdistdir}/tex/latex/sectionbox
%dir %{_texmfdistdir}/tex/latex/sectionbreak
%dir %{_texmfdistdir}/tex/latex/sectsty
%dir %{_texmfdistdir}/tex/latex/seealso
%dir %{_texmfdistdir}/tex/latex/selectp
%dir %{_texmfdistdir}/tex/latex/selinput
%dir %{_texmfdistdir}/tex/latex/semantex
%dir %{_texmfdistdir}/tex/latex/semantic
%dir %{_texmfdistdir}/tex/latex/semantic-markup
%dir %{_texmfdistdir}/tex/latex/semaphor
%dir %{_texmfdistdir}/tex/latex/seminar
%dir %{_texmfdistdir}/tex/latex/semioneside
%dir %{_texmfdistdir}/tex/latex/semproc
%dir %{_texmfdistdir}/tex/latex/semtex
%dir %{_texmfdistdir}/tex/latex/sepfootnotes
%dir %{_texmfdistdir}/tex/latex/sepnum
%dir %{_texmfdistdir}/tex/latex/seqsplit
%dir %{_texmfdistdir}/tex/latex/serbian-apostrophe
%dir %{_texmfdistdir}/tex/latex/serbian-date-lat
%dir %{_texmfdistdir}/tex/latex/serbian-def-cyr
%dir %{_texmfdistdir}/tex/latex/serbian-lig
%dir %{_texmfdistdir}/tex/latex/sesamanuel
%dir %{_texmfdistdir}/tex/latex/sesstime
%dir %{_texmfdistdir}/tex/latex/setdeck
%dir %{_texmfdistdir}/tex/latex/setspace
%dir %{_texmfdistdir}/tex/latex/seu-ml-assign
%dir %{_texmfdistdir}/tex/latex/seuthesix
%dir %{_texmfdistdir}/tex/latex/sf298
%dir %{_texmfdistdir}/tex/latex/sffms
%dir %{_texmfdistdir}/tex/latex/sfg
%dir %{_texmfdistdir}/tex/latex/sfmath
%dir %{_texmfdistdir}/tex/latex/sgame
%dir %{_texmfdistdir}/tex/latex/shadethm
%dir %{_texmfdistdir}/tex/latex/shadow
%dir %{_texmfdistdir}/tex/latex/shadowtext
%dir %{_texmfdistdir}/tex/latex/shdoc
%dir %{_texmfdistdir}/tex/latex/shipunov
%dir %{_texmfdistdir}/tex/latex/shortmathj
%dir %{_texmfdistdir}/tex/latex/shorttoc
%dir %{_texmfdistdir}/tex/latex/show2e
%dir %{_texmfdistdir}/tex/latex/showcharinbox
%dir %{_texmfdistdir}/tex/latex/showdim
%dir %{_texmfdistdir}/tex/latex/showexpl
%dir %{_texmfdistdir}/tex/latex/showlabels
%dir %{_texmfdistdir}/tex/latex/showtags
%dir %{_texmfdistdir}/tex/latex/shtthesis
%dir %{_texmfdistdir}/tex/latex/shuffle
%dir %{_texmfdistdir}/tex/latex/sidecap
%dir %{_texmfdistdir}/tex/latex/sidenotes
%dir %{_texmfdistdir}/tex/latex/sidenotesplus
%dir %{_texmfdistdir}/tex/latex/sides
%dir %{_texmfdistdir}/tex/latex/signchart
%dir %{_texmfdistdir}/tex/latex/silence
%dir %{_texmfdistdir}/tex/latex/sillypage
%dir %{_texmfdistdir}/tex/latex/simplebnf
%dir %{_texmfdistdir}/tex/latex/simplecd
%dir %{_texmfdistdir}/tex/latex/simplecv
%dir %{_texmfdistdir}/tex/latex/simpleicons
%dir %{_texmfdistdir}/tex/latex/simpleinvoice
%dir %{_texmfdistdir}/tex/latex/simplenodes
%dir %{_texmfdistdir}/tex/latex/simpleoptics
%dir %{_texmfdistdir}/tex/latex/simpler-wick
%dir %{_texmfdistdir}/tex/latex/simples-matrices
%dir %{_texmfdistdir}/tex/latex/simplewick
%dir %{_texmfdistdir}/tex/latex/simplivre
%dir %{_texmfdistdir}/tex/latex/sistyle
%dir %{_texmfdistdir}/tex/latex/sitem
%dir %{_texmfdistdir}/tex/latex/siunits
%dir %{_texmfdistdir}/tex/latex/siunitx
%dir %{_texmfdistdir}/tex/latex/skak
%dir %{_texmfdistdir}/tex/latex/skb
%dir %{_texmfdistdir}/tex/latex/skdoc
%dir %{_texmfdistdir}/tex/latex/skeldoc
%dir %{_texmfdistdir}/tex/latex/skeycommand
%dir %{_texmfdistdir}/tex/latex/skeyval
%dir %{_texmfdistdir}/tex/latex/skills
%dir %{_texmfdistdir}/tex/latex/skmath
%dir %{_texmfdistdir}/tex/latex/skrapport
%dir %{_texmfdistdir}/tex/latex/skull
%dir %{_texmfdistdir}/tex/latex/slantsc
%dir %{_texmfdistdir}/tex/latex/smalltableof
%dir %{_texmfdistdir}/tex/latex/smart-eqn
%dir %{_texmfdistdir}/tex/latex/smartdiagram
%dir %{_texmfdistdir}/tex/latex/smartref
%dir %{_texmfdistdir}/tex/latex/smartunits
%dir %{_texmfdistdir}/tex/latex/smflatex
%dir %{_texmfdistdir}/tex/latex/snapshot
%dir %{_texmfdistdir}/tex/latex/snaptodo
%dir %{_texmfdistdir}/tex/latex/snotez
%dir %{_texmfdistdir}/tex/latex/songbook
%dir %{_texmfdistdir}/tex/latex/songproj
%dir %{_texmfdistdir}/tex/latex/songs
%dir %{_texmfdistdir}/tex/latex/soton
%dir %{_texmfdistdir}/tex/latex/soulpos
%dir %{_texmfdistdir}/tex/latex/soup
%dir %{_texmfdistdir}/tex/latex/sourcecodepro
%dir %{_texmfdistdir}/tex/latex/sourcesanspro
%dir %{_texmfdistdir}/tex/latex/sourceserifpro
%dir %{_texmfdistdir}/tex/latex/spacingtricks
%dir %{_texmfdistdir}/tex/latex/spalign
%dir %{_texmfdistdir}/tex/latex/spark-otf
%dir %{_texmfdistdir}/tex/latex/sparklines
%dir %{_texmfdistdir}/tex/latex/spath3
%dir %{_texmfdistdir}/tex/latex/spbmark
%dir %{_texmfdistdir}/tex/latex/spectral
%dir %{_texmfdistdir}/tex/latex/spectralsequences
%dir %{_texmfdistdir}/tex/latex/sphdthesis
%dir %{_texmfdistdir}/tex/latex/spie
%dir %{_texmfdistdir}/tex/latex/splitbib
%dir %{_texmfdistdir}/tex/latex/splitindex
%dir %{_texmfdistdir}/tex/latex/spot
%dir %{_texmfdistdir}/tex/latex/spotcolor
%dir %{_texmfdistdir}/tex/latex/spreadtab
%dir %{_texmfdistdir}/tex/latex/spverbatim
%dir %{_texmfdistdir}/tex/latex/sr-vorl
%dir %{_texmfdistdir}/tex/latex/srbook-mem
%dir %{_texmfdistdir}/tex/latex/srbtiks
%dir %{_texmfdistdir}/tex/latex/srcltx
%dir %{_texmfdistdir}/tex/latex/srdp-mathematik
%dir %{_texmfdistdir}/tex/latex/sseq
%dir %{_texmfdistdir}/tex/latex/sslides
%dir %{_texmfdistdir}/tex/latex/stack
%dir %{_texmfdistdir}/tex/latex/stackengine
%dir %{_texmfdistdir}/tex/latex/stage
%dir %{_texmfdistdir}/tex/latex/standalone
%dir %{_texmfdistdir}/tex/latex/stanli
%dir %{_texmfdistdir}/tex/latex/starfont
%dir %{_texmfdistdir}/tex/latex/statex
%dir %{_texmfdistdir}/tex/latex/statex2
%dir %{_texmfdistdir}/tex/latex/statistics
%dir %{_texmfdistdir}/tex/latex/statistik
%dir %{_texmfdistdir}/tex/latex/statmath
%dir %{_texmfdistdir}/tex/latex/staves
%dir %{_texmfdistdir}/tex/latex/stdclsdv
%dir %{_texmfdistdir}/tex/latex/stdpage
%dir %{_texmfdistdir}/tex/latex/stealcaps
%dir %{_texmfdistdir}/tex/latex/steinmetz
%dir %{_texmfdistdir}/tex/latex/stellenbosch
%dir %{_texmfdistdir}/tex/latex/stellenbosch/logos
%dir %{_texmfdistdir}/tex/latex/step
%dir %{_texmfdistdir}/tex/latex/stepgreek
%dir %{_texmfdistdir}/tex/latex/stex
%dir %{_texmfdistdir}/tex/latex/stex/etc
%dir %{_texmfdistdir}/tex/latex/stex/img
%dir %{_texmfdistdir}/tex/latex/stex/ldf
%dir %{_texmfdistdir}/tex/latex/stickstoo
%dir %{_texmfdistdir}/tex/latex/stix
%dir %{_texmfdistdir}/tex/latex/stix2-type1
%dir %{_texmfdistdir}/tex/latex/stmaryrd
%dir %{_texmfdistdir}/tex/latex/storebox
%dir %{_texmfdistdir}/tex/latex/storecmd
%dir %{_texmfdistdir}/tex/latex/strands
%dir %{_texmfdistdir}/tex/latex/stringstrings
%dir %{_texmfdistdir}/tex/latex/structmech
%dir %{_texmfdistdir}/tex/latex/struktex
%dir %{_texmfdistdir}/tex/latex/sttools
%dir %{_texmfdistdir}/tex/latex/stubs
%dir %{_texmfdistdir}/tex/latex/studenthandouts
%dir %{_texmfdistdir}/tex/latex/styledcmd
%dir %{_texmfdistdir}/tex/latex/subdepth
%dir %{_texmfdistdir}/tex/latex/subdocs
%dir %{_texmfdistdir}/tex/latex/subeqn
%dir %{_texmfdistdir}/tex/latex/subeqnarray
%dir %{_texmfdistdir}/tex/latex/subfig
%dir %{_texmfdistdir}/tex/latex/subfigmat
%dir %{_texmfdistdir}/tex/latex/subfigure
%dir %{_texmfdistdir}/tex/latex/subfiles
%dir %{_texmfdistdir}/tex/latex/subfloat
%dir %{_texmfdistdir}/tex/latex/substances
%dir %{_texmfdistdir}/tex/latex/substitutefont
%dir %{_texmfdistdir}/tex/latex/substr
%dir %{_texmfdistdir}/tex/latex/subsupscripts
%dir %{_texmfdistdir}/tex/latex/subtext
%dir %{_texmfdistdir}/tex/latex/sudoku
%dir %{_texmfdistdir}/tex/latex/sudokubundle
%dir %{_texmfdistdir}/tex/latex/suftesi
%dir %{_texmfdistdir}/tex/latex/sugconf
%dir %{_texmfdistdir}/tex/latex/superiors
%dir %{_texmfdistdir}/tex/latex/supertabular
%dir %{_texmfdistdir}/tex/latex/suppose
%dir %{_texmfdistdir}/tex/latex/susy
%dir %{_texmfdistdir}/tex/latex/svg
%dir %{_texmfdistdir}/tex/latex/svgcolor
%dir %{_texmfdistdir}/tex/latex/svn
%dir %{_texmfdistdir}/tex/latex/svn-multi
%dir %{_texmfdistdir}/tex/latex/svn-prov
%dir %{_texmfdistdir}/tex/latex/svninfo
%dir %{_texmfdistdir}/tex/latex/svrsymbols
%dir %{_texmfdistdir}/tex/latex/swfigure
%dir %{_texmfdistdir}/tex/latex/swimgraf
%dir %{_texmfdistdir}/tex/latex/swungdash
%dir %{_texmfdistdir}/tex/latex/syllogism
%dir %{_texmfdistdir}/tex/latex/symbats3
%dir %{_texmfdistdir}/tex/latex/symbol
%dir %{_texmfdistdir}/tex/latex/synproof
%dir %{_texmfdistdir}/tex/latex/syntax
%dir %{_texmfdistdir}/tex/latex/syntaxdi
%dir %{_texmfdistdir}/tex/latex/syntrace
%dir %{_texmfdistdir}/tex/latex/synttree
%dir %{_texmfdistdir}/tex/latex/t-angles
%dir %{_texmfdistdir}/tex/latex/t2
%dir %{_texmfdistdir}/tex/latex/tabbing
%dir %{_texmfdistdir}/tex/latex/tabfigures
%dir %{_texmfdistdir}/tex/latex/table-fct
%dir %{_texmfdistdir}/tex/latex/tableaux
%dir %{_texmfdistdir}/tex/latex/tablefootnote
%dir %{_texmfdistdir}/tex/latex/tableof
%dir %{_texmfdistdir}/tex/latex/tablists
%dir %{_texmfdistdir}/tex/latex/tablor
%dir %{_texmfdistdir}/tex/latex/tabls
%dir %{_texmfdistdir}/tex/latex/tablvar
%dir %{_texmfdistdir}/tex/latex/tabriz-thesis
%dir %{_texmfdistdir}/tex/latex/tabstackengine
%dir %{_texmfdistdir}/tex/latex/tabto-ltx
%dir %{_texmfdistdir}/tex/latex/tabu
%dir %{_texmfdistdir}/tex/latex/tabularborder
%dir %{_texmfdistdir}/tex/latex/tabularcalc
%dir %{_texmfdistdir}/tex/latex/tabularew
%dir %{_texmfdistdir}/tex/latex/tabularray
%dir %{_texmfdistdir}/tex/latex/tabulary
%dir %{_texmfdistdir}/tex/latex/tabvar
%dir %{_texmfdistdir}/tex/latex/tagging
%dir %{_texmfdistdir}/tex/latex/tagpair
%dir %{_texmfdistdir}/tex/latex/tagpdf
%dir %{_texmfdistdir}/tex/latex/talk
%dir %{_texmfdistdir}/tex/latex/tamefloats
%dir %{_texmfdistdir}/tex/latex/tangramtikz
%dir %{_texmfdistdir}/tex/latex/tasks
%dir %{_texmfdistdir}/tex/latex/tcldoc
%dir %{_texmfdistdir}/tex/latex/tcolorbox
%dir %{_texmfdistdir}/tex/latex/tdclock
%dir %{_texmfdistdir}/tex/latex/tdsfrmath
%dir %{_texmfdistdir}/tex/latex/technics
%dir %{_texmfdistdir}/tex/latex/ted
%dir %{_texmfdistdir}/tex/latex/templatetools
%dir %{_texmfdistdir}/tex/latex/tempora
%dir %{_texmfdistdir}/tex/latex/tengwarscript
%dir %{_texmfdistdir}/tex/latex/tensind
%dir %{_texmfdistdir}/tex/latex/tensor
%dir %{_texmfdistdir}/tex/latex/termcal
%dir %{_texmfdistdir}/tex/latex/termcal-de
%dir %{_texmfdistdir}/tex/latex/termes-otf
%dir %{_texmfdistdir}/tex/latex/termlist
%dir %{_texmfdistdir}/tex/latex/termsim
%dir %{_texmfdistdir}/tex/latex/testhyphens
%dir %{_texmfdistdir}/tex/latex/testidx
%dir %{_texmfdistdir}/tex/latex/teubner
%dir %{_texmfdistdir}/tex/latex/tex-gyre
%dir %{_texmfdistdir}/tex/latex/tex-label
%dir %{_texmfdistdir}/tex/latex/tex-locale
%dir %{_texmfdistdir}/tex/latex/tex4ebook
%dir %{_texmfdistdir}/tex/latex/texilikechaps
%dir %{_texmfdistdir}/tex/latex/texilikecover
%dir %{_texmfdistdir}/tex/latex/texlogos
%dir %{_texmfdistdir}/tex/latex/texmate
%dir %{_texmfdistdir}/tex/latex/texments
%dir %{_texmfdistdir}/tex/latex/texnegar
%dir %{_texmfdistdir}/tex/latex/texosquery
%dir %{_texmfdistdir}/tex/latex/texpower
%dir %{_texmfdistdir}/tex/latex/texshade
%dir %{_texmfdistdir}/tex/latex/texsurgery
%dir %{_texmfdistdir}/tex/latex/textcase
%dir %{_texmfdistdir}/tex/latex/textcsc
%dir %{_texmfdistdir}/tex/latex/textfit
%dir %{_texmfdistdir}/tex/latex/textglos
%dir %{_texmfdistdir}/tex/latex/textgreek
%dir %{_texmfdistdir}/tex/latex/textopo
%dir %{_texmfdistdir}/tex/latex/textpath
%dir %{_texmfdistdir}/tex/latex/textpos
%dir %{_texmfdistdir}/tex/latex/textualicomma
%dir %{_texmfdistdir}/tex/latex/texvc
%dir %{_texmfdistdir}/tex/latex/tfrupee
%dir %{_texmfdistdir}/tex/latex/thaienum
%dir %{_texmfdistdir}/tex/latex/thaispec
%dir %{_texmfdistdir}/tex/latex/thalie
%dir %{_texmfdistdir}/tex/latex/theanodidot
%dir %{_texmfdistdir}/tex/latex/theanomodern
%dir %{_texmfdistdir}/tex/latex/theanooldstyle
%dir %{_texmfdistdir}/tex/latex/theoremref
%dir %{_texmfdistdir}/tex/latex/thermodynamics
%dir %{_texmfdistdir}/tex/latex/thesis-ekf
%dir %{_texmfdistdir}/tex/latex/thesis-gwu
%dir %{_texmfdistdir}/tex/latex/thesis-titlepage-fhac
%dir %{_texmfdistdir}/tex/latex/thinsp
%dir %{_texmfdistdir}/tex/latex/thmbox
%dir %{_texmfdistdir}/tex/latex/thmtools
%dir %{_texmfdistdir}/tex/latex/threadcol
%dir %{_texmfdistdir}/tex/latex/threeparttable
%dir %{_texmfdistdir}/tex/latex/threeparttablex
%dir %{_texmfdistdir}/tex/latex/thuaslogos
%dir %{_texmfdistdir}/tex/latex/thubeamer
%dir %{_texmfdistdir}/tex/latex/thucoursework
%dir %{_texmfdistdir}/tex/latex/thumb
%dir %{_texmfdistdir}/tex/latex/thumbs
%dir %{_texmfdistdir}/tex/latex/thumby
%dir %{_texmfdistdir}/tex/latex/thuthesis
%dir %{_texmfdistdir}/tex/latex/ticket
%dir %{_texmfdistdir}/tex/latex/ticollege
%dir %{_texmfdistdir}/tex/latex/tidyres
%dir %{_texmfdistdir}/tex/latex/tikz-3dplot
%dir %{_texmfdistdir}/tex/latex/tikz-among-us
%dir %{_texmfdistdir}/tex/latex/tikz-bagua
%dir %{_texmfdistdir}/tex/latex/tikz-bayesnet
%dir %{_texmfdistdir}/tex/latex/tikz-bbox
%dir %{_texmfdistdir}/tex/latex/tikz-cd
%dir %{_texmfdistdir}/tex/latex/tikz-dependency
%dir %{_texmfdistdir}/tex/latex/tikz-dimline
%dir %{_texmfdistdir}/tex/latex/tikz-ext
%dir %{_texmfdistdir}/tex/latex/tikz-feynhand
%dir %{_texmfdistdir}/tex/latex/tikz-feynman
%dir %{_texmfdistdir}/tex/latex/tikz-imagelabels
%dir %{_texmfdistdir}/tex/latex/tikz-inet
%dir %{_texmfdistdir}/tex/latex/tikz-kalender
%dir %{_texmfdistdir}/tex/latex/tikz-karnaugh
%dir %{_texmfdistdir}/tex/latex/tikz-ladder
%dir %{_texmfdistdir}/tex/latex/tikz-lake-fig
%dir %{_texmfdistdir}/tex/latex/tikz-layers
%dir %{_texmfdistdir}/tex/latex/tikz-mirror-lens
%dir %{_texmfdistdir}/tex/latex/tikz-nef
%dir %{_texmfdistdir}/tex/latex/tikz-network
%dir %{_texmfdistdir}/tex/latex/tikz-opm
%dir %{_texmfdistdir}/tex/latex/tikz-optics
%dir %{_texmfdistdir}/tex/latex/tikz-page
%dir %{_texmfdistdir}/tex/latex/tikz-palattice
%dir %{_texmfdistdir}/tex/latex/tikz-planets
%dir %{_texmfdistdir}/tex/latex/tikz-qtree
%dir %{_texmfdistdir}/tex/latex/tikz-relay
%dir %{_texmfdistdir}/tex/latex/tikz-sfc
%dir %{_texmfdistdir}/tex/latex/tikz-swigs
%dir %{_texmfdistdir}/tex/latex/tikz-timing
%dir %{_texmfdistdir}/tex/latex/tikz-trackschematic
%dir %{_texmfdistdir}/tex/latex/tikz-truchet
%dir %{_texmfdistdir}/tex/latex/tikzbricks
%dir %{_texmfdistdir}/tex/latex/tikzcodeblocks
%dir %{_texmfdistdir}/tex/latex/tikzfill
%dir %{_texmfdistdir}/tex/latex/tikzinclude
%dir %{_texmfdistdir}/tex/latex/tikzlings
%dir %{_texmfdistdir}/tex/latex/tikzmark
%dir %{_texmfdistdir}/tex/latex/tikzmarmots
%dir %{_texmfdistdir}/tex/latex/tikzorbital
%dir %{_texmfdistdir}/tex/latex/tikzpackets
%dir %{_texmfdistdir}/tex/latex/tikzpagenodes
%dir %{_texmfdistdir}/tex/latex/tikzpeople
%dir %{_texmfdistdir}/tex/latex/tikzpfeile
%dir %{_texmfdistdir}/tex/latex/tikzpingus
%dir %{_texmfdistdir}/tex/latex/tikzposter
%dir %{_texmfdistdir}/tex/latex/tikzscale
%dir %{_texmfdistdir}/tex/latex/tikzsymbols
%dir %{_texmfdistdir}/tex/latex/tikzviolinplots
%dir %{_texmfdistdir}/tex/latex/tile-graphic
%dir %{_texmfdistdir}/tex/latex/timbreicmc
%dir %{_texmfdistdir}/tex/latex/times
%dir %{_texmfdistdir}/tex/latex/timing-diagrams
%dir %{_texmfdistdir}/tex/latex/tinos
%dir %{_texmfdistdir}/tex/latex/tipa
%dir %{_texmfdistdir}/tex/latex/tipauni
%dir %{_texmfdistdir}/tex/latex/tipfr
%dir %{_texmfdistdir}/tex/latex/tiscreen
%dir %{_texmfdistdir}/tex/latex/titlecaps
%dir %{_texmfdistdir}/tex/latex/titlefoot
%dir %{_texmfdistdir}/tex/latex/titlepic
%dir %{_texmfdistdir}/tex/latex/titleref
%dir %{_texmfdistdir}/tex/latex/titlesec
%dir %{_texmfdistdir}/tex/latex/titling
%dir %{_texmfdistdir}/tex/latex/tkz-base
%dir %{_texmfdistdir}/tex/latex/tkz-berge
%dir %{_texmfdistdir}/tex/latex/tkz-euclide
%dir %{_texmfdistdir}/tex/latex/tkz-fct
%dir %{_texmfdistdir}/tex/latex/tkz-graph
%dir %{_texmfdistdir}/tex/latex/tkz-orm
%dir %{_texmfdistdir}/tex/latex/tkz-tab
%dir %{_texmfdistdir}/tex/latex/tkzexample
%dir %{_texmfdistdir}/tex/latex/tlc-article
%dir %{_texmfdistdir}/tex/latex/to-be-determined
%dir %{_texmfdistdir}/tex/latex/tocbibind
%dir %{_texmfdistdir}/tex/latex/tocdata
%dir %{_texmfdistdir}/tex/latex/tocloft
%dir %{_texmfdistdir}/tex/latex/tocvsec2
%dir %{_texmfdistdir}/tex/latex/todo
%dir %{_texmfdistdir}/tex/latex/todonotes
%dir %{_texmfdistdir}/tex/latex/tokenizer
%dir %{_texmfdistdir}/tex/latex/tonevalue
%dir %{_texmfdistdir}/tex/latex/toolbox
%dir %{_texmfdistdir}/tex/latex/tools
%dir %{_texmfdistdir}/tex/latex/topfloat
%dir %{_texmfdistdir}/tex/latex/topiclongtable
%dir %{_texmfdistdir}/tex/latex/topletter
%dir %{_texmfdistdir}/tex/latex/toptesi
%dir %{_texmfdistdir}/tex/latex/totalcount
%dir %{_texmfdistdir}/tex/latex/totcount
%dir %{_texmfdistdir}/tex/latex/totpages
%dir %{_texmfdistdir}/tex/latex/tpslifonts
%dir %{_texmfdistdir}/tex/latex/tqft
%dir %{_texmfdistdir}/tex/latex/tracklang
%dir %{_texmfdistdir}/tex/latex/trajan
%dir %{_texmfdistdir}/tex/latex/tram
%dir %{_texmfdistdir}/tex/latex/tramlines
%dir %{_texmfdistdir}/tex/latex/translations
%dir %{_texmfdistdir}/tex/latex/translator
%dir %{_texmfdistdir}/tex/latex/transparent
%dir %{_texmfdistdir}/tex/latex/tree-dvips
%dir %{_texmfdistdir}/tex/latex/trfsigns
%dir %{_texmfdistdir}/tex/latex/trimspaces
%dir %{_texmfdistdir}/tex/latex/trivfloat
%dir %{_texmfdistdir}/tex/latex/trsym
%dir %{_texmfdistdir}/tex/latex/truncate
%dir %{_texmfdistdir}/tex/latex/tsemlines
%dir %{_texmfdistdir}/tex/latex/tucv
%dir %{_texmfdistdir}/tex/latex/tuda-ci
%dir %{_texmfdistdir}/tex/latex/tudscr
%dir %{_texmfdistdir}/tex/latex/tudscr/logo
%dir %{_texmfdistdir}/tex/latex/tufte-latex
%dir %{_texmfdistdir}/tex/latex/tugboat
%dir %{_texmfdistdir}/tex/latex/tui
%dir %{_texmfdistdir}/tex/latex/turabian
%dir %{_texmfdistdir}/tex/latex/turabian-formatting
%dir %{_texmfdistdir}/tex/latex/turkmen
%dir %{_texmfdistdir}/tex/latex/turnstile
%dir %{_texmfdistdir}/tex/latex/turnthepage
%dir %{_texmfdistdir}/tex/latex/twemojis
%dir %{_texmfdistdir}/tex/latex/twoinone
%dir %{_texmfdistdir}/tex/latex/twoup
%dir %{_texmfdistdir}/tex/latex/txfonts
%dir %{_texmfdistdir}/tex/latex/txfontsb
%dir %{_texmfdistdir}/tex/latex/txgreeks
%dir %{_texmfdistdir}/tex/latex/txuprcal
%dir %{_texmfdistdir}/tex/latex/type1cm
%dir %{_texmfdistdir}/tex/latex/typed-checklist
%dir %{_texmfdistdir}/tex/latex/typeface
%dir %{_texmfdistdir}/tex/latex/typehtml
%dir %{_texmfdistdir}/tex/latex/typicons
%dir %{_texmfdistdir}/tex/latex/typoaid
%dir %{_texmfdistdir}/tex/latex/typogrid
%dir %{_texmfdistdir}/tex/latex/tzplot
%dir %{_texmfdistdir}/tex/latex/uaclasses
%dir %{_texmfdistdir}/tex/latex/uafthesis
%dir %{_texmfdistdir}/tex/latex/uantwerpendocs
%dir %{_texmfdistdir}/tex/latex/uantwerpendocs/Images
%dir %{_texmfdistdir}/tex/latex/uantwerpendocs/Logos
%dir %{_texmfdistdir}/tex/latex/uassign
%dir %{_texmfdistdir}/tex/latex/ucalgmthesis
%dir %{_texmfdistdir}/tex/latex/ucbthesis
%dir %{_texmfdistdir}/tex/latex/ucdavisthesis
%dir %{_texmfdistdir}/tex/latex/ucharcat
%dir %{_texmfdistdir}/tex/latex/ucs
%dir %{_texmfdistdir}/tex/latex/ucs/data
%dir %{_texmfdistdir}/tex/latex/ucsmonograph
%dir %{_texmfdistdir}/tex/latex/ucthesis
%dir %{_texmfdistdir}/tex/latex/udes-genie-these
%dir %{_texmfdistdir}/tex/latex/udesoftec
%dir %{_texmfdistdir}/tex/latex/uebungsblatt
%dir %{_texmfdistdir}/tex/latex/uestcthesis
%dir %{_texmfdistdir}/tex/latex/ufrgscca
%dir %{_texmfdistdir}/tex/latex/uhhassignment
%dir %{_texmfdistdir}/tex/latex/uhrzeit
%dir %{_texmfdistdir}/tex/latex/uiucredborder
%dir %{_texmfdistdir}/tex/latex/uiucthesis
%dir %{_texmfdistdir}/tex/latex/ukbill
%dir %{_texmfdistdir}/tex/latex/ulqda
%dir %{_texmfdistdir}/tex/latex/ulthese
%dir %{_texmfdistdir}/tex/latex/umbclegislation
%dir %{_texmfdistdir}/tex/latex/umich-thesis
%dir %{_texmfdistdir}/tex/latex/uml
%dir %{_texmfdistdir}/tex/latex/umlaute
%dir %{_texmfdistdir}/tex/latex/umoline
%dir %{_texmfdistdir}/tex/latex/umthesis
%dir %{_texmfdistdir}/tex/latex/unam-thesis
%dir %{_texmfdistdir}/tex/latex/unamthesis
%dir %{_texmfdistdir}/tex/latex/unbtex
%dir %{_texmfdistdir}/tex/latex/underlin
%dir %{_texmfdistdir}/tex/latex/underoverlap
%dir %{_texmfdistdir}/tex/latex/underscore
%dir %{_texmfdistdir}/tex/latex/undolabl
%dir %{_texmfdistdir}/tex/latex/uni-titlepage
%dir %{_texmfdistdir}/tex/latex/uni-wtal-ger
%dir %{_texmfdistdir}/tex/latex/uni-wtal-lin
%dir %{_texmfdistdir}/tex/latex/unicode-alphabets
%dir %{_texmfdistdir}/tex/latex/unicode-math
%dir %{_texmfdistdir}/tex/latex/unicodefonttable
%dir %{_texmfdistdir}/tex/latex/unifith
%dir %{_texmfdistdir}/tex/latex/unigrazpub
%dir %{_texmfdistdir}/tex/latex/unisc
%dir %{_texmfdistdir}/tex/latex/unitn-bimrep
%dir %{_texmfdistdir}/tex/latex/units
%dir %{_texmfdistdir}/tex/latex/unitsdef
%dir %{_texmfdistdir}/tex/latex/universa
%dir %{_texmfdistdir}/tex/latex/universalis
%dir %{_texmfdistdir}/tex/latex/univie-ling
%dir %{_texmfdistdir}/tex/latex/unizgklasa
%dir %{_texmfdistdir}/tex/latex/unravel
%dir %{_texmfdistdir}/tex/latex/unswcover
%dir %{_texmfdistdir}/tex/latex/uol-physics-report
%dir %{_texmfdistdir}/tex/latex/uothesis
%dir %{_texmfdistdir}/tex/latex/uowthesis
%dir %{_texmfdistdir}/tex/latex/uowthesistitlepage
%dir %{_texmfdistdir}/tex/latex/upmethodology
%dir %{_texmfdistdir}/tex/latex/uppunctlm
%dir %{_texmfdistdir}/tex/latex/upquote
%dir %{_texmfdistdir}/tex/latex/urcls
%dir %{_texmfdistdir}/tex/latex/uri
%dir %{_texmfdistdir}/tex/latex/url
%dir %{_texmfdistdir}/tex/latex/urwchancal
%dir %{_texmfdistdir}/tex/latex/usebib
%dir %{_texmfdistdir}/tex/latex/ushort
%dir %{_texmfdistdir}/tex/latex/uspace
%dir %{_texmfdistdir}/tex/latex/uspatent
%dir %{_texmfdistdir}/tex/latex/ut-thesis
%dir %{_texmfdistdir}/tex/latex/utexasthesis
%dir %{_texmfdistdir}/tex/latex/utf8add
%dir %{_texmfdistdir}/tex/latex/utfsym
%dir %{_texmfdistdir}/tex/latex/uvaletter
%dir %{_texmfdistdir}/tex/latex/uwa-colours
%dir %{_texmfdistdir}/tex/latex/uwa-letterhead
%dir %{_texmfdistdir}/tex/latex/uwa-pcf
%dir %{_texmfdistdir}/tex/latex/uwa-pif
%dir %{_texmfdistdir}/tex/latex/uwmslide
%dir %{_texmfdistdir}/tex/latex/uwthesis
%dir %{_texmfdistdir}/tex/latex/variablelm
%dir %{_texmfdistdir}/tex/latex/varindex
%dir %{_texmfdistdir}/tex/latex/varsfromjobname
%dir %{_texmfdistdir}/tex/latex/varwidth
%dir %{_texmfdistdir}/tex/latex/vcell
%dir %{_texmfdistdir}/tex/latex/vdmlisting
%dir %{_texmfdistdir}/tex/latex/velthuis
%dir %{_texmfdistdir}/tex/latex/venndiagram
%dir %{_texmfdistdir}/tex/latex/venturis
%dir %{_texmfdistdir}/tex/latex/venturis2
%dir %{_texmfdistdir}/tex/latex/venturisadf
%dir %{_texmfdistdir}/tex/latex/venturisold
%dir %{_texmfdistdir}/tex/latex/venturissans
%dir %{_texmfdistdir}/tex/latex/venturissans2
%dir %{_texmfdistdir}/tex/latex/verbasef
%dir %{_texmfdistdir}/tex/latex/verbatimbox
%dir %{_texmfdistdir}/tex/latex/verbatimcopy
%dir %{_texmfdistdir}/tex/latex/verbdef
%dir %{_texmfdistdir}/tex/latex/verbments
%dir %{_texmfdistdir}/tex/latex/verifica
%dir %{_texmfdistdir}/tex/latex/verifiche
%dir %{_texmfdistdir}/tex/latex/verse
%dir %{_texmfdistdir}/tex/latex/version
%dir %{_texmfdistdir}/tex/latex/versions
%dir %{_texmfdistdir}/tex/latex/versonotes
%dir %{_texmfdistdir}/tex/latex/vertbars
%dir %{_texmfdistdir}/tex/latex/vgrid
%dir %{_texmfdistdir}/tex/latex/vhistory
%dir %{_texmfdistdir}/tex/latex/vmargin
%dir %{_texmfdistdir}/tex/latex/vntex
%dir %{_texmfdistdir}/tex/latex/vocaltract
%dir %{_texmfdistdir}/tex/latex/volumes
%dir %{_texmfdistdir}/tex/latex/vpe
%dir %{_texmfdistdir}/tex/latex/vruler
%dir %{_texmfdistdir}/tex/latex/vtable
%dir %{_texmfdistdir}/tex/latex/vwcol
%dir %{_texmfdistdir}/tex/latex/wallpaper
%dir %{_texmfdistdir}/tex/latex/wargame
%dir %{_texmfdistdir}/tex/latex/warning
%dir %{_texmfdistdir}/tex/latex/warpcol
%dir %{_texmfdistdir}/tex/latex/was
%dir %{_texmfdistdir}/tex/latex/wasysym
%dir %{_texmfdistdir}/tex/latex/webquiz
%dir %{_texmfdistdir}/tex/latex/wheelchart
%dir %{_texmfdistdir}/tex/latex/widetable
%dir %{_texmfdistdir}/tex/latex/widows-and-orphans
%dir %{_texmfdistdir}/tex/latex/williams
%dir %{_texmfdistdir}/tex/latex/willowtreebook
%dir %{_texmfdistdir}/tex/latex/windycity
%dir %{_texmfdistdir}/tex/latex/withargs
%dir %{_texmfdistdir}/tex/latex/wnri-latex
%dir %{_texmfdistdir}/tex/latex/wordcount
%dir %{_texmfdistdir}/tex/latex/wordlike
%dir %{_texmfdistdir}/tex/latex/worksheet
%dir %{_texmfdistdir}/tex/latex/worldflags
%dir %{_texmfdistdir}/tex/latex/wrapfig
%dir %{_texmfdistdir}/tex/latex/wrapfig2
%dir %{_texmfdistdir}/tex/latex/wrapstuff
%dir %{_texmfdistdir}/tex/latex/writeongrid
%dir %{_texmfdistdir}/tex/latex/wsemclassic
%dir %{_texmfdistdir}/tex/latex/wsuipa
%dir %{_texmfdistdir}/tex/latex/wtref
%dir %{_texmfdistdir}/tex/latex/xargs
%dir %{_texmfdistdir}/tex/latex/xassoccnt
%dir %{_texmfdistdir}/tex/latex/xbmks
%dir %{_texmfdistdir}/tex/latex/xcharter
%dir %{_texmfdistdir}/tex/latex/xcharter-math
%dir %{_texmfdistdir}/tex/latex/xcite
%dir %{_texmfdistdir}/tex/latex/xcjk2uni
%dir %{_texmfdistdir}/tex/latex/xcjk2uni/cmap
%dir %{_texmfdistdir}/tex/latex/xcntperchap
%dir %{_texmfdistdir}/tex/latex/xcolor
%dir %{_texmfdistdir}/tex/latex/xcolor-material
%dir %{_texmfdistdir}/tex/latex/xcolor-solarized
%dir %{_texmfdistdir}/tex/latex/xcookybooky
%dir %{_texmfdistdir}/tex/latex/xcpdftips
%dir %{_texmfdistdir}/tex/latex/xdoc
%dir %{_texmfdistdir}/tex/latex/xduthesis
%dir %{_texmfdistdir}/tex/latex/xebaposter
%dir %{_texmfdistdir}/tex/latex/xecyrmongolian
%dir %{_texmfdistdir}/tex/latex/xellipsis
%dir %{_texmfdistdir}/tex/latex/xfakebold
%dir %{_texmfdistdir}/tex/latex/xfor
%dir %{_texmfdistdir}/tex/latex/xgreek
%dir %{_texmfdistdir}/tex/latex/xhfill
%dir %{_texmfdistdir}/tex/latex/xifthen
%dir %{_texmfdistdir}/tex/latex/xindex
%dir %{_texmfdistdir}/tex/latex/xistercian
%dir %{_texmfdistdir}/tex/latex/xkcdcolors
%dir %{_texmfdistdir}/tex/latex/xkeyval
%dir %{_texmfdistdir}/tex/latex/xltabular
%dir %{_texmfdistdir}/tex/latex/xmpincl
%dir %{_texmfdistdir}/tex/latex/xmuthesis
%dir %{_texmfdistdir}/tex/latex/xnewcommand
%dir %{_texmfdistdir}/tex/latex/xoptarg
%dir %{_texmfdistdir}/tex/latex/xpatch
%dir %{_texmfdistdir}/tex/latex/xpeek
%dir %{_texmfdistdir}/tex/latex/xpiano
%dir %{_texmfdistdir}/tex/latex/xpicture
%dir %{_texmfdistdir}/tex/latex/xpinyin
%dir %{_texmfdistdir}/tex/latex/xprintlen
%dir %{_texmfdistdir}/tex/latex/xpunctuate
%dir %{_texmfdistdir}/tex/latex/xq
%dir %{_texmfdistdir}/tex/latex/xsavebox
%dir %{_texmfdistdir}/tex/latex/xsim
%dir %{_texmfdistdir}/tex/latex/xskak
%dir %{_texmfdistdir}/tex/latex/xtab
%dir %{_texmfdistdir}/tex/latex/xtuthesis
%dir %{_texmfdistdir}/tex/latex/xurl
%dir %{_texmfdistdir}/tex/latex/xwatermark
%dir %{_texmfdistdir}/tex/latex/xyling
%dir %{_texmfdistdir}/tex/latex/xymtex
%dir %{_texmfdistdir}/tex/latex/xymtex/base
%dir %{_texmfdistdir}/tex/latex/xymtex/chemist
%dir %{_texmfdistdir}/tex/latex/xymtex/xymtxpdf
%dir %{_texmfdistdir}/tex/latex/xymtex/xymtxps
%dir %{_texmfdistdir}/tex/latex/xytree
%dir %{_texmfdistdir}/tex/latex/yafoot
%dir %{_texmfdistdir}/tex/latex/yagusylo
%dir %{_texmfdistdir}/tex/latex/yaletter
%dir %{_texmfdistdir}/tex/latex/yathesis
%dir %{_texmfdistdir}/tex/latex/yb-book
%dir %{_texmfdistdir}/tex/latex/ycbook
%dir %{_texmfdistdir}/tex/latex/ydoc
%dir %{_texmfdistdir}/tex/latex/yfonts
%dir %{_texmfdistdir}/tex/latex/yfonts-otf
%dir %{_texmfdistdir}/tex/latex/yhmath
%dir %{_texmfdistdir}/tex/latex/york-thesis
%dir %{_texmfdistdir}/tex/latex/yplan
%dir %{_texmfdistdir}/tex/latex/yquant
%dir %{_texmfdistdir}/tex/latex/ytableau
%dir %{_texmfdistdir}/tex/latex/zapfchan
%dir %{_texmfdistdir}/tex/latex/zapfding
%dir %{_texmfdistdir}/tex/latex/zebra-goodies
%dir %{_texmfdistdir}/tex/latex/zed-csp
%dir %{_texmfdistdir}/tex/latex/zennote
%dir %{_texmfdistdir}/tex/latex/zhlineskip
%dir %{_texmfdistdir}/tex/latex/zhlipsum
%dir %{_texmfdistdir}/tex/latex/zhmetrics
%dir %{_texmfdistdir}/tex/latex/zhnumber
%dir %{_texmfdistdir}/tex/latex/ziffer
%dir %{_texmfdistdir}/tex/latex/zlmtt
%dir %{_texmfdistdir}/tex/latex/zref
%dir %{_texmfdistdir}/tex/latex/zref-check
%dir %{_texmfdistdir}/tex/latex/zref-clever
%dir %{_texmfdistdir}/tex/latex/zref-vario
%dir %{_texmfdistdir}/tex/latex/zwgetfdate
%dir %{_texmfdistdir}/tex/latex/zwpagelayout
%dir %{_texmfdistdir}/tex/latex/zx-calculus
%dir %{_texmfdistdir}/tex/latex/zxjafbfont
%dir %{_texmfdistdir}/tex/latex/zxjafont
%dir %{_texmfdistdir}/tex/latex/zxjatype
%dir %{_texmfdistdir}/tex/lollipop
%dir %{_texmfdistdir}/tex/lualatex
%dir %{_texmfdistdir}/tex/lualatex/addliga
%dir %{_texmfdistdir}/tex/lualatex/arabluatex
%dir %{_texmfdistdir}/tex/lualatex/autopuncitems
%dir %{_texmfdistdir}/tex/lualatex/beamer-rl
%dir %{_texmfdistdir}/tex/lualatex/bezierplot
%dir %{_texmfdistdir}/tex/lualatex/combofont
%dir %{_texmfdistdir}/tex/lualatex/cstypo
%dir %{_texmfdistdir}/tex/lualatex/dad
%dir %{_texmfdistdir}/tex/lualatex/datestamp
%dir %{_texmfdistdir}/tex/lualatex/ekdosis
%dir %{_texmfdistdir}/tex/lualatex/emojicite
%dir %{_texmfdistdir}/tex/lualatex/gregoriotex
%dir %{_texmfdistdir}/tex/lualatex/hmtrump
%dir %{_texmfdistdir}/tex/lualatex/hu-berlin-bundle
%dir %{_texmfdistdir}/tex/lualatex/innerscript
%dir %{_texmfdistdir}/tex/lualatex/japanese-mathformulas
%dir %{_texmfdistdir}/tex/lualatex/letgut
%dir %{_texmfdistdir}/tex/lualatex/ligtype
%dir %{_texmfdistdir}/tex/lualatex/linebreaker
%dir %{_texmfdistdir}/tex/lualatex/lua-check-hyphen
%dir %{_texmfdistdir}/tex/lualatex/lua-typo
%dir %{_texmfdistdir}/tex/lualatex/lua-ul
%dir %{_texmfdistdir}/tex/lualatex/lua-widow-control
%dir %{_texmfdistdir}/tex/lualatex/luabibentry
%dir %{_texmfdistdir}/tex/lualatex/luabidi
%dir %{_texmfdistdir}/tex/lualatex/luacas
%dir %{_texmfdistdir}/tex/lualatex/luacas/_lib
%dir %{_texmfdistdir}/tex/lualatex/luacas/algebra
%dir %{_texmfdistdir}/tex/lualatex/luacas/algebra/polynomialring
%dir %{_texmfdistdir}/tex/lualatex/luacas/calculus
%dir %{_texmfdistdir}/tex/lualatex/luacas/core
%dir %{_texmfdistdir}/tex/lualatex/luacas/core/binaryoperation
%dir %{_texmfdistdir}/tex/lualatex/luacas/test
%dir %{_texmfdistdir}/tex/lualatex/luacas/test/calculus
%dir %{_texmfdistdir}/tex/lualatex/luacas/test/expressions
%dir %{_texmfdistdir}/tex/lualatex/luacas/test/polynomials
%dir %{_texmfdistdir}/tex/lualatex/luacas/test/rings
%dir %{_texmfdistdir}/tex/lualatex/luacensor
%dir %{_texmfdistdir}/tex/lualatex/luacode
%dir %{_texmfdistdir}/tex/lualatex/luacomplex
%dir %{_texmfdistdir}/tex/lualatex/luagcd
%dir %{_texmfdistdir}/tex/lualatex/luahyphenrules
%dir %{_texmfdistdir}/tex/lualatex/luaimageembed
%dir %{_texmfdistdir}/tex/lualatex/luaindex
%dir %{_texmfdistdir}/tex/lualatex/luainputenc
%dir %{_texmfdistdir}/tex/lualatex/lualatex-math
%dir %{_texmfdistdir}/tex/lualatex/lualatex-truncate
%dir %{_texmfdistdir}/tex/lualatex/lualinalg
%dir %{_texmfdistdir}/tex/lualatex/luamathalign
%dir %{_texmfdistdir}/tex/lualatex/luamaths
%dir %{_texmfdistdir}/tex/lualatex/luamesh
%dir %{_texmfdistdir}/tex/lualatex/luamodulartables
%dir %{_texmfdistdir}/tex/lualatex/luaoptions
%dir %{_texmfdistdir}/tex/lualatex/luaprogtable
%dir %{_texmfdistdir}/tex/lualatex/luapstricks
%dir %{_texmfdistdir}/tex/lualatex/luaquotes
%dir %{_texmfdistdir}/tex/lualatex/luarandom
%dir %{_texmfdistdir}/tex/lualatex/luaset
%dir %{_texmfdistdir}/tex/lualatex/luasseq
%dir %{_texmfdistdir}/tex/lualatex/luatextra
%dir %{_texmfdistdir}/tex/lualatex/luatodonotes
%dir %{_texmfdistdir}/tex/lualatex/luatruthtable
%dir %{_texmfdistdir}/tex/lualatex/novel
%dir %{_texmfdistdir}/tex/lualatex/odsfile
%dir %{_texmfdistdir}/tex/lualatex/pdfarticle
%dir %{_texmfdistdir}/tex/lualatex/pgfmolbio
%dir %{_texmfdistdir}/tex/lualatex/piton
%dir %{_texmfdistdir}/tex/lualatex/placeat
%dir %{_texmfdistdir}/tex/lualatex/plantuml
%dir %{_texmfdistdir}/tex/lualatex/pyluatex
%dir %{_texmfdistdir}/tex/lualatex/scikgtex
%dir %{_texmfdistdir}/tex/lualatex/selnolig
%dir %{_texmfdistdir}/tex/lualatex/semesterplanner
%dir %{_texmfdistdir}/tex/lualatex/showhyphenation
%dir %{_texmfdistdir}/tex/lualatex/showkerning
%dir %{_texmfdistdir}/tex/lualatex/simurgh
%dir %{_texmfdistdir}/tex/lualatex/spacekern
%dir %{_texmfdistdir}/tex/lualatex/stricttex
%dir %{_texmfdistdir}/tex/lualatex/truthtable
%dir %{_texmfdistdir}/tex/lualatex/typewriter
%dir %{_texmfdistdir}/tex/lualatex/uninormalize
%dir %{_texmfdistdir}/tex/lualatex/unitconv
%dir %{_texmfdistdir}/tex/lualatex/wallcalendar
%dir %{_texmfdistdir}/tex/lualatex/wallcalendar/i18n
%dir %{_texmfdistdir}/tex/lualatex/xindex
%dir %{_texmfdistdir}/tex/lualatex/yamlvars
%dir %{_texmfdistdir}/tex/luatex
%dir %{_texmfdistdir}/tex/luatex/barracuda
%dir %{_texmfdistdir}/tex/luatex/blopentype
%dir %{_texmfdistdir}/tex/luatex/chickenize
%dir %{_texmfdistdir}/tex/luatex/chinese-jfm
%dir %{_texmfdistdir}/tex/luatex/cloze
%dir %{_texmfdistdir}/tex/luatex/cstypo
%dir %{_texmfdistdir}/tex/luatex/ctablestack
%dir %{_texmfdistdir}/tex/luatex/ctex
%dir %{_texmfdistdir}/tex/luatex/evangelion-jfm
%dir %{_texmfdistdir}/tex/luatex/gregoriotex
%dir %{_texmfdistdir}/tex/luatex/hyph-utf8
%dir %{_texmfdistdir}/tex/luatex/interpreter
%dir %{_texmfdistdir}/tex/luatex/jlreq
%dir %{_texmfdistdir}/tex/luatex/kanaparser
%dir %{_texmfdistdir}/tex/luatex/lparse
%dir %{_texmfdistdir}/tex/luatex/lua-uni-algos
%dir %{_texmfdistdir}/tex/luatex/lua-visual-debug
%dir %{_texmfdistdir}/tex/luatex/lua-widow-control
%dir %{_texmfdistdir}/tex/luatex/luaaddplot
%dir %{_texmfdistdir}/tex/luatex/luakeys
%dir %{_texmfdistdir}/tex/luatex/lualibs
%dir %{_texmfdistdir}/tex/luatex/luamplib
%dir %{_texmfdistdir}/tex/luatex/luaotfload
%dir %{_texmfdistdir}/tex/luatex/luapackageloader
%dir %{_texmfdistdir}/tex/luatex/luatexbase
%dir %{_texmfdistdir}/tex/luatex/luatexja
%dir %{_texmfdistdir}/tex/luatex/luatexja/addons
%dir %{_texmfdistdir}/tex/luatex/luatexja/patches
%dir %{_texmfdistdir}/tex/luatex/luatexko
%dir %{_texmfdistdir}/tex/luatex/luavlna
%dir %{_texmfdistdir}/tex/luatex/luaxml
%dir %{_texmfdistdir}/tex/luatex/lutabulartools
%dir %{_texmfdistdir}/tex/luatex/lyluatex
%dir %{_texmfdistdir}/tex/luatex/markdown
%dir %{_texmfdistdir}/tex/luatex/minim
%dir %{_texmfdistdir}/tex/luatex/minim-math
%dir %{_texmfdistdir}/tex/luatex/minim-mp
%dir %{_texmfdistdir}/tex/luatex/minim-pdf
%dir %{_texmfdistdir}/tex/luatex/minim-xmp
%dir %{_texmfdistdir}/tex/luatex/nodetree
%dir %{_texmfdistdir}/tex/luatex/pdfextra
%dir %{_texmfdistdir}/tex/luatex/penlight
%dir %{_texmfdistdir}/tex/luatex/spelling
%dir %{_texmfdistdir}/tex/luatex/tsvtemplate
%dir %{_texmfdistdir}/tex/mex
%dir %{_texmfdistdir}/tex/mex/base
%dir %{_texmfdistdir}/tex/mex/config
%dir %{_texmfdistdir}/tex/mex/utf8mex
%dir %{_texmfdistdir}/tex/mltex
%dir %{_texmfdistdir}/tex/mltex/config
%dir %{_texmfdistdir}/tex/optex
%dir %{_texmfdistdir}/tex/optex/base
%dir %{_texmfdistdir}/tex/optex/demo
%dir %{_texmfdistdir}/tex/optex/lua-widow-control
%dir %{_texmfdistdir}/tex/optex/pdfextra
%dir %{_texmfdistdir}/tex/optex/pkg
%dir %{_texmfdistdir}/tex/plain
%dir %{_texmfdistdir}/tex/plain/amsfonts
%dir %{_texmfdistdir}/tex/plain/antt
%dir %{_texmfdistdir}/tex/plain/armenian
%dir %{_texmfdistdir}/tex/plain/asapsym
%dir %{_texmfdistdir}/tex/plain/base
%dir %{_texmfdistdir}/tex/plain/commutative-diagrams
%dir %{_texmfdistdir}/tex/plain/config
%dir %{_texmfdistdir}/tex/plain/cweb
%dir %{_texmfdistdir}/tex/plain/cweb-old
%dir %{_texmfdistdir}/tex/plain/cweb/cwebbin
%dir %{_texmfdistdir}/tex/plain/cyrplain
%dir %{_texmfdistdir}/tex/plain/encxvlna
%dir %{_texmfdistdir}/tex/plain/enigma
%dir %{_texmfdistdir}/tex/plain/epsf-dvipdfmx
%dir %{_texmfdistdir}/tex/plain/esint-type1
%dir %{_texmfdistdir}/tex/plain/etex
%dir %{_texmfdistdir}/tex/plain/figflow
%dir %{_texmfdistdir}/tex/plain/fixpdfmag
%dir %{_texmfdistdir}/tex/plain/font-change
%dir %{_texmfdistdir}/tex/plain/fontch
%dir %{_texmfdistdir}/tex/plain/fp
%dir %{_texmfdistdir}/tex/plain/getoptk
%dir %{_texmfdistdir}/tex/plain/gfnotation
%dir %{_texmfdistdir}/tex/plain/graphics-pln
%dir %{_texmfdistdir}/tex/plain/gustlib
%dir %{_texmfdistdir}/tex/plain/gustlib/biblotex
%dir %{_texmfdistdir}/tex/plain/gustlib/licz
%dir %{_texmfdistdir}/tex/plain/gustlib/map
%dir %{_texmfdistdir}/tex/plain/gustlib/plbtx993
%dir %{_texmfdistdir}/tex/plain/gustlib/plmac218
%dir %{_texmfdistdir}/tex/plain/hanoi
%dir %{_texmfdistdir}/tex/plain/harvmac
%dir %{_texmfdistdir}/tex/plain/hyplain
%dir %{_texmfdistdir}/tex/plain/iwona
%dir %{_texmfdistdir}/tex/plain/js-misc
%dir %{_texmfdistdir}/tex/plain/knitting
%dir %{_texmfdistdir}/tex/plain/knuth-lib
%dir %{_texmfdistdir}/tex/plain/knuth-local
%dir %{_texmfdistdir}/tex/plain/kotex-plain
%dir %{_texmfdistdir}/tex/plain/kurier
%dir %{_texmfdistdir}/tex/plain/lambda-lists
%dir %{_texmfdistdir}/tex/plain/lh
%dir %{_texmfdistdir}/tex/plain/ly1
%dir %{_texmfdistdir}/tex/plain/makeindex
%dir %{_texmfdistdir}/tex/plain/metatex
%dir %{_texmfdistdir}/tex/plain/mkpattern
%dir %{_texmfdistdir}/tex/plain/newsletr
%dir %{_texmfdistdir}/tex/plain/omega
%dir %{_texmfdistdir}/tex/plain/pgf
%dir %{_texmfdistdir}/tex/plain/pgf/basiclayer
%dir %{_texmfdistdir}/tex/plain/pgf/frontendlayer
%dir %{_texmfdistdir}/tex/plain/pgf/math
%dir %{_texmfdistdir}/tex/plain/pgf/systemlayer
%dir %{_texmfdistdir}/tex/plain/pgf/utilities
%dir %{_texmfdistdir}/tex/plain/pgfplots
%dir %{_texmfdistdir}/tex/plain/pitex
%dir %{_texmfdistdir}/tex/plain/placeins-plain
%dir %{_texmfdistdir}/tex/plain/plipsum
%dir %{_texmfdistdir}/tex/plain/plnfss
%dir %{_texmfdistdir}/tex/plain/plstmary
%dir %{_texmfdistdir}/tex/plain/present
%dir %{_texmfdistdir}/tex/plain/pwebmac
%dir %{_texmfdistdir}/tex/plain/resumemac
%dir %{_texmfdistdir}/tex/plain/rsfs
%dir %{_texmfdistdir}/tex/plain/semaphor
%dir %{_texmfdistdir}/tex/plain/tikz-ext
%dir %{_texmfdistdir}/tex/plain/timetable
%dir %{_texmfdistdir}/tex/plain/treetex
%dir %{_texmfdistdir}/tex/plain/tugboat-plain
%dir %{_texmfdistdir}/tex/plain/varisize
%dir %{_texmfdistdir}/tex/plain/velthuis
%dir %{_texmfdistdir}/tex/plain/vntex
%dir %{_texmfdistdir}/tex/plain/wasy
%dir %{_texmfdistdir}/tex/plain/xintsession
%dir %{_texmfdistdir}/tex/plain/zztex
%dir %{_texmfdistdir}/tex/platex
%dir %{_texmfdistdir}/tex/platex/base
%dir %{_texmfdistdir}/tex/platex/config
%dir %{_texmfdistdir}/tex/platex/japanese-otf
%dir %{_texmfdistdir}/tex/platex/jlreq-deluxe
%dir %{_texmfdistdir}/tex/platex/jsclasses
%dir %{_texmfdistdir}/tex/platex/pxbase
%dir %{_texmfdistdir}/tex/platex/pxchfon
%dir %{_texmfdistdir}/tex/platex/pxjahyper
%dir %{_texmfdistdir}/tex/platex/pxrubrica
%dir %{_texmfdistdir}/tex/psizzl
%dir %{_texmfdistdir}/tex/psizzl/base
%dir %{_texmfdistdir}/tex/psizzl/config
%dir %{_texmfdistdir}/tex/ptex
%dir %{_texmfdistdir}/tex/ptex/ptex-base
%dir %{_texmfdistdir}/tex/startex
%dir %{_texmfdistdir}/tex/support
%dir %{_texmfdistdir}/tex/support/adhocfilelist
%dir %{_texmfdistdir}/tex/texinfo
%dir %{_texmfdistdir}/tex/texsis
%dir %{_texmfdistdir}/tex/texsis/base
%dir %{_texmfdistdir}/tex/texsis/config
%dir %{_texmfdistdir}/tex/uplatex
%dir %{_texmfdistdir}/tex/uplatex/base
%dir %{_texmfdistdir}/tex/uplatex/config
%dir %{_texmfdistdir}/tex/uptex
%dir %{_texmfdistdir}/tex/uptex/uptex-base
%dir %{_texmfdistdir}/tex/xelatex
%dir %{_texmfdistdir}/tex/xelatex/arabic-book
%dir %{_texmfdistdir}/tex/xelatex/arabxetex
%dir %{_texmfdistdir}/tex/xelatex/bhcexam
%dir %{_texmfdistdir}/tex/xelatex/bidi
%dir %{_texmfdistdir}/tex/xelatex/bidi-atbegshi
%dir %{_texmfdistdir}/tex/xelatex/bidicontour
%dir %{_texmfdistdir}/tex/xelatex/bidihl
%dir %{_texmfdistdir}/tex/xelatex/bidipagegrid
%dir %{_texmfdistdir}/tex/xelatex/bidipresentation
%dir %{_texmfdistdir}/tex/xelatex/bidishadowtext
%dir %{_texmfdistdir}/tex/xelatex/buctthesis
%dir %{_texmfdistdir}/tex/xelatex/businesscard-qrcode
%dir %{_texmfdistdir}/tex/xelatex/cqubeamer
%dir %{_texmfdistdir}/tex/xelatex/facture
%dir %{_texmfdistdir}/tex/xelatex/facture-belge-simple-sans-tva
%dir %{_texmfdistdir}/tex/xelatex/fixlatvian
%dir %{_texmfdistdir}/tex/xelatex/fontbook
%dir %{_texmfdistdir}/tex/xelatex/fontwrap
%dir %{_texmfdistdir}/tex/xelatex/hanzibox
%dir %{_texmfdistdir}/tex/xelatex/hfutthesis
%dir %{_texmfdistdir}/tex/xelatex/hithesis
%dir %{_texmfdistdir}/tex/xelatex/imsproc
%dir %{_texmfdistdir}/tex/xelatex/interchar
%dir %{_texmfdistdir}/tex/xelatex/kurdishlipsum
%dir %{_texmfdistdir}/tex/xelatex/langsci
%dir %{_texmfdistdir}/tex/xelatex/mathspec
%dir %{_texmfdistdir}/tex/xelatex/mynsfc
%dir %{_texmfdistdir}/tex/xelatex/na-box
%dir %{_texmfdistdir}/tex/xelatex/na-position
%dir %{_texmfdistdir}/tex/xelatex/nanicolle
%dir %{_texmfdistdir}/tex/xelatex/parsa
%dir %{_texmfdistdir}/tex/xelatex/philokalia
%dir %{_texmfdistdir}/tex/xelatex/ptext
%dir %{_texmfdistdir}/tex/xelatex/quran-de
%dir %{_texmfdistdir}/tex/xelatex/resumecls
%dir %{_texmfdistdir}/tex/xelatex/sexam
%dir %{_texmfdistdir}/tex/xelatex/simple-resume-cv
%dir %{_texmfdistdir}/tex/xelatex/simple-thesis-dissertation
%dir %{_texmfdistdir}/tex/xelatex/tabriz-thesis
%dir %{_texmfdistdir}/tex/xelatex/technion-thesis-template
%dir %{_texmfdistdir}/tex/xelatex/tetragonos
%dir %{_texmfdistdir}/tex/xelatex/thesis-qom
%dir %{_texmfdistdir}/tex/xelatex/ucharclasses
%dir %{_texmfdistdir}/tex/xelatex/unicode-bidi
%dir %{_texmfdistdir}/tex/xelatex/unisugar
%dir %{_texmfdistdir}/tex/xelatex/velthuis
%dir %{_texmfdistdir}/tex/xelatex/xduts
%dir %{_texmfdistdir}/tex/xelatex/xechangebar
%dir %{_texmfdistdir}/tex/xelatex/xecjk
%dir %{_texmfdistdir}/tex/xelatex/xecolor
%dir %{_texmfdistdir}/tex/xelatex/xecyr
%dir %{_texmfdistdir}/tex/xelatex/xeindex
%dir %{_texmfdistdir}/tex/xelatex/xepersian
%dir %{_texmfdistdir}/tex/xelatex/xepersian-hm
%dir %{_texmfdistdir}/tex/xelatex/xespotcolor
%dir %{_texmfdistdir}/tex/xelatex/xetex-pstricks
%dir %{_texmfdistdir}/tex/xelatex/xetexconfig
%dir %{_texmfdistdir}/tex/xelatex/xevlna
%dir %{_texmfdistdir}/tex/xelatex/xltxtra
%dir %{_texmfdistdir}/tex/xelatex/xunicode
%dir %{_texmfdistdir}/tex/xelatex/yazd-thesis
%dir %{_texmfdistdir}/tex/xelatex/zbmath-review-template
%dir %{_texmfdistdir}/tex/xelatex/zhspacing
%dir %{_texmfdistdir}/tex/xelatex/zitie
%dir %{_texmfdistdir}/tex/xetex
%dir %{_texmfdistdir}/tex/xetex/font-change-xetex
%dir %{_texmfdistdir}/tex/xetex/unimath-plain-xetex
%dir %{_texmfdistdir}/tex/xetex/xesearch
%dir %{_texmfdistdir}/tex/xetex/xetex-pstricks
%dir %{_texmfdistdir}/tex/xetex/xetexfontinfo
%dir %{_texmfdistdir}/tex/xetex/xetexko
%dir %{_texmfdistdir}/tex/xmltex
%dir %{_texmfdistdir}/tex/xmltex/base
%dir %{_texmfdistdir}/tex/xmltex/passivetex
%dir %{_texmfdistdir}/tex/xmltex/xmltexconfig
%dir %{_texmfdistdir}/tex4ht
%dir %{_texmfdistdir}/tex4ht/base
%dir %{_texmfdistdir}/tex4ht/base/unix
%dir %{_texmfdistdir}/tex4ht/base/win32
%dir %{_texmfdistdir}/tex4ht/bin
%dir %{_texmfdistdir}/tex4ht/ht-fonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Century_Schoolbook_L
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Bold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Bold_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_ExtraBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_ExtraBold_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Initials
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Medium
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Medium_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_Regular
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_SemiBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/EB_Garamond_SemiBold_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Fourier-Math-Letters
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Ex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Exa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Sy
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Sya
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syb
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp--M-Syd
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Companion
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-Companion
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Ex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Exa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Sy
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syb
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-M-Syd
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-SC-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-Light-SmallCaps
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-SC-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Kp-SmallCaps
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/LibertineMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Biolinum_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Display_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Initials_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Mono_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_Mono_T_
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Linux_Libertine_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/MnSymbol
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/NewTXMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Condensed
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Condensed_Light
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_ExtraBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_Light
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Open_Sans_SemiBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/STIX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/STIX_Two
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Comp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Companion
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Exp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Sc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Sf-Kp-Sc-Exp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_ExtraBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_ExtraLight
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_Light
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_Medium
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Spectral_SemiBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/TeXGyreTermes
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/TeXGyreTermesX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp-Comp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Tt-Kp-Exp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/Utopia
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/XCharterMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/avantgar
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/bookman
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/courier
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/helvetic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/mathppl
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/mathptmx
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/ncntrsbk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/palatino
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/ppalatino
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/pslatex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/symbol
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/times
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/utopia
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/zapfchan
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/adobe/zapfding
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ae
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ams
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ams/euler
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/antt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/arabi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/arev
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/arphic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/bera
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/bitstrea
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/bitstrea/charter
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cc-pl
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/chartervn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/chess
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cjk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cjk/b5ka
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cm/sauter
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/coch
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/concrete
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/currency
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cyklop
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/cyrillic/cmcyr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ec
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/erew
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/eulervm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/euro
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/fourier-orns
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futb-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futbi-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futc-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9c
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futc9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futrc9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futrci9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futrci9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futri-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futs-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9c
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futs9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsc9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsc9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsci9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsci9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9c
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futsi9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9c
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/futso9e
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkcy
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkfs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkhei
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkkai
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkli
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkshu
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbksu
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkxw
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkyao
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/gbk/gbkyou
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/greek
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/greek/ibygrk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/hebrew
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/cs-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/ec-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/qx
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/t5-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/iwona/texnansi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/jknappen
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/jknappen/tc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/cs-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/cs-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/ec
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/ex-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/exp-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/greek-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/mi-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/qx-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/qx-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/rm-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/sy-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2a-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2b-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t2c-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t5-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/t5-iwonacap
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/texnansi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/kurier/wncy-iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/latex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lh/lh-t2a
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/libertine
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-ec
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-qx
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmin
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmrm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cmsc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-csin
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-csrm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-cstt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-plrm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/lm-rep-t5psn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/lm/pre2005
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/marvosym
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/mathdesign
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/mathpple
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/mathtime
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/mlm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/musix
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ntxsups
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/ntxtm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/pazo
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/pl
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/pxfonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/qfonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/sw
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/t1fonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xbtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xbttsc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/t1xttsc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/tcxbtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/times
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/tipa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbexas
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbmiaX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsyb
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsyc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbsys
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txbttsc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txfonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txmiaX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txsys
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/txttsc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/arevvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/chartervn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/classicovn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/cmbrightvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/comicsansvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/concretevn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/garamondvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/grotesqvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/mscorevn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/urwvn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/utopiavn
%dir %{_texmfdistdir}/tex4ht/ht-fonts/alias/vntex/vnr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/aliase
%dir %{_texmfdistdir}/tex4ht/ht-fonts/aliase/mathtime
%dir %{_texmfdistdir}/tex4ht/ht-fonts/ascii
%dir %{_texmfdistdir}/tex4ht/ht-fonts/ascii/manfnt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/cp1256
%dir %{_texmfdistdir}/tex4ht/ht-fonts/cp1256/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/css
%dir %{_texmfdistdir}/tex4ht/ht-fonts/css/emacspeak
%dir %{_texmfdistdir}/tex4ht/ht-fonts/css/emacspeak/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/dbcs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/dbcs/cjk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/dbcs/cjk/b5ka
%dir %{_texmfdistdir}/tex4ht/ht-fonts/gb2312
%dir %{_texmfdistdir}/tex4ht/ht-fonts/gb2312/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/gbk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/gbk/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/html-speech
%dir %{_texmfdistdir}/tex4ht/ht-fonts/html-speech/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/charset/uni
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/chess
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/devanagari
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/euro
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/go
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/html
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/html/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/ipa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/mathtime
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/mongolian
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/ps2mf
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/sw
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/tibetan
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/1/xypic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2/html
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/2/html/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cm/sauter
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/cyrillic/cmcyr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/html
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/html/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/lh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/5/lh/lh-t2a
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6/html
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/6/html/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/7
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/7/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/8
%dir %{_texmfdistdir}/tex4ht/ht-fonts/iso8859/8/hebrew
%dir %{_texmfdistdir}/tex4ht/ht-fonts/jsml
%dir %{_texmfdistdir}/tex4ht/ht-fonts/jsml/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/koi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/koi/8r
%dir %{_texmfdistdir}/tex4ht/ht-fonts/koi/8r/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/koi/8r/lh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/koi/8r/lh/lh-t2a
%dir %{_texmfdistdir}/tex4ht/ht-fonts/mozilla
%dir %{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset/mnemonic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/mozilla/charset/native
%dir %{_texmfdistdir}/tex4ht/ht-fonts/ooffice
%dir %{_texmfdistdir}/tex4ht/ht-fonts/ooffice/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/share
%dir %{_texmfdistdir}/tex4ht/ht-fonts/share/adobe
%dir %{_texmfdistdir}/tex4ht/ht-fonts/share/adobe/helvetic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/symbol
%dir %{_texmfdistdir}/tex4ht/ht-fonts/symbol/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/symbol/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/symbol/hebrew
%dir %{_texmfdistdir}/tex4ht/ht-fonts/symbol/mathtime
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Baskervaldx
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Century_Schoolbook_L
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Initials
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Italic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/EB_Garamond_Regular
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Extension
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Letters
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Fourier-Math-Symbols
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Ex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Exa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Sy
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp--M-Sya
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Companion
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Ex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Sy
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syb
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-M-Syd
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-Light-SmallCaps
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-SC-Expert
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Kp-SmallCaps
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/LibertineMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Biolinum_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Display_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Initials_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_Mono_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Linux_Libertine_T
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/MinLib
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/MnSymbol
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/NCXFourierMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/NewTXMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Nimbus_Roman_No9_L
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Open_Sans_ExtraBold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Open_Sans_Light
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/STIX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/STIX_Two
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Sf-Kp-Sc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Spectral
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/TeXGyreTermes
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/TeXGyreTermesX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Tt-Kp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Tt-Kp-Exp
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/URW_Chancery_L
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/Utopia
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/courier
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/helvetic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/mathptm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/palatino
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/symbol
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/times
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/adobe/zapfding
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ae
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/euler
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ams/symbols
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/antt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/arabi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/arev
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/arphic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/bbold
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/bitstrea
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/bitstrea/charter
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cbgreek
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/chess
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/b5ka
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/gbksong
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/gbksong/long
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cjk/utf8
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/coch
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/concrete
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/currency
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cyklop
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/cyrillic/cmcyr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/dstroke
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ebg
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ec
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/erewMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/fontawesome
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/fourier-orns
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/futr-sup
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/futrc9d
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/futrd8t
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/greek
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/greek/ibygrk
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/hebrew
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/html
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/html/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/iwona
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/jknappen
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/jknappen/tc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/latex
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/lh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/lh/lh-t2a
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/libertine
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/lm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/lm/pre2005
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/marvosym
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/math
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathdesign
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathkerncmssi
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/mathtime
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/mflogo
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/misc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/musix
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ntxsups
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/ntxtm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/pl
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/public
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/pxfonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/stickstooMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/stmaryrd
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/stxickstooMath
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/t1xtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/tcxtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/tibetan
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/tipa
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbexs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbmiaX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txbsys
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txexas
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txexs
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txfonts
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txmiaX
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsyb
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsyc
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txsys
%dir %{_texmfdistdir}/tex4ht/ht-fonts/unicode/txtt
%dir %{_texmfdistdir}/tex4ht/ht-fonts/utf8
%dir %{_texmfdistdir}/tex4ht/ht-fonts/utf8/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/viqr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/viqr/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/viscii
%dir %{_texmfdistdir}/tex4ht/ht-fonts/viscii/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/charset
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cm
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cm/sauter
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cyrillic
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/cyrillic/cmcyr
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/lh
%dir %{_texmfdistdir}/tex4ht/ht-fonts/win/1251/lh/lh-t2a
%dir %{_texmfdistdir}/tex4ht/xtpipes
%dir %{_texmfdistdir}/texconfig
%dir %{_texmfdistdir}/texdoc
%dir %{_texmfdistdir}/texdoctk
%dir %{_texmfdistdir}/ttf2pk
%dir %{_texmfdistdir}/web2c
%dir %{_texmfdistdir}/xdvi
%dir %{_texmfdistdir}/xdvi/pixmap
%dir %{_texmfmaindir}/readme-html.dir
%dir %{_texmfmaindir}/readme-txt.dir
%dir %{_texmfmaindir}/tlpkg
%dir %{_texmfmaindir}/tlpkg/TeXLive
%dir %{_texmfmaindir}/tlpkg/gpg
%dir %attr(1755,root,root) %{_texmfvardir}/
%dir %attr(1755,root,root) %{_texmfvardir}/dist/
%dir %attr(1755,root,root) %{_texmfvardir}/main/
%dir %attr(1755,root,root) %{_texmfvardir}/fonts/
%dir %attr(1755,root,root) %{_texmfvardir}/fonts/dvipdfm/
%dir %attr(1755,root,root) %{_texmfvardir}/fonts/dvips/
%dir %attr(1755,root,root) %{_texmfvardir}/fonts/pdftex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/aleph/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/eptex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/luatex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/metafont/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/pdftex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/ptex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/tex/
%dir %attr(1755,root,root) %{_texmfvardir}/web2c/xetex/
%dir %attr(1755,root,root) %{_texmfcache}/
%dir %attr(3775,%{texusr},%{texgrp}) %verify(not mode) %{_fontcache}/
%dir %attr(3775,%{texusr},%{texgrp}) %verify(not mode) %{_fontcache}/pk/
%dir %attr(3775,%{texusr},%{texgrp}) %verify(not mode) %{_fontcache}/source/
%dir %attr(3775,%{texusr},%{texgrp}) %verify(not mode) %{_fontcache}/tfm/
%dir %{_texmfvardir}/md5
%verify(link) %{_texmfmaindir}/ls-R
%verify(link) %{_texmfdistdir}/ls-R
%ghost %config(noreplace) %attr(0664,root,%{texgrp}) %verify(not md5 size mtime mode) %{_texmfconfdir}/ls-R
%ghost %config(noreplace) %attr(0664,%{texusr},%{texgrp}) %verify(not md5 size mtime mode) %{_fontcache}/ls-R
%ghost %config(noreplace) %attr(0664,root,%{texgrp}) %verify(not md5 size mtime mode) %{_texmfvardir}/ls-R
%ghost %config(noreplace) %attr(0664,root,%{texgrp}) %verify(not md5 size mtime mode) %{_texmfvardir}/dist/ls-R
%ghost %config(noreplace) %attr(0664,root,%{texgrp}) %verify(not md5 size mtime mode) %{_texmfvardir}/main/ls-R
%{_fillupdir}/sysconfig.texlive
%if %{with zypper_posttrans}
/var/adm/update-scripts/%{name}-%{version}-%{release}-zypper
%endif

%files -n texlive-scheme-basic
%defattr(-,root,root,755)

%files -n texlive-scheme-bookpub
%defattr(-,root,root,755)

%files -n texlive-scheme-context
%defattr(-,root,root,755)

%files -n texlive-scheme-full
%defattr(-,root,root,755)

%files -n texlive-scheme-gust
%defattr(-,root,root,755)

%files -n texlive-scheme-infraonly
%defattr(-,root,root,755)

%files -n texlive-scheme-medium
%defattr(-,root,root,755)

%files -n texlive-scheme-minimal
%defattr(-,root,root,755)

%files -n texlive-scheme-small
%defattr(-,root,root,755)

%files -n texlive-scheme-tetex
%defattr(-,root,root,755)

%files -n texlive-collection-basic
%defattr(-,root,root,755)

%files -n texlive-collection-bibtexextra
%defattr(-,root,root,755)

%files -n texlive-collection-binextra
%defattr(-,root,root,755)

%files -n texlive-collection-context
%defattr(-,root,root,755)

%files -n texlive-collection-fontsextra
%defattr(-,root,root,755)

%files -n texlive-collection-fontsrecommended
%defattr(-,root,root,755)

%files -n texlive-collection-fontutils
%defattr(-,root,root,755)

%files -n texlive-collection-formatsextra
%defattr(-,root,root,755)

%files -n texlive-collection-games
%defattr(-,root,root,755)

%files -n texlive-collection-humanities
%defattr(-,root,root,755)

%files -n texlive-collection-langarabic
%defattr(-,root,root,755)

%files -n texlive-collection-langchinese
%defattr(-,root,root,755)

%files -n texlive-collection-langcjk
%defattr(-,root,root,755)

%files -n texlive-collection-langcyrillic
%defattr(-,root,root,755)

%files -n texlive-collection-langczechslovak
%defattr(-,root,root,755)

%files -n texlive-collection-langenglish
%defattr(-,root,root,755)

%files -n texlive-collection-langeuropean
%defattr(-,root,root,755)

%files -n texlive-collection-langfrench
%defattr(-,root,root,755)

%files -n texlive-collection-langgerman
%defattr(-,root,root,755)

%files -n texlive-collection-langgreek
%defattr(-,root,root,755)

%files -n texlive-collection-langitalian
%defattr(-,root,root,755)

%files -n texlive-collection-langjapanese
%defattr(-,root,root,755)

%files -n texlive-collection-langkorean
%defattr(-,root,root,755)

%files -n texlive-collection-langother
%defattr(-,root,root,755)

%files -n texlive-collection-langpolish
%defattr(-,root,root,755)

%files -n texlive-collection-langportuguese
%defattr(-,root,root,755)

%files -n texlive-collection-langspanish
%defattr(-,root,root,755)

%files -n texlive-collection-latex
%defattr(-,root,root,755)

%files -n texlive-collection-latexextra
%defattr(-,root,root,755)

%files -n texlive-collection-latexrecommended
%defattr(-,root,root,755)

%files -n texlive-collection-luatex
%defattr(-,root,root,755)

%files -n texlive-collection-mathscience
%defattr(-,root,root,755)

%files -n texlive-collection-metapost
%defattr(-,root,root,755)

%files -n texlive-collection-music
%defattr(-,root,root,755)

%files -n texlive-collection-pictures
%defattr(-,root,root,755)

%files -n texlive-collection-plaingeneric
%defattr(-,root,root,755)

%files -n texlive-collection-pstricks
%defattr(-,root,root,755)

%files -n texlive-collection-publishers
%defattr(-,root,root,755)

%files -n texlive-collection-xetex
%defattr(-,root,root,755)

%files -n texlive-devel
%defattr(-,root,root,755)

%files -n texlive-alldocumentation
%defattr(-,root,root,755)

%files -n texlive-extratools
%defattr(-,root,root,755)

%files -n texlive-updmap-map
%defattr(-,root,root,755)
%dir %{_texmfdistdir}/fonts/map/dvipdfmx/updmap
%dir %{_texmfdistdir}/fonts/map/dvips/updmap
%dir %{_texmfdistdir}/fonts/map/pdftex/updmap
%{_texmfdistdir}/fonts/map/dvipdfmx/updmap/kanjix.map
%{_texmfdistdir}/fonts/map/dvips/updmap/builtin35.map
%{_texmfdistdir}/fonts/map/dvips/updmap/download35.map
%{_texmfdistdir}/fonts/map/dvips/updmap/ps2pk.map
%{_texmfdistdir}/fonts/map/dvips/updmap/psfonts.map
%{_texmfdistdir}/fonts/map/dvips/updmap/psfonts_pk.map
%{_texmfdistdir}/fonts/map/dvips/updmap/psfonts_t1.map
%{_texmfdistdir}/fonts/map/pdftex/updmap/pdftex.map
%{_texmfdistdir}/fonts/map/pdftex/updmap/pdftex_dl14.map
%{_texmfdistdir}/fonts/map/pdftex/updmap/pdftex_ndl14.map
%if %{with zypper_posttrans}
/var/adm/update-scripts/texlive-updmap-map-%{texlive_version}.%{texlive_noarch}.svn54495-%{release}-zypper
%endif

%changelog
* Tue Jul  4 2023 Dr. Werner Fink <werner@suse.de>
- Rework lua(meta)tex/context resource findings
* Mon Jun  5 2023 Dr. Werner Fink <werner@suse.de>
- For creation of ls-R after transactional update used secure
  way via setpriv(8) (boo#1212006)
* Thu May 25 2023 Dr. Werner Fink <werner@suse.de>
- Switch over to systemd to a) replace cron usage with timer
  and b) to make use the transactional update support of the
  update script (boo#1211613)
* Wed May 24 2023 Dr. Werner Fink <werner@suse.de>
- Better support of transactional updates (boo#1211613)
* Tue May 23 2023 Dr. Werner Fink <werner@suse.de>
- Enable the force mode of update script to handle broken
  /var/lib and /var/cache texmf entries (boo#1211613)
* Mon May 15 2023 Andreas Schwab <schwab@suse.de>
- Fix syntax error in update script
* Wed Apr  5 2023 Dr. Werner Fink <werner@suse.de>
- Support mkiv as well as lmtx ConTeXt formats
* Tue Apr  4 2023 Dr. Werner Fink <werner@suse.de>
- Correct the meta package name for boo#1204746 to
  texlive-alldocumentation as the documentation.sty has its own
  package.
* Fri Mar 31 2023 Dr. Werner Fink <werner@suse.de>
- Modify update script in such way that the hash sum of the
  mtxrun calls agree with those of the users
* Mon Mar 20 2023 Dr. Werner Fink <werner@suse.de>
- Update to final TeXLive 2023
* Thu Mar  9 2023 Dr. Werner Fink <werner@suse.de>
- Update to pretest TeXLive 2023
* Thu Aug 18 2022 Dr. Werner Fink <werner@suse.de>
- Rerun generate perl script to get https urls
* Mon Apr  4 2022 Dr. Werner Fink <werner@suse.de>
- Update to TeXLive 2022
- Try to debug entries like boo#1194496
* Thu Dec  9 2021 Dr. Werner Fink <werner@suse.de>
-  Modifiy texlive.cron
  * boo#1193473 -- /etc/cron.daily/suse-texlive from texlive causes warnings
    OK make them silent
* Sun May 30 2021 Callum Farmer <gmbr3@opensuse.org>
- Change to using systemd-sysusers
* Thu May 27 2021 Matthias Gerstner <matthias.gerstner@suse.com>
- remove 'public' setgid binary from permissions.d files. This entry is
  conflicting with the global permissions profiles from the permissions
  package. E.g. when we set the 'paranoid' profile then the public binary is
  supposed to end up without setgid-bit, which it does not currently.
* Mon Apr 26 2021 Dr. Werner Fink <werner@suse.de>
- Force updmap-sys to sync trees
* Tue Apr 13 2021 Dr. Werner Fink <werner@suse.de>
- Simplify update script, that is always hash before updating
  font maps
* Mon Apr 12 2021 Dr. Werner Fink <werner@suse.de>
- Re-add texlive-updmap-map as it is not part of any archive
  anymore but is required
* Tue Apr  6 2021 Dr. Werner Fink <werner@suse.de>
- Update to TeXLive 2021
* Tue Feb 23 2021 Callum Farmer <gmbr3@opensuse.org>
- Fixes for %%_libexecdir changing to /usr/libexec (bsc#1174075)
* Mon Feb  8 2021 Dr. Werner Fink <werner@suse.de>
- Skip packages which are based on python2
* Fri Oct  2 2020 Dr. Werner Fink <werner@suse.de>
- Enhance update script to detect user changes in configuration
  files to warn the user.  Also run texlinks script to be sure
  that local configuration fits the linked engines (boo#1176557)
* Tue Apr 28 2020 Dr. Werner Fink <werner@suse.de>
- No pstools anymore in texlive database
* Mon Apr 20 2020 Dr. Werner Fink <werner@suse.de>
- Update to TeXLive 2020
* Mon Mar 23 2020 Dr. Werner Fink <werner@suse.de>
- Add new configuration variable HAVE_MKTEX_MEMBERS to texlive
  sysconfig file to control the behaviour of the cron job.
- Change the cron job to clear data of other users which are
  member of the group mktex
* Wed Mar 11 2020 Dr. Werner Fink <werner@suse.de>
- Use CVE numbers
* Thu Feb 20 2020 Dr. Werner Fink <werner@suse.de>
- Use setpriv to create ls-R files, below /var/cache/texmf/fonts
  use uid mktex for this (boo#1159740, CVE-2020-8016)
* Wed Feb  5 2020 Dr. Werner Fink <werner@suse.de>
- Check passwd not group file for user mktex
* Tue Feb  4 2020 Dr. Werner Fink <werner@suse.de>
- Again use setpriv but now switch to every single owner for clearing
  the files of this owner (boo#1159740, CVE-2020-8016)
* Fri Jan 31 2020 Dr. Werner Fink <werner@suse.de>
- Introduce a user mktex as replacement for user nobody (boo#1159740)
* Wed Jan 22 2020 Dr. Werner Fink <werner@suse.de>
- Overwrite not wanted symbolic links on ls-R files
* Thu Jan 16 2020 Dr. Werner Fink <werner@suse.de>
- Be sure that owner of ls-R files are corrected even on update
  of already existing texlive filesystem
* Fri Jan 10 2020 Dr. Werner Fink <werner@suse.de>
- Set default user for ls-R files and font cache directories
  to user nobody (bsc#1159740, CVE-2020-8016)
- Use setpriv to switch to nobody:mktex before clearing
  font cache directories (bsc#1158910, CVE-2020-8017)
* Thu Dec 19 2019 Dr. Werner Fink <werner@suse.de>
- Harden ls-R file generation at installation (bsc#1158910)
* Fri Dec 13 2019 Dr. Werner Fink <werner@suse.de>
- Simply use rm(1) for the cron job of texlive as all files below
  /var/cache/texmf/ belong to texlive and only root can write and
  remove those files (bsc#1158910). All other users do create their
  own files below ~/.cache/texmf/
* Mon Nov 18 2019 Dr. Werner Fink <werner@suse.de>
- Make cron script even more failsafe
* Fri Nov 15 2019 Dr. Werner Fink <werner@suse.de>
- Make cron script more failsafe (boo#1150556)
- Refresh font map files as well on update (boo#1155381)
* Tue Aug 20 2019 kukuk@suse.de
- BuildRequire cron, too, as it contains now the cron directories
* Thu Jun  6 2019 Dr. Werner Fink <werner@suse.de>
- Remove (texlive-)axessibility package as it has a nofree license:
  Creative Commons Attribution-NonCommercial 4.0 License
* Fri May 10 2019 Dr. Werner Fink <werner@suse.de>
- Update to TeXLive 2019
* Wed Feb 20 2019 Dr. Werner Fink <werner@suse.de>
- A binary only TeXLive installation is a fatal error
* Tue Jun 19 2018 werner@suse.de
- Comment out not available font map files during update
* Wed May  2 2018 werner@suse.de
- Switch over to TeXLive 2018 final 20180414
* Fri Apr  6 2018 werner@suse.de
- First intial snap short of TeXLive pre 2018
* Wed Jan 24 2018 werner@suse.de
- Switch over to python 3 (boo#1077170)
* Thu Jan 11 2018 werner@suse.de
- Add debug and force mode to the TeXLive update script which
  might help to fix broken systems as well as might show some
  debug messages as well.
* Mon Jan  8 2018 werner@suse.de
- If zypper way of posttrans scripts are disabled do use the rpm
  %%posttrans scriptlets (boo#1074128)
* Fri Nov 24 2017 werner@suse.de
- Disable by a build conditions using zypper way of posttrans scripts
  as we already use %%posttrans. Nevertheless correct naming scheme
  (boo#1069445)
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Oct 23 2017 werner@suse.de
- Avoid overwriting ls-R files
* Fri Aug 18 2017 werner@suse.de
- Really not define texgid rpm macro (boo#1054325)
* Mon Jul 24 2017 werner@suse.de
- Enforce mktexlsr if texlive-filesystem becomes installed to
  refresh/rehash the kpathsea data base files after this (boo#1046277)
* Mon Jul 24 2017 werner@suse.de
- Avoid error in zypper python script
* Tue Jul 18 2017 werner@suse.de
- Even more speedup for update.texlive, that is remove empty
  work load directory
* Tue Jul 18 2017 werner@suse.de
- Make update.texlive faster and remove specific tag file after
  creating specific format
* Wed Jul 12 2017 werner@suse.de
- Generate/remove specific formats at installation/erease of a
  package (boo#1046277)
* Tue Jul 11 2017 werner@suse.de
- Modify update.texlive script in such a way that we detect old
  format files and enforce a refresh based on hyphen (boo#1046277)
* Tue Jun 13 2017 werner@suse.de
- Final TeXLive 2017 20170520
* Thu Jun  1 2017 werner@suse.de
- Update to TeXLive 2017 20170520 pretest
* Fri May 26 2017 werner@suse.de
- Run luatools and luaotfload-tool at update to get the caches up
* Wed Jun 22 2016 werner@suse.de
- Add some typos in update script (boo#985971)
* Mon Jun 20 2016 werner@suse.de
- Have a directory to hold the splitted hyphen informations
* Tue Jun  7 2016 werner@suse.de
- Update to TeXLive 2016
* Wed Apr 13 2016 werner@suse.de
- Correct cut&paste typo with texlua-devel package name
* Mon Mar 21 2016 werner@suse.de
- Really require the devel packages with texlive-devel
* Mon Feb  8 2016 werner@suse.de
- Add both texlive.infra and texlive.infra.doc as these provides
  some perl module files used by fmtutil.pl
* Thu Jan 28 2016 werner@suse.de
- Update to TeXLive 2015 (timestamp 20150521 revision 26946)
* Thu Mar 26 2015 werner@suse.de
- Update to TeXLive 2014 (timestamp 20140525 revision 34252)
  * Support DVIPDFMx
  * [fix] avoid luatex crash under math_mode 'decimal'
  * luaotfload: Fix incorrect handling of font file formats luaotfload)
  * Sync with Context beta as of 2014-04-05
  * pdfTeX: sync with Knuth TeX 3.14159265, e-TeX 2.6
  * Many more ...
  * Further collection split
  - texlive-collection-langchinese
  - texlive-collection-langjapanese
  - texlive-collection-langkorean
* Tue May 20 2014 schwab@suse.de
- Make sure that texconfig/update is run only once per transaction
* Mon Feb 10 2014 werner@suse.de
- Avoid that missing formats for a hyphen file will cause high
  load at installation
* Wed Aug  7 2013 werner@suse.de
- Repair several wrong paths cause by the move of TEXMFMAIN that is
  the location of TLUtils.pm used by updmap
* Mon Aug  5 2013 werner@suse.de
- Refresh formats if required
* Tue Jul 30 2013 werner@suse.de
- Update to TeXLive 2013 (timestamp 20130620)
  + Distribution layout: the top-level texmf/ directory has been
    merged into texmf-dist/, for simplicity. Both the TEXMFMAIN
    and TEXMFDIST Kpathsea variables now point to texmf-dist.
  + Many small language collections have been merged together,
    to simplify installation.
  + MetaPost: native support for PNG output and floating-point
    (IEEE double) has been added.
  + LuaTEX: updated to Lua 5.2, and includes a new library
    (pdfscanner) to process external PDF page content, among
    much else (see its web pages).
  + XeTEX (also see its web pages for more):
    The HarfBuzz library now used for font layout instead of ICU.
    Graphite2 and HarfBuzz are used instead of SilGraphite for Graphite layout.
    On Macs, Core Text is used instead of the (deprecated) ATSUI.
    Prefer TrueType/OpenType fonts to Type1 when the names are the same.
    Fix occasional mismatch in font finding between XeTEX and xdvipdfmx.
    Support OpenType math cut-ins.
  + xdvi: now uses FreeType instead of t1lib for rendering.
  + microtype.sty: some support for XeTEX (protrusion) and LuaTEX
    (protrusion, font expansion, tracking), among other enhancements.
- Update biblatex-biber to 1.7
- Udpate biblatex of TeXLive 2013 to 2.7a
* Tue Jul 16 2013 werner@suse.de
- New rpm had removed "prereq" flag from installation script bits
  that is that `Requires(prereq)' is not valid anymore :(((
* Mon May  6 2013 werner@suse.de
- Asymptote binaries may have the same version as the format files
  of the asymptote package it self (bnc#813032)
* Wed Mar 27 2013 werner@suse.de
- Change Obsoletes from < 2012+subversion to <= 2011 (bnc#811162)
- Let mathdesign require tex(texnansi.enc) (bnc#808731)
- Let biber-bin require perl(Text::BibTeX) (bnc#811258)
- Do not require xfs as we do not use xfs at all, otherwise we
  have to add some more lua code in the %%post scriptlet.
* Tue Feb  5 2013 werner@suse.de
- Work around missing support of %%posttrans scriptlets in libzypp
  due missing rpm option for not to execute those scriptlets (bnc#773575)
* Wed Sep 19 2012 werner@suse.de
- If update script falis on some points like fmtutils then do not
  remove the execution tag file to handle this later
* Wed Sep 12 2012 werner@suse.de
- Make update script to run updmap-sys only once on texhash
* Tue Sep 11 2012 werner@suse.de
- Fix update script: do not override with wrong md5 check sum for
  language format check
- Run updmap-sys only if required
* Thu Aug  2 2012 werner@suse.de
- Change font config semantic as the font directories below
  /usr/share/fonts will be always found by freetype
* Fri Jul 13 2012 werner@suse.de
- Rename SuSEconfig.texlive to update.texlive to make the quibblers
  happy.  The script was already self-sufficient and does not need
  any help from the old SuSEconfig infrastructure.
* Wed Jun 27 2012 werner@suse.de
- Re-add the rungs script to dvipdfmx-bin
* Mon Jun 25 2012 werner@suse.de
- Reoder update script
* Fri Jun 22 2012 werner@suse.de
- Run update if required
* Fri Jun 22 2012 werner@suse.de
- Do not remove /var/run/texlive, add mtxrun to update script
* Fri Jun 22 2012 werner@suse.de
- The new updmap requires the perl mudules TLConfig.pm and TLUtils.pm
* Wed Jun 20 2012 werner@suse.de
- Finished package split of texlive and texlive-filesystem
* Wed Jun 20 2012 werner@suse.de
- Avoid to be fooled by wrong ownerships during fmtutil that is
  allow user nobody and group mktex to access the temporary
  fmtutil directory if the initial user is root
* Tue Jun 19 2012 werner@suse.de
- Move old SuSEconfig md5 backup files to new location
* Tue Jun 19 2012 werner@suse.de
- Add missed /var/lib/texmf/web2c/ tree to file system
* Mon Jun 18 2012 werner@suse.de
- Simplify dependency chain(s)
* Thu Jun 14 2012 werner@suse.de
- Make RPMlint happy again
* Thu Jun 14 2012 werner@suse.de
- Correct version numbers of kpathsea and ptexenc automatically
* Wed Jun 13 2012 werner@suse.de
- Readd well known paclages like texlive-devel, texlive-bin-devel,
  and texlive-tools.  Also cause texlive-latex to install its
  binary packages.
* Tue Jun 12 2012 werner@suse.de
- Update to frozen/final 2012 (timestamp 20120611)
* Tue Jun 12 2012 werner@suse.de
- Do not drop the tar scheme and collection tar balls for reference
- Split off texlive-filesystem, texlive-scheme, and texlive-collection
  build into a separate spec file
- Make version comparision work as we use upstream version and
  release numbers
* Sat Jun  9 2012 coolo@suse.com
- relax the version requirements
* Fri Jun  8 2012 coolo@suse.com
- split out collections and filesystem
* Mon Jun  4 2012 werner@suse.de
- Avoid source url for all tar balls as our checkin script can not
  handle snapshots nor is knowing about the infrastructure of the
  upstream TeXLive server
* Fri Jun  1 2012 werner@suse.de
- Change also version/release scheme of the sub binary subpackages
* Thu May 31 2012 werner@suse.de
- Change version/release scheme
* Tue May 22 2012 werner@suse.de
- Install manaul page of biber as this is also build
- Require the used perl version for biber
* Mon May 21 2012 werner@suse.de
- Try to support BibteX-Biber perl dumped binary required to
  provide BibteX-Biber also for PPC nad PPC64
* Fri May 18 2012 werner@suse.de
- Use texlive.texlive instead of texlive.texmf for permission file
* Fri May 18 2012 werner@suse.de
- Be aware new poppler library, there is no getSize() but only
  getNumObjects()
* Mon May 14 2012 werner@suse.de
- Cron: remove older sources as well as crap
* Mon May 14 2012 werner@suse.de
- Avoid warning messages from mktexlsr due empty ls-R
- Handle case where public program is not setgid public
- Make spec file more flexible and use a rpm macro for a public
  group which can be named to e.g. public
* Mon May 14 2012 werner@suse.de
- If MT_FEATURES includes varfonts and system default is not
  writable choose $HOME/.cache/texmf/fonts
* Tue Dec 20 2011 werner@suse.de
- First initial main spec file using the original TeX Live packaging
  scheme and layout
